#? Arquivo gerado a partir de equipamentos.json

equipamentos = [{'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante.\r\n'
                 '\r\n'
                 'Uma vez empunhado, suas hastes se tornam pura energia que '
                 'desferem 2d8 de dano elétrico mágico no alvo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday14.json',
              'page': 13}],
  'id': 'acoite-eletrico',
  'name': 'Açoite Elétrico',
  'type': 'Equipment',
  'updated_at': '2025-01-29T22:56:04.468-03:00',
  'url': 'https://olddragon.com.br/equipamentos/acoite-eletrico.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 200,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9)',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'adaga',
  'name': 'Adaga',
  'picture': 'https://public.olddragon.com.br/jj7a110akavz9zfgrbskuzreoo66',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:12.833-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'limited',
  'concept': 'weapon',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 104}],
  'id': 'adaga-de-osso',
  'name': 'Adaga de Osso',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:37.647-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-de-osso.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9)',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 160},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 109}],
  'id': 'adaga-mais-1',
  'name': 'Adaga +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:00.557-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9).\r\n'
                 '\r\n'
                 'Esta adaga afiada é balanceada para permitir mais acertos '
                 'críticos que o normal. Esta adaga precisa de um resultado de '
                 '19 ou 20 no d20 para atingir o alvo com um acerto crítico, '
                 'causando a ele dano dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'adaga-mais-1-critica',
  'name': 'Adaga +1 Crítica',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:02.083-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-mais-1-critica.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9).\r\n'
                 '\r\n'
                 'Esta adaga possui lâmina de prata perfeita para combates '
                 'contra licantropos e alguns tipos especiais de mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'adaga-mais-1-de-prata',
  'name': 'Adaga +1 de Prata',
  'picture': 'https://public.olddragon.com.br/0cu7t9o5n0v5miqzo48ssbh210bt',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:02.685-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-mais-1-de-prata.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9).\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta adaga retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Adagas '
                 'que atingem seus alvos não retornam para a mão dos '
                 'arremessadores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'adaga-mais-1-do-retorno',
  'name': 'Adaga +1 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:01.982-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-mais-1-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9).\r\n'
                 '\r\n'
                 'A ponta da lâmina desta adaga arderá como se fosse uma '
                 'tocha. Seu fogo mágico não causa nenhum dano à arma ou ao '
                 'usuário, mas causa dano adicional de fogo de 1d4 como se '
                 'fosse uma fonte pequena de fogo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'adaga-mais-1-flamejante',
  'name': 'Adaga +1 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:02.188-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-mais-1-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9)',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 160},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 109}],
  'id': 'adaga-mais-2',
  'name': 'Adaga +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:02.299-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9).\r\n'
                 '\r\n'
                 'Esta adaga afiada é balanceada para permitir mais acertos '
                 'críticos que o normal. Esta adaga precisa de um resultado de '
                 '19 ou 20 no d20 para atingir o alvo com um acerto crítico, '
                 'causando a ele dano dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'adaga-mais-2-critica',
  'name': 'Adaga +2 Crítica',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:02.615-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-mais-2-critica.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9).\r\n'
                 '\r\n'
                 'Esta adaga possui lâmina de prata perfeita para combates '
                 'contra licantropos e alguns tipos especiais de mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'adaga-mais-2-de-prata',
  'name': 'Adaga +2 de Prata',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:02.424-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-mais-2-de-prata.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9).\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta adaga retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Adagas '
                 'que atingem seus alvos não retornam para a mão dos '
                 'arremessadores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'adaga-mais-2-do-retorno',
  'name': 'Adaga +2 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:02.518-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-mais-2-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9).\r\n'
                 '\r\n'
                 'A ponta da lâmina desta adaga arderá como se fosse uma '
                 'tocha. Seu fogo mágico não causa nenhum dano à arma ou ao '
                 'usuário, mas causa dano adicional de fogo de 1d4 como se '
                 'fosse uma fonte pequena de fogo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'adaga-mais-2-flamejante',
  'name': 'Adaga +2 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:02.719-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-mais-2-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9)',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 109}],
  'id': 'adaga-mais-3',
  'name': 'Adaga +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:02.816-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9).\r\n'
                 '\r\n'
                 'Esta adaga afiada é balanceada para permitir mais acertos '
                 'críticos que o normal. Esta adaga precisa de um resultado de '
                 '19 ou 20 no d20 para atingir o alvo com um acerto crítico, '
                 'causando a ele dano dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'adaga-mais-3-critica',
  'name': 'Adaga +3 Crítica',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:03.096-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-mais-3-critica.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9).\r\n'
                 '\r\n'
                 'Esta adaga possui lâmina de prata perfeita para combates '
                 'contra licantropos e alguns tipos especiais de mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'adaga-mais-3-de-prata',
  'name': 'Adaga +3 de Prata',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:02.909-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-mais-3-de-prata.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9).\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta adaga retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Adagas '
                 'que atingem seus alvos não retornam para a mão dos '
                 'arremessadores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'adaga-mais-3-do-retorno',
  'name': 'Adaga +3 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:03.000-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-mais-3-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9).\r\n'
                 '\r\n'
                 'A ponta da lâmina desta adaga arderá como se fosse uma '
                 'tocha. Seu fogo mágico não causa nenhum dano à arma ou ao '
                 'usuário, mas causa dano adicional de fogo de 1d4 como se '
                 'fosse uma fonte pequena de fogo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'adaga-mais-3-flamejante',
  'name': 'Adaga +3 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:03.196-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-mais-3-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9)',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 109}],
  'id': 'adaga-menos-1-amaldicoada',
  'name': 'Adaga -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:00.296-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9)',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 109}],
  'id': 'adaga-menos-2-amaldicoada',
  'name': 'Adaga -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:00.410-03:00',
  'url': 'https://olddragon.com.br/equipamentos/adaga-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 2500,
  'damage': None,
  'description': 'Frasco de 500 ml. Dano ácido de 1d6 em mortos-vivos e '
                 'demônios.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'agua-benta',
  'name': 'Água Benta',
  'picture': 'https://public.olddragon.com.br/0o4z4feaai2h4uggmh7wz3n4rwva',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:11.143-03:00',
  'url': 'https://olddragon.com.br/equipamentos/agua-benta.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 800,
  'damage': '1d10',
  'description': 'Grande, Cortante, Duas Mãos, Haste',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'alabarda',
  'name': 'Alabarda',
  'picture': 'https://public.olddragon.com.br/qsm12197xng6n6he2mv17ei1zsxx',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:24.661-03:00',
  'url': 'https://olddragon.com.br/equipamentos/alabarda.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Cortante, Duas Mãos, Haste',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'alabarda-mais-1',
  'name': 'Alabarda +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:03.655-03:00',
  'url': 'https://olddragon.com.br/equipamentos/alabarda-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': 1,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Cortante, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'alabarda-mais-1-defensora',
  'name': 'Alabarda +1 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:03.748-03:00',
  'url': 'https://olddragon.com.br/equipamentos/alabarda-mais-1-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Cortante, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'alabarda-mais-1-do-desarme',
  'name': 'Alabarda +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:03.848-03:00',
  'url': 'https://olddragon.com.br/equipamentos/alabarda-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Cortante, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'Esta arma pode ser usada para vigiar um tipo específico de '
                 'monstro ou raça de personagem. Ao perceber a presença de um '
                 'membro vigiado em um raio de 18m da arma, esta vibrará '
                 'lentamente. Este talento funciona por 24 horas e o tipo de '
                 'monstro vigiado só pode ser alterado uma vez a cada dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'alabarda-mais-1-vigilante',
  'name': 'Alabarda +1 Vigilante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:03.959-03:00',
  'url': 'https://olddragon.com.br/equipamentos/alabarda-mais-1-vigilante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Cortante, Duas Mãos, Haste',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'alabarda-mais-2',
  'name': 'Alabarda +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:04.076-03:00',
  'url': 'https://olddragon.com.br/equipamentos/alabarda-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Cortante, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'alabarda-mais-2-defensora',
  'name': 'Alabarda +2 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:04.169-03:00',
  'url': 'https://olddragon.com.br/equipamentos/alabarda-mais-2-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Cortante, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'alabarda-mais-2-do-desarme',
  'name': 'Alabarda +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:04.274-03:00',
  'url': 'https://olddragon.com.br/equipamentos/alabarda-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Cortante, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'Esta arma pode ser usada para vigiar um tipo específico de '
                 'monstro ou raça de personagem. Ao perceber a presença de um '
                 'membro vigiado em um raio de 18m da arma, esta vibrará '
                 'lentamente. Este talento funciona por 24 horas e o tipo de '
                 'monstro vigiado só pode ser alterado uma vez a cada dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'alabarda-mais-2-vigilante',
  'name': 'Alabarda +2 Vigilante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:04.374-03:00',
  'url': 'https://olddragon.com.br/equipamentos/alabarda-mais-2-vigilante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Cortante, Duas Mãos, Haste',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'alabarda-mais-3',
  'name': 'Alabarda +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:04.465-03:00',
  'url': 'https://olddragon.com.br/equipamentos/alabarda-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Cortante, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'alabarda-mais-3-defensora',
  'name': 'Alabarda +3 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:04.567-03:00',
  'url': 'https://olddragon.com.br/equipamentos/alabarda-mais-3-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Cortante, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'alabarda-mais-3-do-desarme',
  'name': 'Alabarda +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:04.722-03:00',
  'url': 'https://olddragon.com.br/equipamentos/alabarda-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Cortante, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'Esta arma pode ser usada para vigiar um tipo específico de '
                 'monstro ou raça de personagem. Ao perceber a presença de um '
                 'membro vigiado em um raio de 18m da arma, esta vibrará '
                 'lentamente. Este talento funciona por 24 horas e o tipo de '
                 'monstro vigiado só pode ser alterado uma vez a cada dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'alabarda-mais-3-vigilante',
  'name': 'Alabarda +3 Vigilante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:04.817-03:00',
  'url': 'https://olddragon.com.br/equipamentos/alabarda-mais-3-vigilante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Cortante, Duas Mãos, Haste',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'alabarda-menos-1-amaldicoada',
  'name': 'Alabarda -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:03.456-03:00',
  'url': 'https://olddragon.com.br/equipamentos/alabarda-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Cortante, Duas Mãos, Haste',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'alabarda-menos-2-amaldicoada',
  'name': 'Alabarda -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:03.565-03:00',
  'url': 'https://olddragon.com.br/equipamentos/alabarda-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'vehicle',
  'cost': 100,
  'damage': None,
  'description': 'Bolsa de carga presa à sela e acomodada sobre as ancas do '
                 'cavalo. Comporta até 600 moedas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'alforje',
  'name': 'Alforje',
  'type': 'Equipment',
  'updated_at': '2023-05-31T22:00:15.601-03:00',
  'url': 'https://olddragon.com.br/equipamentos/alforje.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 1200,
  'damage': None,
  'description': 'Com cadeados; para pulsos ou tornozelos de criaturas P e M.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'algema',
  'name': 'Algema',
  'picture': 'https://public.olddragon.com.br/7w693r5o6wsz1xaxzonk6y96g1zd',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:47.011-03:00',
  'url': 'https://olddragon.com.br/equipamentos/algema.json',
  'weight_in_grams': 1000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'container',
  'cost': 1,
  'damage': None,
  'description': 'Pequeno saco de couro usado preso ao cinto da roupa. '
                 'Comporta até 50 moedas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'algibeira',
  'name': 'Algibeira',
  'picture': 'https://public.olddragon.com.br/cohqrj5nzu0w8doyfbhtt485k0uf',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:30.705-03:00',
  'url': 'https://olddragon.com.br/equipamentos/algibeira.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'container',
  'cost': 100,
  'damage': None,
  'description': 'De couro, rígida para até 40 flechas ou 80 virotes. Comporta '
                 'até 150 moedas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'aljava',
  'name': 'Aljava',
  'picture': 'https://public.olddragon.com.br/2yre2ma8ot2fj0tvgr1krf97d4wt',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:20.223-03:00',
  'url': 'https://olddragon.com.br/equipamentos/aljava.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Amaldiçoam seus usuários, impossibilitando-os de acumularem '
                 'pontos de experiência enquanto amaldiçoados. Monstros '
                 'derrotados ou tesouros acumulados não acrescentarão nenhum '
                 'XP à sua experiência. Livrar-se do anel não elimina a '
                 'maldição que, por sua vez, só pode ser removida com a magia '
                 'Remover Maldição.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 165},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 118}],
  'id': 'anel-amaldicoado',
  'name': 'Anel Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:36.571-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Enquanto estiver usando este anel, o usuário fica imune a '
                 'qualquer efeito mágico ilusório, inclusive os positivos. '
                 'Note que nenhuma ilusão lançada sobre o alvo terá qualquer '
                 'funcionamento.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 118}],
  'id': 'anel-da-anti-ilusao',
  'name': 'Anel da Anti-Ilusão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:36.757-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-da-anti-ilusao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'O usuário fica invisível enquanto mantiver o anel no dedo ou '
                 'até atacar, lançar magias ou interagir fisicamente com outra '
                 'pessoa. Só é possível usar este anel uma única vez por '
                 'turno.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 165},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 119}],
  'id': 'anel-da-invisibilidade',
  'name': 'Anel da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:36.896-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'O usuário deste anel é capaz de regenerar 1 ponto de vida a '
                 'cada rodada desde que o dano regenerado não tenha sido '
                 'causado por fogo, e desde que o dano não tenha levado o '
                 'usuário a zero ou menos pontos de vida. Membros decepados '
                 'podem ser regenerados, mas em um ritmo lento.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 165},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 119}],
  'id': 'anel-da-regeneracao',
  'name': 'Anel da Regeneração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:37.042-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-da-regeneracao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'O usuário deste anel fica imune ao dano de fogo não mágico. '
                 'Além disso, quando uma fonte de dano mágico permitir uma '
                 'jogada de proteção, o usuário do anel deve melhorar seu '
                 'teste em +2. Se ainda assim o personagem levar dano de fogo '
                 'mágico, este dano deve ser reduzido em 1 ponto para cada '
                 'dado lançado. Por exemplo, um dano de 3d6 seria reduzido '
                 'para 3d6-3.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 119}],
  'id': 'anel-da-resistencia-ao-fogo',
  'name': 'Anel da Resistência ao Fogo',
  'picture': 'https://public.olddragon.com.br/u5nyrznv3brmeivppfof98mfs7i4',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:39.293-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-da-resistencia-ao-fogo.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este anel permite, a qualquer Clérigo que o esteja usando, '
                 'memorizar uma magia adicional durante suas orações diárias, '
                 'respeitando seus limites de nível e Sabedoria. Um Clérigo '
                 'pode escolher qualquer magia extra para memorizar entre os '
                 '1º, 2º ou 3º Círculos, desde que esteja dentro do limite de '
                 'um Círculo que ele já possua acesso. Um Clérigo não pode '
                 'memorizar uma magia de um Círculo maior do que tem '
                 'capacidade de lançar.\r\n'
                 '\r\n'
                 'Se o Anel da Santidade for removido, a magia extra '
                 'memorizada é perdida caso ainda não tenha sido conjurada.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 119}],
  'id': 'anel-da-santidade',
  'name': 'Anel da Santidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:38.489-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-da-santidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'O usuário deste anel passa a ser capaz de erguer lentamente, '
                 'com a força da mente, objetos inanimados de até 1.000 kg e '
                 'movê-los a até 15m de distância. Se a concentração for '
                 'interrompida, o objeto erguido cai imediatamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 119}],
  'id': 'anel-da-telecinesia',
  'name': 'Anel da Telecinesia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:38.597-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-da-telecinesia.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Por até três vezes a cada dia, o usuário deste anel consegue '
                 'sentir se uma declaração proferida é verdade ou uma mentira. '
                 'Este efeito mostra para o usuário do anel se seu '
                 'interlocutor está falando a verdade ou mentindo. Contudo, se '
                 'o interlocutor acreditar que está falando uma verdade, este '
                 'será o resultado mostrado ainda que a declaração seja uma '
                 'mentira.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 119}],
  'id': 'anel-da-verdade',
  'name': 'Anel da Verdade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:38.727-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-da-verdade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Permite ao usuário enxergar a até 9m através de uma parede, '
                 'porta ou muro, desde que o usuário se mantenha quieto, '
                 'concentrado e imóvel. Apenas ouro e chumbo conseguem impedir '
                 'esta visão. Para efeito de controle, uma área de 3m por 3m '
                 'leva um turno completo para ser observada detalhadamente. '
                 'Após o término do turno, o anel se descarrega e precisa de '
                 'uma hora de inatividade antes de ser utilizado novamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 119}],
  'id': 'anel-da-visao-de-raio-x',
  'name': 'Anel da Visão de Raio-X',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:38.823-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-da-visao-de-raio-x.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Enquanto estiver com este anel no dedo, o personagem é capaz '
                 'de andar sobre as águas (como um rio, mar ou lago) sem '
                 'afundar.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 118}],
  'id': 'anel-de-andar-sobre-as-aguas',
  'name': 'Anel de Andar Sobre as Águas',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:38.922-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-de-andar-sobre-as-aguas.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Quando encontrado, este anel armazena 1d6 magias dentro '
                 'dele. Quando o anel é colocado, o usuário sabe magicamente '
                 'quais magias estão armazenadas e exatamente como usá-las. '
                 'Após uma magia ser usada, pode-se armazenar uma outra magia '
                 'em seu lugar caso o conjurador efetivamente lance a magia '
                 'para o anel. Note que este anel não absorve magias.\r\n'
                 '\r\n'
                 'As magias armazenadas neste anel possuem duração, alcances, '
                 'efeitos e resistências iguais ao nível mais baixo necessário '
                 'para a sua conjuração. Sempre existe 1 chance em 1d6 deste '
                 'anel ser um anel de Armazenar Magias Divinas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 118}],
  'id': 'anel-de-armazenar-magia',
  'name': 'Anel de Armazenar Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:39.024-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-de-armazenar-magia.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este anel melhora a CA do usuário em 1 ponto e concede o '
                 'mesmo bônus em uma jogada de proteção. Um anel de proteção '
                 'não pode ser usado com outro anel de proteção, ainda que em '
                 'mãos diferentes. Caso isso seja tentado, os efeitos de ambos '
                 'se anulam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 165},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 119}],
  'id': 'anel-de-protecao-mais-1',
  'name': 'Anel de Proteção +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:39.131-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-de-protecao-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este anel melhora a CA do usuário em 2 pontos e concede o '
                 'mesmo bônus em uma jogada de proteção. Um anel de proteção '
                 'não pode ser usado com outro anel de proteção, ainda que em '
                 'mãos diferentes. Caso isso seja tentado, os efeitos de ambos '
                 'se anulam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 119}],
  'id': 'anel-de-protecao-mais-2',
  'name': 'Anel de Proteção +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:39.243-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-de-protecao-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este anel melhora a CA do usuário em 3 pontos e concede o '
                 'mesmo bônus em uma jogada de proteção. Um anel de proteção '
                 'não pode ser usado com outro anel de proteção, ainda que em '
                 'mãos diferentes. Caso isso seja tentado, os efeitos de ambos '
                 'se anulam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 119}],
  'id': 'anel-de-protecao-mais-3',
  'name': 'Anel de Proteção +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:39.332-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-de-protecao-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este anel melhora a CA do usuário em 4 pontos e concede o '
                 'mesmo bônus em uma jogada de proteção. Um anel de proteção '
                 'não pode ser usado com outro anel de proteção, ainda que em '
                 'mãos diferentes. Caso isso seja tentado, os efeitos de ambos '
                 'se anulam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 119}],
  'id': 'anel-de-protecao-mais-4',
  'name': 'Anel de Proteção +4',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:39.421-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-de-protecao-mais-4.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este anel consegue refletir 2d6 círculos de magias de volta '
                 'aos seus conjuradores a cada dia, de modo que o usuário do '
                 'anel não sofra nenhum efeito destas magias (incluindo '
                 'efeitos positivos). Note que apenas magias são refletidas, '
                 'já poderes de monstros semelhantes a magias ou efeitos '
                 'mágicos oriundos de itens mágicos não são refletidos. Ao '
                 'atingir o limite de círculos refletidos, o anel vira um anel '
                 'comum pelo resto do dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 119}],
  'id': 'anel-de-refletir-magias',
  'name': 'Anel de Refletir Magias',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:39.515-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-de-refletir-magias.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este anel permite ao usuário usá-lo uma vez por turno para '
                 'controlar até 1d6 alvos ou até um alvo gigante (sempre '
                 'limitado a 6 dados de vida) desde que o alvo esteja fazendo '
                 'contato visual com o usuário. O controle dura enquanto o '
                 'usuário do anel estiver concentrado no alvo. O usuário não '
                 'pode se mover ou atacar. Quando o controle é encerrado, o '
                 'alvo estará livre para fazer o que desejar, sem nenhum elo '
                 'empático com o usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 165},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 118}],
  'id': 'anel-do-controle-de-animais',
  'name': 'Anel do Controle de Animais',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:39.616-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-do-controle-de-animais.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este anel permite ao usuário usá-lo uma vez por turno para '
                 'controlar até 1d6 alvos ou até um alvo gigante (sempre '
                 'limitado a 6 dados de vida) desde que o alvo esteja fazendo '
                 'contato visual com o usuário. O controle dura enquanto o '
                 'usuário do anel estiver concentrado no alvo. O usuário não '
                 'pode se mover ou atacar. Quando o controle é encerrado, o '
                 'alvo estará livre para fazer o que desejar, sem nenhum elo '
                 'empático com o usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 118}],
  'id': 'anel-do-controle-de-humanos',
  'name': 'Anel do Controle de Humanos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:39.737-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-do-controle-de-humanos.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este anel permite ao usuário usá-lo uma vez por turno para '
                 'controlar até 1d6 alvos ou até um alvo gigante (sempre '
                 'limitado a 6 dados de vida) desde que o alvo esteja fazendo '
                 'contato visual com o usuário. O controle dura enquanto o '
                 'usuário do anel estiver concentrado no alvo. O usuário não '
                 'pode se mover ou atacar. Quando o controle é encerrado, o '
                 'alvo estará livre para fazer o que desejar, sem nenhum elo '
                 'empático com o usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 118}],
  'id': 'anel-do-controle-de-plantas',
  'name': 'Anel do Controle de Plantas',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:39.829-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-do-controle-de-plantas.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este anel concede um ou mais desejos ao seu portador. O '
                 'Desejo concedido pelo anel é o mesmo que seria conjurado por '
                 'um Mago com acesso ao 9º círculo de magia. Existe 1-3 '
                 'chances em 1d6 de haver uma carga de magia no anel, e apenas '
                 '1 chance em 1d6 de haver três cargas. Uma vez esgotados os '
                 'desejos, o anel vira um item comum, sem a possibilidade de '
                 'ser recarregado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 119}],
  'id': 'anel-do-desejo',
  'name': 'Anel do Desejo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:39.932-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-do-desejo.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Enquanto estiver usando este anel, todas as moedas seguradas '
                 'em suas mãos serão ilusoriamente transformadas em moedas de '
                 'ouro. Qualquer criatura a ter contato com estas moedas '
                 'falsas, precisará ser bem-sucedida em uma JPS ou perceberá '
                 'que as moedas não são de ouro. Um anel do ouro de tolo pode '
                 'transformar ilusoriamente até 100 moedas por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 119}],
  'id': 'anel-do-ouro-de-tolo',
  'name': 'Anel do Ouro de Tolo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:40.036-03:00',
  'url': 'https://olddragon.com.br/equipamentos/anel-do-ouro-de-tolo.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Esta poção possui substâncias que anulam os efeitos de um '
                 'veneno. Se o veneno é mortal, tomar um antídoto faz com que '
                 'a JPC seja refeita com um bônus de +10 no resultado do dado. '
                 'Se o veneno não é mortal, um antídoto encerra qualquer '
                 'efeito em 1d4 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 113}],
  'id': 'antidoto',
  'name': 'Antídoto',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:40.135-03:00',
  'url': 'https://olddragon.com.br/equipamentos/antidoto.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 100,
  'damage': None,
  'description': 'Pequeno; com cordão para pescoço.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'apito',
  'name': 'Apito',
  'picture': 'https://public.olddragon.com.br/b7eno7zry7ert400itgo9f1wvk7n',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:39.348-03:00',
  'url': 'https://olddragon.com.br/equipamentos/apito.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 2500,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'arco-curto',
  'name': 'Arco Curto',
  'picture': 'https://public.olddragon.com.br/seuvk6qmar4lnnyw1lxck82k618p',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:08.902-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-curto-mais-1',
  'name': 'Arco Curto +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:05.198-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma explode ao tocar o alvo '
                 'causando 1d6 de dano extra a todos em até metros de '
                 'distância do local da explosão. O atacante não é atingido '
                 'pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-curto-mais-1-da-explosao',
  'name': 'Arco Curto +1 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:05.310-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto-mais-1-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-curto-mais-1-do-atordoamento',
  'name': 'Arco Curto +1 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:05.415-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto-mais-1-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-curto-mais-1-do-desarme',
  'name': 'Arco Curto +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:05.519-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma é extremamente poderoso e '
                 'ignora qualquer tipo de proteção ou cobertura, passando por '
                 'pessoas, móveis, folhagens, teia ou qualquer outra barreira '
                 'menos maciça que uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-curto-mais-1-penetrante',
  'name': 'Arco Curto +1 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:05.639-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto-mais-1-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-curto-mais-2',
  'name': 'Arco Curto +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:05.731-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma explode ao tocar o alvo '
                 'causando 1d6 de dano extra a todos em até metros de '
                 'distância do local da explosão. O atacante não é atingido '
                 'pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-curto-mais-2-da-explosao',
  'name': 'Arco Curto +2 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:05.820-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto-mais-2-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-curto-mais-2-do-atordoamento',
  'name': 'Arco Curto +2 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:05.910-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto-mais-2-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-curto-mais-2-do-desarme',
  'name': 'Arco Curto +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:06.009-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma é extremamente poderoso e '
                 'ignora qualquer tipo de proteção ou cobertura, passando por '
                 'pessoas, móveis, folhagens, teia ou qualquer outra barreira '
                 'menos maciça que uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-curto-mais-2-penetrante',
  'name': 'Arco Curto +2 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:06.105-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto-mais-2-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-curto-mais-3',
  'name': 'Arco Curto +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:06.191-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma explode ao tocar o alvo '
                 'causando 1d6 de dano extra a todos em até metros de '
                 'distância do local da explosão. O atacante não é atingido '
                 'pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-curto-mais-3-da-explosao',
  'name': 'Arco Curto +3 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:06.290-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto-mais-3-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-curto-mais-3-do-atordoamento',
  'name': 'Arco Curto +3 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:06.380-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto-mais-3-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-curto-mais-3-do-desarme',
  'name': 'Arco Curto +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:06.471-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma é extremamente poderoso e '
                 'ignora qualquer tipo de proteção ou cobertura, passando por '
                 'pessoas, móveis, folhagens, teia ou qualquer outra barreira '
                 'menos maciça que uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-curto-mais-3-penetrante',
  'name': 'Arco Curto +3 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:06.562-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto-mais-3-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-curto-menos-1-amaldicoado',
  'name': 'Arco Curto -1 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:05.001-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto-menos-1-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (30), Duas Mãos',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-curto-menos-2-amaldicoado',
  'name': 'Arco Curto -2 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:05.105-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-curto-menos-2-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 6000,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'arco-longo',
  'name': 'Arco Longo',
  'picture': 'https://public.olddragon.com.br/c2d47jp09e36youq69b8qfdoswf2',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:15.130-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-longo-mais-1',
  'name': 'Arco Longo +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:06.911-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma explode ao tocar o alvo '
                 'causando 1d6 de dano extra a todos em até metros de '
                 'distância do local da explosão. O atacante não é atingido '
                 'pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-longo-mais-1-da-explosao',
  'name': 'Arco Longo +1 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:07.004-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo-mais-1-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-longo-mais-1-do-atordoamento',
  'name': 'Arco Longo +1 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:07.091-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo-mais-1-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-longo-mais-1-do-desarme',
  'name': 'Arco Longo +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:07.182-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma é extremamente poderoso e '
                 'ignora qualquer tipo de proteção ou cobertura, passando por '
                 'pessoas, móveis, folhagens, teia ou qualquer outra barreira '
                 'menos maciça que uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-longo-mais-1-penetrante',
  'name': 'Arco Longo +1 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:07.346-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo-mais-1-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-longo-mais-2',
  'name': 'Arco Longo +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:07.436-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma explode ao tocar o alvo '
                 'causando 1d6 de dano extra a todos em até metros de '
                 'distância do local da explosão. O atacante não é atingido '
                 'pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-longo-mais-2-da-explosao',
  'name': 'Arco Longo +2 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:07.529-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo-mais-2-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-longo-mais-2-do-atordoamento',
  'name': 'Arco Longo +2 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:07.627-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo-mais-2-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-longo-mais-2-do-desarme',
  'name': 'Arco Longo +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:07.720-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma é extremamente poderoso e '
                 'ignora qualquer tipo de proteção ou cobertura, passando por '
                 'pessoas, móveis, folhagens, teia ou qualquer outra barreira '
                 'menos maciça que uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-longo-mais-2-penetrante',
  'name': 'Arco Longo +2 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:07.811-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo-mais-2-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-longo-mais-3',
  'name': 'Arco Longo +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:07.902-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma explode ao tocar o alvo '
                 'causando 1d6 de dano extra a todos em até metros de '
                 'distância do local da explosão. O atacante não é atingido '
                 'pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-longo-mais-3-da-explosao',
  'name': 'Arco Longo +3 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:07.999-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo-mais-3-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-longo-mais-3-do-atordoamento',
  'name': 'Arco Longo +3 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:08.090-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo-mais-3-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-longo-mais-3-do-desarme',
  'name': 'Arco Longo +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:08.183-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma é extremamente poderoso e '
                 'ignora qualquer tipo de proteção ou cobertura, passando por '
                 'pessoas, móveis, folhagens, teia ou qualquer outra barreira '
                 'menos maciça que uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-longo-mais-3-penetrante',
  'name': 'Arco Longo +3 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:08.270-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo-mais-3-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-longo-menos-1-amaldicoado',
  'name': 'Arco Longo -1 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:06.726-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo-menos-1-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Grande, Disparo (45), Duas Mãos',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'arco-longo-menos-2-amaldicoado',
  'name': 'Arco Longo -2 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:06.811-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arco-longo-menos-2-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': 1,
  'concept': 'armor',
  'cost': 500,
  'damage': None,
  'description': 'Leve, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 60}],
  'id': 'armadura-acolchoada',
  'name': 'Armadura Acolchoada',
  'picture': 'https://public.olddragon.com.br/oop7f4bc49ndh57t3zc9a4ukmmua',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:45.587-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 160},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-1',
  'name': 'Armadura Acolchoada +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:35.060-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-1-contra-projeteis',
  'name': 'Armadura Acolchoada +1 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:35.642-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-1-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-1-curadora',
  'name': 'Armadura Acolchoada +1 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:35.738-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-1-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-1-da-absorcao',
  'name': 'Armadura Acolchoada +1 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:35.181-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-1-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-1-da-invisibilidade',
  'name': 'Armadura Acolchoada +1 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:35.279-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-1-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-1-da-reflexao',
  'name': 'Armadura Acolchoada +1 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:35.375-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-1-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-1-da-retribuicao',
  'name': 'Armadura Acolchoada +1 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:35.465-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-1-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-1-da-velocidade',
  'name': 'Armadura Acolchoada +1 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:35.552-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-1-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-2',
  'name': 'Armadura Acolchoada +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:35.833-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-2-contra-projeteis',
  'name': 'Armadura Acolchoada +2 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:36.438-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-2-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-2-curadora',
  'name': 'Armadura Acolchoada +2 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:36.527-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-2-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-2-da-absorcao',
  'name': 'Armadura Acolchoada +2 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:35.921-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-2-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-2-da-invisibilidade',
  'name': 'Armadura Acolchoada +2 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:36.017-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-2-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-2-da-reflexao',
  'name': 'Armadura Acolchoada +2 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:36.109-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-2-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-2-da-retribuicao',
  'name': 'Armadura Acolchoada +2 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:36.253-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-2-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-2-da-velocidade',
  'name': 'Armadura Acolchoada +2 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:36.346-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-2-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-3',
  'name': 'Armadura Acolchoada +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:36.621-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-3-contra-projeteis',
  'name': 'Armadura Acolchoada +3 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:37.168-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-3-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-3-curadora',
  'name': 'Armadura Acolchoada +3 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:37.260-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-3-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-3-da-absorcao',
  'name': 'Armadura Acolchoada +3 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:36.710-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-3-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-3-da-invisibilidade',
  'name': 'Armadura Acolchoada +3 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:36.801-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-3-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-3-da-reflexao',
  'name': 'Armadura Acolchoada +3 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:36.888-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-3-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-3-da-retribuicao',
  'name': 'Armadura Acolchoada +3 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:36.977-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-3-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-mais-3-da-velocidade',
  'name': 'Armadura Acolchoada +3 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:37.078-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-mais-3-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-menos-1-amaldicoada',
  'name': 'Armadura Acolchoada -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:34.855-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': -1,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-acolchoada-menos-2-amaldicoada',
  'name': 'Armadura Acolchoada -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:34.942-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-acolchoada-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 7,
  'concept': 'armor',
  'cost': 200000,
  'damage': None,
  'description': 'Pesada, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 60}],
  'id': 'armadura-completa',
  'name': 'Armadura Completa',
  'picture': 'https://public.olddragon.com.br/n26cse9282u6cmprkvgfk4w6rldc',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:23.667-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': 8,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-1',
  'name': 'Armadura Completa +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:37.592-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 8,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-1-contra-projeteis',
  'name': 'Armadura Completa +1 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:39.869-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-1-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 8,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-1-curadora',
  'name': 'Armadura Completa +1 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:39.956-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-1-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 8,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-1-da-absorcao',
  'name': 'Armadura Completa +1 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:37.680-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-1-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 8,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-1-da-invisibilidade',
  'name': 'Armadura Completa +1 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:37.772-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-1-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 8,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-1-da-reflexao',
  'name': 'Armadura Completa +1 da Reflexão',
  'picture': 'https://public.olddragon.com.br/mobfddcnesjylqexdn0tquoaxpmz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:40.417-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-1-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 8,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-1-da-retribuicao',
  'name': 'Armadura Completa +1 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:39.691-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-1-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 8,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-1-da-velocidade',
  'name': 'Armadura Completa +1 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:39.782-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-1-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 9,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-2',
  'name': 'Armadura Completa +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:40.056-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 9,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-2-contra-projeteis',
  'name': 'Armadura Completa +2 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:40.644-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-2-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 9,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-2-curadora',
  'name': 'Armadura Completa +2 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:40.743-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-2-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 9,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-2-da-absorcao',
  'name': 'Armadura Completa +2 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:40.171-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-2-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 9,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-2-da-invisibilidade',
  'name': 'Armadura Completa +2 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:40.273-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-2-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 9,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-2-da-reflexao',
  'name': 'Armadura Completa +2 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:40.362-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-2-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 9,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-2-da-retribuicao',
  'name': 'Armadura Completa +2 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:40.448-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-2-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 9,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-2-da-velocidade',
  'name': 'Armadura Completa +2 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:40.552-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-2-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 10,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-3',
  'name': 'Armadura Completa +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:40.836-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 10,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-3-contra-projeteis',
  'name': 'Armadura Completa +3 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:41.475-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-3-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 10,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-3-curadora',
  'name': 'Armadura Completa +3 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:41.570-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-3-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 10,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-3-da-absorcao',
  'name': 'Armadura Completa +3 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:40.933-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-3-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 10,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-3-da-invisibilidade',
  'name': 'Armadura Completa +3 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:41.043-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-3-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 10,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-3-da-reflexao',
  'name': 'Armadura Completa +3 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:41.156-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-3-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 10,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-3-da-retribuicao',
  'name': 'Armadura Completa +3 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:41.271-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-3-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 10,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-mais-3-da-velocidade',
  'name': 'Armadura Completa +3 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:41.370-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-mais-3-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 8,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-menos-1-amaldicoada',
  'name': 'Armadura Completa -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:37.416-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-completa-menos-2-amaldicoada',
  'name': 'Armadura Completa -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:37.503-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-completa-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'armor',
  'cost': 2000,
  'damage': None,
  'description': 'Leve, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 60}],
  'id': 'armadura-de-couro',
  'name': 'Armadura de Couro',
  'picture': 'https://public.olddragon.com.br/xwqkqi78wgktt93vp5tndk6v761p',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:23.397-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'armor',
  'cost': 3000,
  'damage': None,
  'description': 'Média, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 60}],
  'id': 'armadura-de-couro-batido',
  'name': 'Armadura de Couro Batido',
  'picture': 'https://public.olddragon.com.br/zhx8om528n85z2n48f0q9jmzzt8c',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:48.273-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 160},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-1',
  'name': 'Armadura de Couro Batido +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:44.536-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-1-contra-projeteis',
  'name': 'Armadura de Couro Batido +1 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:45.118-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-1-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-1-curadora',
  'name': 'Armadura de Couro Batido +1 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:45.206-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-1-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-1-da-absorcao',
  'name': 'Armadura de Couro Batido +1 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:44.651-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-1-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-1-da-invisibilidade',
  'name': 'Armadura de Couro Batido +1 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:44.739-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-1-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-1-da-reflexao',
  'name': 'Armadura de Couro Batido +1 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:44.827-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-1-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-1-da-retribuicao',
  'name': 'Armadura de Couro Batido +1 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:44.919-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-1-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-1-da-velocidade',
  'name': 'Armadura de Couro Batido +1 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:45.010-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-1-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-2',
  'name': 'Armadura de Couro Batido +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:45.298-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-2-contra-projeteis',
  'name': 'Armadura de Couro Batido +2 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:45.860-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-2-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-2-curadora',
  'name': 'Armadura de Couro Batido +2 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:45.949-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-2-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-2-da-absorcao',
  'name': 'Armadura de Couro Batido +2 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:45.399-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-2-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-2-da-invisibilidade',
  'name': 'Armadura de Couro Batido +2 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:45.492-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-2-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-2-da-reflexao',
  'name': 'Armadura de Couro Batido +2 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:45.595-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-2-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-2-da-retribuicao',
  'name': 'Armadura de Couro Batido +2 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:45.681-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-2-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-2-da-velocidade',
  'name': 'Armadura de Couro Batido +2 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:45.770-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-2-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-3',
  'name': 'Armadura de Couro Batido +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:46.042-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-3-contra-projeteis',
  'name': 'Armadura de Couro Batido +3 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:46.681-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-3-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-3-curadora',
  'name': 'Armadura de Couro Batido +3 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:46.774-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-3-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-3-da-absorcao',
  'name': 'Armadura de Couro Batido +3 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:46.209-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-3-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-3-da-invisibilidade',
  'name': 'Armadura de Couro Batido +3 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:46.297-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-3-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-3-da-reflexao',
  'name': 'Armadura de Couro Batido +3 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:46.391-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-3-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-3-da-retribuicao',
  'name': 'Armadura de Couro Batido +3 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:46.484-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-3-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-mais-3-da-velocidade',
  'name': 'Armadura de Couro Batido +3 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:46.586-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-mais-3-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-menos-1-amaldicoada',
  'name': 'Armadura de Couro Batido -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:44.330-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 1,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-batido-menos-2-amaldicoada',
  'name': 'Armadura de Couro Batido -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:44.427-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-batido-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 160},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-1',
  'name': 'Armadura de Couro +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:41.950-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-1-contra-projeteis',
  'name': 'Armadura de Couro +1 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:42.578-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-1-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-1-curadora',
  'name': 'Armadura de Couro +1 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:42.675-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-1-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-1-da-absorcao',
  'name': 'Armadura de Couro +1 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:42.067-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-1-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-1-da-invisibilidade',
  'name': 'Armadura de Couro +1 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:42.177-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-1-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-1-da-reflexao',
  'name': 'Armadura de Couro +1 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:42.290-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-1-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-1-da-retribuicao',
  'name': 'Armadura de Couro +1 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:42.389-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-1-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-1-da-velocidade',
  'name': 'Armadura de Couro +1 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:42.484-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-1-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-2',
  'name': 'Armadura de Couro +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:42.767-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-2-contra-projeteis',
  'name': 'Armadura de Couro +2 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:43.335-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-2-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-2-curadora',
  'name': 'Armadura de Couro +2 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:43.426-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-2-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-2-da-absorcao',
  'name': 'Armadura de Couro +2 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:42.856-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-2-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-2-da-invisibilidade',
  'name': 'Armadura de Couro +2 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:42.950-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-2-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-2-da-reflexao',
  'name': 'Armadura de Couro +2 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:43.039-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-2-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-2-da-retribuicao',
  'name': 'Armadura de Couro +2 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:43.127-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-2-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-2-da-velocidade',
  'name': 'Armadura de Couro +2 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:43.230-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-2-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-3',
  'name': 'Armadura de Couro +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:43.520-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-3-contra-projeteis',
  'name': 'Armadura de Couro +3 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:44.073-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-3-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-3-curadora',
  'name': 'Armadura de Couro +3 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:44.166-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-3-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-3-da-absorcao',
  'name': 'Armadura de Couro +3 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:43.618-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-3-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-3-da-invisibilidade',
  'name': 'Armadura de Couro +3 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:43.711-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-3-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-3-da-reflexao',
  'name': 'Armadura de Couro +3 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:43.804-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-3-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-3-da-retribuicao',
  'name': 'Armadura de Couro +3 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:43.898-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-3-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-mais-3-da-velocidade',
  'name': 'Armadura de Couro +3 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:43.985-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-mais-3-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 1,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-menos-1-amaldicoada',
  'name': 'Armadura de Couro -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:41.743-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Leve, Couro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-couro-menos-2-amaldicoada',
  'name': 'Armadura de Couro -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:41.853-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-couro-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': 30000,
  'damage': None,
  'description': 'Pesada, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 60}],
  'id': 'armadura-de-placas',
  'name': 'Armadura de Placas',
  'picture': 'https://public.olddragon.com.br/xw947pk0i2thl9ybzhtjpfzbun7d',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:27.082-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-1',
  'name': 'Armadura de Placas +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:47.124-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-1-contra-projeteis',
  'name': 'Armadura de Placas +1 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:47.677-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-1-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-1-curadora',
  'name': 'Armadura de Placas +1 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:47.767-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-1-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-1-da-absorcao',
  'name': 'Armadura de Placas +1 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:47.215-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-1-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-1-da-invisibilidade',
  'name': 'Armadura de Placas +1 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:47.306-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-1-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-1-da-reflexao',
  'name': 'Armadura de Placas +1 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:47.406-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-1-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-1-da-retribuicao',
  'name': 'Armadura de Placas +1 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:47.493-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-1-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-1-da-velocidade',
  'name': 'Armadura de Placas +1 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:47.582-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-1-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 7,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-2',
  'name': 'Armadura de Placas +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:47.854-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 7,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-2-contra-projeteis',
  'name': 'Armadura de Placas +2 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:48.416-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-2-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 7,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-2-curadora',
  'name': 'Armadura de Placas +2 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:48.502-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-2-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 7,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-2-da-absorcao',
  'name': 'Armadura de Placas +2 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:47.946-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-2-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 7,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-2-da-invisibilidade',
  'name': 'Armadura de Placas +2 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:48.038-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-2-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 7,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-2-da-reflexao',
  'name': 'Armadura de Placas +2 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:48.122-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-2-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 7,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-2-da-retribuicao',
  'name': 'Armadura de Placas +2 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:48.223-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-2-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 7,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-2-da-velocidade',
  'name': 'Armadura de Placas +2 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:48.317-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-2-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 8,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-3',
  'name': 'Armadura de Placas +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:48.588-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 8,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-3-contra-projeteis',
  'name': 'Armadura de Placas +3 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:49.177-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-3-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 8,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-3-curadora',
  'name': 'Armadura de Placas +3 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:49.260-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-3-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 8,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-3-da-absorcao',
  'name': 'Armadura de Placas +3 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:48.681-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-3-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 8,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-3-da-invisibilidade',
  'name': 'Armadura de Placas +3 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:48.770-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-3-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 8,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-3-da-reflexao',
  'name': 'Armadura de Placas +3 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:48.860-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-3-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 8,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-3-da-retribuicao',
  'name': 'Armadura de Placas +3 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:48.967-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-3-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 8,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-mais-3-da-velocidade',
  'name': 'Armadura de Placas +3 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:49.076-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-mais-3-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-menos-1-amaldicoada',
  'name': 'Armadura de Placas -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:46.933-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Pesada, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'armadura-de-placas-menos-2-amaldicoada',
  'name': 'Armadura de Placas -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:47.022-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-de-placas-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'vehicle',
  'cost': 15000,
  'damage': None,
  'description': 'Proteção de couro para cavalos de guerra. Melhora a CA em 2.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'armadura-leve',
  'name': 'Armadura Leve',
  'type': 'Equipment',
  'updated_at': '2023-05-31T22:00:15.620-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-leve.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'vehicle',
  'cost': 50000,
  'damage': None,
  'description': 'Proteção de metal para cavalos de guerra. Melhora a CA em 4.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'armadura-pesada',
  'name': 'Armadura Pesada',
  'type': 'Equipment',
  'updated_at': '2023-05-31T22:00:15.637-03:00',
  'url': 'https://olddragon.com.br/equipamentos/armadura-pesada.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 200,
  'damage': None,
  'description': 'Gancho triplo para escaladas (corda vendida separadamente).',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'arpeu',
  'name': 'Arpéu',
  'picture': 'https://public.olddragon.com.br/qq9zf0e89id0bginox6bucnb9m8z',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:13.801-03:00',
  'url': 'https://olddragon.com.br/equipamentos/arpeu.json',
  'weight_in_grams': 1000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 100,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Perfurante, Arremesso (18), Contra '
                 'investida.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'azagaia',
  'name': 'Azagaia',
  'picture': 'https://public.olddragon.com.br/sn4ajpi0appf916rnkffbgxt7hw1',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:52.767-03:00',
  'url': 'https://olddragon.com.br/equipamentos/azagaia.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'limited',
  'concept': 'weapon',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 104}],
  'id': 'azagaia-de-pedra',
  'name': 'Azagaia de Pedra',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:19.884-03:00',
  'url': 'https://olddragon.com.br/equipamentos/azagaia-de-pedra.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Perfurante, Arremesso (18), Contra '
                 'investida.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'azagaia-mais-1',
  'name': 'Azagaia +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:08.624-03:00',
  'url': 'https://olddragon.com.br/equipamentos/azagaia-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 1,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Perfurante, Arremesso (18), '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'azagaia-mais-1-defensora',
  'name': 'Azagaia +1 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:08.710-03:00',
  'url': 'https://olddragon.com.br/equipamentos/azagaia-mais-1-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Perfurante, Arremesso (18), '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'azagaia-mais-1-do-desarme',
  'name': 'Azagaia +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:08.798-03:00',
  'url': 'https://olddragon.com.br/equipamentos/azagaia-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Perfurante, Arremesso (18), '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'azagaia-mais-1-do-retorno',
  'name': 'Azagaia +1 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:08.885-03:00',
  'url': 'https://olddragon.com.br/equipamentos/azagaia-mais-1-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Perfurante, Arremesso (18), Contra '
                 'investida.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'azagaia-mais-2',
  'name': 'Azagaia +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:08.977-03:00',
  'url': 'https://olddragon.com.br/equipamentos/azagaia-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Perfurante, Arremesso (18), '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'azagaia-mais-2-defensora',
  'name': 'Azagaia +2 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:09.073-03:00',
  'url': 'https://olddragon.com.br/equipamentos/azagaia-mais-2-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Perfurante, Arremesso (18), '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'azagaia-mais-2-do-desarme',
  'name': 'Azagaia +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:09.160-03:00',
  'url': 'https://olddragon.com.br/equipamentos/azagaia-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Perfurante, Arremesso (18), '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'azagaia-mais-2-do-retorno',
  'name': 'Azagaia +2 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:09.249-03:00',
  'url': 'https://olddragon.com.br/equipamentos/azagaia-mais-2-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Perfurante, Arremesso (18), Contra '
                 'investida.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'azagaia-mais-3',
  'name': 'Azagaia +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:09.336-03:00',
  'url': 'https://olddragon.com.br/equipamentos/azagaia-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Perfurante, Arremesso (18), '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'azagaia-mais-3-defensora',
  'name': 'Azagaia +3 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:09.424-03:00',
  'url': 'https://olddragon.com.br/equipamentos/azagaia-mais-3-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Perfurante, Arremesso (18), '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'azagaia-mais-3-do-desarme',
  'name': 'Azagaia +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:09.512-03:00',
  'url': 'https://olddragon.com.br/equipamentos/azagaia-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Perfurante, Arremesso (18), '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'azagaia-mais-3-do-retorno',
  'name': 'Azagaia +3 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:09.600-03:00',
  'url': 'https://olddragon.com.br/equipamentos/azagaia-mais-3-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Perfurante, Arremesso (18), Contra '
                 'investida.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'azagaia-menos-1-amaldicoada',
  'name': 'Azagaia -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:08.443-03:00',
  'url': 'https://olddragon.com.br/equipamentos/azagaia-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Perfurante, Arremesso (18), Contra '
                 'investida.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'azagaia-menos-2-amaldicoada',
  'name': 'Azagaia -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:08.538-03:00',
  'url': 'https://olddragon.com.br/equipamentos/azagaia-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este baralho confeccionado com finas folhas de prata e ouro '
                 'pode ser usado para navegação planar.\r\n'
                 '\r\n'
                 'Lançando uma das cartas relativas ao plano representado pela '
                 'carta, ela se torna um portal para referido plano, e ficará '
                 'aberta por 1d6 turnos. O lançador da carta pode escolher '
                 'exatamente para qual plano abrir o portal, bastando para '
                 'isso escolher a carta correspondente.\r\n'
                 '\r\n'
                 'Mais detalhes sobre a cosmologia planar podem ser '
                 'encontrados no Capítulo 9: Mestrando, do LB2.\r\n'
                 '\r\n'
                 'Os planos e as cartas correspondentes são dados pela '
                 'listagem presente na página 124 do LB2.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 124}],
  'id': 'baralho-da-navegacao-planar',
  'name': 'Baralho da Navegação Planar',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:40.401-03:00',
  'url': 'https://olddragon.com.br/equipamentos/baralho-da-navegacao-planar.json',
  'weight_in_grams': 300,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este maço comum de cartas de jogo possui encantamentos '
                 'variados em cada uma das suas cartas. Os efeitos das cartas '
                 'são ativados aleatoriamente após serem embaralhadas e a '
                 'carta de cima do baralho ser revelada com sua face para '
                 'cima, sobre uma superfície.\r\n'
                 '\r\n'
                 'Se uma nova carta for revelada sem um novo embaralhamento, '
                 'ou se o baralho não se sentir devidamente embaralhado, uma '
                 'nova carta aberta não ativará nenhum efeito. Quando o '
                 'usuário parar de revelar cartas e guardar o baralho, este '
                 'desaparecerá com um som de uma risada alta e insana.\r\n'
                 '\r\n'
                 'Os resultados das cartas são mostrados no LB2 (página 123).',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 122}],
  'id': 'baralho-das-maravilhas-caotico',
  'name': 'Baralho das Maravilhas (Caótico)',
  'picture': 'https://public.olddragon.com.br/1sswe5ch92kez2kdw53evcqtwhkv',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:42.596-03:00',
  'url': 'https://olddragon.com.br/equipamentos/baralho-das-maravilhas-caotico.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'container',
  'cost': 500,
  'damage': None,
  'description': 'De madeira, reforçado para transporte. Capacidade de 200 '
                 'litros. Comporta até 2.000 moedas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'barril-caixa-grande',
  'name': 'Barril/Caixa grande',
  'picture': 'https://public.olddragon.com.br/vuqp8chcr3wz7rwh9r0y20eoumri',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:33.358-03:00',
  'url': 'https://olddragon.com.br/equipamentos/barril-caixa-grande.json',
  'weight_in_grams': 10000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'container',
  'cost': 200,
  'damage': None,
  'description': 'De madeira, reforçado para transporte. Capacidade de 20 '
                 'litros. Comporta até 200 moedas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'barril-caixa-pequena',
  'name': 'Barril/Caixa pequena',
  'picture': 'https://public.olddragon.com.br/8lmdzf1vhd9dbcb5ttvowjfkpvve',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:56.518-03:00',
  'url': 'https://olddragon.com.br/equipamentos/barril-caixa-pequena.json',
  'weight_in_grams': 5000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Este pequeno bastão de 20 centímetros de comprimento é uma '
                 'arma +5 e, ao sinal do usuário, se prolonga em um bastão com '
                 '2m. Pode-se dividir este bastão prolongado em duas partes de '
                 '1m, que se tornam duas armas +2, ou ainda em quatro armas +1 '
                 'de 50 centímetros cada.\r\n'
                 '\r\n'
                 'Este bastão pode ser usado por pessoas diferentes e não se '
                 'divide por engano ou acidente, respeitando sempre a intenção '
                 'do usuário original. Independentemente do tamanho, cada '
                 'pedaço do bastão causa sempre 1d6 de dano + os bônus mágicos '
                 'de acordo com o tamanho da arma. Quando reunidos na mão do '
                 'usuário, os pedaços se unem novamente, retornando ao tamanho '
                 'de origem.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 120}],
  'id': 'bastao-do-armamento',
  'name': 'Bastão do Armamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:09.755-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bastao-do-armamento.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Este bastão pode ser usado como uma arma corpo a corpo, '
                 'causando 1d8+5 pontos de dano. Além disso, no início de toda '
                 'rodada, seu usuário pode escolher não usá-lo como arma e '
                 'aplicá-lo exclusivamente na sua defesa, usando-o para '
                 'bloquear ataques corpo a corpo recebidos. Nestas '
                 'circunstâncias, a Classe de Armadura do usuário recebe um '
                 'bônus de +5. No entanto, isto não se aplica em ataques à '
                 'distância. Enquanto estiver usando um bastão de bloqueio, '
                 'nenhuma outra ação ofensiva é possível. Este bastão é '
                 'utilizável por qualquer personagem.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 120}],
  'id': 'bastao-do-bloqueio',
  'name': 'Bastão do Bloqueio',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:09.850-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bastao-do-bloqueio.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Este bastão pode ser utilizado por qualquer personagem. Ele '
                 'funciona drenando o poder mágico de outro item mágico, '
                 'transformando este em um item comum para sempre. Caso '
                 'resista, o alvo é atacado como se tivesse uma CA 10. O '
                 'Mestre pode determinar uma CA diferente se o alvo usar uma '
                 'armadura ou uma espada em combate. Um bastão do cancelamento '
                 'possui uma única carga.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 167},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 121}],
  'id': 'bastao-do-cancelamento',
  'name': 'Bastão do Cancelamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:09.942-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bastao-do-cancelamento.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Este bastão imponente e ricamente adornado permite ao seu '
                 'usuário ter algumas facilidades no governo de reinos e '
                 'Domínios. Seu usuário possui Carisma 20 quando estiver se '
                 'relacionando com qualquer governado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 121}],
  'id': 'bastao-do-governante',
  'name': 'Bastão do Governante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:10.068-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bastao-do-governante.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 5000,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'besta',
  'name': 'Besta',
  'picture': 'https://public.olddragon.com.br/su50t98trswyrueqkq0yforynkzb',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:46.572-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 3000,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'besta-de-mao',
  'name': 'Besta de Mão',
  'picture': 'https://public.olddragon.com.br/q7hlhjwd6uezjs78gkynp0czbies',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:48.809-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-de-mao-mais-1',
  'name': 'Besta de Mão +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:12.007-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma explode ao tocar o alvo '
                 'causando 1d6 de dano extra a todos em até metros de '
                 'distância do local da explosão. O atacante não é atingido '
                 'pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-de-mao-mais-1-da-explosao',
  'name': 'Besta de Mão +1 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:12.095-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao-mais-1-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-de-mao-mais-1-do-atordoamento',
  'name': 'Besta de Mão +1 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:12.183-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao-mais-1-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-de-mao-mais-1-do-desarme',
  'name': 'Besta de Mão +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:12.268-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma é extremamente poderoso e '
                 'ignora qualquer tipo de proteção ou cobertura, passando por '
                 'pessoas, móveis, folhagens, teia ou qualquer outra barreira '
                 'menos maciça que uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-de-mao-mais-1-penetrante',
  'name': 'Besta de Mão +1 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:12.357-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao-mais-1-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-de-mao-mais-2',
  'name': 'Besta de Mão +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:12.442-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma explode ao tocar o alvo '
                 'causando 1d6 de dano extra a todos em até metros de '
                 'distância do local da explosão. O atacante não é atingido '
                 'pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-de-mao-mais-2-da-explosao',
  'name': 'Besta de Mão +2 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:12.530-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao-mais-2-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-de-mao-mais-2-do-atordoamento',
  'name': 'Besta de Mão +2 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:12.619-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao-mais-2-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-de-mao-mais-2-do-desarme',
  'name': 'Besta de Mão +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:12.701-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma é extremamente poderoso e '
                 'ignora qualquer tipo de proteção ou cobertura, passando por '
                 'pessoas, móveis, folhagens, teia ou qualquer outra barreira '
                 'menos maciça que uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-de-mao-mais-2-penetrante',
  'name': 'Besta de Mão +2 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:12.786-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao-mais-2-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-de-mao-mais-3',
  'name': 'Besta de Mão +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:12.875-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma explode ao tocar o alvo '
                 'causando 1d6 de dano extra a todos em até metros de '
                 'distância do local da explosão. O atacante não é atingido '
                 'pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-de-mao-mais-3-da-explosao',
  'name': 'Besta de Mão +3 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:12.962-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao-mais-3-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-de-mao-mais-3-do-atordoamento',
  'name': 'Besta de Mão +3 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:13.055-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao-mais-3-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-de-mao-mais-3-do-desarme',
  'name': 'Besta de Mão +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:13.147-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma é extremamente poderoso e '
                 'ignora qualquer tipo de proteção ou cobertura, passando por '
                 'pessoas, móveis, folhagens, teia ou qualquer outra barreira '
                 'menos maciça que uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-de-mao-mais-3-penetrante',
  'name': 'Besta de Mão +3 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:13.234-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao-mais-3-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-de-mao-menos-1-amaldicoada',
  'name': 'Besta de Mão -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:11.831-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Disparo (36), Recarga',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-de-mao-menos-2-amaldicoada',
  'name': 'Besta de Mão -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:11.917-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-de-mao-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-mais-1',
  'name': 'Besta +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:10.418-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma explode ao tocar o alvo '
                 'causando 1d6 de dano extra a todos em até metros de '
                 'distância do local da explosão. O atacante não é atingido '
                 'pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-mais-1-da-explosao',
  'name': 'Besta +1 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:10.502-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-mais-1-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-mais-1-do-atordoamento',
  'name': 'Besta +1 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:10.591-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-mais-1-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-mais-1-do-desarme',
  'name': 'Besta +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:10.679-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma é extremamente poderoso e '
                 'ignora qualquer tipo de proteção ou cobertura, passando por '
                 'pessoas, móveis, folhagens, teia ou qualquer outra barreira '
                 'menos maciça que uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-mais-1-penetrante',
  'name': 'Besta +1 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:10.766-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-mais-1-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-mais-2',
  'name': 'Besta +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:10.891-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma explode ao tocar o alvo '
                 'causando 1d6 de dano extra a todos em até metros de '
                 'distância do local da explosão. O atacante não é atingido '
                 'pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-mais-2-da-explosao',
  'name': 'Besta +2 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:10.977-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-mais-2-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-mais-2-do-atordoamento',
  'name': 'Besta +2 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:11.074-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-mais-2-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-mais-2-do-desarme',
  'name': 'Besta +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:11.163-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma é extremamente poderoso e '
                 'ignora qualquer tipo de proteção ou cobertura, passando por '
                 'pessoas, móveis, folhagens, teia ou qualquer outra barreira '
                 'menos maciça que uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-mais-2-penetrante',
  'name': 'Besta +2 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:11.248-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-mais-2-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-mais-3',
  'name': 'Besta +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:11.335-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma explode ao tocar o alvo '
                 'causando 1d6 de dano extra a todos em até metros de '
                 'distância do local da explosão. O atacante não é atingido '
                 'pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-mais-3-da-explosao',
  'name': 'Besta +3 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:11.422-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-mais-3-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-mais-3-do-atordoamento',
  'name': 'Besta +3 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:11.505-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-mais-3-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-mais-3-do-desarme',
  'name': 'Besta +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:11.591-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga.\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma é extremamente poderoso e '
                 'ignora qualquer tipo de proteção ou cobertura, passando por '
                 'pessoas, móveis, folhagens, teia ou qualquer outra barreira '
                 'menos maciça que uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-mais-3-penetrante',
  'name': 'Besta +3 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:11.676-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-mais-3-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-menos-1-amaldicoada',
  'name': 'Besta -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:10.238-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': None,
  'description': 'Média, Disparo (54), Duas Mãos, Recarga',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'besta-menos-2-amaldicoada',
  'name': 'Besta -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:10.332-03:00',
  'url': 'https://olddragon.com.br/equipamentos/besta-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este manual é um apanhado compilado de monstros e criaturas '
                 'existentes pelos reinos, ordenado em ordem alfabética.\r\n'
                 '\r\n'
                 'Centenas de criaturas possuem descrições físicas completas, '
                 'ataques comentados, ilustrações para perfeita identificação '
                 'e descrições dos seus habitats e hábitos mais comuns.\r\n'
                 '\r\n'
                 'Qualquer personagem de posse de um bestiário conhece, em '
                 'profundidade, qualquer criatura e é capaz de pesquisar em '
                 '1d6+2 rodadas as principais formas de ataque e as fraquezas '
                 'de um monstro.\r\n'
                 '\r\n'
                 'O Mestre pode lançar secretamente a chance de identificar '
                 'corretamente uma criatura, que é de 100% -5% para cada DV da '
                 'criatura. Desta forma, uma criatura de 4DV possui uma chance '
                 'de 80% de ser corretamente identificada (100 - 20 = 80).\r\n'
                 '\r\n'
                 'A chance mínima de uma criatura ser identificada é de 10%, '
                 'não importando a quantidade de DV possuídos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 124}],
  'id': 'bestiario-o-livro-dos-monstros',
  'name': 'Bestiário: o Livro dos Monstros',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:41.808-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bestiario-o-livro-dos-monstros.json',
  'weight_in_grams': 2000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'O usuário de uma bola de cristal pode olhar dentro dela e '
                 'enxergar qualquer lugar, pessoa ou objeto por ele '
                 'desejado.\r\n'
                 '\r\n'
                 'Uma bola de cristal funciona até três vezes por dia, e '
                 'qualquer imagem dura no máximo 1 turno.\r\n'
                 '\r\n'
                 'Quanto mais conhecido for o objeto, o lugar ou a pessoa, '
                 'mais claras as imagens serão.\r\n'
                 '\r\n'
                 'Apenas Magos podem usar Bolas de Cristal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 167},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 125}],
  'id': 'bola-de-cristal',
  'name': 'Bola de Cristal',
  'picture': 'https://public.olddragon.com.br/8dt60vvvt805l8ltdnszo9kxsvjm',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:44.799-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bola-de-cristal.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 10,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Impactante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'bordao-cajado',
  'name': 'Bordão/Cajado',
  'picture': 'https://public.olddragon.com.br/bqaq0h3tbt8vibat9xra9dq2452k',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:18.020-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bordao-cajado.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Impactante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'bordao-cajado-mais-1',
  'name': 'Bordão/Cajado +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:13.585-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bordao-cajado-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Impactante, Duas Mãos.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela arma.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'bordao-cajado-mais-1-curador',
  'name': 'Bordão/Cajado +1 Curador',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:13.703-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bordao-cajado-mais-1-curador.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 1,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Impactante, Duas Mãos.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'bordao-cajado-mais-1-defensor',
  'name': 'Bordão/Cajado +1 Defensor',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:13.810-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bordao-cajado-mais-1-defensor.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Impactante, Duas Mãos.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'bordao-cajado-mais-1-do-desarme',
  'name': 'Bordão/Cajado +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:13.921-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bordao-cajado-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Impactante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'bordao-cajado-mais-2',
  'name': 'Bordão/Cajado +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:14.023-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bordao-cajado-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Impactante, Duas Mãos.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela arma.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'bordao-cajado-mais-2-curador',
  'name': 'Bordão/Cajado +2 Curador',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:14.153-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bordao-cajado-mais-2-curador.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Impactante, Duas Mãos.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'bordao-cajado-mais-2-defensor',
  'name': 'Bordão/Cajado +2 Defensor',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:14.262-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bordao-cajado-mais-2-defensor.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Impactante, Duas Mãos.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'bordao-cajado-mais-2-do-desarme',
  'name': 'Bordão/Cajado +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:14.362-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bordao-cajado-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Impactante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'bordao-cajado-mais-3',
  'name': 'Bordão/Cajado +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:14.455-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bordao-cajado-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Impactante, Duas Mãos.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela arma.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'bordao-cajado-mais-3-curador',
  'name': 'Bordão/Cajado +3 Curador',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:14.547-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bordao-cajado-mais-3-curador.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Impactante, Duas Mãos.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'bordao-cajado-mais-3-defensor',
  'name': 'Bordão/Cajado +3 Defensor',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:14.633-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bordao-cajado-mais-3-defensor.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Impactante, Duas Mãos.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'bordao-cajado-mais-3-do-desarme',
  'name': 'Bordão/Cajado +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:14.723-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bordao-cajado-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Impactante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'bordao-cajado-menos-1-amaldicoado',
  'name': 'Bordão/Cajado -1 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:13.396-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bordao-cajado-menos-1-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Madeira, Impactante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'bordao-cajado-menos-2-amaldicoado',
  'name': 'Bordão/Cajado -2 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:13.488-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bordao-cajado-menos-2-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'O usuário destas botas pode levitar como se estivesse sob o '
                 'efeito da magia arcana Levitação. Não há limite de duração.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 125}],
  'id': 'bota-da-levitacao',
  'name': 'Bota da Levitação',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:44.108-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bota-da-levitacao.json',
  'weight_in_grams': 1000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Estas botas de tecido macio e solado amortecedor faz com que '
                 'o usuário se mova em silêncio, como um Ladrão em qualquer '
                 'ambiente. Mesmo em pisos barulhentos (como chão forrado de '
                 'palha, gravetos que estalam, ou tábuas que rangem) concedem '
                 '1-5 chances em 1d6 de andar sem ser ouvido.\r\n'
                 '\r\n'
                 'O usuário sempre se moverá em silêncio caso o piso seja '
                 'limpo e não ruidoso.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 167},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 125}],
  'id': 'bota-elfica',
  'name': 'Bota Élfica',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:44.209-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bota-elfica.json',
  'weight_in_grams': 1000,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'armor',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 54}],
  'id': 'bracadeiras',
  'name': 'Braçadeiras',
  'type': 'Equipment',
  'updated_at': '2025-02-15T23:31:10.532-03:00',
  'url': 'https://olddragon.com.br/equipamentos/bracadeiras.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este estranho objeto pode ser descrito como um círculo de '
                 'tecido negro com 2 metros de diâmetro que, quando apoiado '
                 'sobre uma superfície, vira um buraco interdimensional com 3 '
                 'metros de profundidade.\r\n'
                 '\r\n'
                 'O buraco pode ser dobrado várias vezes como um lenço de '
                 'bolso e ser guardado como qualquer outro tecido.\r\n'
                 '\r\n'
                 'Quando aberto, o buraco pode ser usado como um depósito (com '
                 'uma área cilíndrica de 2 metros por 3 metros) no qual '
                 'pode-se guardar objetos sem se preocupar com o peso.\r\n'
                 '\r\n'
                 'É possível se esconder dentro de um buraco portátil, mas, '
                 'como o oxigênio em seu interior é reduzido, só é possível '
                 'ficar lá dentro por no máximo 10 minutos. Cada pessoa '
                 'adicional reduz o tempo em 2 minutos. Desta forma, é '
                 'possível que 5 pessoas (máximo) fiquem no interior do buraco '
                 'por até 2 minutos.\r\n'
                 '\r\n'
                 'O buraco pode ser fechado e aberto pelo lado de dentro sem '
                 'maiores problemas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 125}],
  'id': 'buraco-portatil',
  'name': 'Buraco Portátil',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:44.328-03:00',
  'url': 'https://olddragon.com.br/equipamentos/buraco-portatil.json',
  'weight_in_grams': 1000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 1200,
  'damage': None,
  'description': 'Com duas chaves.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'cadeado',
  'name': 'Cadeado',
  'picture': 'https://public.olddragon.com.br/o5kxk2np0qkt4ffua2a0ucflmtnz',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:09.937-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cadeado.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Este cajado possui o mesmo efeito de um Dissipar Magia, como '
                 'se fosse conjurado por um Mago de 15º Nível, mas afetando '
                 'apenas um item ou efeito mágico tocado pelo cajado. Qualquer '
                 'poção ou pergaminho é totalmente destruído, e outros itens '
                 'mágicos se tornam itens comuns por até 1d4 turnos (que é '
                 'quando retornam seus efeitos mágicos). Armas inteligentes '
                 'podem sofrer demasiadamente os efeitos de uma anulação. Há '
                 'três chances em 1d6 de uma arma inteligente jamais recuperar '
                 'sua Inteligência, virando uma arma mágica comum.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 121}],
  'id': 'cajado-da-anulacao',
  'name': 'Cajado da Anulação',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:14.813-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cajado-da-anulacao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Este cajado cura 1d8+1 de pontos de vida ao alvo tocado. '
                 'Este cajado não possui cargas, mas só pode ser usado uma '
                 'única vez por dia em cada pessoa, embora possa ser usado em '
                 'várias pessoas por dia. Este cajado só pode ser usado por '
                 'Clérigos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 166},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 121}],
  'id': 'cajado-da-cura',
  'name': 'Cajado da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:14.910-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cajado-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Este cajado deve ser tratado como um cajado mágico +1 em '
                 'combate. Este cajado pode se transformar em uma serpente que '
                 'atacarão ao comando do Clérigo. A serpente possui uma chance '
                 'de 5% por nível do conjurador de ser venenosa.\r\n'
                 '\r\n'
                 'A Serpente pode retornar ao Clérigo e se transformar '
                 'novamente em cajado, curando todo o dano sofrido. Caso seja '
                 'morta, a Serpente imediatamente volta a ser um cajado, '
                 'podendo ser transformada novamente em serpente após 1d4 '
                 'horas. Este cajado não possui cargas e pode ser usado '
                 'inúmeras vezes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 121}],
  'id': 'cajado-da-serpente',
  'name': 'Cajado da Serpente',
  'picture': 'https://public.olddragon.com.br/p353d9pv2sm6tlnjzjf164j6leua',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:17.614-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cajado-da-serpente.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Ao ser usado como arma, em um ataque bem-sucedido causando '
                 'dano ao alvo, este cajado gasta uma carga e causa um dano '
                 'adicional de 2d6. Apenas uma carga pode ser usada por '
                 'ataque. Este cajado pode ser usado por Clérigos e Magos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 166},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 121}],
  'id': 'cajado-de-ataque',
  'name': 'Cajado de Ataque',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:16.809-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cajado-de-ataque.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Média, Madeira, Versátil, Impactante.\r\n'
                 '\r\n'
                 'O usuário pode fazer um ataque à distância usando seu BAD e '
                 'lançar um raio de energia que causa 1d6 de dano mágico. O '
                 'alvo deve estar visível e dentro do alcance de 30 metros. '
                 'Contém 20 cargas, que são usadas a cada ataque feito, '
                 'acertando ou não o alvo. As cargas se restauram a cada '
                 'nascer do sol.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 9}],
  'id': 'cajado-disparador',
  'name': 'Cajado Disparador',
  'type': 'Equipment',
  'updated_at': '2025-01-29T22:56:12.439-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cajado-disparador.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Este cajado pode ser usado apenas por conjuradores de '
                 'magias. Une as habilidades do Anel de Controle de Animais, '
                 'de Controle de Humanos e de Controle de Plantas em um mesmo '
                 'item.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 121}],
  'id': 'cajado-do-controle',
  'name': 'Cajado do Controle',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:16.940-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cajado-do-controle.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Esta pequena joia ovalada pode aprisionar criaturas médias '
                 'até o tamanho de um humano por um período indefinido. '
                 'Qualquer criatura a abrir o camafeu e olhar para o pequeno '
                 'espelho em seu interior deve ser bem-sucedida em uma JPS ou '
                 'será imediatamente sugada para o interior da joia.\r\n'
                 '\r\n'
                 'Um camafeu pode aprisionar até 3d6+2 criaturas e, uma vez no '
                 'interior do camafeu, as criaturas param de envelhecer e '
                 'qualquer necessidade de comida ou bebida deixa de existir, '
                 'como se o tempo tivesse parado para elas.\r\n'
                 '\r\n'
                 'Para liberar as criaturas do interior do camafeu é '
                 'necessário quebrar o espelho, danificando permanentemente a '
                 'joia e seu funcionamento.\r\n'
                 '\r\n'
                 'Uma magia Desejo pode liberar uma criatura específica do '
                 'camafeu sem que este deixe de funcionar.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 125}],
  'id': 'camafeu-do-aprisionamento',
  'name': 'Camafeu do Aprisionamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:44.500-03:00',
  'url': 'https://olddragon.com.br/equipamentos/camafeu-do-aprisionamento.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'container',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 64}],
  'id': 'cantil-vazio',
  'name': 'Cantil Vazio',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:34.506-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cantil-vazio.json'},
 {'access': 'limited',
  'concept': 'armor',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 54}],
  'id': 'capa-de-urso',
  'name': 'Capa de Urso',
  'type': 'Equipment',
  'updated_at': '2025-02-15T23:31:10.620-03:00',
  'url': 'https://olddragon.com.br/equipamentos/capa-de-urso.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'vehicle',
  'cost': 40000,
  'damage': None,
  'description': 'Puxada por 1 cavalo. Transporta 1 condutor + 1 passageiro ou '
                 '150 kg.  Comporta até 4.000 moedas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'carroca',
  'name': 'Carroça',
  'type': 'Equipment',
  'updated_at': '2023-05-31T22:00:15.657-03:00',
  'url': 'https://olddragon.com.br/equipamentos/carroca.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'vehicle',
  'cost': 150000,
  'damage': None,
  'description': 'Puxada por 2 ou + cavalos. Transporta 1 condutor + 4 '
                 'passageiros ou 350 kg.  Comporta até 10.000 moedas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'carruagem',
  'name': 'Carruagem',
  'type': 'Equipment',
  'updated_at': '2023-05-31T22:00:15.674-03:00',
  'url': 'https://olddragon.com.br/equipamentos/carruagem.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'vehicle',
  'cost': 25000,
  'damage': None,
  'description': 'Treinado para combates e para armaduras. Carrega até 4.000 '
                 'moedas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'cavalo-de-guerra',
  'name': 'Cavalo de Guerra',
  'type': 'Equipment',
  'updated_at': '2023-05-31T22:00:15.490-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cavalo-de-guerra.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'vehicle',
  'cost': 7500,
  'damage': None,
  'description': 'Treinado para montaria. Carrega até 3.000 moedas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'cavalo-de-montaria',
  'name': 'Cavalo de Montaria',
  'type': 'Equipment',
  'updated_at': '2023-05-31T22:00:15.509-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cavalo-de-montaria.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'vehicle',
  'cost': 12000,
  'damage': None,
  'description': 'Para trabalhos de tração, puxar arados ou veículos. Carrega '
                 'até 4.500 moedas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'cavalo-de-tracao',
  'name': 'Cavalo de Tração',
  'type': 'Equipment',
  'updated_at': '2023-05-31T22:00:15.529-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cavalo-de-tracao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 1500,
  'damage': '1d6',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'cimitarra',
  'name': 'Cimitarra',
  'picture': 'https://public.olddragon.com.br/ebprsdbsgtfwajwxgtyhwtgjeipf',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:59.626-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-1',
  'name': 'Cimitarra +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:17.268-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-1-da-cura',
  'name': 'Cimitarra +1 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:17.354-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'cimitarra estivesse sob o efeito da magia Luz, lançada por '
                 'um Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-1-da-luz',
  'name': 'Cimitarra +1 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:17.441-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-1-da-respiracao',
  'name': 'Cimitarra +1 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:17.530-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-1-da-velocidade',
  'name': 'Cimitarra +1 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:17.620-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma '
                 'cimitarra de Drenar Energia possui 1d6+6 cargas e pode '
                 'drenar 1d4+4 níveis/dados de vida. Uma vez que esgote as '
                 'cargas, ela perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-1-de-drenar-energia',
  'name': 'Cimitarra +1 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:17.707-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-1-defensora',
  'name': 'Cimitarra +1 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:17.795-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da cimitarra desejar, faz '
                 'com que a lâmina da cimitarra arda coberta por chamas '
                 'mágicas, como se fosse uma tocha. Suas chamas causam um dano '
                 'extra de 1d6 ao atingir uma criatura que tenha o gelo ou o '
                 'frio como habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma cimitarra flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'cimitarra flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-1-flamejante',
  'name': 'Cimitarra +1 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:17.882-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da cimitarra deseje, faz '
                 'com que a lâmina da cimitarra congele ao menor toque. Seu '
                 'frio causa um dano extra de 1d6 ao atingir uma criatura que '
                 'tenha o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma cimitarra gélida não causa dano ao seu '
                 'portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-1-gelida',
  'name': 'Cimitarra +1 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:17.982-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+2 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-1-matadora-de-dragoes',
  'name': 'Cimitarra +1 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:18.082-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+2 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-1-matadora-de-extraplanares',
  'name': 'Cimitarra +1 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:18.181-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+2 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-1-matadora-de-gigantes',
  'name': 'Cimitarra +1 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:18.277-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+2 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-1-matadora-de-licantropos',
  'name': 'Cimitarra +1 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:18.380-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+2 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-1-matadora-de-mortos-vivos',
  'name': 'Cimitarra +1 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:18.489-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+2 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-1-matadora-de-orcs',
  'name': 'Cimitarra +1 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:18.588-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+2 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-1-matadora-de-regeneradores',
  'name': 'Cimitarra +1 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:18.682-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+2 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-1-matadora-de-usuarios-de-magia',
  'name': 'Cimitarra +1 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:18.783-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma cimitarra '
                 'Vorpal.\r\n'
                 '\r\n'
                 'O efeito da cimitarra Vorpal não é sentido por criaturas '
                 'cuja morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-1-vorpal',
  'name': 'Cimitarra +1 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:18.887-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-1-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-2',
  'name': 'Cimitarra +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:18.980-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-2-da-cura',
  'name': 'Cimitarra +2 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:19.072-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'cimitarra estivesse sob o efeito da magia Luz, lançada por '
                 'um Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-2-da-luz',
  'name': 'Cimitarra +2 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:19.165-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-2-da-respiracao',
  'name': 'Cimitarra +2 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:19.260-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-2-da-velocidade',
  'name': 'Cimitarra +2 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:19.353-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma '
                 'cimitarra de Drenar Energia possui 1d6+6 cargas e pode '
                 'drenar 1d4+4 níveis/dados de vida. Uma vez que esgote as '
                 'cargas, ela perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-2-de-drenar-energia',
  'name': 'Cimitarra +2 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:19.438-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-2-defensora',
  'name': 'Cimitarra +2 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:19.536-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da cimitarra desejar, faz '
                 'com que a lâmina da cimitarra arda coberta por chamas '
                 'mágicas, como se fosse uma tocha. Suas chamas causam um dano '
                 'extra de 1d6 ao atingir uma criatura que tenha o gelo ou o '
                 'frio como habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma cimitarra flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'cimitarra flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-2-flamejante',
  'name': 'Cimitarra +2 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:19.623-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da cimitarra deseje, faz '
                 'com que a lâmina da cimitarra congele ao menor toque. Seu '
                 'frio causa um dano extra de 1d6 ao atingir uma criatura que '
                 'tenha o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma cimitarra gélida não causa dano ao seu '
                 'portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-2-gelida',
  'name': 'Cimitarra +2 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:19.717-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+3 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-2-matadora-de-dragoes',
  'name': 'Cimitarra +2 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:19.802-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+3 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-2-matadora-de-extraplanares',
  'name': 'Cimitarra +2 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:19.948-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+3 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-2-matadora-de-gigantes',
  'name': 'Cimitarra +2 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:20.044-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+3 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-2-matadora-de-licantropos',
  'name': 'Cimitarra +2 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:20.138-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+3 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-2-matadora-de-mortos-vivos',
  'name': 'Cimitarra +2 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:20.229-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+3 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-2-matadora-de-orcs',
  'name': 'Cimitarra +2 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:20.317-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+3 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-2-matadora-de-regeneradores',
  'name': 'Cimitarra +2 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:20.412-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+3 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-2-matadora-de-usuarios-de-magia',
  'name': 'Cimitarra +2 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:20.502-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma cimitarra '
                 'Vorpal.\r\n'
                 '\r\n'
                 'O efeito da cimitarra Vorpal não é sentido por criaturas '
                 'cuja morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-2-vorpal',
  'name': 'Cimitarra +2 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:20.591-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-2-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-3',
  'name': 'Cimitarra +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:20.715-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-3-da-cura',
  'name': 'Cimitarra +3 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:20.810-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'cimitarra estivesse sob o efeito da magia Luz, lançada por '
                 'um Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-3-da-luz',
  'name': 'Cimitarra +3 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:20.900-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-3-da-respiracao',
  'name': 'Cimitarra +3 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:20.992-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-3-da-velocidade',
  'name': 'Cimitarra +3 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:21.097-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma '
                 'cimitarra de Drenar Energia possui 1d6+6 cargas e pode '
                 'drenar 1d4+4 níveis/dados de vida. Uma vez que esgote as '
                 'cargas, ela perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-3-de-drenar-energia',
  'name': 'Cimitarra +3 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:21.186-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-3-defensora',
  'name': 'Cimitarra +3 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:21.278-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da cimitarra desejar, faz '
                 'com que a lâmina da cimitarra arda coberta por chamas '
                 'mágicas, como se fosse uma tocha. Suas chamas causam um dano '
                 'extra de 1d6 ao atingir uma criatura que tenha o gelo ou o '
                 'frio como habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma cimitarra flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'cimitarra flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-3-flamejante',
  'name': 'Cimitarra +3 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:21.377-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da cimitarra deseje, faz '
                 'com que a lâmina da cimitarra congele ao menor toque. Seu '
                 'frio causa um dano extra de 1d6 ao atingir uma criatura que '
                 'tenha o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma cimitarra gélida não causa dano ao seu '
                 'portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-3-gelida',
  'name': 'Cimitarra +3 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:21.467-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+4 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-3-matadora-de-dragoes',
  'name': 'Cimitarra +3 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:21.558-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+4 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-3-matadora-de-extraplanares',
  'name': 'Cimitarra +3 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:21.646-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+4 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-3-matadora-de-gigantes',
  'name': 'Cimitarra +3 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:21.730-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+4 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-3-matadora-de-licantropos',
  'name': 'Cimitarra +3 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:21.818-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+4 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-3-matadora-de-mortos-vivos',
  'name': 'Cimitarra +3 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:21.909-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+4 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-3-matadora-de-orcs',
  'name': 'Cimitarra +3 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:21.994-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+4 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-3-matadora-de-regeneradores',
  'name': 'Cimitarra +3 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:22.092-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+4 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-3-matadora-de-usuarios-de-magia',
  'name': 'Cimitarra +3 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:22.189-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma cimitarra '
                 'Vorpal.\r\n'
                 '\r\n'
                 'O efeito da cimitarra Vorpal não é sentido por criaturas '
                 'cuja morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-3-vorpal',
  'name': 'Cimitarra +3 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:22.286-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-3-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-4',
  'name': 'Cimitarra +4',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:22.378-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-4-da-cura',
  'name': 'Cimitarra +4 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:22.469-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'cimitarra estivesse sob o efeito da magia Luz, lançada por '
                 'um Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-4-da-luz',
  'name': 'Cimitarra +4 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:22.555-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-4-da-respiracao',
  'name': 'Cimitarra +4 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:22.655-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-4-da-velocidade',
  'name': 'Cimitarra +4 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:22.743-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma '
                 'cimitarra de Drenar Energia possui 1d6+6 cargas e pode '
                 'drenar 1d4+4 níveis/dados de vida. Uma vez que esgote as '
                 'cargas, ela perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-4-de-drenar-energia',
  'name': 'Cimitarra +4 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:22.843-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-4-defensora',
  'name': 'Cimitarra +4 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:22.931-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da cimitarra desejar, faz '
                 'com que a lâmina da cimitarra arda coberta por chamas '
                 'mágicas, como se fosse uma tocha. Suas chamas causam um dano '
                 'extra de 1d6 ao atingir uma criatura que tenha o gelo ou o '
                 'frio como habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma cimitarra flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'cimitarra flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-4-flamejante',
  'name': 'Cimitarra +4 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:23.030-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da cimitarra deseje, faz '
                 'com que a lâmina da cimitarra congele ao menor toque. Seu '
                 'frio causa um dano extra de 1d6 ao atingir uma criatura que '
                 'tenha o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma cimitarra gélida não causa dano ao seu '
                 'portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-4-gelida',
  'name': 'Cimitarra +4 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:23.139-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+5 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-4-matadora-de-dragoes',
  'name': 'Cimitarra +4 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:23.226-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+5 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-4-matadora-de-extraplanares',
  'name': 'Cimitarra +4 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:23.319-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+5 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-4-matadora-de-gigantes',
  'name': 'Cimitarra +4 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:23.407-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+5 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-4-matadora-de-licantropos',
  'name': 'Cimitarra +4 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:23.507-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+5 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-4-matadora-de-mortos-vivos',
  'name': 'Cimitarra +4 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:23.592-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+5 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-4-matadora-de-orcs',
  'name': 'Cimitarra +4 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:23.675-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+5 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-4-matadora-de-regeneradores',
  'name': 'Cimitarra +4 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:23.762-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+5 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-4-matadora-de-usuarios-de-magia',
  'name': 'Cimitarra +4 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:23.872-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma cimitarra '
                 'Vorpal.\r\n'
                 '\r\n'
                 'O efeito da cimitarra Vorpal não é sentido por criaturas '
                 'cuja morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-4-vorpal',
  'name': 'Cimitarra +4 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:23.959-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-4-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-5',
  'name': 'Cimitarra +5',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:24.054-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-5-da-cura',
  'name': 'Cimitarra +5 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:24.152-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'cimitarra estivesse sob o efeito da magia Luz, lançada por '
                 'um Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-5-da-luz',
  'name': 'Cimitarra +5 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:24.244-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-5-da-respiracao',
  'name': 'Cimitarra +5 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:24.328-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-5-da-velocidade',
  'name': 'Cimitarra +5 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:24.419-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma '
                 'cimitarra de Drenar Energia possui 1d6+6 cargas e pode '
                 'drenar 1d4+4 níveis/dados de vida. Uma vez que esgote as '
                 'cargas, ela perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-5-de-drenar-energia',
  'name': 'Cimitarra +5 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:24.509-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-5-defensora',
  'name': 'Cimitarra +5 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:24.594-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da cimitarra desejar, faz '
                 'com que a lâmina da cimitarra arda coberta por chamas '
                 'mágicas, como se fosse uma tocha. Suas chamas causam um dano '
                 'extra de 1d6 ao atingir uma criatura que tenha o gelo ou o '
                 'frio como habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma cimitarra flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'cimitarra flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-5-flamejante',
  'name': 'Cimitarra +5 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:24.681-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da cimitarra deseje, faz '
                 'com que a lâmina da cimitarra congele ao menor toque. Seu '
                 'frio causa um dano extra de 1d6 ao atingir uma criatura que '
                 'tenha o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma cimitarra gélida não causa dano ao seu '
                 'portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-5-gelida',
  'name': 'Cimitarra +5 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:24.768-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+6 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-5-matadora-de-dragoes',
  'name': 'Cimitarra +5 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:24.858-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+6 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-5-matadora-de-extraplanares',
  'name': 'Cimitarra +5 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:24.942-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+6 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-5-matadora-de-gigantes',
  'name': 'Cimitarra +5 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:25.032-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+6 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-5-matadora-de-licantropos',
  'name': 'Cimitarra +5 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:25.126-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+6 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-5-matadora-de-mortos-vivos',
  'name': 'Cimitarra +5 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:25.217-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+6 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-mais-5-matadora-de-orcs',
  'name': 'Cimitarra +5 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:25.304-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+6 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-5-matadora-de-regeneradores',
  'name': 'Cimitarra +5 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:25.395-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n\r\n+6 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-5-matadora-de-usuarios-de-magia',
  'name': 'Cimitarra +5 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:25.479-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma cimitarra '
                 'Vorpal.\r\n'
                 '\r\n'
                 'O efeito da cimitarra Vorpal não é sentido por criaturas '
                 'cuja morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'cimitarra-mais-5-vorpal',
  'name': 'Cimitarra +5 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:25.568-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-mais-5-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-menos-1-amaldicoada',
  'name': 'Cimitarra -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:17.096-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'cimitarra-menos-2-amaldicoada',
  'name': 'Cimitarra -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:17.181-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cimitarra-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este grosso cinto de couro reforçado dá ao seu usuário a '
                 'mesma Força de um gigante da colina.\r\n'
                 '\r\n'
                 'Ao usar o cinto da força do gigante o usuário recebe um '
                 'bônus de +6 para atingir seus oponentes e um bônus de +6 no '
                 'dano dos ataques físicos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 125}],
  'id': 'cinto-da-forca-do-gigante',
  'name': 'Cinto da Força do Gigante',
  'picture': 'https://public.olddragon.com.br/uix8a14v346ipe6yv34dslolcb99',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:46.988-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cinto-da-forca-do-gigante.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'armor',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 54}],
  'id': 'cinturao-reforcado',
  'name': 'Cinturão Reforçado',
  'type': 'Equipment',
  'updated_at': '2025-02-15T23:31:13.019-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cinturao-reforcado.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 100,
  'damage': None,
  'description': 'Grossa de lã e peles com 2 x 2 metros.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'coberta-de-inverno',
  'name': 'Coberta de Inverno',
  'picture': 'https://public.olddragon.com.br/5n7sz1ifqnrjptugpcwvisqz0kds',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:11.959-03:00',
  'url': 'https://olddragon.com.br/equipamentos/coberta-de-inverno.json',
  'weight_in_grams': 1000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Fungos mágicos criados pelos feiticeiros hecatianos que, ao '
                 'serem ingeridos, modificam temporariamente o corpo do '
                 'personagem, concedendo +3 em Força por 1d4+1 rodadas de '
                 'combate.\r\n'
                 '\r\n'
                 'Após o efeito, o usuário perde 1d4 PV, recuperados apenas '
                 'com uma noite de sono.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday17.json',
              'page': 14}],
  'id': 'cogumelo-de-combate',
  'name': 'Cogumelo de Combate',
  'type': 'Equipment',
  'updated_at': '2025-04-24T19:13:26.562-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cogumelo-de-combate.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Esta corda longa, fina e resistente é feita da mais pura '
                 'seda. Tem 15 metros de comprimento e escala em qualquer '
                 'direção apontada pelo alvo. Ela se agarra a qualquer '
                 'superfície proeminente e pode suportar até 100kg.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 126}],
  'id': 'corda-da-escalada',
  'name': 'Corda da Escalada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:46.290-03:00',
  'url': 'https://olddragon.com.br/equipamentos/corda-da-escalada.json',
  'weight_in_grams': 1000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 100,
  'damage': None,
  'description': '15 metros. Suporta erguer até 250 kg.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'corda-de-canhamo',
  'name': 'Corda de Cânhamo',
  'picture': 'https://public.olddragon.com.br/fi8xwljzmpg8z0hlwhcsea1a9p12',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:13.714-03:00',
  'url': 'https://olddragon.com.br/equipamentos/corda-de-canhamo.json',
  'weight_in_grams': 2000,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'misc',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 102}],
  'id': 'corda-fragil',
  'name': 'Corda Frágil',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:04.731-03:00',
  'url': 'https://olddragon.com.br/equipamentos/corda-fragil.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 500,
  'damage': None,
  'description': '15 metros. Suporta erguer até 1.000 kg.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'corrente',
  'name': 'Corrente',
  'picture': 'https://public.olddragon.com.br/0d7mvkebm978ygom7yll69r4nkt5',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:17.413-03:00',
  'url': 'https://olddragon.com.br/equipamentos/corrente.json',
  'weight_in_grams': 20000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'armor',
  'cost': 6000,
  'damage': None,
  'description': 'Média, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 60}],
  'id': 'cota-de-malha',
  'name': 'Cota de Malha',
  'picture': 'https://public.olddragon.com.br/vgcgr71g4r6snijigxn1coswl0mu',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:37.802-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 160},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-1',
  'name': 'Cota de Malha +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:49.610-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-1-contra-projeteis',
  'name': 'Cota de Malha +1 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:50.232-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-1-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-1-curadora',
  'name': 'Cota de Malha +1 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:50.322-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-1-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-1-da-absorcao',
  'name': 'Cota de Malha +1 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:49.720-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-1-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-1-da-invisibilidade',
  'name': 'Cota de Malha +1 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:49.832-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-1-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-1-da-reflexao',
  'name': 'Cota de Malha +1 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:49.924-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-1-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-1-da-retribuicao',
  'name': 'Cota de Malha +1 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:50.023-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-1-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-1-da-velocidade',
  'name': 'Cota de Malha +1 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:50.110-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-1-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-2',
  'name': 'Cota de Malha +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:50.438-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-2-contra-projeteis',
  'name': 'Cota de Malha +2 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:51.130-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-2-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-2-curadora',
  'name': 'Cota de Malha +2 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:51.232-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-2-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-2-da-absorcao',
  'name': 'Cota de Malha +2 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:50.538-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-2-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-2-da-invisibilidade',
  'name': 'Cota de Malha +2 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:50.650-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-2-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-2-da-reflexao',
  'name': 'Cota de Malha +2 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:50.762-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-2-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-2-da-retribuicao',
  'name': 'Cota de Malha +2 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:50.898-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-2-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 6,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-2-da-velocidade',
  'name': 'Cota de Malha +2 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:51.027-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-2-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 7,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-3',
  'name': 'Cota de Malha +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:51.325-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 7,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura é particularmente boa para proteger seu '
                 'usuário de qualquer ataque de projétil ou arma arremessada. '
                 'Para esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-3-contra-projeteis',
  'name': 'Cota de Malha +3 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:51.938-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-3-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 7,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura faz com que o usuário possa curar 1d8 pontos '
                 'de vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-3-curadora',
  'name': 'Cota de Malha +3 Curadora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:52.033-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-3-curadora.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 7,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura absorve qualquer ataque do tipo dreno causado '
                 'ao usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção da armadura ou escudo '
                 'que se desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-3-da-absorcao',
  'name': 'Cota de Malha +3 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:51.422-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-3-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 7,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-3-da-invisibilidade',
  'name': 'Cota de Malha +3 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:51.526-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-3-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 7,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-3-da-reflexao',
  'name': 'Cota de Malha +3 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:51.630-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-3-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 7,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Esta armadura permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-3-da-retribuicao',
  'name': 'Cota de Malha +3 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:51.731-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-3-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 7,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário desta armadura pode ativar sobre '
                 'si os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-mais-3-da-velocidade',
  'name': 'Cota de Malha +3 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:51.845-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-mais-3-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 5,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-menos-1-amaldicoada',
  'name': 'Cota de Malha -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:49.426-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'armor',
  'cost': None,
  'damage': None,
  'description': 'Média, Metal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'cota-de-malha-menos-2-amaldicoada',
  'name': 'Cota de Malha -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:49.517-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cota-de-malha-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'limited',
  'concept': 'misc',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 102}],
  'id': 'couro-branco-e-carvao-para-escrever-grimorio-inicial',
  'name': 'Couro Branco e Carvão para Escrever (grimório inicial)',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:15.354-03:00',
  'url': 'https://olddragon.com.br/equipamentos/couro-branco-e-carvao-para-escrever-grimorio-inicial.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Caso seja examinado por um jogador, o crânio emitirá um raio '
                 'de suas cavidades oculares em direção aos olhos do '
                 'personagem, deixando-o cego por 1d4 Turnos de 10 minutos.\r\n'
                 '\r\n'
                 'Após esse tempo, a visão retornará, seus olhos ficam '
                 'vermelhos e o personagem adquire uma Infravisão temporária '
                 'pelo dobro do tempo que ficou cego, com um alcance de 30 '
                 'metros.\r\n'
                 '\r\n'
                 'Durante esse tempo ele também pode ler instruções e fórmulas '
                 'em idiomas desconhecidos, embora não decifre nenhum enigma '
                 'ou código, apenas permitindo ao personagem compreender o que '
                 'está escrito.\r\n'
                 '\r\n'
                 ' Pode ser usado duas vezes por dia, uma vez para cada '
                 'cavidade ocular do crânio.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 10}],
  'id': 'cranio-da-visao',
  'name': 'Crânio da Visão',
  'type': 'Equipment',
  'updated_at': '2025-01-29T22:55:58.366-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cranio-da-visao.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 100,
  'damage': None,
  'description': '5 unidades de cravos ou ganchos para escaladas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'cravos-ganchos',
  'name': 'Cravos/Ganchos',
  'picture': 'https://public.olddragon.com.br/ineq9bjfvl1cd02j5wugu85pryhr',
  'type': 'Equipment',
  'updated_at': '2025-04-09T12:18:15.639-03:00',
  'url': 'https://olddragon.com.br/equipamentos/cravos-ganchos.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'armor',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 54}],
  'id': 'elmo',
  'name': 'Elmo',
  'type': 'Equipment',
  'updated_at': '2025-02-15T23:31:16.687-03:00',
  'url': 'https://olddragon.com.br/equipamentos/elmo.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este elmo altera imediatamente o alinhamento do usuário (50% '
                 'de chance para qualquer um dos outros alinhamentos).\r\n'
                 '\r\n'
                 'É impossível remover o elmo pois este se agarra a cabeça do '
                 'alvo, sendo retirado apenas com o uso da magia Remover '
                 'Maldição. Uma vez removido, o alinhamento original do alvo '
                 'retorna.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 126}],
  'id': 'elmo-da-mudanca-de-alinhamento-caotico',
  'name': 'Elmo da Mudança de Alinhamento (Caótico)',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:46.739-03:00',
  'url': 'https://olddragon.com.br/equipamentos/elmo-da-mudanca-de-alinhamento-caotico.json',
  'weight_in_grams': 2000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este elegante elmo confeccionado com metais nobres ricamente '
                 'adornado permite ao seu usuário enviar mensagens telepáticas '
                 'a qualquer criatura a até 27 metros de distância.\r\n'
                 '\r\n'
                 'O alvo das mensagens entenderá caso compreenda o idioma do '
                 'emissor da mensagem, e poderá responder apenas se '
                 'desejar.\r\n'
                 '\r\n'
                 'O usuário do elmo da telepatia também pode ler os '
                 'pensamentos de uma única criatura viva no raio de alcance. '
                 'Para conseguir usar o elmo, o usuário precisa se concentrar '
                 'na mente da criatura a qual deseja contactar ou ler. '
                 'Enquanto usar este poder, o usuário do elmo não pode se '
                 'mover, atacar ou conjurar magias.\r\n'
                 '\r\n'
                 'Se o alvo não desejar ter seus pensamentos lidos, pode '
                 'realizar uma JPS para negar o ataque do usuário do elmo da '
                 'telepatia, mas não é possível usar uma JPS para não receber '
                 'as comunicações do elmo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 126}],
  'id': 'elmo-da-telepatia',
  'name': 'Elmo da Telepatia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:46.827-03:00',
  'url': 'https://olddragon.com.br/equipamentos/elmo-da-telepatia.json',
  'weight_in_grams': 2000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Dose única. Recupera 2 PV quando bebida ou 1 PV se ingerida '
                 'de outra forma.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 7}],
  'id': 'erva-relaxante',
  'name': 'Erva Relaxante',
  'type': 'Equipment',
  'updated_at': '2025-03-06T23:39:58.045-03:00',
  'url': 'https://olddragon.com.br/equipamentos/erva-relaxante.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 100,
  'damage': None,
  'description': '3 metros. Com corrimão de corda e degrau de ripas de madeira '
                 'para escaladas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'escada',
  'name': 'Escada',
  'picture': 'https://public.olddragon.com.br/gzwugetpnky8peyell4dopv7i0bq',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:54.941-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escada.json',
  'weight_in_grams': 5000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 1,
  'concept': 'shield',
  'cost': 800,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 60}],
  'id': 'escudo',
  'name': 'Escudo',
  'picture': 'https://public.olddragon.com.br/d2tlv2sycyeqlvj0v62rlxntreox',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:49.426-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 160},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-1',
  'name': 'Escudo +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:52.510-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo é particularmente bom para proteger seu usuário '
                 'de qualquer ataque de projétil ou arma arremessada. Para '
                 'esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-1-contra-projeteis',
  'name': 'Escudo +1 Contra Projéteis',
  'picture': 'https://public.olddragon.com.br/tsqs2vvhobkqvwvdwxhq6j9g2ux9',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:55.200-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-1-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo faz com que o usuário possa curar 1d8 pontos de '
                 'vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-1-curador',
  'name': 'Escudo +1 Curador',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:54.481-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-1-curador.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo absorve qualquer ataque do tipo dreno causado ao '
                 'usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção do escudo que se '
                 'desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-1-da-absorcao',
  'name': 'Escudo +1 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:52.643-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-1-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-1-da-invisibilidade',
  'name': 'Escudo +1 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:52.742-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-1-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-1-da-reflexao',
  'name': 'Escudo +1 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:52.834-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-1-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-1-da-retribuicao',
  'name': 'Escudo +1 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:52.917-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-1-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário deste escudo pode ativar sobre si '
                 'os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-1-da-velocidade',
  'name': 'Escudo +1 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:53.026-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-1-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-2',
  'name': 'Escudo +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:54.563-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo é particularmente bom para proteger seu usuário '
                 'de qualquer ataque de projétil ou arma arremessada. Para '
                 'esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-2-contra-projeteis',
  'name': 'Escudo +2 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:55.064-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-2-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo faz com que o usuário possa curar 1d8 pontos de '
                 'vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-2-curador',
  'name': 'Escudo +2 Curador',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:55.160-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-2-curador.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo absorve qualquer ataque do tipo dreno causado ao '
                 'usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção do escudo que se '
                 'desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-2-da-absorcao',
  'name': 'Escudo +2 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:54.646-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-2-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-2-da-invisibilidade',
  'name': 'Escudo +2 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:54.726-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-2-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-2-da-reflexao',
  'name': 'Escudo +2 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:54.810-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-2-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-2-da-retribuicao',
  'name': 'Escudo +2 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:54.895-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-2-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário deste escudo pode ativar sobre si '
                 'os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-2-da-velocidade',
  'name': 'Escudo +2 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:54.976-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-2-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-3',
  'name': 'Escudo +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:55.248-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo é particularmente bom para proteger seu usuário '
                 'de qualquer ataque de projétil ou arma arremessada. Para '
                 'esse tipo de ataque, o bônus de proteção é dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-3-contra-projeteis',
  'name': 'Escudo +3 Contra Projéteis',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:55.764-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-3-contra-projeteis.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo faz com que o usuário possa curar 1d8 pontos de '
                 'vida por dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-3-curador',
  'name': 'Escudo +3 Curador',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:55.847-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-3-curador.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo absorve qualquer ataque do tipo dreno causado ao '
                 'usuário que recebe apenas o dano físico do ataque. Cada '
                 'absorção consome um bônus de proteção do escudo que se '
                 'desfaz em pó quando chegar a um bônus de zero.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-3-da-absorcao',
  'name': 'Escudo +3 da Absorção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:55.330-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-3-da-absorcao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo torna o usuário invisível, como se a magia de '
                 'mesmo nome tivesse sido lançada no usuário. Este poder pode '
                 'ser ativado até 2 vezes por dia sob o comando do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-3-da-invisibilidade',
  'name': 'Escudo +3 da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:55.420-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-3-da-invisibilidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo permite ao usuário refletir todos os ataques '
                 'mágicos e de energia (como eletricidade ou fogo de uma '
                 'baforada de dragão) até três vezes ao dia. Qualquer dano '
                 'causado por estas magias e energias é ignorado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-3-da-reflexao',
  'name': 'Escudo +3 da Reflexão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:55.510-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-3-da-reflexao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Este escudo permite ao usuário redirecionar um ataque '
                 'recebido por dia. O uso desta habilidade deve ser ativado '
                 'antes do ataque ocorrer. Caso o ataque falhe, o usuário da '
                 'armadura perde seu uso diário. O alvo da retribuição recebe '
                 'todo o dano que causaria ao usuário da armadura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-3-da-retribuicao',
  'name': 'Escudo +3 da Retribuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:55.600-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-3-da-retribuicao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 4,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.\r\n'
                 '\r\n'
                 'Uma vez ao dia, o usuário deste escudo pode ativar sobre si '
                 'os efeitos da velocidade como a magia de mesmo nome. A '
                 'movimentação do usuário passa a ser dobrada, além de receber '
                 'um bônus de +2 na Classe de Armadura e um ataque extra por '
                 'turno usando o mesmo bônus do ataque principal. Essa '
                 'aceleração é prejudicial ao organismo do alvo, fazendo-o '
                 'envelhecer 1 ano biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-mais-3-da-velocidade',
  'name': 'Escudo +3 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:55.679-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-mais-3-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-menos-1-amaldicoado',
  'name': 'Escudo -1 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:52.287-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-menos-1-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': -1,
  'concept': 'shield',
  'cost': None,
  'damage': None,
  'description': 'Leve, Mão Exclusiva, Madeira.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 112}],
  'id': 'escudo-menos-2-amaldicoado',
  'name': 'Escudo -2 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:52.394-03:00',
  'url': 'https://olddragon.com.br/equipamentos/escudo-menos-2-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 1500,
  'damage': '1d8',
  'description': 'Média, Versátil, Cortante',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'espada-bastarda',
  'name': 'Espada Bastarda',
  'picture': 'https://public.olddragon.com.br/vdl6dk0crggtnjzbl3giv2mnj2c1',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:02.919-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Versátil, Cortante',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-1',
  'name': 'Espada Bastarda +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:25.894-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-1-da-cura',
  'name': 'Espada Bastarda +1 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:25.982-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'espada estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-1-da-luz',
  'name': 'Espada Bastarda +1 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:26.071-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-1-da-respiracao',
  'name': 'Espada Bastarda +1 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:26.160-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-1-da-velocidade',
  'name': 'Espada Bastarda +1 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:26.264-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma espada '
                 'de Drenar Energia possui 1d6+6 cargas e pode drenar 1d4+4 '
                 'níveis/dados de vida. Uma vez que esgote as cargas, ela '
                 'perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-1-de-drenar-energia',
  'name': 'Espada Bastarda +1 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:26.347-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-1-defensora',
  'name': 'Espada Bastarda +1 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:26.479-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da espada desejar, faz com '
                 'que a lâmina da espada arda coberta por chamas mágicas, como '
                 'se fosse uma tocha. Suas chamas causam um dano extra de 1d6 '
                 'ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma espada flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'espada flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-1-flamejante',
  'name': 'Espada Bastarda +1 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:26.573-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da espada deseje, faz '
                 'com que a lâmina da espada congele ao menor toque. Seu frio '
                 'causa um dano extra de 1d6 ao atingir uma criatura que tenha '
                 'o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma espada gélida não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-1-gelida',
  'name': 'Espada Bastarda +1 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:26.667-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+2 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-1-matadora-de-dragoes',
  'name': 'Espada Bastarda +1 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:26.754-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+2 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-1-matadora-de-extraplanares',
  'name': 'Espada Bastarda +1 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:26.837-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+2 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-1-matadora-de-gigantes',
  'name': 'Espada Bastarda +1 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:26.933-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+2 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-1-matadora-de-licantropos',
  'name': 'Espada Bastarda +1 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:27.037-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+2 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-1-matadora-de-mortos-vivos',
  'name': 'Espada Bastarda +1 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:27.120-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+2 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-1-matadora-de-orcs',
  'name': 'Espada Bastarda +1 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:27.219-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+2 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-1-matadora-de-regeneradores',
  'name': 'Espada Bastarda +1 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:27.311-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 '+2 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-1-matadora-de-usuarios-de-magia',
  'name': 'Espada Bastarda +1 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:27.399-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma espada Vorpal.\r\n'
                 '\r\n'
                 'O efeito da espada Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-1-vorpal',
  'name': 'Espada Bastarda +1 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:27.497-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-1-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Versátil, Cortante',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-2',
  'name': 'Espada Bastarda +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:27.587-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-2-da-cura',
  'name': 'Espada Bastarda +2 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:27.670-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'espada estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-2-da-luz',
  'name': 'Espada Bastarda +2 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:27.759-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-2-da-respiracao',
  'name': 'Espada Bastarda +2 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:27.851-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-2-da-velocidade',
  'name': 'Espada Bastarda +2 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:27.938-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma espada '
                 'de Drenar Energia possui 1d6+6 cargas e pode drenar 1d4+4 '
                 'níveis/dados de vida. Uma vez que esgote as cargas, ela '
                 'perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-2-de-drenar-energia',
  'name': 'Espada Bastarda +2 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:28.036-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-2-defensora',
  'name': 'Espada Bastarda +2 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:28.123-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da espada desejar, faz com '
                 'que a lâmina da espada arda coberta por chamas mágicas, como '
                 'se fosse uma tocha. Suas chamas causam um dano extra de 1d6 '
                 'ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma espada flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'espada flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-2-flamejante',
  'name': 'Espada Bastarda +2 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:28.212-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da espada deseje, faz '
                 'com que a lâmina da espada congele ao menor toque. Seu frio '
                 'causa um dano extra de 1d6 ao atingir uma criatura que tenha '
                 'o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma espada gélida não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-2-gelida',
  'name': 'Espada Bastarda +2 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:28.311-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+3 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-2-matadora-de-dragoes',
  'name': 'Espada Bastarda +2 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:28.397-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+3 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-2-matadora-de-extraplanares',
  'name': 'Espada Bastarda +2 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:28.491-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+3 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-2-matadora-de-gigantes',
  'name': 'Espada Bastarda +2 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:28.581-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+3 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-2-matadora-de-licantropos',
  'name': 'Espada Bastarda +2 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:28.668-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+3 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-2-matadora-de-mortos-vivos',
  'name': 'Espada Bastarda +2 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:28.760-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+3 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-2-matadora-de-orcs',
  'name': 'Espada Bastarda +2 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:28.848-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+3 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-2-matadora-de-regeneradores',
  'name': 'Espada Bastarda +2 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:28.937-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 '+3 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-2-matadora-de-usuarios-de-magia',
  'name': 'Espada Bastarda +2 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:29.027-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma espada Vorpal.\r\n'
                 '\r\n'
                 'O efeito da espada Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-2-vorpal',
  'name': 'Espada Bastarda +2 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:29.110-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-2-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Versátil, Cortante',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-3',
  'name': 'Espada Bastarda +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:29.200-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-3-da-cura',
  'name': 'Espada Bastarda +3 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:29.285-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'espada estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-3-da-luz',
  'name': 'Espada Bastarda +3 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:29.371-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-3-da-respiracao',
  'name': 'Espada Bastarda +3 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:29.457-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-3-da-velocidade',
  'name': 'Espada Bastarda +3 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:29.557-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma espada '
                 'de Drenar Energia possui 1d6+6 cargas e pode drenar 1d4+4 '
                 'níveis/dados de vida. Uma vez que esgote as cargas, ela '
                 'perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-3-de-drenar-energia',
  'name': 'Espada Bastarda +3 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:29.645-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-3-defensora',
  'name': 'Espada Bastarda +3 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:29.727-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da espada desejar, faz com '
                 'que a lâmina da espada arda coberta por chamas mágicas, como '
                 'se fosse uma tocha. Suas chamas causam um dano extra de 1d6 '
                 'ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma espada flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'espada flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-3-flamejante',
  'name': 'Espada Bastarda +3 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:29.813-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da espada deseje, faz '
                 'com que a lâmina da espada congele ao menor toque. Seu frio '
                 'causa um dano extra de 1d6 ao atingir uma criatura que tenha '
                 'o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma espada gélida não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-3-gelida',
  'name': 'Espada Bastarda +3 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:29.898-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+4 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-3-matadora-de-dragoes',
  'name': 'Espada Bastarda +3 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:29.983-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+4 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-3-matadora-de-extraplanares',
  'name': 'Espada Bastarda +3 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:30.085-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+4 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-3-matadora-de-gigantes',
  'name': 'Espada Bastarda +3 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:30.182-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+4 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-3-matadora-de-licantropos',
  'name': 'Espada Bastarda +3 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:30.270-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+4 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-3-matadora-de-mortos-vivos',
  'name': 'Espada Bastarda +3 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:30.358-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+4 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-3-matadora-de-orcs',
  'name': 'Espada Bastarda +3 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:30.448-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+4 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-3-matadora-de-regeneradores',
  'name': 'Espada Bastarda +3 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:30.535-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 '+4 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-3-matadora-de-usuarios-de-magia',
  'name': 'Espada Bastarda +3 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:30.642-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma espada Vorpal.\r\n'
                 '\r\n'
                 'O efeito da espada Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-3-vorpal',
  'name': 'Espada Bastarda +3 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:30.730-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-3-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Versátil, Cortante',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-4',
  'name': 'Espada Bastarda +4',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:30.815-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-4-da-cura',
  'name': 'Espada Bastarda +4 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:30.950-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'espada estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-4-da-luz',
  'name': 'Espada Bastarda +4 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:31.045-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-4-da-respiracao',
  'name': 'Espada Bastarda +4 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:31.141-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-4-da-velocidade',
  'name': 'Espada Bastarda +4 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:31.231-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma espada '
                 'de Drenar Energia possui 1d6+6 cargas e pode drenar 1d4+4 '
                 'níveis/dados de vida. Uma vez que esgote as cargas, ela '
                 'perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-4-de-drenar-energia',
  'name': 'Espada Bastarda +4 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:31.323-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-4-defensora',
  'name': 'Espada Bastarda +4 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:31.412-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da espada desejar, faz com '
                 'que a lâmina da espada arda coberta por chamas mágicas, como '
                 'se fosse uma tocha. Suas chamas causam um dano extra de 1d6 '
                 'ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma espada flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'espada flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-4-flamejante',
  'name': 'Espada Bastarda +4 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:31.501-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da espada deseje, faz '
                 'com que a lâmina da espada congele ao menor toque. Seu frio '
                 'causa um dano extra de 1d6 ao atingir uma criatura que tenha '
                 'o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma espada gélida não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-4-gelida',
  'name': 'Espada Bastarda +4 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:31.589-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+5 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-4-matadora-de-dragoes',
  'name': 'Espada Bastarda +4 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:31.695-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+5 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-4-matadora-de-extraplanares',
  'name': 'Espada Bastarda +4 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:31.782-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+5 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-4-matadora-de-gigantes',
  'name': 'Espada Bastarda +4 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:31.868-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+5 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-4-matadora-de-licantropos',
  'name': 'Espada Bastarda +4 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:31.962-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+5 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-4-matadora-de-mortos-vivos',
  'name': 'Espada Bastarda +4 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:32.054-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+5 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-4-matadora-de-orcs',
  'name': 'Espada Bastarda +4 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:32.170-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+5 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-4-matadora-de-regeneradores',
  'name': 'Espada Bastarda +4 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:32.256-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 '+5 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-4-matadora-de-usuarios-de-magia',
  'name': 'Espada Bastarda +4 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:32.352-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma espada Vorpal.\r\n'
                 '\r\n'
                 'O efeito da espada Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-4-vorpal',
  'name': 'Espada Bastarda +4 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:32.442-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-4-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Versátil, Cortante',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-5',
  'name': 'Espada Bastarda +5',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:32.536-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-5-da-cura',
  'name': 'Espada Bastarda +5 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:32.631-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'espada estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-5-da-luz',
  'name': 'Espada Bastarda +5 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:32.752-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-5-da-respiracao',
  'name': 'Espada Bastarda +5 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:32.846-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-5-da-velocidade',
  'name': 'Espada Bastarda +5 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:32.949-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma espada '
                 'de Drenar Energia possui 1d6+6 cargas e pode drenar 1d4+4 '
                 'níveis/dados de vida. Uma vez que esgote as cargas, ela '
                 'perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-5-de-drenar-energia',
  'name': 'Espada Bastarda +5 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:33.054-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-5-defensora',
  'name': 'Espada Bastarda +5 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:33.154-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da espada desejar, faz com '
                 'que a lâmina da espada arda coberta por chamas mágicas, como '
                 'se fosse uma tocha. Suas chamas causam um dano extra de 1d6 '
                 'ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma espada flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'espada flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-5-flamejante',
  'name': 'Espada Bastarda +5 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:33.252-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da espada deseje, faz '
                 'com que a lâmina da espada congele ao menor toque. Seu frio '
                 'causa um dano extra de 1d6 ao atingir uma criatura que tenha '
                 'o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma espada gélida não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-5-gelida',
  'name': 'Espada Bastarda +5 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:33.426-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+6 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-5-matadora-de-dragoes',
  'name': 'Espada Bastarda +5 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:33.522-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+6 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-5-matadora-de-extraplanares',
  'name': 'Espada Bastarda +5 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:33.620-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+6 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-5-matadora-de-gigantes',
  'name': 'Espada Bastarda +5 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:33.713-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+6 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-5-matadora-de-licantropos',
  'name': 'Espada Bastarda +5 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:33.818-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+6 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-5-matadora-de-mortos-vivos',
  'name': 'Espada Bastarda +5 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:33.919-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+6 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-mais-5-matadora-de-orcs',
  'name': 'Espada Bastarda +5 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:34.019-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n\r\n+6 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-5-matadora-de-regeneradores',
  'name': 'Espada Bastarda +5 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:34.115-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 '+6 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-5-matadora-de-usuarios-de-magia',
  'name': 'Espada Bastarda +5 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:34.223-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Versátil, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma espada Vorpal.\r\n'
                 '\r\n'
                 'O efeito da espada Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-bastarda-mais-5-vorpal',
  'name': 'Espada Bastarda +5 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:34.322-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-mais-5-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Versátil, Cortante',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-menos-1-amaldicoada',
  'name': 'Espada Bastarda -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:25.724-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Versátil, Cortante',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-bastarda-menos-2-amaldicoada',
  'name': 'Espada Bastarda -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:25.809-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-bastarda-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 600,
  'damage': '1d6',
  'description': 'Pequena, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'espada-curta',
  'name': 'Espada Curta',
  'picture': 'https://public.olddragon.com.br/f0v37vin450apz72tiheocl21v17',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:00.528-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-1',
  'name': 'Espada Curta +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:34.669-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-1-da-cura',
  'name': 'Espada Curta +1 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:34.752-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'espada estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-1-da-luz',
  'name': 'Espada Curta +1 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:34.839-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-1-da-respiracao',
  'name': 'Espada Curta +1 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:34.926-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-1-da-velocidade',
  'name': 'Espada Curta +1 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:35.017-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma espada '
                 'de Drenar Energia possui 1d6+6 cargas e pode drenar 1d4+4 '
                 'níveis/dados de vida. Uma vez que esgote as cargas, ela '
                 'perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-1-de-drenar-energia',
  'name': 'Espada Curta +1 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:35.108-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-1-defensora',
  'name': 'Espada Curta +1 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:35.197-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da espada desejar, faz com '
                 'que a lâmina da espada arda coberta por chamas mágicas, como '
                 'se fosse uma tocha. Suas chamas causam um dano extra de 1d6 '
                 'ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma espada flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'espada flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-1-flamejante',
  'name': 'Espada Curta +1 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:35.287-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da espada deseje, faz '
                 'com que a lâmina da espada congele ao menor toque. Seu frio '
                 'causa um dano extra de 1d6 ao atingir uma criatura que tenha '
                 'o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma espada gélida não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-1-gelida',
  'name': 'Espada Curta +1 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:35.382-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+2 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-1-matadora-de-dragoes',
  'name': 'Espada Curta +1 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:35.481-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+2 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-1-matadora-de-extraplanares',
  'name': 'Espada Curta +1 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:35.569-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+2 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-1-matadora-de-gigantes',
  'name': 'Espada Curta +1 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:35.665-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+2 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-1-matadora-de-licantropos',
  'name': 'Espada Curta +1 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:35.757-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+2 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-1-matadora-de-mortos-vivos',
  'name': 'Espada Curta +1 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:35.855-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+2 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-1-matadora-de-orcs',
  'name': 'Espada Curta +1 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:35.960-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+2 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-1-matadora-de-regeneradores',
  'name': 'Espada Curta +1 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:36.053-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+2 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-1-matadora-de-usuarios-de-magia',
  'name': 'Espada Curta +1 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:36.144-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma espada Vorpal.\r\n'
                 '\r\n'
                 'O efeito da espada Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-1-vorpal',
  'name': 'Espada Curta +1 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:36.238-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-1-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-2',
  'name': 'Espada Curta +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:36.340-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-2-da-cura',
  'name': 'Espada Curta +2 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:36.435-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'espada estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-2-da-luz',
  'name': 'Espada Curta +2 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:36.530-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-2-da-respiracao',
  'name': 'Espada Curta +2 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:36.624-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-2-da-velocidade',
  'name': 'Espada Curta +2 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:36.713-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma espada '
                 'de Drenar Energia possui 1d6+6 cargas e pode drenar 1d4+4 '
                 'níveis/dados de vida. Uma vez que esgote as cargas, ela '
                 'perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-2-de-drenar-energia',
  'name': 'Espada Curta +2 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:36.805-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-2-defensora',
  'name': 'Espada Curta +2 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:36.890-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da espada desejar, faz com '
                 'que a lâmina da espada arda coberta por chamas mágicas, como '
                 'se fosse uma tocha. Suas chamas causam um dano extra de 1d6 '
                 'ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma espada flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'espada flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-2-flamejante',
  'name': 'Espada Curta +2 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:36.985-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da espada deseje, faz '
                 'com que a lâmina da espada congele ao menor toque. Seu frio '
                 'causa um dano extra de 1d6 ao atingir uma criatura que tenha '
                 'o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma espada gélida não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-2-gelida',
  'name': 'Espada Curta +2 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:37.077-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+3 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-2-matadora-de-dragoes',
  'name': 'Espada Curta +2 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:37.165-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+3 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-2-matadora-de-extraplanares',
  'name': 'Espada Curta +2 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:37.254-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+3 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-2-matadora-de-gigantes',
  'name': 'Espada Curta +2 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:37.345-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+3 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-2-matadora-de-licantropos',
  'name': 'Espada Curta +2 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:37.437-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+3 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-2-matadora-de-mortos-vivos',
  'name': 'Espada Curta +2 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:37.536-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+3 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-2-matadora-de-orcs',
  'name': 'Espada Curta +2 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:37.623-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+3 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-2-matadora-de-regeneradores',
  'name': 'Espada Curta +2 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:37.710-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+3 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-2-matadora-de-usuarios-de-magia',
  'name': 'Espada Curta +2 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:37.802-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma espada Vorpal.\r\n'
                 '\r\n'
                 'O efeito da espada Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-2-vorpal',
  'name': 'Espada Curta +2 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:37.887-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-2-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-3',
  'name': 'Espada Curta +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:37.987-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-3-da-cura',
  'name': 'Espada Curta +3 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:38.082-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'espada estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-3-da-luz',
  'name': 'Espada Curta +3 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:38.173-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-3-da-respiracao',
  'name': 'Espada Curta +3 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:38.262-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-3-da-velocidade',
  'name': 'Espada Curta +3 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:38.347-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma espada '
                 'de Drenar Energia possui 1d6+6 cargas e pode drenar 1d4+4 '
                 'níveis/dados de vida. Uma vez que esgote as cargas, ela '
                 'perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-3-de-drenar-energia',
  'name': 'Espada Curta +3 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:38.435-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-3-defensora',
  'name': 'Espada Curta +3 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:38.528-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da espada desejar, faz com '
                 'que a lâmina da espada arda coberta por chamas mágicas, como '
                 'se fosse uma tocha. Suas chamas causam um dano extra de 1d6 '
                 'ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma espada flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'espada flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-3-flamejante',
  'name': 'Espada Curta +3 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:38.621-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da espada deseje, faz '
                 'com que a lâmina da espada congele ao menor toque. Seu frio '
                 'causa um dano extra de 1d6 ao atingir uma criatura que tenha '
                 'o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma espada gélida não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-3-gelida',
  'name': 'Espada Curta +3 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:38.713-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+4 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-3-matadora-de-dragoes',
  'name': 'Espada Curta +3 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:38.801-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+4 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-3-matadora-de-extraplanares',
  'name': 'Espada Curta +3 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:38.892-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+4 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-3-matadora-de-gigantes',
  'name': 'Espada Curta +3 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:38.978-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+4 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-3-matadora-de-licantropos',
  'name': 'Espada Curta +3 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:39.066-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+4 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-3-matadora-de-mortos-vivos',
  'name': 'Espada Curta +3 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:39.158-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+4 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-3-matadora-de-orcs',
  'name': 'Espada Curta +3 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:39.252-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+4 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-3-matadora-de-regeneradores',
  'name': 'Espada Curta +3 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:39.336-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+4 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-3-matadora-de-usuarios-de-magia',
  'name': 'Espada Curta +3 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:39.419-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma espada Vorpal.\r\n'
                 '\r\n'
                 'O efeito da espada Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-3-vorpal',
  'name': 'Espada Curta +3 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:39.514-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-3-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-4',
  'name': 'Espada Curta +4',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:39.600-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-4-da-cura',
  'name': 'Espada Curta +4 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:39.688-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'espada estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-4-da-luz',
  'name': 'Espada Curta +4 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:39.780-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-4-da-respiracao',
  'name': 'Espada Curta +4 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:39.869-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-4-da-velocidade',
  'name': 'Espada Curta +4 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:39.959-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma espada '
                 'de Drenar Energia possui 1d6+6 cargas e pode drenar 1d4+4 '
                 'níveis/dados de vida. Uma vez que esgote as cargas, ela '
                 'perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-4-de-drenar-energia',
  'name': 'Espada Curta +4 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:40.060-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-4-defensora',
  'name': 'Espada Curta +4 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:40.155-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da espada desejar, faz com '
                 'que a lâmina da espada arda coberta por chamas mágicas, como '
                 'se fosse uma tocha. Suas chamas causam um dano extra de 1d6 '
                 'ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma espada flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'espada flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-4-flamejante',
  'name': 'Espada Curta +4 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:40.249-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da espada deseje, faz '
                 'com que a lâmina da espada congele ao menor toque. Seu frio '
                 'causa um dano extra de 1d6 ao atingir uma criatura que tenha '
                 'o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma espada gélida não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-4-gelida',
  'name': 'Espada Curta +4 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:40.346-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+5 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-4-matadora-de-dragoes',
  'name': 'Espada Curta +4 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:40.450-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+5 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-4-matadora-de-extraplanares',
  'name': 'Espada Curta +4 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:40.549-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+5 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-4-matadora-de-gigantes',
  'name': 'Espada Curta +4 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:40.640-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+5 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-4-matadora-de-licantropos',
  'name': 'Espada Curta +4 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:40.740-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+5 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-4-matadora-de-mortos-vivos',
  'name': 'Espada Curta +4 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:40.827-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+5 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-4-matadora-de-orcs',
  'name': 'Espada Curta +4 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:40.920-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+5 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-4-matadora-de-regeneradores',
  'name': 'Espada Curta +4 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:41.008-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+5 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-4-matadora-de-usuarios-de-magia',
  'name': 'Espada Curta +4 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:41.102-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma espada Vorpal.\r\n'
                 '\r\n'
                 'O efeito da espada Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-4-vorpal',
  'name': 'Espada Curta +4 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:41.210-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-4-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-5',
  'name': 'Espada Curta +5',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:41.298-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-5-da-cura',
  'name': 'Espada Curta +5 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:41.393-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'espada estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-5-da-luz',
  'name': 'Espada Curta +5 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:41.497-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-5-da-respiracao',
  'name': 'Espada Curta +5 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:41.594-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-5-da-velocidade',
  'name': 'Espada Curta +5 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:41.682-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma espada '
                 'de Drenar Energia possui 1d6+6 cargas e pode drenar 1d4+4 '
                 'níveis/dados de vida. Uma vez que esgote as cargas, ela '
                 'perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-5-de-drenar-energia',
  'name': 'Espada Curta +5 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:41.784-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-5-defensora',
  'name': 'Espada Curta +5 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:41.878-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da espada desejar, faz com '
                 'que a lâmina da espada arda coberta por chamas mágicas, como '
                 'se fosse uma tocha. Suas chamas causam um dano extra de 1d6 '
                 'ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma espada flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'espada flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-5-flamejante',
  'name': 'Espada Curta +5 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:41.968-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da espada deseje, faz '
                 'com que a lâmina da espada congele ao menor toque. Seu frio '
                 'causa um dano extra de 1d6 ao atingir uma criatura que tenha '
                 'o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma espada gélida não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-5-gelida',
  'name': 'Espada Curta +5 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:42.064-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+6 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-5-matadora-de-dragoes',
  'name': 'Espada Curta +5 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:42.164-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+6 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-5-matadora-de-extraplanares',
  'name': 'Espada Curta +5 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:42.254-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+6 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-5-matadora-de-gigantes',
  'name': 'Espada Curta +5 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:42.350-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+6 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-5-matadora-de-licantropos',
  'name': 'Espada Curta +5 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:42.445-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+6 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-5-matadora-de-mortos-vivos',
  'name': 'Espada Curta +5 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:42.545-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+6 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-mais-5-matadora-de-orcs',
  'name': 'Espada Curta +5 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:42.643-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+6 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-5-matadora-de-regeneradores',
  'name': 'Espada Curta +5 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:42.796-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n\r\n+6 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-5-matadora-de-usuarios-de-magia',
  'name': 'Espada Curta +5 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:42.884-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma espada Vorpal.\r\n'
                 '\r\n'
                 'O efeito da espada Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-curta-mais-5-vorpal',
  'name': 'Espada Curta +5 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:42.972-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-mais-5-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-menos-1-amaldicoada',
  'name': 'Espada Curta -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:34.490-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-curta-menos-2-amaldicoada',
  'name': 'Espada Curta -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:34.581-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-curta-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 3000,
  'damage': '2d4',
  'description': 'Média, Cortante, Sangrenta (um resultado 19 no ataque com '
                 'esta arma também é considerado como um acerto crítico para '
                 'todos os efeitos).',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao.json',
              'page': 306},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao-od2.json',
              'page': None}],
  'id': 'espada-kundur',
  'name': 'Espada Kundur',
  'type': 'Equipment',
  'updated_at': '2024-05-26T21:58:40.433-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-kundur.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 1000,
  'damage': '1d8',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'espada-longa',
  'name': 'Espada Longa',
  'picture': 'https://public.olddragon.com.br/pq4cnk6uxn0ngj86py1enbj54e3y',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:42.722-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 160},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-1',
  'name': 'Espada Longa +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:43.432-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-1-da-cura',
  'name': 'Espada Longa +1 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:43.538-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'espada estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-1-da-luz',
  'name': 'Espada Longa +1 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:43.626-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Ao realizar um acerto crítico, paralisa o alvo por uma '
                 'rodada. Em uma falha crítica, o portador é paralisado por '
                 'uma rodada.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 13}],
  'id': 'espada-longa-mais-1-da-paralisia-caotica',
  'name': 'Espada Longa +1 da Paralisia (Caótica)',
  'type': 'Equipment',
  'updated_at': '2025-01-29T22:56:27.843-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-da-paralisia-caotica.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-1-da-respiracao',
  'name': 'Espada Longa +1 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:43.718-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-1-da-velocidade',
  'name': 'Espada Longa +1 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:43.804-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma espada '
                 'de Drenar Energia possui 1d6+6 cargas e pode drenar 1d4+4 '
                 'níveis/dados de vida. Uma vez que esgote as cargas, ela '
                 'perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-1-de-drenar-energia',
  'name': 'Espada Longa +1 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:43.888-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-1-defensora',
  'name': 'Espada Longa +1 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:43.979-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da espada desejar, faz com '
                 'que a lâmina da espada arda coberta por chamas mágicas, como '
                 'se fosse uma tocha. Suas chamas causam um dano extra de 1d6 '
                 'ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma espada flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'espada flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-1-flamejante',
  'name': 'Espada Longa +1 Flamejante',
  'picture': 'https://public.olddragon.com.br/wgp24ytqzutzpt0g03cdwcei1pbo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:46.573-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da espada deseje, faz '
                 'com que a lâmina da espada congele ao menor toque. Seu frio '
                 'causa um dano extra de 1d6 ao atingir uma criatura que tenha '
                 'o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma espada gélida não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-1-gelida',
  'name': 'Espada Longa +1 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:45.806-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+2 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-1-matadora-de-dragoes',
  'name': 'Espada Longa +1 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:45.893-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+2 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-1-matadora-de-extraplanares',
  'name': 'Espada Longa +1 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:45.985-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+2 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-1-matadora-de-gigantes',
  'name': 'Espada Longa +1 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:46.082-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+2 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 160},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-1-matadora-de-licantropos',
  'name': 'Espada Longa +1 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:46.196-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+2 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 160},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-1-matadora-de-mortos-vivos',
  'name': 'Espada Longa +1 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:46.318-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+2 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 160},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-1-matadora-de-orcs',
  'name': 'Espada Longa +1 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:46.465-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+2 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-1-matadora-de-regeneradores',
  'name': 'Espada Longa +1 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:46.588-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+2 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-1-matadora-de-usuarios-de-magia',
  'name': 'Espada Longa +1 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:46.696-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma espada Vorpal.\r\n'
                 '\r\n'
                 'O efeito da espada Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-1-vorpal',
  'name': 'Espada Longa +1 Vorpal',
  'picture': 'https://public.olddragon.com.br/w2h5yfziwwom65ucutp6ubr4rszs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:48.751-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-1-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 160},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-2',
  'name': 'Espada Longa +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:48.061-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-2-da-cura',
  'name': 'Espada Longa +2 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:48.172-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'espada estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-2-da-luz',
  'name': 'Espada Longa +2 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:48.261-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-2-da-respiracao',
  'name': 'Espada Longa +2 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:48.346-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-2-da-velocidade',
  'name': 'Espada Longa +2 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:48.434-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma espada '
                 'de Drenar Energia possui 1d6+6 cargas e pode drenar 1d4+4 '
                 'níveis/dados de vida. Uma vez que esgote as cargas, ela '
                 'perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-2-de-drenar-energia',
  'name': 'Espada Longa +2 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:48.520-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-2-defensora',
  'name': 'Espada Longa +2 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:48.608-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da espada desejar, faz com '
                 'que a lâmina da espada arda coberta por chamas mágicas, como '
                 'se fosse uma tocha. Suas chamas causam um dano extra de 1d6 '
                 'ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma espada flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'espada flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-2-flamejante',
  'name': 'Espada Longa +2 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:48.693-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da espada deseje, faz '
                 'com que a lâmina da espada congele ao menor toque. Seu frio '
                 'causa um dano extra de 1d6 ao atingir uma criatura que tenha '
                 'o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma espada gélida não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-2-gelida',
  'name': 'Espada Longa +2 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:48.790-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+3 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-2-matadora-de-dragoes',
  'name': 'Espada Longa +2 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:48.887-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+3 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-2-matadora-de-extraplanares',
  'name': 'Espada Longa +2 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:48.976-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+3 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-2-matadora-de-gigantes',
  'name': 'Espada Longa +2 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:49.064-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+3 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-2-matadora-de-licantropos',
  'name': 'Espada Longa +2 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:49.150-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+3 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-2-matadora-de-mortos-vivos',
  'name': 'Espada Longa +2 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:49.239-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+3 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-2-matadora-de-orcs',
  'name': 'Espada Longa +2 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:49.322-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+3 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-2-matadora-de-regeneradores',
  'name': 'Espada Longa +2 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:49.413-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+3 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-2-matadora-de-usuarios-de-magia',
  'name': 'Espada Longa +2 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:49.499-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma espada Vorpal.\r\n'
                 '\r\n'
                 'O efeito da espada Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-2-vorpal',
  'name': 'Espada Longa +2 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:49.593-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-2-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-3',
  'name': 'Espada Longa +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:49.682-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-3-da-cura',
  'name': 'Espada Longa +3 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:49.780-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'espada estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-3-da-luz',
  'name': 'Espada Longa +3 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:49.880-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-3-da-respiracao',
  'name': 'Espada Longa +3 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:49.974-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-3-da-velocidade',
  'name': 'Espada Longa +3 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:50.102-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma espada '
                 'de Drenar Energia possui 1d6+6 cargas e pode drenar 1d4+4 '
                 'níveis/dados de vida. Uma vez que esgote as cargas, ela '
                 'perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-3-de-drenar-energia',
  'name': 'Espada Longa +3 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:50.196-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-3-defensora',
  'name': 'Espada Longa +3 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:50.291-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da espada desejar, faz com '
                 'que a lâmina da espada arda coberta por chamas mágicas, como '
                 'se fosse uma tocha. Suas chamas causam um dano extra de 1d6 '
                 'ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma espada flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'espada flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-3-flamejante',
  'name': 'Espada Longa +3 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:50.393-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da espada deseje, faz '
                 'com que a lâmina da espada congele ao menor toque. Seu frio '
                 'causa um dano extra de 1d6 ao atingir uma criatura que tenha '
                 'o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma espada gélida não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-3-gelida',
  'name': 'Espada Longa +3 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:50.479-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+4 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-3-matadora-de-dragoes',
  'name': 'Espada Longa +3 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:50.574-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+4 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-3-matadora-de-extraplanares',
  'name': 'Espada Longa +3 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:50.664-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+4 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-3-matadora-de-gigantes',
  'name': 'Espada Longa +3 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:50.755-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+4 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-3-matadora-de-licantropos',
  'name': 'Espada Longa +3 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:50.857-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+4 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-3-matadora-de-mortos-vivos',
  'name': 'Espada Longa +3 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:50.946-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+4 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-3-matadora-de-orcs',
  'name': 'Espada Longa +3 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:51.041-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+4 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-3-matadora-de-regeneradores',
  'name': 'Espada Longa +3 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:51.131-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+4 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-3-matadora-de-usuarios-de-magia',
  'name': 'Espada Longa +3 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:51.219-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma espada Vorpal.\r\n'
                 '\r\n'
                 'O efeito da espada Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-3-vorpal',
  'name': 'Espada Longa +3 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:51.308-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-3-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-4',
  'name': 'Espada Longa +4',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:51.409-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-4-da-cura',
  'name': 'Espada Longa +4 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:51.537-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'espada estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-4-da-luz',
  'name': 'Espada Longa +4 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:51.625-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-4-da-respiracao',
  'name': 'Espada Longa +4 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:51.711-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-4-da-velocidade',
  'name': 'Espada Longa +4 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:51.804-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma espada '
                 'de Drenar Energia possui 1d6+6 cargas e pode drenar 1d4+4 '
                 'níveis/dados de vida. Uma vez que esgote as cargas, ela '
                 'perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-4-de-drenar-energia',
  'name': 'Espada Longa +4 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:51.896-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-4-defensora',
  'name': 'Espada Longa +4 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:51.982-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da espada desejar, faz com '
                 'que a lâmina da espada arda coberta por chamas mágicas, como '
                 'se fosse uma tocha. Suas chamas causam um dano extra de 1d6 '
                 'ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma espada flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'espada flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-4-flamejante',
  'name': 'Espada Longa +4 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:52.082-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da espada deseje, faz '
                 'com que a lâmina da espada congele ao menor toque. Seu frio '
                 'causa um dano extra de 1d6 ao atingir uma criatura que tenha '
                 'o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma espada gélida não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-4-gelida',
  'name': 'Espada Longa +4 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:52.174-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+5 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-4-matadora-de-dragoes',
  'name': 'Espada Longa +4 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:52.266-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+5 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-4-matadora-de-extraplanares',
  'name': 'Espada Longa +4 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:52.352-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+5 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-4-matadora-de-gigantes',
  'name': 'Espada Longa +4 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:52.438-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+5 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-4-matadora-de-licantropos',
  'name': 'Espada Longa +4 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:52.528-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+5 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-4-matadora-de-mortos-vivos',
  'name': 'Espada Longa +4 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:52.614-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+5 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-4-matadora-de-orcs',
  'name': 'Espada Longa +4 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:52.711-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+5 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-4-matadora-de-regeneradores',
  'name': 'Espada Longa +4 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:52.804-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+5 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-4-matadora-de-usuarios-de-magia',
  'name': 'Espada Longa +4 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:52.899-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma espada Vorpal.\r\n'
                 '\r\n'
                 'O efeito da espada Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-4-vorpal',
  'name': 'Espada Longa +4 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:52.992-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-4-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-5',
  'name': 'Espada Longa +5',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:53.081-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-5-da-cura',
  'name': 'Espada Longa +5 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:53.172-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se a '
                 'espada estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-5-da-luz',
  'name': 'Espada Longa +5 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:53.267-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-5-da-respiracao',
  'name': 'Espada Longa +5 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:53.351-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-5-da-velocidade',
  'name': 'Espada Longa +5 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:53.439-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Uma espada '
                 'de Drenar Energia possui 1d6+6 cargas e pode drenar 1d4+4 '
                 'níveis/dados de vida. Uma vez que esgote as cargas, ela '
                 'perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-5-de-drenar-energia',
  'name': 'Espada Longa +5 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:53.529-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-5-defensora',
  'name': 'Espada Longa +5 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:53.623-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador da espada desejar, faz com '
                 'que a lâmina da espada arda coberta por chamas mágicas, como '
                 'se fosse uma tocha. Suas chamas causam um dano extra de 1d6 '
                 'ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, uma espada flamejante pode ser usada como '
                 'uma tocha enquanto estiver ativada. As chamas mágicas de uma '
                 'espada flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-5-flamejante',
  'name': 'Espada Longa +5 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:53.716-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador da espada deseje, faz '
                 'com que a lâmina da espada congele ao menor toque. Seu frio '
                 'causa um dano extra de 1d6 ao atingir uma criatura que tenha '
                 'o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de uma espada gélida não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-5-gelida',
  'name': 'Espada Longa +5 Gélida',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:53.823-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5-gelida.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+6 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-5-matadora-de-dragoes',
  'name': 'Espada Longa +5 Matadora de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:53.919-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5-matadora-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+6 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-5-matadora-de-extraplanares',
  'name': 'Espada Longa +5 Matadora de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:54.020-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5-matadora-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+6 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-5-matadora-de-gigantes',
  'name': 'Espada Longa +5 Matadora de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:54.130-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5-matadora-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+6 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-5-matadora-de-licantropos',
  'name': 'Espada Longa +5 Matadora de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:54.237-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5-matadora-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+6 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-5-matadora-de-mortos-vivos',
  'name': 'Espada Longa +5 Matadora de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:54.330-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5-matadora-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+6 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-mais-5-matadora-de-orcs',
  'name': 'Espada Longa +5 Matadora de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:54.425-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5-matadora-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+6 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-5-matadora-de-regeneradores',
  'name': 'Espada Longa +5 Matadora de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:54.517-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5-matadora-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+6 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-5-matadora-de-usuarios-de-magia',
  'name': 'Espada Longa +5 Matadora de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:54.624-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5-matadora-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'É magicamente afiada e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por uma espada Vorpal.\r\n'
                 '\r\n'
                 'O efeito da espada Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'espada-longa-mais-5-vorpal',
  'name': 'Espada Longa +5 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:54.717-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-mais-5-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 160},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-menos-1-amaldicoada',
  'name': 'Espada Longa -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:43.216-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'espada-longa-menos-2-amaldicoada',
  'name': 'Espada Longa -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:43.332-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-longa-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante.\r\n'
                 '\r\n'
                 'Esta espada possui lâmina de prata. Ataques feitos com essa '
                 'espada, são fáceis contra licantropos e lobos, causando '
                 'também 1d4 de dano extra contra essas criaturas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 13}],
  'id': 'espada-lupicida',
  'name': 'Espada Lupicida',
  'type': 'Equipment',
  'updated_at': '2025-03-06T23:40:36.014-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espada-lupicida.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 700,
  'damage': None,
  'description': 'Superfície de metal polido do tamanho da palma da mão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'espelho',
  'name': 'Espelho',
  'picture': 'https://public.olddragon.com.br/o6na5xggkp0ophv72myhmqylyse8',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:04.759-03:00',
  'url': 'https://olddragon.com.br/equipamentos/espelho.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'misc',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 102}],
  'id': 'estatueta-de-pedra-de-um-deus-simbolo-sagrado',
  'name': 'Estatueta de Pedra de um Deus (símbolo sagrado)',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:28.950-03:00',
  'url': 'https://olddragon.com.br/equipamentos/estatueta-de-pedra-de-um-deus-simbolo-sagrado.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Pílulas feitas a partir do Extrato de Mandra, uma raiz com '
                 'propriedades curativas.\r\n'
                 '\r\n'
                 'Cada dose cura instantaneamente 4d6 PV, além de servir como '
                 'antídoto universal, curar doenças e regenerar membros '
                 'decepados ou ossos quebrados.\r\n'
                 '\r\n'
                 'No entanto, o extrato é altamente viciante e seu uso '
                 'prolongado pode causar sérios danos mentais.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday17.json',
              'page': 5}],
  'id': 'extrato-de-mandra',
  'name': 'Extrato de Mandra',
  'type': 'Equipment',
  'updated_at': '2025-04-24T19:13:28.110-03:00',
  'url': 'https://olddragon.com.br/equipamentos/extrato-de-mandra.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'weapon',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 104}],
  'id': 'femur-humano',
  'name': 'Fêmur Humano',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:36.447-03:00',
  'url': 'https://olddragon.com.br/equipamentos/femur-humano.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 2500,
  'damage': None,
  'description': 'Chave, pinça, martelo e serra para arrombar e desarmar '
                 'armadilhas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'ferramentas-de-ladrao',
  'name': 'Ferramentas de Ladrão',
  'picture': 'https://public.olddragon.com.br/lp9vqh3julrlpa6ojqwom9lbid3m',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:08.267-03:00',
  'url': 'https://olddragon.com.br/equipamentos/ferramentas-de-ladrao.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'misc',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 102}],
  'id': 'ferramentas-de-ladrao-feita-de-pequenos-ossos',
  'name': 'Ferramentas de Ladrão (feita de pequenos ossos)',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:29.807-03:00',
  'url': 'https://olddragon.com.br/equipamentos/ferramentas-de-ladrao-feita-de-pequenos-ossos.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 10,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'flecha-de-caca',
  'name': 'Flecha de Caça',
  'picture': 'https://public.olddragon.com.br/1yr0efnqyd7sc860c4wwy43ygjor',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:41.151-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 160},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-caca-mais-1',
  'name': 'Flecha de Caça +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:55.180-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.\r\n'
                 '\r\n'
                 'Este projétil explode ao tocar o alvo causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-caca-mais-1-da-explosao',
  'name': 'Flecha de Caça +1 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:55.303-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca-mais-1-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-caca-mais-1-do-atordoamento',
  'name': 'Flecha de Caça +1 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:55.409-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca-mais-1-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-caca-mais-1-do-desarme',
  'name': 'Flecha de Caça +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:55.511-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.\r\n'
                 '\r\n'
                 'Este projétil é extremamente poderoso e ignora qualquer tipo '
                 'de proteção ou cobertura, passando por pessoas, móveis, '
                 'folhagens, teia ou qualquer outra barreira menos maciça que '
                 'uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-caca-mais-1-penetrante',
  'name': 'Flecha de Caça +1 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:55.607-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca-mais-1-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-caca-mais-2',
  'name': 'Flecha de Caça +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:55.706-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.\r\n'
                 '\r\n'
                 'Este projétil explode ao tocar o alvo causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-caca-mais-2-da-explosao',
  'name': 'Flecha de Caça +2 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:55.792-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca-mais-2-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-caca-mais-2-do-atordoamento',
  'name': 'Flecha de Caça +2 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:55.892-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca-mais-2-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-caca-mais-2-do-desarme',
  'name': 'Flecha de Caça +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:55.987-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.\r\n'
                 '\r\n'
                 'Este projétil é extremamente poderoso e ignora qualquer tipo '
                 'de proteção ou cobertura, passando por pessoas, móveis, '
                 'folhagens, teia ou qualquer outra barreira menos maciça que '
                 'uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-caca-mais-2-penetrante',
  'name': 'Flecha de Caça +2 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:56.084-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca-mais-2-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-caca-mais-3',
  'name': 'Flecha de Caça +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:56.181-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.\r\n'
                 '\r\n'
                 'Este projétil explode ao tocar o alvo causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-caca-mais-3-da-explosao',
  'name': 'Flecha de Caça +3 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:56.284-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca-mais-3-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-caca-mais-3-do-atordoamento',
  'name': 'Flecha de Caça +3 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:56.384-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca-mais-3-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-caca-mais-3-do-desarme',
  'name': 'Flecha de Caça +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:56.479-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.\r\n'
                 '\r\n'
                 'Este projétil é extremamente poderoso e ignora qualquer tipo '
                 'de proteção ou cobertura, passando por pessoas, móveis, '
                 'folhagens, teia ou qualquer outra barreira menos maciça que '
                 'uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-caca-mais-3-penetrante',
  'name': 'Flecha de Caça +3 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:56.576-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca-mais-3-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-caca-menos-1-amaldicoada',
  'name': 'Flecha de Caça -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:54.958-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante, Madeira. Peso e preço pelo conjunto de 20 '
                 'unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-caca-menos-2-amaldicoada',
  'name': 'Flecha de Caça -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:55.061-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-caca-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 100,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'flecha-de-guerra',
  'name': 'Flecha de Guerra',
  'picture': 'https://public.olddragon.com.br/lo9ah0thyn6lxawku7zqbktjxwdz',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:18.407-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 160},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-guerra-mais-1',
  'name': 'Flecha de Guerra +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:56.993-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil explode ao tocar o alvo causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-guerra-mais-1-da-explosao',
  'name': 'Flecha de Guerra +1 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:57.105-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra-mais-1-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-guerra-mais-1-do-atordoamento',
  'name': 'Flecha de Guerra +1 do Atordoamento',
  'picture': 'https://public.olddragon.com.br/jj6czb928ce6xf2n1baqfi1v704s',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:59.784-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra-mais-1-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-guerra-mais-1-do-desarme',
  'name': 'Flecha de Guerra +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:59.058-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil é extremamente poderoso e ignora qualquer tipo '
                 'de proteção ou cobertura, passando por pessoas, móveis, '
                 'folhagens, teia ou qualquer outra barreira menos maciça que '
                 'uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-guerra-mais-1-penetrante',
  'name': 'Flecha de Guerra +1 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:59.154-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra-mais-1-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-guerra-mais-2',
  'name': 'Flecha de Guerra +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:59.252-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil explode ao tocar o alvo causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-guerra-mais-2-da-explosao',
  'name': 'Flecha de Guerra +2 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:59.342-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra-mais-2-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-guerra-mais-2-do-atordoamento',
  'name': 'Flecha de Guerra +2 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:59.458-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra-mais-2-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-guerra-mais-2-do-desarme',
  'name': 'Flecha de Guerra +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:59.565-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil é extremamente poderoso e ignora qualquer tipo '
                 'de proteção ou cobertura, passando por pessoas, móveis, '
                 'folhagens, teia ou qualquer outra barreira menos maciça que '
                 'uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-guerra-mais-2-penetrante',
  'name': 'Flecha de Guerra +2 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:59.694-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra-mais-2-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-guerra-mais-3',
  'name': 'Flecha de Guerra +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:59.782-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil explode ao tocar o alvo causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-guerra-mais-3-da-explosao',
  'name': 'Flecha de Guerra +3 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:59.871-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra-mais-3-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-guerra-mais-3-do-atordoamento',
  'name': 'Flecha de Guerra +3 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:59.964-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra-mais-3-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-guerra-mais-3-do-desarme',
  'name': 'Flecha de Guerra +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:00.193-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil é extremamente poderoso e ignora qualquer tipo '
                 'de proteção ou cobertura, passando por pessoas, móveis, '
                 'folhagens, teia ou qualquer outra barreira menos maciça que '
                 'uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-guerra-mais-3-penetrante',
  'name': 'Flecha de Guerra +3 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:00.406-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra-mais-3-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-guerra-menos-1-amaldicoada',
  'name': 'Flecha de Guerra -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:56.793-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'flecha-de-guerra-menos-2-amaldicoada',
  'name': 'Flecha de Guerra -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:56.887-03:00',
  'url': 'https://olddragon.com.br/equipamentos/flecha-de-guerra-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 50,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27).',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'funda',
  'name': 'Funda',
  'picture': 'https://public.olddragon.com.br/9e7hr0xuxv66b7j59tz0kjwmr6vy',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:10.817-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'limited',
  'concept': 'weapon',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 104}],
  'id': 'funda-de-tripas',
  'name': 'Funda de Tripas',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:45.156-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-de-tripas.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27)',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'funda-mais-1',
  'name': 'Funda +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:00.962-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27).\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma explode ao tocar o alvo '
                 'causando 1d6 de dano extra a todos em até 1d4 metros de '
                 'distância do local da explosão. O atacante não é atingido '
                 'pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'funda-mais-1-da-explosao',
  'name': 'Funda +1 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:01.052-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-mais-1-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27).\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'funda-mais-1-do-atordoamento',
  'name': 'Funda +1 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:01.150-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-mais-1-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27).\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'funda-mais-1-do-desarme',
  'name': 'Funda +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:01.251-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27).\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma é extremamente poderoso e '
                 'ignora qualquer tipo de proteção ou cobertura, passando por '
                 'pessoas, móveis, folhagens, teia ou qualquer outra barreira '
                 'menos maciça que uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'funda-mais-1-penetrante',
  'name': 'Funda +1 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:01.341-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-mais-1-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27)',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'funda-mais-2',
  'name': 'Funda +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:01.430-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27).\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma explode ao tocar o alvo '
                 'causando 1d6 de dano extra a todos em até 1d4 metros de '
                 'distância do local da explosão. O atacante não é atingido '
                 'pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'funda-mais-2-da-explosao',
  'name': 'Funda +2 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:01.524-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-mais-2-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27).\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'funda-mais-2-do-atordoamento',
  'name': 'Funda +2 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:01.619-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-mais-2-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27).\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'funda-mais-2-do-desarme',
  'name': 'Funda +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:01.707-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27).\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma é extremamente poderoso e '
                 'ignora qualquer tipo de proteção ou cobertura, passando por '
                 'pessoas, móveis, folhagens, teia ou qualquer outra barreira '
                 'menos maciça que uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'funda-mais-2-penetrante',
  'name': 'Funda +2 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:01.800-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-mais-2-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27)',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'funda-mais-3',
  'name': 'Funda +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:01.900-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27).\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma explode ao tocar o alvo '
                 'causando 1d6 de dano extra a todos em até 1d4 metros de '
                 'distância do local da explosão. O atacante não é atingido '
                 'pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'funda-mais-3-da-explosao',
  'name': 'Funda +3 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:01.995-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-mais-3-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27).\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'funda-mais-3-do-atordoamento',
  'name': 'Funda +3 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:02.095-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-mais-3-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27).\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'funda-mais-3-do-desarme',
  'name': 'Funda +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:02.193-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27).\r\n'
                 '\r\n'
                 'O projétil disparado por esta arma é extremamente poderoso e '
                 'ignora qualquer tipo de proteção ou cobertura, passando por '
                 'pessoas, móveis, folhagens, teia ou qualquer outra barreira '
                 'menos maciça que uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'funda-mais-3-penetrante',
  'name': 'Funda +3 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:02.339-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-mais-3-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27)',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'funda-menos-1-amaldicoada',
  'name': 'Funda -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:00.745-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Impactante, Arremesso (27)',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'funda-menos-2-amaldicoada',
  'name': 'Funda -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:00.854-03:00',
  'url': 'https://olddragon.com.br/equipamentos/funda-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'limited',
  'concept': 'misc',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 102}],
  'id': 'ganchos-de-pedra',
  'name': 'Ganchos de Pedra',
  'type': 'Equipment',
  'updated_at': '2025-04-09T12:18:16.350-03:00',
  'url': 'https://olddragon.com.br/equipamentos/ganchos-de-pedra.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este item famoso pelas lendas é, na verdade, uma grande '
                 'garrafa de vidro colorido, adornada com pedras preciosas e '
                 'lacrada por uma grossa e resistente rolha, protegida por um '
                 'selo mágico. Para ser aberta, é preciso romper o selo.\r\n'
                 '\r\n'
                 'Neste momento, um Efreeti surgirá de dentro da garrafa para '
                 'servir ao seu amo e libertador pelos próximos 101 dias ou '
                 'até que seja morto.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 126}],
  'id': 'garrafa-do-genio',
  'name': 'Garrafa do Gênio',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:47.373-03:00',
  'url': 'https://olddragon.com.br/equipamentos/garrafa-do-genio.json',
  'weight_in_grams': 400,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'armor',
  'cost': 4000,
  'damage': None,
  'description': 'Leve, Couro, Antifuro (esta armadura possui proteção '
                 'adicional de +1 contra ataques realizados com o uso de armas '
                 'perfurantes).',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao.json',
              'page': 306},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao-od2.json',
              'page': None}],
  'id': 'gibao-iboniano',
  'name': 'Gibão Iboniano',
  'type': 'Equipment',
  'updated_at': '2024-05-26T21:58:41.519-03:00',
  'url': 'https://olddragon.com.br/equipamentos/gibao-iboniano.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 200,
  'damage': None,
  'description': 'Na cor branca para marcações.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'giz',
  'name': 'Giz',
  'picture': 'https://public.olddragon.com.br/01s685i9a7i0w6l29nljv91qbrzf',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:58.770-03:00',
  'url': 'https://olddragon.com.br/equipamentos/giz.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Objeto redondo metálico que armazena energia mágica que '
                 'explode ao sofrer um impacto forte.\r\n'
                 '\r\n'
                 'Ao ser arremessada, causa 1d8 de dano em todas as criaturas '
                 'num raio de 3m ao redor do local que explodiu.\r\n'
                 '\r\n'
                 'Os alvos podem fazer uma JPD para reduzir o dano pela '
                 'metade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 13}],
  'id': 'granada-magica',
  'name': 'Granada Mágica',
  'type': 'Equipment',
  'updated_at': '2025-01-29T22:55:59.165-03:00',
  'url': 'https://olddragon.com.br/equipamentos/granada-magica.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este livro compila uma série de segredos e conhecimentos '
                 'místicos e fantásticos, ideais para Magos e outros usuários '
                 'de magias arcanas ampliarem seus conhecimentos.\r\n'
                 '\r\n'
                 'Ao ler o Grande Livro da Conjuração, tarefa que pode ser '
                 'realizada em uma semana de estudos diários, um Mago recebe '
                 'permanentemente a capacidade de Memorizar Magia como se '
                 'tivesse um nível a mais do que realmente tem. Desta forma, '
                 'um Mago de 3º nível que leia o Grande Livro da Conjuração '
                 'memorizaria 2 magias de 1º Círculo e 2 magias de 2º Círculo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 126}],
  'id': 'grande-livro-da-conjuracao',
  'name': 'Grande Livro da Conjuração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:47.532-03:00',
  'url': 'https://olddragon.com.br/equipamentos/grande-livro-da-conjuracao.json',
  'weight_in_grams': 2000,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'armor',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 54}],
  'id': 'grevas',
  'name': 'Grevas',
  'type': 'Equipment',
  'updated_at': '2025-02-15T23:31:18.356-03:00',
  'url': 'https://olddragon.com.br/equipamentos/grevas.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 2500,
  'damage': None,
  'description': 'Livro em branco de capa de couro e 128 folhas de papel.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'grimorio',
  'name': 'Grimório',
  'picture': 'https://public.olddragon.com.br/jq73tv0yrj3xg8gluobwmtr018hb',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:26.445-03:00',
  'url': 'https://olddragon.com.br/equipamentos/grimorio.json',
  'weight_in_grams': 1000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'vehicle',
  'cost': 3000,
  'damage': None,
  'description': 'Para tração ou montaria. Carrega até 2.000 moedas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'jumento-ou-mula',
  'name': 'Jumento ou Mula',
  'type': 'Equipment',
  'updated_at': '2023-05-31T22:00:15.547-03:00',
  'url': 'https://olddragon.com.br/equipamentos/jumento-ou-mula.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'kit',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-jogador.json',
              'page': 18}],
  'id': 'kit-basico',
  'name': 'Kit Básico',
  'type': 'Equipment',
  'updated_at': '2023-11-08T00:35:17.862-03:00',
  'url': 'https://olddragon.com.br/equipamentos/kit-basico.json'},
 {'access': 'limited',
  'concept': 'kit',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-jogador.json',
              'page': 18}],
  'id': 'kit-cavaleiro',
  'name': 'Kit Cavaleiro',
  'type': 'Equipment',
  'updated_at': '2023-11-08T00:35:17.960-03:00',
  'url': 'https://olddragon.com.br/equipamentos/kit-cavaleiro.json'},
 {'access': 'limited',
  'concept': 'kit',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-jogador.json',
              'page': 18}],
  'id': 'kit-ermos',
  'name': 'Kit Ermos',
  'type': 'Equipment',
  'updated_at': '2023-11-08T00:35:17.936-03:00',
  'url': 'https://olddragon.com.br/equipamentos/kit-ermos.json'},
 {'access': 'limited',
  'concept': 'kit',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-jogador.json',
              'page': 18}],
  'id': 'kit-guerreiro-atirador',
  'name': 'Kit Guerreiro Atirador',
  'type': 'Equipment',
  'updated_at': '2023-11-08T00:35:18.005-03:00',
  'url': 'https://olddragon.com.br/equipamentos/kit-guerreiro-atirador.json'},
 {'access': 'limited',
  'concept': 'kit',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-jogador.json',
              'page': 18}],
  'id': 'kit-guerreiro-de-batalha',
  'name': 'Kit Guerreiro de Batalha',
  'type': 'Equipment',
  'updated_at': '2023-11-08T00:35:17.985-03:00',
  'url': 'https://olddragon.com.br/equipamentos/kit-guerreiro-de-batalha.json'},
 {'access': 'limited',
  'concept': 'kit',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-jogador.json',
              'page': 18}],
  'id': 'kit-ladrao',
  'name': 'Kit Ladrão',
  'type': 'Equipment',
  'updated_at': '2023-11-08T00:35:18.040-03:00',
  'url': 'https://olddragon.com.br/equipamentos/kit-ladrao.json'},
 {'access': 'limited',
  'concept': 'kit',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-jogador.json',
              'page': 18}],
  'id': 'kit-mago',
  'name': 'Kit Mago',
  'type': 'Equipment',
  'updated_at': '2023-11-08T00:35:18.057-03:00',
  'url': 'https://olddragon.com.br/equipamentos/kit-mago.json'},
 {'access': 'limited',
  'concept': 'kit',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-jogador.json',
              'page': 18}],
  'id': 'kit-masmorra',
  'name': 'Kit Masmorra',
  'type': 'Equipment',
  'updated_at': '2023-11-08T00:35:17.891-03:00',
  'url': 'https://olddragon.com.br/equipamentos/kit-masmorra.json'},
 {'access': 'limited',
  'concept': 'kit',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-jogador.json',
              'page': 18}],
  'id': 'kit-sacerdote',
  'name': 'Kit Sacerdote',
  'type': 'Equipment',
  'updated_at': '2023-11-08T00:35:18.023-03:00',
  'url': 'https://olddragon.com.br/equipamentos/kit-sacerdote.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 100,
  'damage': None,
  'description': 'Com chama protegida pelo vento. Ilumina em todas as '
                 'direções.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'lamparina',
  'name': 'Lamparina',
  'picture': 'https://public.olddragon.com.br/2m9ha1wi6k8sj2ng1vglanowebjw',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:19.069-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lamparina.json',
  'weight_in_grams': 1000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 400,
  'damage': '1d6',
  'description': 'Média, Madeira, Perfurante, Arremesso (12), Haste, Versátil, '
                 'Contrainvestida.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'lanca',
  'name': 'Lança',
  'picture': 'https://public.olddragon.com.br/pa81hn8sily2r8mbziyfo2bh560s',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:06.472-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Madeira, Perfurante, Arremesso (12), Haste, Versátil, '
                 'Contrainvestida',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-mais-1',
  'name': 'Lança +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:02.766-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 1,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Madeira, Perfurante, Arremesso (12), Haste, Versátil, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-mais-1-defensora',
  'name': 'Lança +1 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:02.856-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-mais-1-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Madeira, Perfurante, Arremesso (12), Haste, Versátil, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-mais-1-do-desarme',
  'name': 'Lança +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:02.958-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Madeira, Perfurante, Arremesso (12), Haste, Versátil, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-mais-1-do-retorno',
  'name': 'Lança +1 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:03.062-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-mais-1-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Madeira, Perfurante, Arremesso (12), Haste, Versátil, '
                 'Contrainvestida',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-mais-2',
  'name': 'Lança +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:03.155-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Madeira, Perfurante, Arremesso (12), Haste, Versátil, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-mais-2-defensora',
  'name': 'Lança +2 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:03.250-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-mais-2-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Madeira, Perfurante, Arremesso (12), Haste, Versátil, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-mais-2-do-desarme',
  'name': 'Lança +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:03.343-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Madeira, Perfurante, Arremesso (12), Haste, Versátil, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-mais-2-do-retorno',
  'name': 'Lança +2 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:03.435-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-mais-2-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Madeira, Perfurante, Arremesso (12), Haste, Versátil, '
                 'Contrainvestida',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-mais-3',
  'name': 'Lança +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:03.529-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Madeira, Perfurante, Arremesso (12), Haste, Versátil, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-mais-3-defensora',
  'name': 'Lança +3 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:03.623-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-mais-3-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Madeira, Perfurante, Arremesso (12), Haste, Versátil, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-mais-3-do-desarme',
  'name': 'Lança +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:03.713-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Madeira, Perfurante, Arremesso (12), Haste, Versátil, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-mais-3-do-retorno',
  'name': 'Lança +3 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:03.811-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-mais-3-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Madeira, Perfurante, Arremesso (12), Haste, Versátil, '
                 'Contrainvestida',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-menos-1-amaldicoada',
  'name': 'Lança -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:02.580-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Média, Madeira, Perfurante, Arremesso (12), Haste, Versátil, '
                 'Contrainvestida',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-menos-2-amaldicoada',
  'name': 'Lança -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:02.676-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 500,
  'damage': '1d8',
  'description': 'Grande, Perfurante, Haste, Duas Mãos, Montada, '
                 'Contrainvestida.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'lanca-montada',
  'name': 'Lança Montada',
  'picture': 'https://public.olddragon.com.br/n1e15lmccr9puarx5dvw53blrgnf',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:52.645-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-montada.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Perfurante, Haste, Duas Mãos, Montada, '
                 'Contrainvestida',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-montada-mais-1',
  'name': 'Lança Montada +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:04.172-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-montada-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': 1,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Perfurante, Haste, Duas Mãos, Montada, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-montada-mais-1-defensora',
  'name': 'Lança Montada +1 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:04.302-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-montada-mais-1-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Perfurante, Haste, Duas Mãos, Montada, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-montada-mais-1-do-desarme',
  'name': 'Lança Montada +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:04.398-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-montada-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Perfurante, Haste, Duas Mãos, Montada, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'Esta arma pode ser usada para vigiar um tipo específico de '
                 'monstro ou raça de personagem. Ao perceber a presença de um '
                 'membro vigiado em um raio de 18m da arma, esta vibrará '
                 'lentamente. Este talento funciona por 24 horas e o tipo de '
                 'monstro vigiado só pode ser alterado uma vez a cada dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-montada-mais-1-vigilante',
  'name': 'Lança Montada +1 Vigilante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:04.484-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-montada-mais-1-vigilante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Perfurante, Haste, Duas Mãos, Montada, '
                 'Contrainvestida',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-montada-mais-2',
  'name': 'Lança Montada +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:04.570-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-montada-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Perfurante, Haste, Duas Mãos, Montada, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-montada-mais-2-defensora',
  'name': 'Lança Montada +2 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:04.660-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-montada-mais-2-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Perfurante, Haste, Duas Mãos, Montada, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-montada-mais-2-do-desarme',
  'name': 'Lança Montada +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:04.749-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-montada-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Perfurante, Haste, Duas Mãos, Montada, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'Esta arma pode ser usada para vigiar um tipo específico de '
                 'monstro ou raça de personagem. Ao perceber a presença de um '
                 'membro vigiado em um raio de 18m da arma, esta vibrará '
                 'lentamente. Este talento funciona por 24 horas e o tipo de '
                 'monstro vigiado só pode ser alterado uma vez a cada dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-montada-mais-2-vigilante',
  'name': 'Lança Montada +2 Vigilante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:04.837-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-montada-mais-2-vigilante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Perfurante, Haste, Duas Mãos, Montada, '
                 'Contrainvestida',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-montada-mais-3',
  'name': 'Lança Montada +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:04.937-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-montada-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Perfurante, Haste, Duas Mãos, Montada, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-montada-mais-3-defensora',
  'name': 'Lança Montada +3 Defensora',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:05.031-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-montada-mais-3-defensora.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Perfurante, Haste, Duas Mãos, Montada, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-montada-mais-3-do-desarme',
  'name': 'Lança Montada +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:05.121-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-montada-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Perfurante, Haste, Duas Mãos, Montada, '
                 'Contrainvestida.\r\n'
                 '\r\n'
                 'Esta arma pode ser usada para vigiar um tipo específico de '
                 'monstro ou raça de personagem. Ao perceber a presença de um '
                 'membro vigiado em um raio de 18m da arma, esta vibrará '
                 'lentamente. Este talento funciona por 24 horas e o tipo de '
                 'monstro vigiado só pode ser alterado uma vez a cada dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-montada-mais-3-vigilante',
  'name': 'Lança Montada +3 Vigilante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:05.209-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-montada-mais-3-vigilante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Perfurante, Haste, Duas Mãos, Montada, '
                 'Contrainvestida.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-montada-menos-1-amaldicoada',
  'name': 'Lança Montada -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:03.975-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-montada-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Perfurante, Haste, Duas Mãos, Montada, '
                 'Contrainvestida.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'lanca-montada-menos-2-amaldicoada',
  'name': 'Lança Montada -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:04.071-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanca-montada-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 200,
  'damage': None,
  'description': 'Com chama protegida pelo vento. Ilumina apenas em uma '
                 'direção.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'lanterna-furta-fogo',
  'name': 'Lanterna furta-fogo',
  'picture': 'https://public.olddragon.com.br/w9w3r3441q94n1p6zkgcjku4hl5a',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:40.763-03:00',
  'url': 'https://olddragon.com.br/equipamentos/lanterna-furta-fogo.json',
  'weight_in_grams': 2000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este livro contém escrituras sagradas para Clérigos e outros '
                 'Sacerdotes. O livro, em sua essência, conta histórias '
                 'ligadas a ordem e feitos honrosos de grandes expoentes '
                 'sagrados da ordem.\r\n'
                 '\r\n'
                 'Ao estudar diariamente o Livro dos Grandes Feitos durante '
                 'uma semana, um Clérigo recebe permanentemente um ponto extra '
                 'no modificador de Sabedoria e toda a experiência necessária '
                 'para chegar ao meio do caminho do próximo nível.\r\n'
                 '\r\n'
                 'Clérigos caóticos que leem um Livro dos Grandes Feitos '
                 'Ordeiro perdem um nível completamente. O mesmo ocorre com '
                 'Clérigos ordeiros que leem a versão caótica do Livro dos '
                 'Grandes Feitos.\r\n'
                 '\r\n'
                 'Clérigos neutros não recebem os benefícios e nem as '
                 'penalidades de ler qualquer uma das versões do Livro dos '
                 'Grandes Feitos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 126}],
  'id': 'livro-dos-grandes-feitos',
  'name': 'Livro dos Grandes Feitos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:47.835-03:00',
  'url': 'https://olddragon.com.br/equipamentos/livro-dos-grandes-feitos.json',
  'weight_in_grams': 2000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 600,
  'damage': '1d8',
  'description': 'Média, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'maca',
  'name': 'Maça',
  'picture': 'https://public.olddragon.com.br/u0qho2vaksy012s01bgis52d77ha',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:20.465-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'maca-mais-1',
  'name': 'Maça +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:05.552-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Impactante.\r\n'
                 '\r\n'
                 'Esta arma explode ao atingir o alvo, causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'maca-mais-1-da-explosao',
  'name': 'Maça +1 da Explosão',
  'picture': 'https://public.olddragon.com.br/ei1j1ak8a7cuphn10j27yjg2bfli',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:08.105-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca-mais-1-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Impactante.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'maca-mais-1-do-desarme',
  'name': 'Maça +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:07.265-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Impactante.\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'maca-mais-1-do-retorno',
  'name': 'Maça +1 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:07.353-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca-mais-1-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Impactante.\r\n'
                 '\r\n'
                 'Como a magia de mesmo nome, o usuário da arma recebe o poder '
                 'de voar, com deslocamento de 36m por turno, na direção ou '
                 'orientação desejada por até 3 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'maca-mais-1-do-voo',
  'name': 'Maça +1 do Voo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:07.442-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca-mais-1-do-voo.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'maca-mais-2',
  'name': 'Maça +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:07.527-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Impactante.\r\n'
                 '\r\n'
                 'Esta arma explode ao atingir o alvo, causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'maca-mais-2-da-explosao',
  'name': 'Maça +2 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:07.623-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca-mais-2-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Impactante.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'maca-mais-2-do-desarme',
  'name': 'Maça +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:07.712-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Impactante.\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'maca-mais-2-do-retorno',
  'name': 'Maça +2 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:07.807-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca-mais-2-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Impactante.\r\n'
                 '\r\n'
                 'Como a magia de mesmo nome, o usuário da arma recebe o poder '
                 'de voar, com deslocamento de 36m por turno, na direção ou '
                 'orientação desejada por até 3 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'maca-mais-2-do-voo',
  'name': 'Maça +2 do Voo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:07.893-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca-mais-2-do-voo.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'maca-mais-3',
  'name': 'Maça +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:07.986-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Impactante.\r\n'
                 '\r\n'
                 'Esta arma explode ao atingir o alvo, causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'maca-mais-3-da-explosao',
  'name': 'Maça +3 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:08.073-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca-mais-3-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Impactante.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'maca-mais-3-do-desarme',
  'name': 'Maça +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:08.160-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Impactante.\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'maca-mais-3-do-retorno',
  'name': 'Maça +3 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:08.256-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca-mais-3-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Impactante.\r\n'
                 '\r\n'
                 'Como a magia de mesmo nome, o usuário da arma recebe o poder '
                 'de voar, com deslocamento de 36m por turno, na direção ou '
                 'orientação desejada por até 3 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'maca-mais-3-do-voo',
  'name': 'Maça +3 do Voo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:08.342-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca-mais-3-do-voo.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'maca-menos-1-amaldicoada',
  'name': 'Maça -1 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:05.367-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca-menos-1-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'maca-menos-2-amaldicoada',
  'name': 'Maça -2 Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:05.460-03:00',
  'url': 'https://olddragon.com.br/equipamentos/maca-menos-2-amaldicoada.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 600,
  'damage': '1d8',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'machado',
  'name': 'Machado',
  'picture': 'https://public.olddragon.com.br/ntc1cldiqr36jf9teevyfuklrxyr',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:05.745-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9)',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-1',
  'name': 'Machado de Arremesso +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:11.051-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n'
                 '\r\n'
                 'Esta arma afiada é balanceada para permitir mais acertos '
                 'críticos que o normal. Esta arma precisa de um resultado de '
                 '19 ou 20 no d20 para atingir o alvo com um acerto crítico, '
                 'causando a ele dano dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-1-critico',
  'name': 'Machado de Arremesso +1 Crítico',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:11.138-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-1-critico.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 1 ano '
                 'biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-1-da-velocidade',
  'name': 'Machado de Arremesso +1 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:11.236-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-1-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9), Arremesso (9).\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-1-do-retorno',
  'name': 'Machado de Arremesso +1 do Retorno',
  'picture': 'https://public.olddragon.com.br/fcukxg55sbj26ck5n0iiozoq5pes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:13.401-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-1-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n\r\n+2 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-1-matador-de-gigantes',
  'name': 'Machado de Arremesso +1 Matador de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:12.529-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-1-matador-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n'
                 '\r\n'
                 '+2 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-1-matador-de-mortos-vivos',
  'name': 'Machado de Arremesso +1 Matador de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:12.634-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-1-matador-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n\r\n+2 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-1-matador-de-orcs',
  'name': 'Machado de Arremesso +1 Matador de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:12.725-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-1-matador-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n'
                 '\r\n'
                 '+2 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-1-matador-de-usuarios-de-magia',
  'name': 'Machado de Arremesso +1 Matador de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:12.817-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-1-matador-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9)',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-2',
  'name': 'Machado de Arremesso +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:12.907-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n'
                 '\r\n'
                 'Esta arma afiada é balanceada para permitir mais acertos '
                 'críticos que o normal. Esta arma precisa de um resultado de '
                 '19 ou 20 no d20 para atingir o alvo com um acerto crítico, '
                 'causando a ele dano dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-2-critico',
  'name': 'Machado de Arremesso +2 Crítico',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:12.996-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-2-critico.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 1 ano '
                 'biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-2-da-velocidade',
  'name': 'Machado de Arremesso +2 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:13.084-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-2-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9), Arremesso (9).\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-2-do-retorno',
  'name': 'Machado de Arremesso +2 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:13.176-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-2-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n\r\n+3 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-2-matador-de-gigantes',
  'name': 'Machado de Arremesso +2 Matador de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:13.275-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-2-matador-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n'
                 '\r\n'
                 '+3 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-2-matador-de-mortos-vivos',
  'name': 'Machado de Arremesso +2 Matador de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:13.367-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-2-matador-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n\r\n+3 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-2-matador-de-orcs',
  'name': 'Machado de Arremesso +2 Matador de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:13.454-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-2-matador-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n'
                 '\r\n'
                 '+3 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-2-matador-de-usuarios-de-magia',
  'name': 'Machado de Arremesso +2 Matador de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:13.541-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-2-matador-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9)',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-3',
  'name': 'Machado de Arremesso +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:13.628-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n'
                 '\r\n'
                 'Esta arma afiada é balanceada para permitir mais acertos '
                 'críticos que o normal. Esta arma precisa de um resultado de '
                 '19 ou 20 no d20 para atingir o alvo com um acerto crítico, '
                 'causando a ele dano dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-3-critico',
  'name': 'Machado de Arremesso +3 Crítico',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:13.716-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-3-critico.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 1 ano '
                 'biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-3-da-velocidade',
  'name': 'Machado de Arremesso +3 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:13.804-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-3-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9), Arremesso (9).\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-3-do-retorno',
  'name': 'Machado de Arremesso +3 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:13.895-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-3-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n\r\n+4 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-3-matador-de-gigantes',
  'name': 'Machado de Arremesso +3 Matador de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:13.979-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-3-matador-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n'
                 '\r\n'
                 '+4 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-3-matador-de-mortos-vivos',
  'name': 'Machado de Arremesso +3 Matador de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:14.068-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-3-matador-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n\r\n+4 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-3-matador-de-orcs',
  'name': 'Machado de Arremesso +3 Matador de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:14.151-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-3-matador-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9).\r\n'
                 '\r\n'
                 '+4 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-mais-3-matador-de-usuarios-de-magia',
  'name': 'Machado de Arremesso +3 Matador de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:14.239-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-mais-3-matador-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9)',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-menos-1-amaldicoado',
  'name': 'Machado de Arremesso -1 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:10.838-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-menos-1-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Pequena, Cortante, Arremesso (9)',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-arremesso-menos-2-amaldicoado',
  'name': 'Machado de Arremesso -2 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:10.953-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-arremesso-menos-2-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 1600,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'machado-de-batalha',
  'name': 'Machado de Batalha',
  'picture': 'https://public.olddragon.com.br/4wdwz7qihmwd8zfgvw6yxg8j5odj',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:17.824-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 160},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-1',
  'name': 'Machado de Batalha +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:14.585-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Esta arma afiada é balanceada para permitir mais acertos '
                 'críticos que o normal. Esta arma precisa de um resultado de '
                 '19 ou 20 no d20 para atingir o alvo com um acerto crítico, '
                 'causando a ele dano dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-1-critico',
  'name': 'Machado de Batalha +1 Crítico',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:14.691-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-1-critico.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 1 ano '
                 'biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-1-da-velocidade',
  'name': 'Machado de Batalha +1 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:14.786-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-1-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos, Arremesso (9).\r\n'
                 '\r\n'
                 'É magicamente encantado para ter o balanço perfeito, podendo '
                 'ser arremessado além do seu uso normal em combate corpo a '
                 'corpo. O ataque de arremesso segue as mesmas regras de um '
                 'ataque à distância normal, como se estivesse sendo empunhado '
                 'pelo personagem.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-1-de-arremesso',
  'name': 'Machado de Batalha +1 de Arremesso',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:14.873-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-1-de-arremesso.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+2 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-1-matador-de-gigantes',
  'name': 'Machado de Batalha +1 Matador de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:14.962-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-1-matador-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+2 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-1-matador-de-mortos-vivos',
  'name': 'Machado de Batalha +1 Matador de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:15.059-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-1-matador-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+2 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-1-matador-de-orcs',
  'name': 'Machado de Batalha +1 Matador de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:15.150-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-1-matador-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 '+2 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-1-matador-de-usuarios-de-magia',
  'name': 'Machado de Batalha +1 Matador de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:15.247-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-1-matador-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-2',
  'name': 'Machado de Batalha +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:15.338-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Esta arma afiada é balanceada para permitir mais acertos '
                 'críticos que o normal. Esta arma precisa de um resultado de '
                 '19 ou 20 no d20 para atingir o alvo com um acerto crítico, '
                 'causando a ele dano dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-2-critico',
  'name': 'Machado de Batalha +2 Crítico',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:15.427-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-2-critico.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 1 ano '
                 'biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-2-da-velocidade',
  'name': 'Machado de Batalha +2 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:15.512-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-2-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos, Arremesso (9).\r\n'
                 '\r\n'
                 'É magicamente encantado para ter o balanço perfeito, podendo '
                 'ser arremessado além do seu uso normal em combate corpo a '
                 'corpo. O ataque de arremesso segue as mesmas regras de um '
                 'ataque à distância normal, como se estivesse sendo empunhado '
                 'pelo personagem.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-2-de-arremesso',
  'name': 'Machado de Batalha +2 de Arremesso',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:15.609-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-2-de-arremesso.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+3 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-2-matador-de-gigantes',
  'name': 'Machado de Batalha +2 Matador de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:15.696-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-2-matador-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+3 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-2-matador-de-mortos-vivos',
  'name': 'Machado de Batalha +2 Matador de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:15.781-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-2-matador-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+3 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-2-matador-de-orcs',
  'name': 'Machado de Batalha +2 Matador de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:15.872-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-2-matador-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 '+3 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-2-matador-de-usuarios-de-magia',
  'name': 'Machado de Batalha +2 Matador de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:15.958-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-2-matador-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-3',
  'name': 'Machado de Batalha +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:16.059-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Esta arma afiada é balanceada para permitir mais acertos '
                 'críticos que o normal. Esta arma precisa de um resultado de '
                 '19 ou 20 no d20 para atingir o alvo com um acerto crítico, '
                 'causando a ele dano dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-3-critico',
  'name': 'Machado de Batalha +3 Crítico',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:16.156-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-3-critico.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 1 ano '
                 'biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-3-da-velocidade',
  'name': 'Machado de Batalha +3 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:16.251-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-3-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos, Arremesso (9).\r\n'
                 '\r\n'
                 'É magicamente encantado para ter o balanço perfeito, podendo '
                 'ser arremessado além do seu uso normal em combate corpo a '
                 'corpo. O ataque de arremesso segue as mesmas regras de um '
                 'ataque à distância normal, como se estivesse sendo empunhado '
                 'pelo personagem.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-3-de-arremesso',
  'name': 'Machado de Batalha +3 de Arremesso',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:16.341-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-3-de-arremesso.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+4 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-3-matador-de-gigantes',
  'name': 'Machado de Batalha +3 Matador de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:16.443-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-3-matador-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+4 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-3-matador-de-mortos-vivos',
  'name': 'Machado de Batalha +3 Matador de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:16.538-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-3-matador-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+4 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-3-matador-de-orcs',
  'name': 'Machado de Batalha +3 Matador de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:16.632-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-3-matador-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 '+4 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-mais-3-matador-de-usuarios-de-magia',
  'name': 'Machado de Batalha +3 Matador de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:16.724-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-mais-3-matador-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-menos-1-amaldicoado',
  'name': 'Machado de Batalha -1 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:14.392-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-menos-1-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-de-batalha-menos-2-amaldicoado',
  'name': 'Machado de Batalha -2 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:14.493-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-de-batalha-menos-2-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-1',
  'name': 'Machado +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:08.696-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Esta arma afiada é balanceada para permitir mais acertos '
                 'críticos que o normal. Esta arma precisa de um resultado de '
                 '19 ou 20 no d20 para atingir o alvo com um acerto crítico, '
                 'causando a ele dano dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-1-critico',
  'name': 'Machado +1 Crítico',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:08.781-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-1-critico.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 1 ano '
                 'biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-1-da-velocidade',
  'name': 'Machado +1 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:08.869-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-1-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante, Arremesso (9).\r\n'
                 '\r\n'
                 'É magicamente encantado para ter o balanço perfeito, podendo '
                 'ser arremessado além do seu uso normal em combate corpo a '
                 'corpo. O ataque de arremesso segue as mesmas regras de um '
                 'ataque à distância normal, como se estivesse sendo empunhado '
                 'pelo personagem.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-1-de-arremesso',
  'name': 'Machado +1 de Arremesso',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:08.958-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-1-de-arremesso.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+2 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-1-matador-de-gigantes',
  'name': 'Machado +1 Matador de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:09.048-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-1-matador-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+2 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-1-matador-de-mortos-vivos',
  'name': 'Machado +1 Matador de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:09.144-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-1-matador-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+2 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-1-matador-de-orcs',
  'name': 'Machado +1 Matador de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:09.226-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-1-matador-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+2 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-1-matador-de-usuarios-de-magia',
  'name': 'Machado +1 Matador de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:09.311-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-1-matador-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-2',
  'name': 'Machado +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:09.400-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Esta arma afiada é balanceada para permitir mais acertos '
                 'críticos que o normal. Esta arma precisa de um resultado de '
                 '19 ou 20 no d20 para atingir o alvo com um acerto crítico, '
                 'causando a ele dano dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-2-critico',
  'name': 'Machado +2 Crítico',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:09.495-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-2-critico.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 1 ano '
                 'biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-2-da-velocidade',
  'name': 'Machado +2 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:09.582-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-2-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante, Arremesso (9).\r\n'
                 '\r\n'
                 'É magicamente encantado para ter o balanço perfeito, podendo '
                 'ser arremessado além do seu uso normal em combate corpo a '
                 'corpo. O ataque de arremesso segue as mesmas regras de um '
                 'ataque à distância normal, como se estivesse sendo empunhado '
                 'pelo personagem.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-2-de-arremesso',
  'name': 'Machado +2 de Arremesso',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:09.668-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-2-de-arremesso.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+3 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-2-matador-de-gigantes',
  'name': 'Machado +2 Matador de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:09.753-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-2-matador-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+3 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-2-matador-de-mortos-vivos',
  'name': 'Machado +2 Matador de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:09.836-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-2-matador-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+3 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-2-matador-de-orcs',
  'name': 'Machado +2 Matador de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:09.939-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-2-matador-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+3 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-2-matador-de-usuarios-de-magia',
  'name': 'Machado +2 Matador de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:10.042-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-2-matador-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-3',
  'name': 'Machado +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:10.129-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Esta arma afiada é balanceada para permitir mais acertos '
                 'críticos que o normal. Esta arma precisa de um resultado de '
                 '19 ou 20 no d20 para atingir o alvo com um acerto crítico, '
                 'causando a ele dano dobrado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-3-critico',
  'name': 'Machado +3 Crítico',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:10.219-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-3-critico.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 1 ano '
                 'biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-3-da-velocidade',
  'name': 'Machado +3 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:10.305-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-3-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante, Arremesso (9).\r\n'
                 '\r\n'
                 'É magicamente encantado para ter o balanço perfeito, podendo '
                 'ser arremessado além do seu uso normal em combate corpo a '
                 'corpo. O ataque de arremesso segue as mesmas regras de um '
                 'ataque à distância normal, como se estivesse sendo empunhado '
                 'pelo personagem.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-3-de-arremesso',
  'name': 'Machado +3 de Arremesso',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:10.393-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-3-de-arremesso.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+4 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-3-matador-de-gigantes',
  'name': 'Machado +3 Matador de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:10.484-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-3-matador-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+4 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-3-matador-de-mortos-vivos',
  'name': 'Machado +3 Matador de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:10.576-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-3-matador-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+4 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-3-matador-de-orcs',
  'name': 'Machado +3 Matador de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:10.663-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-3-matador-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.\r\n\r\n+4 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-mais-3-matador-de-usuarios-de-magia',
  'name': 'Machado +3 Matador de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:10.753-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-mais-3-matador-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-menos-1-amaldicoado',
  'name': 'Machado -1 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:08.506-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-menos-1-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Média, Cortante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'machado-menos-2-amaldicoado',
  'name': 'Machado -2 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:08.603-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-menos-2-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'limited',
  'concept': 'weapon',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 53}],
  'id': 'machado-saxao',
  'name': 'Machado Saxão',
  'type': 'Equipment',
  'updated_at': '2025-02-15T23:30:47.518-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-saxao.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 2000,
  'damage': '2d6',
  'description': 'Grande, Cortante, Duas Mãos, Haste.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao.json',
              'page': 306},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao-od2.json',
              'page': None}],
  'id': 'machado-ulbariano',
  'name': 'Machado Ulbariano',
  'type': 'Equipment',
  'updated_at': '2024-05-26T21:58:40.950-03:00',
  'url': 'https://olddragon.com.br/equipamentos/machado-ulbariano.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 1000,
  'damage': '1d8',
  'description': 'Grande, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'mangual',
  'name': 'Mangual',
  'picture': 'https://public.olddragon.com.br/d1s2denkwn440f3wlmcmrnae5rl3',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:34.899-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'mangual-mais-1',
  'name': 'Mangual +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:17.138-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'Esta arma explode ao atingir o alvo, causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'mangual-mais-1-da-explosao',
  'name': 'Mangual +1 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:17.229-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual-mais-1-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'mangual-mais-1-do-desarme',
  'name': 'Mangual +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:17.343-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'mangual-mais-1-do-retorno',
  'name': 'Mangual +1 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:17.434-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual-mais-1-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'Como a magia de mesmo nome, o usuário da arma recebe o poder '
                 'de voar, com deslocamento de 36m por turno, na direção ou '
                 'orientação desejada por até 3 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'mangual-mais-1-do-voo',
  'name': 'Mangual +1 do Voo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:17.541-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual-mais-1-do-voo.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'mangual-mais-2',
  'name': 'Mangual +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:17.637-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'Esta arma explode ao atingir o alvo, causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'mangual-mais-2-da-explosao',
  'name': 'Mangual +2 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:17.726-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual-mais-2-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'mangual-mais-2-do-desarme',
  'name': 'Mangual +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:17.818-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'mangual-mais-2-do-retorno',
  'name': 'Mangual +2 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:17.907-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual-mais-2-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'Como a magia de mesmo nome, o usuário da arma recebe o poder '
                 'de voar, com deslocamento de 36m por turno, na direção ou '
                 'orientação desejada por até 3 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'mangual-mais-2-do-voo',
  'name': 'Mangual +2 do Voo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:17.993-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual-mais-2-do-voo.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'mangual-mais-3',
  'name': 'Mangual +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:18.086-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'Esta arma explode ao atingir o alvo, causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'mangual-mais-3-da-explosao',
  'name': 'Mangual +3 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:18.175-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual-mais-3-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'mangual-mais-3-do-desarme',
  'name': 'Mangual +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:18.259-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'mangual-mais-3-do-retorno',
  'name': 'Mangual +3 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:18.342-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual-mais-3-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'Como a magia de mesmo nome, o usuário da arma recebe o poder '
                 'de voar, com deslocamento de 36m por turno, na direção ou '
                 'orientação desejada por até 3 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'mangual-mais-3-do-voo',
  'name': 'Mangual +3 do Voo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:18.425-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual-mais-3-do-voo.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'mangual-menos-1-amaldicoado',
  'name': 'Mangual -1 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:16.965-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual-menos-1-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d8',
  'description': 'Grande, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'mangual-menos-2-amaldicoado',
  'name': 'Mangual -2 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:17.051-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mangual-menos-2-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Estas manoplas aumentam a Força do usuário imediatamente '
                 'para 18, fazendo com que o personagem receba todos os '
                 'efeitos de possuir uma Força deste valor. Se atacar usando '
                 'apenas a manopla (ou seja, sem usar nenhuma outra arma), o '
                 'ataque recebe um bônus de +3 para acertar e causa 1d4+3 de '
                 'dano.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 167},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 126}],
  'id': 'manoplas-da-forca-do-ogro',
  'name': 'Manoplas da Força do Ogro',
  'type': 'Equipment',
  'updated_at': '2025-02-19T12:05:46.544-03:00',
  'url': 'https://olddragon.com.br/equipamentos/manoplas-da-forca-do-ogro.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Pequena, Impactante, Duas Mãos.\r\n'
                 '\r\n'
                 'Manoplas metálicas mágicas feitas em cota de malha. Aumenta '
                 'em +1 o dano em um Ataque Desarmado, além do tipo de ataque '
                 'ter propriedades mágicas. Uma vez por dia, é possível '
                 'conjurar a magia Relâmpago, considerando o nível do usuário '
                 'como nível de conjurador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 9}],
  'id': 'manoplas-eletricas',
  'name': 'Manoplas Elétricas',
  'type': 'Equipment',
  'updated_at': '2025-01-29T22:55:59.625-03:00',
  'url': 'https://olddragon.com.br/equipamentos/manoplas-eletricas.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 50,
  'damage': None,
  'description': 'De tecido de lã grossa e resistente para viagens.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'manto',
  'name': 'Manto',
  'picture': 'https://public.olddragon.com.br/yyfd7c8pl5nscw10gy8gmc1ruopm',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:03.079-03:00',
  'url': 'https://olddragon.com.br/equipamentos/manto.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este manto, formado por uma elegante malha mágica élfica, '
                 'concede ao usuário 1-5 chances em 1d6 de ficar invisível até '
                 'atacar ou conjurar uma magia.\r\n'
                 '\r\n'
                 'Ao sair do efeito do manto élfico, este precisa de 1 turno '
                 'inteiro para se recarregar e poder tornar o usuário '
                 'invisível novamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 167},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 127}],
  'id': 'manto-elfico',
  'name': 'Manto Élfico',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:48.255-03:00',
  'url': 'https://olddragon.com.br/equipamentos/manto-elfico.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'O manto do deslocamento deixa seu usuário "camuflado" como '
                 'se estivesse levemente deslocado (1,5 metro ao lado de onde '
                 'verdadeiramente está). O usuário do manto recebe um bônus de '
                 '+2 nas JPD e +2 no CA contra ataques corpo a corpo. Ataques '
                 'à distância errarão automaticamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 126}],
  'id': 'mantos-do-deslocamento',
  'name': 'Manto do Deslocamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:48.147-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mantos-do-deslocamento.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Um mapa indicando um tesouro com um valor significativo que '
                 'chame a atenção dos personagens. Normalmente os tesouros são '
                 'guardados em masmorras protegidas por armadilhas, magias ou '
                 'mesmo guardiões poderosos. Um mapa do tesouro nunca é uma '
                 'garantia da real existência do tesouro ou de que este esteja '
                 'intocado em seu lugar de origem.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 165}],
  'id': 'mapa-do-tesouro',
  'name': 'Mapa do Tesouro',
  'picture': 'https://public.olddragon.com.br/mpgyycanvxoc3elw90xyxpogc1d7',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:50.348-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mapa-do-tesouro.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'weapon',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 53}],
  'id': 'marreta-de-guerra',
  'name': 'Marreta de Guerra',
  'type': 'Equipment',
  'updated_at': '2025-02-15T23:30:48.227-03:00',
  'url': 'https://olddragon.com.br/equipamentos/marreta-de-guerra.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 600,
  'damage': '1d6',
  'description': 'Média, Arremesso (6), Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'martelo',
  'name': 'Martelo',
  'picture': 'https://public.olddragon.com.br/z1yia9k9ada0c2heit7hsdqj7kuj',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:18.083-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 1200,
  'damage': '2d4',
  'description': 'Grande, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'martelo-de-batalha',
  'name': 'Martelo de Batalha',
  'picture': 'https://public.olddragon.com.br/stlzhcyly67yk8lwoz2ymjd4gli6',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:43.692-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d4',
  'description': 'Grande, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 160},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'martelo-de-batalha-mais-1',
  'name': 'Martelo de Batalha +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:18.814-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d4',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'Esta arma explode ao atingir o alvo, causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'martelo-de-batalha-mais-1-da-explosao',
  'name': 'Martelo de Batalha +1 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:18.931-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha-mais-1-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d4',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'martelo-de-batalha-mais-1-do-desarme',
  'name': 'Martelo de Batalha +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:19.028-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d4',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'martelo-de-batalha-mais-1-do-retorno',
  'name': 'Martelo de Batalha +1 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:19.116-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha-mais-1-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d4',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'Como a magia de mesmo nome, o usuário da arma recebe o poder '
                 'de voar, com deslocamento de 36m por turno, na direção ou '
                 'orientação desejada por até 3 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'martelo-de-batalha-mais-1-do-voo',
  'name': 'Martelo de Batalha +1 do Voo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:19.199-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha-mais-1-do-voo.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d4',
  'description': 'Grande, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'martelo-de-batalha-mais-2',
  'name': 'Martelo de Batalha +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:19.287-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d4',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'Esta arma explode ao atingir o alvo, causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'martelo-de-batalha-mais-2-da-explosao',
  'name': 'Martelo de Batalha +2 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:19.373-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha-mais-2-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d4',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'martelo-de-batalha-mais-2-do-desarme',
  'name': 'Martelo de Batalha +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:19.457-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d4',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'martelo-de-batalha-mais-2-do-retorno',
  'name': 'Martelo de Batalha +2 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:19.538-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha-mais-2-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d4',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'Como a magia de mesmo nome, o usuário da arma recebe o poder '
                 'de voar, com deslocamento de 36m por turno, na direção ou '
                 'orientação desejada por até 3 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'martelo-de-batalha-mais-2-do-voo',
  'name': 'Martelo de Batalha +2 do Voo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:19.621-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha-mais-2-do-voo.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d4',
  'description': 'Grande, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'martelo-de-batalha-mais-3',
  'name': 'Martelo de Batalha +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:19.702-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d4',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'Esta arma explode ao atingir o alvo, causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'martelo-de-batalha-mais-3-da-explosao',
  'name': 'Martelo de Batalha +3 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:19.785-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha-mais-3-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d4',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'martelo-de-batalha-mais-3-do-desarme',
  'name': 'Martelo de Batalha +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:19.872-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d4',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'No final da rodada do combate, esta arma retornará, em '
                 'segurança, para a mão do atacante que a arremessou. Armas '
                 'que atingem seus alvos não retornam.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'martelo-de-batalha-mais-3-do-retorno',
  'name': 'Martelo de Batalha +3 do Retorno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:19.959-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha-mais-3-do-retorno.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d4',
  'description': 'Grande, Impactante.\r\n'
                 '\r\n'
                 'Como a magia de mesmo nome, o usuário da arma recebe o poder '
                 'de voar, com deslocamento de 36m por turno, na direção ou '
                 'orientação desejada por até 3 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'martelo-de-batalha-mais-3-do-voo',
  'name': 'Martelo de Batalha +3 do Voo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:20.075-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha-mais-3-do-voo.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d4',
  'description': 'Grande, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'martelo-de-batalha-menos-1-amaldicoado',
  'name': 'Martelo de Batalha -1 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:18.631-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha-menos-1-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '2d4',
  'description': 'Grande, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'martelo-de-batalha-menos-2-amaldicoado',
  'name': 'Martelo de Batalha -2 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:18.715-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-de-batalha-menos-2-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 50,
  'damage': None,
  'description': 'Metálico; usado para pregos, ganchos de escalada e trabalhos '
                 'manuais.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'martelo-ferramenta',
  'name': 'Martelo (ferramenta)',
  'picture': 'https://public.olddragon.com.br/87exuu8523bsnol745mq0t26qgrv',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:57.959-03:00',
  'url': 'https://olddragon.com.br/equipamentos/martelo-ferramenta.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Uma máscara cravejada de joias.\r\n'
                 '\r\n'
                 'Enquanto estiver sendo usada, cura 1 PV do usuário a cada '
                 'minuto, somando 10 PV a cada Turno. Ela cura um máximo de 30 '
                 'PV a cada dia, voltando a curar no próximo amanhecer.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 15}],
  'id': 'mascara-de-joias',
  'name': 'Máscara de Joias',
  'type': 'Equipment',
  'updated_at': '2025-01-29T22:56:00.132-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mascara-de-joias.json',
  'weight_in_grams': 300,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'O usuário deste medalhão, ao prendê-lo em uma corrente em '
                 'volta do pescoço e manter a concentração por 1 rodada, pode '
                 'ler os pensamentos de qualquer alvo a até 9 metros de '
                 'distância.\r\n'
                 '\r\n'
                 'O usuário pode se mover, mas não pode combater ou conjurar '
                 'feitiços enquanto estiver lendo os pensamentos.\r\n'
                 '\r\n'
                 'Existe uma chance em 1d6 da leitura da mente não funcionar '
                 'corretamente e, em vez disso, enviar os pensamentos do '
                 'usuário para todos dentro de um raio de 9 metros.\r\n'
                 '\r\n'
                 'Uma JPS pode negar o medalhão de invadir uma mente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 127}],
  'id': 'medalhao-da-pes',
  'name': 'Medalhão da PES',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:49.726-03:00',
  'url': 'https://olddragon.com.br/equipamentos/medalhao-da-pes.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Um medalhão com um cristal roxo que emite um brilho '
                 'intenso.\r\n'
                 '\r\n'
                 ' Proporciona visões do passado ou do futuro, como se o '
                 'usuário tivesse conjurado a magia arcana Visão.\r\n'
                 '\r\n'
                 'Há 50% de chance de mostrar o passado e 50% de chance de '
                 'mostrar o futuro.\r\n'
                 '\r\n'
                 'Pode ser usado uma vez por semana.\r\n'
                 '\r\n'
                 'O personagem deve realizar uma JPS para evitar ficar '
                 'completamente obcecado pelas visões, buscando '
                 'desesperadamente entender o que elas significam, como se '
                 'estivesse sob o efeito da magia Missão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 13}],
  'id': 'medalhao-da-teia-temporal-caotico',
  'name': 'Medalhão da Teia Temporal (Caótico)',
  'type': 'Equipment',
  'updated_at': '2025-01-29T22:56:00.302-03:00',
  'url': 'https://olddragon.com.br/equipamentos/medalhao-da-teia-temporal-caotico.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'container',
  'cost': 200,
  'damage': None,
  'description': 'De couro, com compartimentos para exploradores e reforço '
                 'para peso. Adiciona 5 ao valor de carga do personagem. '
                 'Comporta até 400 moedas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'mochila',
  'name': 'Mochila',
  'picture': 'https://public.olddragon.com.br/b1v4vw5qx7f5jsj6gmbgt9a7uvke',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:11.648-03:00',
  'url': 'https://olddragon.com.br/equipamentos/mochila.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 1600,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'montante',
  'name': 'Montante',
  'picture': 'https://public.olddragon.com.br/ezdy6m5nk4yetjf55jpkuqus478s',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:36.103-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-1',
  'name': 'Montante +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T21:47:54.948-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-1-da-cura',
  'name': 'Montante +1 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:20.512-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se o '
                 'montante estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-1-da-luz',
  'name': 'Montante +1 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:20.601-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-1-da-respiracao',
  'name': 'Montante +1 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:20.687-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-1-da-velocidade',
  'name': 'Montante +1 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:20.769-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Um '
                 'montante de Drenar Energia possui 1d6+6 cargas e pode drenar '
                 '1d4+4 níveis/dados de vida. Uma vez que esgote as cargas, '
                 'ela perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-1-de-drenar-energia',
  'name': 'Montante +1 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:20.855-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-1-defensor',
  'name': 'Montante +1 Defensor',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:20.939-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1-defensor.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador do montante desejar, faz com '
                 'que a lâmina do montante arda coberta por chamas mágicas, '
                 'como se fosse uma tocha. Suas chamas causam um dano extra de '
                 '1d6 ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, um montante flamejante pode ser usado como '
                 'uma tocha enquanto estiver ativado. As chamas mágicas de um '
                 'montante flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-1-flamejante',
  'name': 'Montante +1 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:21.026-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador do montante deseje, faz '
                 'com que a lâmina do montante congele ao menor toque. Seu '
                 'frio causa um dano extra de 1d6 ao atingir uma criatura que '
                 'tenha o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de um montante gélido não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-1-gelido',
  'name': 'Montante +1 Gélido',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:21.115-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1-gelido.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+2 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-1-matador-de-dragoes',
  'name': 'Montante +1 Matador de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:21.198-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1-matador-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+2 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-1-matador-de-extraplanares',
  'name': 'Montante +1 Matador de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:21.308-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1-matador-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+2 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-1-matador-de-gigantes',
  'name': 'Montante +1 Matador de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:21.400-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1-matador-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+2 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-1-matador-de-licantropos',
  'name': 'Montante +1 Matador de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:21.488-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1-matador-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+2 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-1-matador-de-mortos-vivos',
  'name': 'Montante +1 Matador de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:21.580-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1-matador-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+2 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-1-matador-de-orcs',
  'name': 'Montante +1 Matador de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:21.668-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1-matador-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+2 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-1-matador-de-regeneradores',
  'name': 'Montante +1 Matador de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:21.756-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1-matador-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 '+2 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-1-matador-de-usuarios-de-magia',
  'name': 'Montante +1 Matador de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:21.854-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1-matador-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'É magicamente afiado e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por um montante Vorpal.\r\n'
                 '\r\n'
                 'O efeito do montante Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-1-vorpal',
  'name': 'Montante +1 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:21.943-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-1-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-2',
  'name': 'Montante +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T21:47:55.036-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-2-da-cura',
  'name': 'Montante +2 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:22.126-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se o '
                 'montante estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-2-da-luz',
  'name': 'Montante +2 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:22.215-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-2-da-respiracao',
  'name': 'Montante +2 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:22.306-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-2-da-velocidade',
  'name': 'Montante +2 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:22.392-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Um '
                 'montante de Drenar Energia possui 1d6+6 cargas e pode drenar '
                 '1d4+4 níveis/dados de vida. Uma vez que esgote as cargas, '
                 'ela perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-2-de-drenar-energia',
  'name': 'Montante +2 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:22.483-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-2-defensor',
  'name': 'Montante +2 Defensor',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:22.595-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2-defensor.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador do montante desejar, faz com '
                 'que a lâmina do montante arda coberta por chamas mágicas, '
                 'como se fosse uma tocha. Suas chamas causam um dano extra de '
                 '1d6 ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, um montante flamejante pode ser usado como '
                 'uma tocha enquanto estiver ativado. As chamas mágicas de um '
                 'montante flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-2-flamejante',
  'name': 'Montante +2 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:22.681-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador do montante deseje, faz '
                 'com que a lâmina do montante congele ao menor toque. Seu '
                 'frio causa um dano extra de 1d6 ao atingir uma criatura que '
                 'tenha o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de um montante gélido não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-2-gelido',
  'name': 'Montante +2 Gélido',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:22.778-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2-gelido.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+3 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-2-matador-de-dragoes',
  'name': 'Montante +2 Matador de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:22.864-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2-matador-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+3 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-2-matador-de-extraplanares',
  'name': 'Montante +2 Matador de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:22.959-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2-matador-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+3 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-2-matador-de-gigantes',
  'name': 'Montante +2 Matador de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:23.058-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2-matador-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+3 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-2-matador-de-licantropos',
  'name': 'Montante +2 Matador de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:23.143-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2-matador-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+3 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-2-matador-de-mortos-vivos',
  'name': 'Montante +2 Matador de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:23.232-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2-matador-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+3 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-2-matador-de-orcs',
  'name': 'Montante +2 Matador de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:23.318-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2-matador-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+3 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-2-matador-de-regeneradores',
  'name': 'Montante +2 Matador de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:23.405-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2-matador-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 '+3 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-2-matador-de-usuarios-de-magia',
  'name': 'Montante +2 Matador de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:23.497-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2-matador-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'É magicamente afiado e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por um montante Vorpal.\r\n'
                 '\r\n'
                 'O efeito do montante Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-2-vorpal',
  'name': 'Montante +2 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:23.630-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-2-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-3',
  'name': 'Montante +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T21:47:55.063-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-3-da-cura',
  'name': 'Montante +3 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:23.807-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se o '
                 'montante estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-3-da-luz',
  'name': 'Montante +3 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:23.906-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-3-da-respiracao',
  'name': 'Montante +3 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:24.002-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-3-da-velocidade',
  'name': 'Montante +3 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:24.099-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Um '
                 'montante de Drenar Energia possui 1d6+6 cargas e pode drenar '
                 '1d4+4 níveis/dados de vida. Uma vez que esgote as cargas, '
                 'ela perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-3-de-drenar-energia',
  'name': 'Montante +3 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:24.188-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-3-defensor',
  'name': 'Montante +3 Defensor',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:24.269-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3-defensor.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador do montante desejar, faz com '
                 'que a lâmina do montante arda coberta por chamas mágicas, '
                 'como se fosse uma tocha. Suas chamas causam um dano extra de '
                 '1d6 ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, um montante flamejante pode ser usado como '
                 'uma tocha enquanto estiver ativado. As chamas mágicas de um '
                 'montante flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-3-flamejante',
  'name': 'Montante +3 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:24.357-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador do montante deseje, faz '
                 'com que a lâmina do montante congele ao menor toque. Seu '
                 'frio causa um dano extra de 1d6 ao atingir uma criatura que '
                 'tenha o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de um montante gélido não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-3-gelido',
  'name': 'Montante +3 Gélido',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:24.441-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3-gelido.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+4 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-3-matador-de-dragoes',
  'name': 'Montante +3 Matador de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:24.526-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3-matador-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+4 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-3-matador-de-extraplanares',
  'name': 'Montante +3 Matador de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:24.607-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3-matador-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+4 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-3-matador-de-gigantes',
  'name': 'Montante +3 Matador de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:24.696-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3-matador-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+4 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-3-matador-de-licantropos',
  'name': 'Montante +3 Matador de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:24.780-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3-matador-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+4 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-3-matador-de-mortos-vivos',
  'name': 'Montante +3 Matador de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:24.862-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3-matador-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+4 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-3-matador-de-orcs',
  'name': 'Montante +3 Matador de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:24.954-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3-matador-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+4 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-3-matador-de-regeneradores',
  'name': 'Montante +3 Matador de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:25.037-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3-matador-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 '+4 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-3-matador-de-usuarios-de-magia',
  'name': 'Montante +3 Matador de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:25.129-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3-matador-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'É magicamente afiado e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por um montante Vorpal.\r\n'
                 '\r\n'
                 'O efeito do montante Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-3-vorpal',
  'name': 'Montante +3 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:25.218-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-3-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-4',
  'name': 'Montante +4',
  'type': 'Equipment',
  'updated_at': '2025-01-09T21:47:55.105-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-4-da-cura',
  'name': 'Montante +4 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:25.386-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se o '
                 'montante estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-4-da-luz',
  'name': 'Montante +4 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:25.471-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-4-da-respiracao',
  'name': 'Montante +4 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:25.556-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-4-da-velocidade',
  'name': 'Montante +4 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:25.668-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Um '
                 'montante de Drenar Energia possui 1d6+6 cargas e pode drenar '
                 '1d4+4 níveis/dados de vida. Uma vez que esgote as cargas, '
                 'ela perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-4-de-drenar-energia',
  'name': 'Montante +4 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:25.761-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-4-defensor',
  'name': 'Montante +4 Defensor',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:25.855-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4-defensor.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador do montante desejar, faz com '
                 'que a lâmina do montante arda coberta por chamas mágicas, '
                 'como se fosse uma tocha. Suas chamas causam um dano extra de '
                 '1d6 ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, um montante flamejante pode ser usado como '
                 'uma tocha enquanto estiver ativado. As chamas mágicas de um '
                 'montante flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-4-flamejante',
  'name': 'Montante +4 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:25.947-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador do montante deseje, faz '
                 'com que a lâmina do montante congele ao menor toque. Seu '
                 'frio causa um dano extra de 1d6 ao atingir uma criatura que '
                 'tenha o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de um montante gélido não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-4-gelido',
  'name': 'Montante +4 Gélido',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:26.046-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4-gelido.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+5 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-4-matador-de-dragoes',
  'name': 'Montante +4 Matador de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:26.130-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4-matador-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+5 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-4-matador-de-extraplanares',
  'name': 'Montante +4 Matador de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:26.214-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4-matador-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+5 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-4-matador-de-gigantes',
  'name': 'Montante +4 Matador de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:26.307-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4-matador-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+5 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-4-matador-de-licantropos',
  'name': 'Montante +4 Matador de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:26.401-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4-matador-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+5 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-4-matador-de-mortos-vivos',
  'name': 'Montante +4 Matador de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:26.484-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4-matador-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+5 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-4-matador-de-orcs',
  'name': 'Montante +4 Matador de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:26.574-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4-matador-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+5 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-4-matador-de-regeneradores',
  'name': 'Montante +4 Matador de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:26.673-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4-matador-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 '+5 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-4-matador-de-usuarios-de-magia',
  'name': 'Montante +4 Matador de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:26.755-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4-matador-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'É magicamente afiado e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por um montante Vorpal.\r\n'
                 '\r\n'
                 'O efeito do montante Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-4-vorpal',
  'name': 'Montante +4 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:26.842-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-4-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-5',
  'name': 'Montante +5',
  'type': 'Equipment',
  'updated_at': '2025-01-09T21:47:55.141-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela parte chata da lâmina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-5-da-cura',
  'name': 'Montante +5 da Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:27.018-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5-da-cura.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia, é capaz de acender sua lâmina como se o '
                 'montante estivesse sob o efeito da magia Luz, lançada por um '
                 'Mago de 1º nível. A luz é tão brilhante quanto uma tocha, '
                 'podendo iluminar uma área com raio de 6m por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-5-da-luz',
  'name': 'Montante +5 da Luz',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:27.106-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5-da-luz.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Faz com que o portador consiga respirar em qualquer ambiente '
                 'sem ar disponível, como debaixo da água, no vácuo ou em '
                 'áreas tomadas por nuvens venenosas. Este poder pode ser '
                 'ativado uma vez ao dia e dura por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-5-da-respiracao',
  'name': 'Montante +5 da Respiração',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:27.195-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5-da-respiracao.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia, seu usuário pode ativar sobre si os efeitos '
                 'da velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na classe de armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 10% '
                 'da idade atual.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-5-da-velocidade',
  'name': 'Montante +5 da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:27.279-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5-da-velocidade.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Além do dano, causa um ataque de Dreno de Energia do alvo, '
                 'sugando 1 dado de vida ou nível do alvo atingido. Um '
                 'montante de Drenar Energia possui 1d6+6 cargas e pode drenar '
                 '1d4+4 níveis/dados de vida. Uma vez que esgote as cargas, '
                 'ela perde definitivamente esta habilidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-5-de-drenar-energia',
  'name': 'Montante +5 de Drenar Energia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:27.362-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5-de-drenar-energia.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Pode alternar seu bônus entre a classe de armadura do '
                 'usuário e o bônus de ataque. O portador deve escolher, no '
                 'início do combate, qual tipo de bônus quer usufruir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-5-defensor',
  'name': 'Montante +5 Defensor',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:27.444-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5-defensor.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até o portador do montante desejar, faz com '
                 'que a lâmina do montante arda coberta por chamas mágicas, '
                 'como se fosse uma tocha. Suas chamas causam um dano extra de '
                 '1d6 ao atingir uma criatura que tenha o gelo ou o frio como '
                 'habilidade.\r\n'
                 '\r\n'
                 'Por emitir luz, um montante flamejante pode ser usado como '
                 'uma tocha enquanto estiver ativado. As chamas mágicas de um '
                 'montante flamejante não causam dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-5-flamejante',
  'name': 'Montante +5 Flamejante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:27.535-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5-flamejante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'Uma vez ao dia e até que o portador do montante deseje, faz '
                 'com que a lâmina do montante congele ao menor toque. Seu '
                 'frio causa um dano extra de 1d6 ao atingir uma criatura que '
                 'tenha o fogo como habilidade.\r\n'
                 '\r\n'
                 'Além disso, seu portador fica protegido contra os efeitos do '
                 'fogo ou calor enquanto sua lâmina estiver ativada. O frio '
                 'mágico de um montante gélido não causa dano ao seu portador.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-5-gelido',
  'name': 'Montante +5 Gélido',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:27.626-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5-gelido.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+6 contra dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-5-matador-de-dragoes',
  'name': 'Montante +5 Matador de Dragões',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:27.711-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5-matador-de-dragoes.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+6 contra extraplanares.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-5-matador-de-extraplanares',
  'name': 'Montante +5 Matador de Extraplanares',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:27.797-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5-matador-de-extraplanares.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+6 contra gigantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-5-matador-de-gigantes',
  'name': 'Montante +5 Matador de Gigantes',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:27.884-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5-matador-de-gigantes.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+6 contra licantropos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-5-matador-de-licantropos',
  'name': 'Montante +5 Matador de Licantropos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:27.973-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5-matador-de-licantropos.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+6 contra mortos-vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-5-matador-de-mortos-vivos',
  'name': 'Montante +5 Matador de Mortos-Vivos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:28.063-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5-matador-de-mortos-vivos.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+6 contra orcs.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-mais-5-matador-de-orcs',
  'name': 'Montante +5 Matador de Orcs',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:28.153-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5-matador-de-orcs.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n\r\n+6 contra regeneradores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-5-matador-de-regeneradores',
  'name': 'Montante +5 Matador de Regeneradores',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:28.249-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5-matador-de-regeneradores.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 '+6 contra usuários de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-5-matador-de-usuarios-de-magia',
  'name': 'Montante +5 Matador de Usuários de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:28.338-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5-matador-de-usuarios-de-magia.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.\r\n'
                 '\r\n'
                 'É magicamente afiado e faz com que todo ataque crítico '
                 'resulte na decapitação imediata do alvo, sem direito a '
                 'nenhum teste ou jogada de proteção. Criaturas capazes de se '
                 'regenerar ainda conseguem regenerar suas cabeças '
                 'normalmente, mesmo se decapitadas por um montante Vorpal.\r\n'
                 '\r\n'
                 'O efeito do montante Vorpal não é sentido por criaturas cuja '
                 'morfologia seja indiferente à presença de uma cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 106}],
  'id': 'montante-mais-5-vorpal',
  'name': 'Montante +5 Vorpal',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:28.426-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-mais-5-vorpal.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-menos-1-amaldicoado',
  'name': 'Montante -1 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T21:47:54.997-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-menos-1-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d12',
  'description': 'Grande, Cortante, Duas Mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 105}],
  'id': 'montante-menos-2-amaldicoado',
  'name': 'Montante -2 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T21:47:54.873-03:00',
  'url': 'https://olddragon.com.br/equipamentos/montante-menos-2-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'container',
  'cost': 50,
  'damage': None,
  'description': 'Saco de couro com rolha para líquidos com capacidade para 1 '
                 'litro. Não comporta moedas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'odre',
  'name': 'Odre',
  'picture': 'https://public.olddragon.com.br/g9k2pnu01b1xgxecw0ta3wl3kmfv',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:40.274-03:00',
  'url': 'https://olddragon.com.br/equipamentos/odre.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 50,
  'damage': None,
  'description': 'Frasco com 500 ml.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'oleo',
  'name': 'Óleo',
  'picture': 'https://public.olddragon.com.br/wckvl6490ihqvlp1qsczrvxpq5fc',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:23.694-03:00',
  'url': 'https://olddragon.com.br/equipamentos/oleo.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 50,
  'damage': None,
  'description': 'Ferramenta para escavações.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'pa-ou-picareta',
  'name': 'Pá ou Picareta',
  'picture': 'https://public.olddragon.com.br/co53wh50xs2p7rq98m3z8jxm75up',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:14.748-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pa-ou-picareta.json',
  'weight_in_grams': 1000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 100,
  'damage': None,
  'description': 'Ferramenta para arrombamento.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'pe-de-cabra',
  'name': 'Pé de Cabra',
  'picture': 'https://public.olddragon.com.br/rg7acb6jif6abjoo0gwdc8d2n57i',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:28.759-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pe-de-cabra.json',
  'weight_in_grams': 1000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 5,
  'damage': None,
  'description': 'Gera faíscas para acender pavios, lanternas ou fogueiras.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'pederneira',
  'name': 'Pederneira',
  'picture': 'https://public.olddragon.com.br/ellztn5dp393562uggz6mninnajl',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:56.256-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pederneira.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'misc',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 102}],
  'id': 'pederneira-de-baixa-qualidade',
  'name': 'Pederneira de Baixa Qualidade',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:41.717-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pederneira-de-baixa-qualidade.json'},
 {'access': 'limited',
  'concept': 'armor',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 54}],
  'id': 'peitoral-romano',
  'name': 'Peitoral Romano',
  'type': 'Equipment',
  'updated_at': '2025-02-15T23:31:21.250-03:00',
  'url': 'https://olddragon.com.br/equipamentos/peitoral-romano.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 800,
  'damage': None,
  'description': 'Para escrita e desenhos. Frasco de 30 ml.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'pena-e-tinta',
  'name': 'Pena e Tinta',
  'picture': 'https://public.olddragon.com.br/r2jd8vnh62hk7guz0gh1y11zm28x',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:54.428-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pena-e-tinta.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 50,
  'damage': None,
  'description': '10 folhas soltas, sem encadernação.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'pergaminho',
  'name': 'Pergaminho',
  'picture': 'https://public.olddragon.com.br/igbtbt0gng20zbupmpea9de4g2ud',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:32.133-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pergaminho.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Amaldiçoam todos os que tentam lê-los. Apenas tentativas '
                 'mágicas de identificar o conteúdo do pergaminho são '
                 'suficientemente seguras para evitar seus efeitos '
                 'caóticos.\r\n'
                 '\r\n'
                 'Apenas uma magia Remover Maldição pode remover os efeitos de '
                 'um pergaminho amaldiçoado.\r\n'
                 '\r\n'
                 'Os efeitos de maldições de um pergaminho amaldiçoado são '
                 'variados e os Mestres são bem-vindos em criar suas próprias '
                 'maldições.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 164},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 117}],
  'id': 'pergaminho-amaldicoado',
  'name': 'Pergaminho Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:50.367-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pergaminho-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Um pergaminho arcano pode conter até 9 círculos de magias '
                 'distribuídos da forma determinada pelo Mestre. Um pergaminho '
                 'com 3 círculos de magia pode conter ou três magias de 1º '
                 'círculo, ou uma magia de 1º círculo e outra de 2º círculo, '
                 'ou uma única magia de 3º círculo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 164},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 117}],
  'id': 'pergaminho-arcano',
  'name': 'Pergaminho Arcano',
  'picture': 'https://public.olddragon.com.br/hj964dx9feq6wn2kcs34y46bwpf1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:52.653-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pergaminho-arcano.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Qualquer personagem alfabetizado é capaz de usar um '
                 'pergaminho de proteção, que, ao ser lido e ativado, cria um '
                 'círculo de proteção de 3 metros de raio ao redor do leitor '
                 'do pergaminho. O círculo de proteção acompanhará o leitor '
                 'caso este se desloque.\r\n'
                 '\r\n'
                 'As criaturas alvo do círculo de proteção estão impedidas de '
                 'adentrar na área do círculo, mas não de realizarem ataques à '
                 'distância ou de conjurarem magias contra a área de proteção '
                 'ou a alvos dentro dele.\r\n'
                 '\r\n'
                 'Caso o protegido pela área de proteção ataque uma criatura '
                 'fora do círculo em um ataque corpo a corpo, o círculo de '
                 'proteção é extinto.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 164},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 117}],
  'id': 'pergaminho-de-protecao',
  'name': 'Pergaminho de Proteção',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:51.789-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pergaminho-de-protecao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Um pergaminho Divino pode conter até 7 círculos de magias '
                 'distribuídos da forma determinada pelo Mestre. Um pergaminho '
                 'com 3 círculos de magia pode conter ou três magias de 1º '
                 'círculo, ou uma magia de 1º círculo e outra de 2º círculo, '
                 'ou uma única magia de 3º círculo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 164},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 117}],
  'id': 'pergaminho-divino',
  'name': 'Pergaminho Divino',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:51.916-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pergaminho-divino.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'misc',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 102}],
  'id': 'pinos-de-pedra',
  'name': 'Pinos de Pedra',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:33.348-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pinos-de-pedra.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 800,
  'damage': '1d10',
  'description': 'Grande, Perfurante, Contrainvestida, Duas Mãos, Haste.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'pique',
  'name': 'Pique',
  'picture': 'https://public.olddragon.com.br/7u2aezb7jt4njxxf1owdbaz82j36',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:25.744-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pique.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Perfurante, Contrainvestida, Duas Mãos, Haste',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'pique-mais-1',
  'name': 'Pique +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:28.754-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pique-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': 1,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Perfurante, Contrainvestida, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'pique-mais-1-defensor',
  'name': 'Pique +1 Defensor',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:28.841-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pique-mais-1-defensor.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Perfurante, Contrainvestida, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'pique-mais-1-do-desarme',
  'name': 'Pique +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:28.927-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pique-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Perfurante, Contrainvestida, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'Esta arma pode ser usada para vigiar um tipo específico de '
                 'monstro ou raça de personagem. Ao perceber a presença de um '
                 'membro vigiado em um raio de 18m da arma, esta vibrará '
                 'lentamente. Este talento funciona por 24 horas e o tipo de '
                 'monstro vigiado só pode ser alterado uma vez a cada dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'pique-mais-1-vigilante',
  'name': 'Pique +1 Vigilante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:29.015-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pique-mais-1-vigilante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Perfurante, Contrainvestida, Duas Mãos, Haste',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'pique-mais-2',
  'name': 'Pique +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:29.099-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pique-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Perfurante, Contrainvestida, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'pique-mais-2-defensor',
  'name': 'Pique +2 Defensor',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:29.188-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pique-mais-2-defensor.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Perfurante, Contrainvestida, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'pique-mais-2-do-desarme',
  'name': 'Pique +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:29.269-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pique-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Perfurante, Contrainvestida, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'Esta arma pode ser usada para vigiar um tipo específico de '
                 'monstro ou raça de personagem. Ao perceber a presença de um '
                 'membro vigiado em um raio de 18m da arma, esta vibrará '
                 'lentamente. Este talento funciona por 24 horas e o tipo de '
                 'monstro vigiado só pode ser alterado uma vez a cada dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'pique-mais-2-vigilante',
  'name': 'Pique +2 Vigilante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:29.360-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pique-mais-2-vigilante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Perfurante, Contrainvestida, Duas Mãos, Haste',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'pique-mais-3',
  'name': 'Pique +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:29.447-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pique-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Perfurante, Contrainvestida, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'pique-mais-3-defensor',
  'name': 'Pique +3 Defensor',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:29.539-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pique-mais-3-defensor.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Perfurante, Contrainvestida, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'pique-mais-3-do-desarme',
  'name': 'Pique +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:29.625-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pique-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Perfurante, Contrainvestida, Duas Mãos, Haste.\r\n'
                 '\r\n'
                 'Esta arma pode ser usada para vigiar um tipo específico de '
                 'monstro ou raça de personagem. Ao perceber a presença de um '
                 'membro vigiado em um raio de 18m da arma, esta vibrará '
                 'lentamente. Este talento funciona por 24 horas e o tipo de '
                 'monstro vigiado só pode ser alterado uma vez a cada dia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'pique-mais-3-vigilante',
  'name': 'Pique +3 Vigilante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:29.710-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pique-mais-3-vigilante.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Perfurante, Contrainvestida, Duas Mãos, Haste',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'pique-menos-1-amaldicoado',
  'name': 'Pique -1 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:28.578-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pique-menos-1-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d10',
  'description': 'Grande, Perfurante, Contrainvestida, Duas Mãos, Haste',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'pique-menos-2-amaldicoado',
  'name': 'Pique -2 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:28.660-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pique-menos-2-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': 3},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 2500,
  'damage': '2d6',
  'description': 'Média, Disparo (30), Duas Mãos, Recarga.\r\n'
                 '\r\n'
                 'Contém 10 balas e um chifre de pólvora que prepara 10 tiros. '
                 'São necessárias 3 rodadas para recarregar e pode ser '
                 'disparada apenas uma vez por rodada.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday16.json',
              'page': 9}],
  'id': 'pistola',
  'name': 'Pistola',
  'type': 'Equipment',
  'updated_at': '2025-03-27T21:53:32.269-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pistola.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'São totalmente imprevisíveis. Qualquer tentativa não mágica '
                 'de identificar uma poção sempre resultará em um engano. O '
                 'Mestre escolhe aleatoriamente o efeito de uma poção apenas '
                 'após uma poção caótica ser tomada.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 163},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 113}],
  'id': 'pocao-amaldicoada',
  'name': 'Poção Amaldiçoada',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:52.127-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-amaldicoada.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Seu usuário ativa os efeitos da magia Clarividência. Ao se '
                 'concentrar em um lugar específico já conhecido previamente, '
                 'o usuário pode visualizá-lo como se estivesse lá.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 114}],
  'id': 'pocao-da-clarividencia',
  'name': 'Poção da Clarividência',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:52.262-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-da-clarividencia.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Seu usuário fica imediatamente diminuto, com apenas 15cm de '
                 'altura. Com este tamanho, o indivíduo não consegue atacar '
                 'nenhuma criatura pequena ou maior, mas pode passar por '
                 'frestas ou entrar em tocas de ratos. Possui uma chance de '
                 '1-5 em 6 de não ser percebido se ficar imóvel. Esta poção '
                 'anula os efeitos de uma poção de crescimento.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 163},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 114}],
  'id': 'pocao-da-diminuicao',
  'name': 'Poção da Diminuição',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:52.394-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-da-diminuicao.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'O bebedor da poção recebe a Força extraordinária dos '
                 'gigantes. Qualquer ataque com uma arma neste estado causa '
                 'dano dobrado. Um personagem sob o efeito desta poção pode '
                 'realizar um disparo em área com pequenas pedras, causando '
                 '3d6 de dano.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 163},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 115}],
  'id': 'pocao-da-forca-gigante',
  'name': 'Poção da Força Gigante',
  'picture': 'https://public.olddragon.com.br/7u1apqvfnzdux8zpnj1f2jtecb5j',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:54.509-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-da-forca-gigante.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'O bebedor da poção se torna uma imensa nuvem de gás. Todos '
                 'os pertences, roupas, equipamento, etc. caem no chão '
                 'imediatamente, mesmo se o personagem continuar mantendo '
                 'controle sobre seu corpo.\r\n'
                 '\r\n'
                 'Na forma gasosa, o personagem é capaz de passar por pequenos '
                 'buracos na parede, penetrar em fechaduras ou passar por '
                 'debaixo de portas, mas não é capaz de atacar um alvo. Porém, '
                 'pode ser atacado com um ataque muito difícil.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 163},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 115}],
  'id': 'pocao-da-forma-gasosa',
  'name': 'Poção da Forma Gasosa',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:53.786-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-da-forma-gasosa.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Esta poção possui os mesmos efeitos da magia arcana de 2º '
                 'círculo Invisibilidade. Quando sob seu efeito, o personagem '
                 'fica invisível, incluindo seus pertences e roupas (ao menos '
                 'até o personagem soltar ou deixar de vestir estes itens). '
                 'Esta poção pode ser bebida em até 6 goles fazendo efeito por '
                 '1 turno por gole.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 115}],
  'id': 'pocao-da-invisibilidade',
  'name': 'Poção da Invisibilidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:53.901-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-da-invisibilidade.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'O usuário da poção consegue modificar fisicamente a sua '
                 'forma para que se pareça com outra criatura, da mesma forma '
                 'que a magia de mesmo nome. O usuário desta poção é o único '
                 'alvo possível.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 115}],
  'id': 'pocao-da-metamorfose',
  'name': 'Poção da Metamorfose',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:53.995-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-da-metamorfose.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Seu usuário ativa sobre si os efeitos da magia Percepção '
                 'Extrassensorial, permitindo-lhe detectar os pensamentos de '
                 'outros seres a uma distância máxima de 18m. A magia não pode '
                 'penetrar mais de 60cm de pedra e é bloqueada até mesmo pela '
                 'mais fina folha de chumbo. Esta percepção faz com que o Mago '
                 'compreenda qualquer pensamento como se lhe fosse dito em voz '
                 'alta, mas desde que o Mago e o alvo da magia compartilhem do '
                 'mesmo idioma.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 115}],
  'id': 'pocao-da-percepcao-extrassensorial',
  'name': 'Poção da Percepção Extrassensorial',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:54.091-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-da-percepcao-extrassensorial.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'O usuário desta poção ativa sobre si a proteção mágica '
                 'contra o fogo. Assim, ele não pode ser ferido por fogo '
                 'normal e recebe um bônus de +2 para todas as JP contra '
                 'ataques mágicos de fogo. Além disso, o usuário recebe 1 '
                 'ponto a menos de qualquer dano por fogo mágico, como uma '
                 'baforada de dragão ou bola de fogo. Neste caso, o dano '
                 'mínimo sempre será de 1 ponto de dano.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 115}],
  'id': 'pocao-da-resistencia-ao-fogo',
  'name': 'Poção da Resistência ao Fogo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:54.187-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-da-resistencia-ao-fogo.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Esta poção concede ao seu usuário uma sorte incrível. Pelas '
                 'próximas 1d6 horas, o personagem pode realizar um teste à '
                 'sua escolha, lançando dois dados e escolhendo o resultado '
                 'mais vantajoso para si. O jogador precisa usar sua sorte '
                 'antes de realizar o teste. Assim que o teste for realizado, '
                 'o efeito desta poção se encerra.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 116}],
  'id': 'pocao-da-sorte',
  'name': 'Poção da Sorte',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:54.282-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-da-sorte.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'O usuário desta poção ativa sobre si os efeitos da '
                 'velocidade como a magia de mesmo nome. A movimentação do '
                 'usuário passa a ser dobrada, além de receber um bônus de +2 '
                 'na Classe de Armadura e um ataque extra por turno usando o '
                 'mesmo bônus do ataque principal. Essa aceleração é '
                 'prejudicial ao organismo do alvo, fazendo-o envelhecer 1 ano '
                 'biologicamente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 116}],
  'id': 'pocao-da-velocidade',
  'name': 'Poção da Velocidade',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:54.368-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-da-velocidade.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Permite ao usuário controlar até 1d6 alvos ou até um alvo '
                 'gigante (sempre limitado a 6 DV) desde que o alvo esteja '
                 'fazendo contato visual com o usuário. O controle dura '
                 'enquanto o usuário da poção estiver concentrado no alvo. '
                 'Quando o controle acaba, o alvo estará livre para fazer o '
                 'que quiser, sem nenhum elo empático com o usuário. Há '
                 'versões diferentes dessa poção.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 114}],
  'id': 'pocao-de-controle-de-animais',
  'name': 'Poção de Controle de Animais',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:54.468-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-de-controle-de-animais.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Permite ao usuário controlar até 1d6 alvos ou até um alvo '
                 'gigante (sempre limitado a 6 DV) desde que o alvo esteja '
                 'fazendo contato visual com o usuário. O controle dura '
                 'enquanto o usuário da poção estiver concentrado no alvo. '
                 'Quando o controle acaba, o alvo estará livre para fazer o '
                 'que quiser, sem nenhum elo empático com o usuário. Há '
                 'versões diferentes dessa poção.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 114}],
  'id': 'pocao-de-controle-de-humanos',
  'name': 'Poção de Controle de Humanos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:54.562-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-de-controle-de-humanos.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Permite ao usuário controlar até 1d6 alvos ou até um alvo '
                 'gigante (sempre limitado a 6 DV) desde que o alvo esteja '
                 'fazendo contato visual com o usuário. O controle dura '
                 'enquanto o usuário da poção estiver concentrado no alvo. '
                 'Quando o controle acaba, o alvo estará livre para fazer o '
                 'que quiser, sem nenhum elo empático com o usuário. Há '
                 'versões diferentes dessa poção.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 114}],
  'id': 'pocao-de-controle-de-plantas',
  'name': 'Poção de Controle de Plantas',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:54.657-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-de-controle-de-plantas.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Seu usuário sofre crescimento exponencial, dobrando de '
                 'tamanho. A Força do personagem também dobra (máximo de 18). '
                 'Todos os danos causados por alguém sob o efeito de '
                 'crescimento causam dano dobrado em seus ataques. Esta poção '
                 'anula os efeitos de uma poção de diminuição.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 114}],
  'id': 'pocao-de-crescimento',
  'name': 'Poção do Crescimento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:55.192-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-de-crescimento.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Cura 1d8 PV perdidos ou qualquer doença no usuário, '
                 'exatamente como nas magias divinas Curar Ferimentos (1º '
                 'círculo) ou Curar Doenças.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 163},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 114}],
  'id': 'pocao-de-cura',
  'name': 'Poção de Cura',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:54.764-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-de-cura.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Seu usuário recebe um benefício temporário na sua CA. O '
                 'bônus de 1d4+1 na CA dura 1 turno e é acumulativo com outros '
                 'bônus mágicos na CA como os concedidos por armaduras ou '
                 'armas mágicas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 114}],
  'id': 'pocao-de-defesa',
  'name': 'Poção de Defesa',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:54.885-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-de-defesa.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Esta poção caótica engana o usuário que acredita ter tomado '
                 'uma poção de cura sem que ela efetivamente cure qualquer '
                 'ponto de vida. O Mestre deve controlar em suas anotações o '
                 '"verdadeiro" valor dos pontos de vida do personagem que '
                 'acredita ter curado 1d8 pontos de vida.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 115}],
  'id': 'pocao-de-placebo',
  'name': 'Poção de Placebo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:54.982-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-de-placebo.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Esta poção concede ao seu usuário a habilidade de respirar '
                 'normalmente na água, como se estivesse fora dela. Esta poção '
                 'dura 24 horas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 115}],
  'id': 'pocao-de-respirar-na-agua',
  'name': 'Poção de Respirar na Água',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:55.095-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-de-respirar-na-agua.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Concede ao seu usuário os efeitos temporários de ser um '
                 'herói. O bebedor da poção recebe um nível aleatório de uma '
                 'das classes básicas (role 1d4: 1 - Clérigo, 2 - Guerreiro, 3 '
                 '- Ladrão e 4 - Mago) e todos os poderes concedidos por essa '
                 'classe no 1º nível.\r\n'
                 '\r\n'
                 'Caso um personagem receba uma classe à qual ele já possua '
                 'algum nível, um nível adicional é somado ao seu atual pela '
                 'duração da poção. Habilidades, dados de vida, pontos de '
                 'vida, bônus em ataque, dano e jogadas de proteção são '
                 'melhoradas por esta poção. Os efeitos duram 1d4 horas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 115}],
  'id': 'pocao-do-heroismo',
  'name': 'Poção do Heroísmo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:55.292-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-do-heroismo.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Esta poção concede ao seu usuário o poder de saltar acima '
                 'dos limites normais. O salto pode ser de até 10 metros, os '
                 'quais podem ser divididos entre altura e distância. Assim, é '
                 'possível saltar 10 metros para cima ou 5 metros para frente '
                 'e ao mesmo tempo, 5 metros para cima. Assim que 10 metros no '
                 'total forem saltados, os efeitos da poção se encerram.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 115}],
  'id': 'pocao-do-salto',
  'name': 'Poção do Salto',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:55.386-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-do-salto.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'O usuário desta poção ativa sobre si os efeitos da magia de '
                 'mesmo nome, recebendo o poder de voar, com deslocamento de '
                 '36m por turno, na direção ou orientação desejada por até 3 '
                 'turnos de duração.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 116}],
  'id': 'pocao-do-voo',
  'name': 'Poção do Voo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:55.485-03:00',
  'url': 'https://olddragon.com.br/equipamentos/pocao-do-voo.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'vehicle',
  'cost': 4000,
  'damage': None,
  'description': 'Para tração ou montaria. Carrega até 1.500 moedas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'ponei',
  'name': 'Pônei',
  'type': 'Equipment',
  'updated_at': '2023-05-31T22:00:15.565-03:00',
  'url': 'https://olddragon.com.br/equipamentos/ponei.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'vehicle',
  'cost': 8000,
  'damage': None,
  'description': 'Treinado para combates. Carrega até 1.500 moedas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'ponei-de-guerra',
  'name': 'Pônei de Guerra',
  'type': 'Equipment',
  'updated_at': '2023-05-31T22:00:15.583-03:00',
  'url': 'https://olddragon.com.br/equipamentos/ponei-de-guerra.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 50,
  'damage': '1d4',
  'description': 'Média, Madeira, Versátil, Impactante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'porrete-clava',
  'name': 'Porrete/Clava',
  'picture': 'https://public.olddragon.com.br/5h3iekj8ky8ev90dowwj87unyqhd',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:21.476-03:00',
  'url': 'https://olddragon.com.br/equipamentos/porrete-clava.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Média, Madeira, Versátil, Impactante',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'porrete-clava-mais-1',
  'name': 'Porrete/Clava +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:30.064-03:00',
  'url': 'https://olddragon.com.br/equipamentos/porrete-clava-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Média, Madeira, Versátil, Impactante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela arma.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'porrete-clava-mais-1-curador',
  'name': 'Porrete/Clava +1 Curador',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:30.159-03:00',
  'url': 'https://olddragon.com.br/equipamentos/porrete-clava-mais-1-curador.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 1,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Média, Madeira, Versátil, Impactante.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'porrete-clava-mais-1-defensor',
  'name': 'Porrete/Clava +1 Defensor',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:30.245-03:00',
  'url': 'https://olddragon.com.br/equipamentos/porrete-clava-mais-1-defensor.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Média, Madeira, Versátil, Impactante.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'porrete-clava-mais-1-do-desarme',
  'name': 'Porrete/Clava +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:30.329-03:00',
  'url': 'https://olddragon.com.br/equipamentos/porrete-clava-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Média, Madeira, Versátil, Impactante',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'porrete-clava-mais-2',
  'name': 'Porrete/Clava +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:30.417-03:00',
  'url': 'https://olddragon.com.br/equipamentos/porrete-clava-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Média, Madeira, Versátil, Impactante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela arma.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'porrete-clava-mais-2-curador',
  'name': 'Porrete/Clava +2 Curador',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:30.503-03:00',
  'url': 'https://olddragon.com.br/equipamentos/porrete-clava-mais-2-curador.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 2,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Média, Madeira, Versátil, Impactante.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'porrete-clava-mais-2-defensor',
  'name': 'Porrete/Clava +2 Defensor',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:30.592-03:00',
  'url': 'https://olddragon.com.br/equipamentos/porrete-clava-mais-2-defensor.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Média, Madeira, Versátil, Impactante.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'porrete-clava-mais-2-do-desarme',
  'name': 'Porrete/Clava +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:30.769-03:00',
  'url': 'https://olddragon.com.br/equipamentos/porrete-clava-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Média, Madeira, Versátil, Impactante',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'porrete-clava-mais-3',
  'name': 'Porrete/Clava +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:30.870-03:00',
  'url': 'https://olddragon.com.br/equipamentos/porrete-clava-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Média, Madeira, Versátil, Impactante.\r\n'
                 '\r\n'
                 'Pode curar 1d8+4 pontos de vida por dia de um único alvo, se '
                 'este for tocado delicadamente pela arma.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'porrete-clava-mais-3-curador',
  'name': 'Porrete/Clava +3 Curador',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:30.960-03:00',
  'url': 'https://olddragon.com.br/equipamentos/porrete-clava-mais-3-curador.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': 3,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Média, Madeira, Versátil, Impactante.\r\n'
                 '\r\n'
                 'Seu bônus também é somado à classe de armadura do usuário.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'porrete-clava-mais-3-defensor',
  'name': 'Porrete/Clava +3 Defensor',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:31.078-03:00',
  'url': 'https://olddragon.com.br/equipamentos/porrete-clava-mais-3-defensor.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Média, Madeira, Versátil, Impactante.\r\n'
                 '\r\n'
                 'O alvo do dano de ataque desta arma deve ser bem-sucedido em '
                 'uma JPC ou largará qualquer arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'porrete-clava-mais-3-do-desarme',
  'name': 'Porrete/Clava +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:31.167-03:00',
  'url': 'https://olddragon.com.br/equipamentos/porrete-clava-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Média, Madeira, Versátil, Impactante',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'porrete-clava-menos-1',
  'name': 'Porrete/Clava -1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:29.866-03:00',
  'url': 'https://olddragon.com.br/equipamentos/porrete-clava-menos-1.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Média, Madeira, Versátil, Impactante',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 110}],
  'id': 'porrete-clava-menos-2',
  'name': 'Porrete/Clava -2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:29.960-03:00',
  'url': 'https://olddragon.com.br/equipamentos/porrete-clava-menos-2.json',
  'weight_in_grams': None,
  'weight_in_load': 2},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'container',
  'cost': 100,
  'damage': None,
  'description': 'Acomoda até 20 folhas de pergaminhos ou mapas. Comporta até '
                 '50 moedas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'porta-mapas',
  'name': 'Porta Mapas',
  'picture': 'https://public.olddragon.com.br/zjwfyvbodvqxmkwd8zmqw8h01mh6',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:16.338-03:00',
  'url': 'https://olddragon.com.br/equipamentos/porta-mapas.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Pequena, Perfurante, Arremesso (9).\r\n'
                 '\r\n'
                 'Um artefato de épocas remotas, dedicado ao Rei Sapo e usado '
                 'contra répteis de todos os tipos, causando 1d4 de dano ou '
                 '3d4 de dano em criaturas reptilianas, além de impedir que se '
                 'regenerem ou se curem por 30 dias após o ferimento.\r\n'
                 '\r\n'
                 'Seu cabo possui uma cabeça de sapo esculpida, e na lâmina, '
                 'em baixo relevo dourado, a imagem de serpentes sem cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday24.json',
              'page': 10}],
  'id': 'punhal-reptilicida',
  'name': 'Punhal Reptilicida',
  'type': 'Equipment',
  'updated_at': '2025-01-29T22:56:52.388-03:00',
  'url': 'https://olddragon.com.br/equipamentos/punhal-reptilicida.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 100,
  'damage': None,
  'description': 'Ração diária de comida para viagem para uma pessoa.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'racao-de-viagem',
  'name': 'Ração de viagem',
  'picture': 'https://public.olddragon.com.br/w0cq11u2sixux6pd9j1pbcw5eeg2',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:25.367-03:00',
  'url': 'https://olddragon.com.br/equipamentos/racao-de-viagem.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 200,
  'damage': None,
  'description': 'Pode ser usada num ataque em área para enredar inimigos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'rede',
  'name': 'Rede',
  'picture': 'https://public.olddragon.com.br/obm234xq1egk2eggdkr7ek7h9miv',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:49.735-03:00',
  'url': 'https://olddragon.com.br/equipamentos/rede.json',
  'weight_in_grams': 2000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 1500,
  'damage': '1d10',
  'description': 'Média, Perfurante',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday16.json',
              'page': 9}],
  'id': 'sabre',
  'name': 'Sabre',
  'type': 'Equipment',
  'updated_at': '2025-03-27T21:53:33.934-03:00',
  'url': 'https://olddragon.com.br/equipamentos/sabre.json',
  'weight_in_grams': None,
  'weight_in_load': 1},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 50,
  'damage': None,
  'description': 'Para uma pessoa de tamanho P ou M.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'saco-de-dormir',
  'name': 'Saco de Dormir',
  'picture': 'https://public.olddragon.com.br/ste03nhnemw2b9wgwhw3yoxk7zpw',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:15.554-03:00',
  'url': 'https://olddragon.com.br/equipamentos/saco-de-dormir.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'misc',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 102}],
  'id': 'saco-de-dormir-de-peles',
  'name': 'Saco de Dormir de Peles',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:07.374-03:00',
  'url': 'https://olddragon.com.br/equipamentos/saco-de-dormir-de-peles.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'container',
  'cost': 5,
  'damage': None,
  'description': 'Para carregar até 15 kg. Quando carregado, reduz pela metade '
                 'o peso dos objetos em seu interior. Comporta até 600 moedas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'saco-de-estopa',
  'name': 'Saco de estopa',
  'type': 'Equipment',
  'updated_at': '2023-05-31T22:00:15.471-03:00',
  'url': 'https://olddragon.com.br/equipamentos/saco-de-estopa.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'container',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 102}],
  'id': 'saco-de-retalhos',
  'name': 'Saco de Retalhos',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:25.918-03:00',
  'url': 'https://olddragon.com.br/equipamentos/saco-de-retalhos.json'},
 {'access': 'limited',
  'concept': 'container',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 102}],
  'id': 'saco-grande-de-retalhos',
  'name': 'Saco Grande de Retalhos',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:51.538-03:00',
  'url': 'https://olddragon.com.br/equipamentos/saco-grande-de-retalhos.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'container',
  'cost': None,
  'damage': None,
  'description': 'Esta sacola de pano, aparentemente normal, devora '
                 'literalmente os itens não vivos inseridos dentro do saco em '
                 'até 1d6+6 turnos, fazendo-os desaparecer para sempre.\r\n'
                 '\r\n'
                 'Até os itens serem devorados é possível enfiar as mãos '
                 'dentro da sacola e retirá-los normalmente como em uma sacola '
                 'comum.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 167},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 127}],
  'id': 'sacola-devoradora-caotica',
  'name': 'Sacola Devoradora (Caótica)',
  'type': 'Equipment',
  'updated_at': '2025-01-29T22:57:06.605-03:00',
  'url': 'https://olddragon.com.br/equipamentos/sacola-devoradora-caotica.json',
  'weight_in_grams': 300,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'container',
  'cost': None,
  'damage': None,
  'description': 'Esta sacola de pano, aparentemente normal, atua guardando '
                 'itens maiores dos quais uma sacola igual normalmente faria, '
                 'e reduz em 95% o peso do que está dentro dela.\r\n'
                 '\r\n'
                 'Na prática, 1.000 moedas guardadas dentro de uma sacola '
                 'guardiã pesam o mesmo que 50 moedas. Itens muito grandes, '
                 'superiores a 3 x 1,5m, não cabem na sacola.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 127}],
  'id': 'sacola-guardia',
  'name': 'Sacola Guardiã',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:56.765-03:00',
  'url': 'https://olddragon.com.br/equipamentos/sacola-guardia.json',
  'weight_in_grams': 300,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'weapon',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/sdg.json',
              'page': 53}],
  'id': 'saex',
  'name': 'Sæx',
  'type': 'Equipment',
  'updated_at': '2025-02-15T23:30:58.720-03:00',
  'url': 'https://olddragon.com.br/equipamentos/saex.json'},
 {'access': 'limited',
  'concept': 'misc',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 102}],
  'id': 'sandalias-usadas-e-farrapos-para-vestir',
  'name': 'Sandálias Usadas e Farrapos para Vestir',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:06.937-03:00',
  'url': 'https://olddragon.com.br/equipamentos/sandalias-usadas-e-farrapos-para-vestir.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'vehicle',
  'cost': 1000,
  'damage': None,
  'description': 'Kit de arreios, sela e correias para montar, para parelha ou '
                 'para tração.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 64}],
  'id': 'selas-e-arreios',
  'name': 'Selas e Arreios',
  'type': 'Equipment',
  'updated_at': '2023-05-31T22:00:15.706-03:00',
  'url': 'https://olddragon.com.br/equipamentos/selas-e-arreios.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 100,
  'damage': None,
  'description': 'Simples e pequeno, de madeira ou latão, para Afastar '
                 'Mortos-Vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'simbolo-divino',
  'name': 'Símbolo divino',
  'picture': 'https://public.olddragon.com.br/w6py96hh0mch6z9kfepi7uvz80pp',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:13.312-03:00',
  'url': 'https://olddragon.com.br/equipamentos/simbolo-divino.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este enorme tambor de som grave e alto afeta todas as '
                 'criaturas que estejam entre 3 e 72 metros do usuário. Tais '
                 'criaturas devem ser bem-sucedidas em uma JPS ou fugirão '
                 'correndo em pânico por até 3 turnos completos.\r\n'
                 '\r\n'
                 'Há 60% de chance de as criaturas soltarem qualquer objeto '
                 'que estejam segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 127}],
  'id': 'tambores-do-panico-caotico',
  'name': 'Tambores do Pânico (Caótico)',
  'picture': 'https://public.olddragon.com.br/tgtqrxs86gsptkpx5w2y6hpafhvl',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:58.782-03:00',
  'url': 'https://olddragon.com.br/equipamentos/tambores-do-panico-caotico.json',
  'weight_in_grams': 3000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este tapete luxuoso e finamente tecido, pode voar e carregar '
                 'um passageiro a uma velocidade de 72 metros por turno, ou '
                 'até três passageiros por até 54 metros por turno.\r\n'
                 '\r\n'
                 'Um tapete voador também é capaz de transportar 600 kg em '
                 'equipamentos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 127}],
  'id': 'tapete-voador',
  'name': 'Tapete Voador',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:58.042-03:00',
  'url': 'https://olddragon.com.br/equipamentos/tapete-voador.json',
  'weight_in_grams': 2000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 1000,
  'damage': None,
  'description': 'Para até 4 pessoas P ou M e com 2 x 2 metros.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'tenda-pequena',
  'name': 'Tenda pequena',
  'picture': 'https://public.olddragon.com.br/uawm7kmctf2o6b0oelbot47y84i5',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:44.033-03:00',
  'url': 'https://olddragon.com.br/equipamentos/tenda-pequena.json',
  'weight_in_grams': 3000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 100,
  'damage': None,
  'description': '5 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'tocha',
  'name': 'Tocha',
  'picture': 'https://public.olddragon.com.br/h6rl9nbulz5s4kre21jz86t449kf',
  'type': 'Equipment',
  'updated_at': '2025-04-09T12:18:21.143-03:00',
  'url': 'https://olddragon.com.br/equipamentos/tocha.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'misc',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 102}],
  'id': 'tocha-de-salvia-do-deserto',
  'name': 'Tocha de Sálvia do Deserto',
  'type': 'Equipment',
  'updated_at': '2025-04-09T12:18:21.234-03:00',
  'url': 'https://olddragon.com.br/equipamentos/tocha-de-salvia-do-deserto.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 300,
  'damage': None,
  'description': 'Calça, cinto, camisa, gibão e manto.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'traje-de-exploracao',
  'name': 'Traje de exploração',
  'type': 'Equipment',
  'updated_at': '2023-05-31T21:59:59.458-03:00',
  'url': 'https://olddragon.com.br/equipamentos/traje-de-exploracao.json',
  'weight_in_grams': 2000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 500,
  'damage': None,
  'description': 'Calça, cinto, camisa, gibão e manto de lã e peles para o '
                 'Inverno.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'traje-de-inverno',
  'name': 'Traje de inverno',
  'type': 'Equipment',
  'updated_at': '2023-05-31T21:59:59.529-03:00',
  'url': 'https://olddragon.com.br/equipamentos/traje-de-inverno.json',
  'weight_in_grams': 3000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 2000,
  'damage': None,
  'description': 'Gibão, camisa, calça, cinto e manto de materiais nobres.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'traje-nobre',
  'name': 'Traje nobre',
  'type': 'Equipment',
  'updated_at': '2023-05-31T21:59:59.499-03:00',
  'url': 'https://olddragon.com.br/equipamentos/traje-nobre.json',
  'weight_in_grams': 1500,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'A trombeta da destruição cria um cone sônico com 30 metros '
                 'de comprimento e 6 metros de largura na parte mais distante '
                 'do usuário da trombeta.\r\n'
                 '\r\n'
                 'Os alvos dentro área do cone recebem 2d6 de dano e devem ser '
                 'bem-sucedidos em uma JPC ou ficarão surdos por um turno.\r\n'
                 '\r\n'
                 'Objetos dentro da área do cone devem ser bem-sucedidos em '
                 'uma Jogada de Proteção de Objetos contra Queda, com base na '
                 'tabela 5.10 do LB2 (página 54), para não serem destruídos '
                 'pelas fortes ondas sonoras.\r\n'
                 '\r\n'
                 'Uma trombeta da destruição precisa de 1d4 horas para se '
                 'recarregar entre um uso e outro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 127}],
  'id': 'trombeta-da-destruicao-caotica',
  'name': 'Trombeta da Destruição (Caótica)',
  'type': 'Equipment',
  'updated_at': '2025-01-29T22:56:03.565-03:00',
  'url': 'https://olddragon.com.br/equipamentos/trombeta-da-destruicao-caotica.json',
  'weight_in_grams': 1000,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 10,
  'damage': None,
  'description': 'De madeira com 3 metros. Para exploração e caminhadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'vara-de-exploracao',
  'name': 'Vara de exploração',
  'picture': 'https://public.olddragon.com.br/nl9x8uz38ilceg9yxxhofon1yuti',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:28.106-03:00',
  'url': 'https://olddragon.com.br/equipamentos/vara-de-exploracao.json',
  'weight_in_grams': 500,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Quando uma carga é usada, a varinha cria um efeito de Ilusão '
                 'exatamente como a magia arcana de Ilusionista de mesmo nome. '
                 'O usuário deve estar concentrado na ilusão para mantê-la, '
                 'mas ainda pode fazer pequenas caminhadas, como se seu '
                 'movimento estivesse reduzido à metade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 122}],
  'id': 'varinha-da-ilusao',
  'name': 'Varinha da Ilusão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:58.812-03:00',
  'url': 'https://olddragon.com.br/equipamentos/varinha-da-ilusao.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Quando uma carga é usada, a varinha cria uma modificação '
                 'corporal em um alvo como se este estivesse sob o efeito de '
                 'uma magia Metamorfose. Um alvo não voluntário pode realizar '
                 'uma JPC para evitar esse efeito.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 122}],
  'id': 'varinha-da-transformacao',
  'name': 'Varinha da Transformação',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:58.915-03:00',
  'url': 'https://olddragon.com.br/equipamentos/varinha-da-transformacao.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Quando uma carga é usada, a varinha dispara uma bola de fogo '
                 'do tamanho de uma pequena pérola de fogo que explode ao '
                 'chegar ao alvo. O raio da explosão é de 6 metros, causando '
                 '6d6 de dano a todos na área. Um sucesso em uma JPD reduz o '
                 'dano pela metade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 166},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 122}],
  'id': 'varinha-de-bola-de-fogo',
  'name': 'Varinha de Bola de Fogo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:59.015-03:00',
  'url': 'https://olddragon.com.br/equipamentos/varinha-de-bola-de-fogo.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Quando uma carga é usada, a varinha faz todas as armadilhas '
                 'e suas partes brilharem dentro de uma área de 6 metros. Se a '
                 'armadilha não estiver visível, o brilho não será visto. Esta '
                 'varinha não identifica o modo de ativação da armadilha e nem '
                 'faz com que o usuário consiga desarmá-la.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 122}],
  'id': 'varinha-de-deteccao-de-armadilhas',
  'name': 'Varinha de Detecção de Armadilhas',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:59.127-03:00',
  'url': 'https://olddragon.com.br/equipamentos/varinha-de-deteccao-de-armadilhas.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Quando uma carga é usada, a varinha faz todos os inimigos '
                 'dentro de uma área de 18 metros brilharem com uma aura '
                 'mágica. A varinha detecta até mesmo inimigos escondidos ou '
                 'invisíveis.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 122}],
  'id': 'varinha-de-deteccao-de-inimigos',
  'name': 'Varinha de Detecção de Inimigos',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:59.229-03:00',
  'url': 'https://olddragon.com.br/equipamentos/varinha-de-deteccao-de-inimigos.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Quando uma carga é usada, a varinha faz todos os objetos '
                 'mágicos, itens ou pessoas sob efeito de uma magia brilharem '
                 'dentro de uma área de 6 metros. Se o item não estiver '
                 'visível, o brilho não será visto.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 166},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 122}],
  'id': 'varinha-de-deteccao-de-magia',
  'name': 'Varinha de Detecção de Magia',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:59.346-03:00',
  'url': 'https://olddragon.com.br/equipamentos/varinha-de-deteccao-de-magia.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'limited',
  'concept': 'misc',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/ja1.json',
              'page': 33}],
  'id': 'varinha-de-misseis-magicos',
  'name': 'Varinha de Mísseis Mágicos',
  'type': 'Equipment',
  'updated_at': '2025-02-15T23:29:55.573-03:00',
  'url': 'https://olddragon.com.br/equipamentos/varinha-de-misseis-magicos.json'},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Quando uma carga é usada, a varinha emite um raio em formato '
                 'de cone com 18m de comprimento e 9 m de largura na '
                 'extremidade. Qualquer criatura pega pelo raio deve ser '
                 'bem-sucedida em uma JPC ou ficará paralisada por 6 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 166},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 122}],
  'id': 'varinha-de-paralisacao',
  'name': 'Varinha de Paralisação',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:59.471-03:00',
  'url': 'https://olddragon.com.br/equipamentos/varinha-de-paralisacao.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Quando uma carga é usada, a varinha cria um cone de frio '
                 'intenso e instantâneo com 18 metros de comprimento e 9 '
                 'metros de largura na extremidade mais distante da varinha. '
                 'Todos dentro da área do cone recebem 6d6 de dano devido ao '
                 'frio extremo, mas uma JPD bem-sucedida reduz o dano pela '
                 'metade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 122}],
  'id': 'varinha-do-congelamento',
  'name': 'Varinha do Congelamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:59.584-03:00',
  'url': 'https://olddragon.com.br/equipamentos/varinha-do-congelamento.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Quando uma carga é usada, a varinha cria um cone com 18 '
                 'metros de comprimento e 9 metros de largura na extremidade '
                 'mais distante da varinha. Todos dentro da área do cone devem '
                 'ser bem-sucedidos em uma JPS ou fugirão do usuário da '
                 'varinha como se estivessem sob o efeito de uma magia Medo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 122}],
  'id': 'varinha-do-medo',
  'name': 'Varinha do Medo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:59.675-03:00',
  'url': 'https://olddragon.com.br/equipamentos/varinha-do-medo.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Quando uma carga é usada, a varinha emite um raio elétrico '
                 'causando 5d8 pontos de dano a um único alvo. Uma JPD '
                 'bem-sucedida reduz o dano pela metade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 122}],
  'id': 'varinha-do-relampago',
  'name': 'Varinha do Relâmpago',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:59.764-03:00',
  'url': 'https://olddragon.com.br/equipamentos/varinha-do-relampago.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'Este item mundano com aparência normal e comum é ativado por '
                 'uma palavra de comando, a qual o transforma em um objeto '
                 'voador. Seu montador pode ser levado a até 72 metros por '
                 'turno, na direção ou orientação desejada.\r\n'
                 '\r\n'
                 'Se uma pessoa adicional ou bagagem estiver sendo carregada, '
                 'a velocidade da vassoura cai para 54 metros por turno.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 127}],
  'id': 'vassoura-de-voo',
  'name': 'Vassoura de Voo',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:54:59.853-03:00',
  'url': 'https://olddragon.com.br/equipamentos/vassoura-de-voo.json',
  'weight_in_grams': 600,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': 10,
  'damage': None,
  'description': '12 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 62}],
  'id': 'vela',
  'name': 'Vela',
  'picture': 'https://public.olddragon.com.br/9qz6ya48yi8jmmvljeagcgh60pa7',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:11:03.278-03:00',
  'url': 'https://olddragon.com.br/equipamentos/vela.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'misc',
  'cost': None,
  'damage': None,
  'description': 'São substâncias mortais e perigosas que se passam '
                 'perfeitamente por poções. Se qualquer gole desta substância '
                 'for ingerido (até mesmo os pequenos goles que visam '
                 'identificar uma poção), quem a ingeriu precisará de um '
                 'sucesso em uma JPC ou morrerá em 1d4 turnos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 163},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 116}],
  'id': 'veneno',
  'name': 'Veneno',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:55:00.046-03:00',
  'url': 'https://olddragon.com.br/equipamentos/veneno.json',
  'weight_in_grams': 100,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 40,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'virote',
  'name': 'Virote',
  'picture': 'https://public.olddragon.com.br/2tpy5axk251xtk0ljl5grlo3j40h',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:10:27.040-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-mais-1',
  'name': 'Virote +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:31.583-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil explode ao tocar o alvo causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-mais-1-da-explosao',
  'name': 'Virote +1 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:31.679-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-mais-1-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-mais-1-do-atordoamento',
  'name': 'Virote +1 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:31.770-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-mais-1-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-mais-1-do-desarme',
  'name': 'Virote +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:31.866-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil é extremamente poderoso e ignora qualquer tipo '
                 'de proteção ou cobertura, passando por pessoas, móveis, '
                 'folhagens, teia ou qualquer outra barreira menos maciça que '
                 'uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-mais-1-penetrante',
  'name': 'Virote +1 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:31.958-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-mais-1-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-mais-2',
  'name': 'Virote +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:32.064-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil explode ao tocar o alvo causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-mais-2-da-explosao',
  'name': 'Virote +2 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:32.190-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-mais-2-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-mais-2-do-atordoamento',
  'name': 'Virote +2 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:32.293-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-mais-2-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-mais-2-do-desarme',
  'name': 'Virote +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:32.395-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil é extremamente poderoso e ignora qualquer tipo '
                 'de proteção ou cobertura, passando por pessoas, móveis, '
                 'folhagens, teia ou qualquer outra barreira menos maciça que '
                 'uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-mais-2-penetrante',
  'name': 'Virote +2 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:32.487-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-mais-2-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-mais-3',
  'name': 'Virote +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:32.584-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil explode ao tocar o alvo causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-mais-3-da-explosao',
  'name': 'Virote +3 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:32.690-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-mais-3-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-mais-3-do-atordoamento',
  'name': 'Virote +3 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:32.795-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-mais-3-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-mais-3-do-desarme',
  'name': 'Virote +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:32.910-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil é extremamente poderoso e ignora qualquer tipo '
                 'de proteção ou cobertura, passando por pessoas, móveis, '
                 'folhagens, teia ou qualquer outra barreira menos maciça que '
                 'uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-mais-3-penetrante',
  'name': 'Virote +3 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:33.017-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-mais-3-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-menos-1-amaldicoado',
  'name': 'Virote -1 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:31.332-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-menos-1-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d6',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-menos-2-amaldicoado',
  'name': 'Virote -2 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:31.498-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-menos-2-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': 20,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 58}],
  'id': 'virote-pequeno',
  'name': 'Virote pequeno',
  'picture': 'https://public.olddragon.com.br/otyh51w95dggkf3jygk4buywowpk',
  'type': 'Equipment',
  'updated_at': '2023-12-26T22:09:57.773-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-pequeno-mais-1',
  'name': 'Virote pequeno +1',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:33.374-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno-mais-1.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil explode ao tocar o alvo causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-pequeno-mais-1-da-explosao',
  'name': 'Virote pequeno +1 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:33.463-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno-mais-1-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-pequeno-mais-1-do-atordoamento',
  'name': 'Virote pequeno +1 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:33.554-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno-mais-1-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-pequeno-mais-1-do-desarme',
  'name': 'Virote pequeno +1 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:33.644-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno-mais-1-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil é extremamente poderoso e ignora qualquer tipo '
                 'de proteção ou cobertura, passando por pessoas, móveis, '
                 'folhagens, teia ou qualquer outra barreira menos maciça que '
                 'uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-pequeno-mais-1-penetrante',
  'name': 'Virote pequeno +1 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:33.741-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno-mais-1-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-pequeno-mais-2',
  'name': 'Virote pequeno +2',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:33.866-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno-mais-2.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil explode ao tocar o alvo causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-pequeno-mais-2-da-explosao',
  'name': 'Virote pequeno +2 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:33.955-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno-mais-2-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-pequeno-mais-2-do-atordoamento',
  'name': 'Virote pequeno +2 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:34.051-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno-mais-2-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-pequeno-mais-2-do-desarme',
  'name': 'Virote pequeno +2 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:34.143-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno-mais-2-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil é extremamente poderoso e ignora qualquer tipo '
                 'de proteção ou cobertura, passando por pessoas, móveis, '
                 'folhagens, teia ou qualquer outra barreira menos maciça que '
                 'uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-pequeno-mais-2-penetrante',
  'name': 'Virote pequeno +2 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:34.239-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno-mais-2-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-pequeno-mais-3',
  'name': 'Virote pequeno +3',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:34.327-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno-mais-3.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil explode ao tocar o alvo causando 1d6 de dano '
                 'extra a todos em até 1d4 metros de distância do local da '
                 'explosão. O atacante não é atingido pelo dano da explosão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-pequeno-mais-3-da-explosao',
  'name': 'Virote pequeno +3 da Explosão',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:34.412-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno-mais-3-da-explosao.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou ficará atordoado '
                 'por 1d6 rodadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-pequeno-mais-3-do-atordoamento',
  'name': 'Virote pequeno +3 do Atordoamento',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:34.501-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno-mais-3-do-atordoamento.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'O alvo deve ser bem-sucedido em uma JPC ou largará qualquer '
                 'arma que esteja segurando.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-pequeno-mais-3-do-desarme',
  'name': 'Virote pequeno +3 do Desarme',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:34.590-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno-mais-3-do-desarme.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.\r\n'
                 '\r\n'
                 'Este projétil é extremamente poderoso e ignora qualquer tipo '
                 'de proteção ou cobertura, passando por pessoas, móveis, '
                 'folhagens, teia ou qualquer outra barreira menos maciça que '
                 'uma parede fina.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-pequeno-mais-3-penetrante',
  'name': 'Virote pequeno +3 Penetrante',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:34.688-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno-mais-3-penetrante.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-pequeno-menos-1-amaldicoado',
  'name': 'Virote pequeno -1 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:33.178-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno-menos-1-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': None},
 {'access': 'complete',
  'bonus_ca': None,
  'concept': 'weapon',
  'cost': None,
  'damage': '1d4',
  'description': 'Perfurante. Peso e preço pelo conjunto de 20 unidades.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 111}],
  'id': 'virote-pequeno-menos-2-amaldicoado',
  'name': 'Virote pequeno -2 Amaldiçoado',
  'type': 'Equipment',
  'updated_at': '2025-01-09T14:56:33.279-03:00',
  'url': 'https://olddragon.com.br/equipamentos/virote-pequeno-menos-2-amaldicoado.json',
  'weight_in_grams': None,
  'weight_in_load': None}]
