#? Arquivo gerado a partir de monstros.json

monstros = [{'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Abelhas gigantes (30cm) de temperamento agressivo. Constroem '
            'colmeias subterrâneas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 56}],
  'habitats': ['desertos'],
  'id': 'abelha-diamante',
  'name': 'Abelha-Diamante',
  'size': 'miudo',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/abelha-diamante.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4 + Veneno',
               'description': 'Ferrão',
               'text': '1 × Ferrão +2 (1d4 + Veneno)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'inseto',
  'description': '\n'
                 '\n'
                 '  * **Veneno**: causa morte em 1d3+1 turnos em caso de falha '
                 'em uma JPC.\n'
                 '\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '5d6',
  'flavor': 'Agressivas e venenosas, fazem colmeia nos subterrâneos e tocas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 114}],
  'habitats': [],
  'id': 'abelhas-assassinas',
  'jp': '5',
  'mo': 12,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Abelhas Assassinas',
  'picture': None,
  'pv': '10',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/abelhas-assassinas.json',
  'variant': False,
  'xp': '65'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 8,
               'damage': '1d12',
               'damage_bonus': None,
               'damage_description': '1d12',
               'description': 'Mordida',
               'text': '1 × Mordida +8 (1d12)',
               'times': 1,
               'weapon': False},
              {'ba': 8,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Tentáculos',
               'text': '2 × Tentáculos +8 (1d8+2)',
               'times': 2,
               'weapon': False}],
  'ca': '17',
  'concept': 'besta',
  'description': '\n'
                 '\n'
                 '  * **Imunidades**: imune a ataques físicos e de '
                 'eletricidade.\n'
                 '\n',
  'dv': '5',
  'dv_bonus': '+10',
  'encounters': '',
  'encounters_lair': '',
  'flavor': 'Um monstro incorpóreo feito de energia. Exibe seus tentáculos num '
            'corpo de aranha, e sua cabeça lembra uma forma corrompida do que '
            'um dia foi um elfo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 15}],
  'habitats': ['qualquer'],
  'id': 'aberracao-de-veldren-estagio-1',
  'jp': '10',
  'mo': 10,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Aberração de Veldren (Estágio 1)',
  'picture': None,
  'pv': '35',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/aberracao-de-veldren-estagio-1.json',
  'variant': False,
  'xp': '740'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 13,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Tentáculos',
               'text': '2 × Tentáculos +13 (2d6)',
               'times': 2,
               'weapon': False},
              {'ba': 13,
               'damage': '3d8',
               'damage_bonus': None,
               'damage_description': '3d8',
               'description': 'Mordida',
               'text': '1 × Mordida +13 (3d8)',
               'times': 1,
               'weapon': False}],
  'ca': '19',
  'concept': 'besta',
  'description': '  * **Imunidades**: imune a ataques físicos e de '
                 'eletricidade.',
  'dv': '15',
  'dv_bonus': '',
  'encounters': '',
  'encounters_lair': '',
  'flavor': 'Um monstro incorpóreo feito de energia. Exibe seus tentáculos num '
            'corpo de aranha, e sua cabeça lembra uma forma corrompida do que '
            'um dia foi um elfo.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 15}],
  'habitats': ['qualquer'],
  'id': 'aberracao-de-veldren-estagio-2',
  'jp': '14',
  'mo': 10,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Aberração de Veldren (Estágio 2)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/aberracao-de-veldren-estagio-1.json',
  'pv': '75',
  'size': 'grande',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/aberracao-de-veldren-estagio-2.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '3150'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 13,
               'damage': '2d6',
               'damage_bonus': 4,
               'damage_description': '2d6+4',
               'description': 'Tentáculos',
               'text': '3 × Tentáculos +13 (2d6+4)',
               'times': 3,
               'weapon': False},
              {'ba': 13,
               'damage': '3d10',
               'damage_bonus': None,
               'damage_description': '3d10',
               'description': 'Mordida',
               'text': '1 × Mordida +13 (3d10)',
               'times': 1,
               'weapon': False}],
  'ca': '19',
  'concept': 'besta',
  'description': '  * **Imunidades**: imune a ataques físicos e de '
                 'eletricidade.',
  'dv': '18',
  'dv_bonus': '+2',
  'encounters': '',
  'encounters_lair': '',
  'flavor': 'Um monstro incorpóreo feito de energia. Exibe seus tentáculos num '
            'corpo de aranha, e sua cabeça lembra uma forma corrompida do que '
            'um dia foi um elfo.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 15}],
  'habitats': ['qualquer'],
  'id': 'aberracao-de-veldren-estagio-3',
  'jp': '14',
  'mo': 10,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Aberração de Veldren (Estágio 3)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/aberracao-de-veldren-estagio-1.json',
  'pv': '92',
  'size': 'grande',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/aberracao-de-veldren-estagio-3.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '4200'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide_monstruoso',
  'flavor': 'Antigo aldeão transformado em uma aberração que conserva pouco de '
            'sua mente, substituída por um instinto aquático, odioso e '
            'animalesco.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday18.json',
              'page': 13}],
  'habitats': ['oceanos'],
  'id': 'aberracao-do-culto',
  'name': 'Aberração do Culto',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/aberracao-do-culto.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide_monstruoso',
  'flavor': 'Antigo pirata transformado em uma aberração que conserva pouco de '
            'sua mente, substituída por um instinto aquático, odioso e '
            'animalesco.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday18.json',
              'page': 13}],
  'habitats': ['oceanos'],
  'id': 'aberracao-pirata',
  'name': 'Aberração Pirata',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/aberracao-pirata.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Tão grandes quanto cães. Se famintos, podem atacar humanos ou '
            'criaturas de tamanho parecido.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 56}],
  'habitats': ['desertos'],
  'id': 'abutre-gigante',
  'name': 'Abutre Gigante',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/abutre-gigante.json',
  'variant': False},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Martelo',
               'text': '1 × Martelo +3 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '10',
  'concept': 'humanoide',
  'description': '',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '0',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 80},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 8}],
  'habitats': [],
  'id': 'acolito',
  'jp': '5',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Acólito',
  'pv': '10',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/acolito.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d2',
               'damage_bonus': None,
               'damage_description': '1d2',
               'description': 'Garra',
               'text': '1 × Garra +1 (1d2)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Rasante**: podem realizar um ataque rasante com +2 '
                 'para acertar o ataque, +2 no dano causado e -2 na CA. Causam '
                 'dano dobrado em vítimas surpresas.\n'
                 '\n',
  'dv': '½',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1d6',
  'flavor': 'Ave de rapina carnívora e caçadora que vive nas montanhas e '
            'florestas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 15},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['colinas', 'florestas', 'montanhas'],
  'id': 'aguia',
  'jp': '4',
  'mo': 9,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 30,
  'name': 'Águia',
  'picture': None,
  'pv': '2',
  'size': 'pequeno',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/aguia.json',
  'variant': False,
  'xp': '10'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Mordida',
               'text': '1 × Mordida +4 (1d6)',
               'times': 1,
               'weapon': False},
              {'ba': 4,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Garras',
               'text': '2 × Garras +4 (1d4)',
               'times': 2,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': 'Estes belos animais não são muito diferentes de sua versão '
                 'normal, abrangendo praticamente o mesmo padrão de cores das '
                 'águias encontradas na natureza.  Contudo, sua postura e modo '
                 'de interagir com os demais denotam uma criatura de '
                 'inteligência claramente perigosa.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam principalmente para defender seu ninho, território de '
                 'caça e filhotes.\n'
                 '\n'
                 'Dão um voo rasante, podendo inclusive agarrar suas vítimas '
                 'para soltá-las de uma altura mortal.\n'
                 '\n'
                 '  * **Ataque rasante**: a Águia pode fazer um ataque rasante '
                 'no seu primeiro ataque e tentar pegar seus inimigos de '
                 'surpresa com uma chance de 1-4 em 1d6. Nestas '
                 'circunstâncias, a Águia Gigante recebe +2 para acertar o '
                 'ataque e +2 no dano causado. Porém, recebe -2 no CA. Se o '
                 'inimigo estiver surpreso, troca-se o bônus de +2 no dano '
                 'para causar o dobro de dano no alvo surpreendido.\n'
                 '\n'
                 '  * **Agarrar**: se preferir, a Águia Gigante pode agarrar '
                 'seus alvos com suas garras em vez de causar dano. A vítima '
                 'pode realizar uma JPD para evitar ser agarrada pela águia.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Estas águias constroem seus ninhos apenas nas montanhas mais '
                 'altas e inacessíveis, onde podem voar, caçar e chocar seus '
                 'ovos sem serem incomodadas.\n'
                 '\n'
                 'Vivem em duplas até terem seus filhotes. Quando isso '
                 'acontece, a fêmea vai embora e deixa o macho cuidando dos '
                 'filhos.\n'
                 '\n'
                 'São mais sociais do que as águias de tamanho comuns, mas '
                 'apenas com quem consideram aliados e amigos, sem intenção '
                 'maligna alguma.\n'
                 '\n'
                 'Respeitam Magos e elfos ligados às artes arcanas, servindo '
                 'de montaria àqueles que julgarem merecedores.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Ovos de Águias Gigantes possuem grande valor para criadores '
                 'de montarias.\n'
                 '\n'
                 'Um ninho de Águia Gigante estará ocupado pela Águia em 1-3 '
                 'vezes em 1d6 que for visitado. Há ainda 1 chance em 1d6 do '
                 'ninho ter 1d2 ovos ainda não chocados.',
  'dv': '3',
  'dv_bonus': '+5',
  'encounters': '0',
  'encounters_lair': '1d3',
  'flavor': 'Usada como animal de carga. Apesar do seu tamanho, é extremamente '
            'ágil.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 12},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['montanhas'],
  'id': 'aguia-gigante',
  'jp': '6',
  'mo': 9,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Águia Gigante',
  'picture': 'https://public.olddragon.com.br/mxft9mt8fwrnalgf91dwus5356d0',
  'pv': '20',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/70iw4tr15q1j5zpew08cgwjjyheh',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/aguia-gigante.json',
  'variant': False,
  'xp': '75'},
 {'access': 'partial',
  'alignment': 'neutro',
  'attacks': [{'ba': 0,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma (Arma)',
               'times': 1,
               'weapon': True}],
  'ca': '10',
  'concept': 'humanoide',
  'description': '',
  'dv': '½',
  'dv_bonus': '+1',
  'encounters': None,
  'encounters_lair': None,
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 78},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'ajudante',
  'jp': '4',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Ajudante',
  'pv': '3',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/ajudante.json',
  'variant': False,
  'xp': '5'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Alma amaldiçoada, presa ao mundo material por feitiços negativos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 56}],
  'habitats': ['desertos'],
  'id': 'alma-conspurcada',
  'name': 'Alma Conspurcada',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/alma-conspurcada.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Machado',
               'text': '1 × Machado +1 (1d8+1)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': 'Normalmente são encontrados como um grupo de patrulha '
                 'próximos às suas terras, em um destacamento militar, em um '
                 'pequeno clã em deslocamento ou ainda como um grupo de '
                 'mineradores.\n'
                 '\n'
                 'Encontrados em grupos pequenos de 1d6 indivíduos ou em '
                 'grupos maiores como um acampamento com 5d8 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 20 anões, um deles será o Anão '
                 'Líder.\n'
                 '\n'
                 '  * **Liderança**: há 1-2 chances em 1d6 de um Anão '
                 'Aventureiro de 3º Nível estar liderando o grupo em vez de um '
                 'Anão Líder.\n'
                 '\n'
                 '  * **Inimigos**: realizam ataques fáceis contra Orcs, Ogros '
                 'e Hobgoblins.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '+1',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 182},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'anao',
  'jp': '5',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Anão',
  'picture': 'https://public.olddragon.com.br/ossl7piak5skgt9fs4870724tv23',
  'pv': '6',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/niga7jvt1b9dkcod5gjtfku5nk8j',
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/anao.json',
  'variant': False,
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '2d4',
               'damage_bonus': 4,
               'damage_description': '2d4+4',
               'description': 'Martelo de batalha',
               'text': '1 × Martelo de batalha +3 (2d4+4)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Normalmente são encontrados como um grupo de patrulha '
                 'próximos às suas terras, em um destacamento militar, em um '
                 'pequeno clã em deslocamento ou ainda como um grupo de '
                 'mineradores.\n'
                 '\n'
                 'Encontrados em grupos pequenos de 1d6 indivíduos ou em '
                 'grupos maiores como um acampamento com 5d8 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 20 anões, um deles será o Anão '
                 'Líder.\n'
                 '\n'
                 '  * **Liderança**: há 1-2 chances em 1d6 de um Anão '
                 'Aventureiro de 3º Nível estar liderando o grupo em vez de um '
                 'Anão Líder.\n'
                 '\n'
                 '  * **Inimigos**: realizam ataques fáceis contra Orcs, Ogros '
                 'e Hobgoblins.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '+2',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 182},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'anao-aventureiro',
  'jp': '6',
  'mo': 10,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Anão Aventureiro',
  'parent_monster_url': 'https://olddragon.com.br/monstros/anao.json',
  'picture': 'https://public.olddragon.com.br/ossl7piak5skgt9fs4870724tv23',
  'pv': '17',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/niga7jvt1b9dkcod5gjtfku5nk8j',
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/anao-aventureiro.json',
  'variant': True,
  'variant_modifications': ['Duro na queda: um anão aventureiro de 3º nível '
                            'possui 27 pontos de vida.',
                            'Montado: há 1-4 chances de estar montado em um '
                            'Pônei de Guerra.'],
  'xp': '95'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma +3 (Arma)',
               'times': 1,
               'weapon': True},
              {'ba': 7,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4',
               'description': 'Espada Kundur',
               'text': '1 × Espada Kundur +7 (2d4)',
               'times': 1,
               'weapon': False}],
  'ca': '13/16',
  'concept': 'humanoide',
  'description': 'Aproximadamente do tamanho de um anão, mas com estrutura '
                 'corporoal bem diferente. São magros e esguios, mas muito '
                 'fortes para seu tamanho. Sua pele é branca como o leite, '
                 'assim como seus olhos que emitem uma leve luz azulada dos '
                 'globos oculares totalmente sem íris.\n'
                 '\n'
                 'Usam armaduras de couro de criaturas do subterrâneo e armas '
                 'forjadas com incrível capacidade de afiação nas lâminas.\n'
                 '\n'
                 '**Som**: passos leves e abafados.\n'
                 '\n'
                 '**Odor**: odor corporal (suor).\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Os Anões das Sombras sempre combatem, de modo a levar '
                 'vantagem sobre seus inimigos.  Dentre a raça, é comum o '
                 'bordão “Fuja hoje para vencê-los amanhã”.\n'
                 '\n'
                 'Sempre utilizam artifícios extras em combate para obter '
                 'vantagem. Preparam armadilhas, armam tocaias e soltam '
                 'animais ou bestas do subterrâneo para minar as forças do '
                 'inimigo, atacando somente quando tiverem uma considerável '
                 'vantagem.\n'
                 '\n'
                 '  * **Classe de armadura**: possuem CA 13 ou 16 quando usam '
                 'armadura de couro batido.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '  * **Espada Kundur**: possuem uma espada racial típica com '
                 'lâminas extremamente afiadas, serrilhadas e em formato de '
                 'cruz que são o terror de seus inimigos. Todo ataque '
                 'realizado com uma espada Kundur é considerado fácil para um '
                 'Anão das Sombras, mas todo ataque com outras armas são '
                 'considerados difíceis.\n'
                 '\n'
                 '  * **Furtivos**: são mestres em esconder-se nos '
                 'subterrâneos com 1-3 chances em 1d6.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Sua civilização é amplamente ancorada no comércio e na lei '
                 'de prata, um conjunto de leis mercantis que ditam todo o '
                 'comportamento destes anões.\n'
                 '\n'
                 'Dentre eles, existe a lenda do grande conquistador que os '
                 'levará de volta à superfície e escravizará todas as raças da '
                 'superfície, restaurando os tempos de glória destes anões.',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '3d10',
  'flavor': 'Grandes senhores dos subterrâneos, rivalizam com os Elfos Drow '
            'pelo controle total e soberania dos reinos sob a terra.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 13},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'anao-das-sombras',
  'jp': '6',
  'mo': 9,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Anão das Sombras',
  'picture': 'https://public.olddragon.com.br/0jek7o56ezgtpz3vneui9fc37mxk',
  'pv': '15',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/eemntqkuunulvgxr8evkx1em7s0p',
  'treasure': 'q',
  'treasure_lair': 'f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/anao-das-sombras.json',
  'variant': False,
  'xp': '95'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '2d4',
               'damage_bonus': 2,
               'damage_description': '2d4+2',
               'description': 'Martelo de batalha',
               'text': '1 × Martelo de batalha +3 (2d4+2)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Normalmente são encontrados como um grupo de patrulha '
                 'próximos às suas terras, em um destacamento militar, em um '
                 'pequeno clã em deslocamento ou ainda como um grupo de '
                 'mineradores.\n'
                 '\n'
                 'Encontrados em grupos pequenos de 1d6 indivíduos ou em '
                 'grupos maiores como um acampamento com 5d8 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 20 anões, um deles será o Anão '
                 'Líder.\n'
                 '\n'
                 '  * **Liderança**: há 1-2 chances em 1d6 de um Anão '
                 'Aventureiro de 3º Nível estar liderando o grupo em vez de um '
                 'Anão Líder.\n'
                 '\n'
                 '  * **Inimigos**: realizam ataques fáceis contra Orcs, Ogros '
                 'e Hobgoblins.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '+2',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 182},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'anao-lider',
  'jp': '6',
  'mo': 10,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Anão Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/anao.json',
  'picture': 'https://public.olddragon.com.br/ossl7piak5skgt9fs4870724tv23',
  'pv': '17',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/niga7jvt1b9dkcod5gjtfku5nk8j',
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/anao-lider.json',
  'variant': True,
  'variant_modifications': ['Moral: enquanto o líder estiver em combate, todos '
                            'os anões fazem o teste de moral com um bônus de '
                            '+1.',
                            'Montado: há 1-4 chances de estar montado em um '
                            'Pônei de Guerra.'],
  'xp': '75'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'besta',
  'flavor': 'Criaturas que misturam características de aranha e polvo. São '
            'azuladas e sua pele parece de látex. Possuem 8 patas em formato '
            'de tentáculos articulados semiflexíveis, usados como bastões para '
            'contundir suas vítimas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 57}],
  'habitats': ['desertos'],
  'id': 'anhandera',
  'name': 'Anhandêra',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/anhandera.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 10,
               'damage': '3d6',
               'damage_bonus': None,
               'damage_description': '3d6',
               'description': 'Cauda',
               'text': '1 × Cauda +10 (3d6)',
               'times': 1,
               'weapon': False}],
  'ca': '20',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '9',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1d4',
  'flavor': 'Este dinossauro possui uma das mais grossas couraças conhecidas. '
            'Ataca com sua cauda em forma de maça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 42},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': [],
  'id': 'anquilossauro',
  'jp': '11',
  'mo': 9,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Anquilossauro',
  'picture': None,
  'pv': '45',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/anquilossauro.json',
  'variant': False,
  'xp': '925'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Um criador de mundos de sofrimento e dor. Tem um poder absurdo, '
            'mas sua mentalidade infantil, egoísta e desatenta o deixam ainda '
            'mais terrível.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 57}],
  'habitats': ['desertos'],
  'id': 'antigo',
  'name': 'Antigo',
  'size': 'imenso',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/antigo.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'besta',
  'flavor': 'Um monstro insetoide terrível. Enterra-se nas areias e tem '
            'paladar para carne fresca. Tem seis patas e uma coloração '
            'amarelada.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 58}],
  'habitats': ['desertos'],
  'id': 'antlion',
  'name': 'Antlion',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/antlion.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 5,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6 + Dreno',
               'description': 'Garra',
               'text': '1 × Garra +5 (1d6 + Dreno)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'morto_vivo',
  'description': 'Estas criaturas parecem feitas de sombras, mas ainda com '
                 'forma humanoide.  Seus olhos são vermelhos, facilmente '
                 'perceptíveis mesmo na escuridão.\n'
                 '\n'
                 'Falam de forma lenta e profunda, flutuando um pouco acima do '
                 'nível do solo.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Aparições atacam todas as formas de vida, ignorando '
                 'autômatos e mortos-vivos.\n'
                 '\n'
                 'Nutrem ódio especial por Elfos, Halflings e seres feéricos, '
                 'atacando-os antes dos outros.\n'
                 '\n'
                 'Animais sentirão uma aura tão poderosa de terror que ficarão '
                 'agitados e evitarão a aproximação da criatura.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar-se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Imunidades**: além das imunidades comuns aos '
                 'mortos-vivos, Aparições são feridas apenas por magia e armas '
                 'mágicas ou de prata. Armas de prata causam apenas metade do '
                 'dano.\n'
                 '\n'
                 '  * **Dreno**: o ataque de uma Aparição, além do dano '
                 'normal, drena 1 nível do alvo caso este não passe em uma '
                 'JPC. Se um alvo tiver todos os seus níveis drenados por uma '
                 'Aparição, irá retornar como uma Aparição sob controle da '
                 'aparição que o criou.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar '
                 'Mortos-Vivos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Criaturas que exultam a morte, as aparições se alimentam da '
                 'vida. Quando famintos, deixam um rastro de plantas mortas e '
                 'grama queimada ao passarem por áreas de vegetação.\n'
                 '\n'
                 'Os animais fogem das criaturas, pressentindo-as a 18 metros '
                 'de distância.\n'
                 '\n'
                 '## Tesouro\n'
                 '\n'
                 '3x V, 50% de 1 Item Mágico',
  'dv': '5',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '1d6',
  'flavor': 'Poderosos humanos que sucumbiram à forças obscuras, e agora se '
            'alimentam do espírito e da vontade de viver de suas vítimas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 20},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday14.json',
              'page': 17},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'aparicao',
  'jp': '9',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Aparição',
  'picture': 'https://public.olddragon.com.br/fnj8b114dhc8l29civq5wq5gv0ag',
  'pv': '25',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/o7tfl24xd3eklo6e6qhs38uudawy',
  'treasure': 'especial',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/aparicao.json',
  'variant': False,
  'xp': '235'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Poderosos humanos que sucumbiram a forças obscuras, e agora se '
            'alimentam do espírito e da vontade de viver de suas vítimas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 58}],
  'habitats': ['desertos'],
  'id': 'aparicao-sombria',
  'name': 'Aparição Sombria',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/aparicao-sombria.json',
  'variant': False},
 {'access': 'partial',
  'alignment': 'neutro',
  'attacks': [{'ba': 0,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma (Arma)',
               'times': 1,
               'weapon': True}],
  'ca': '10',
  'concept': 'humanoide',
  'description': '',
  'dv': '½',
  'dv_bonus': '+1',
  'encounters': None,
  'encounters_lair': None,
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 77},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'aprendiz',
  'jp': '4',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Aprendiz',
  'pv': '3',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/aprendiz.json',
  'variant': False,
  'xp': '5'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8 + Veneno',
               'description': 'Ferrão',
               'text': '1 × Ferrão +4 (1d8 + Veneno)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'inseto',
  'description': '\n'
                 '\n'
                 '  * **Veneno**: causa morte em 1d3 turnos em caso de falha '
                 'em uma JPC.\n'
                 '\n',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1d3',
  'encounters_lair': '1d3',
  'flavor': 'Essa monstruosa caçadora peluda vive em tocas escondidas, só '
            'saindo para ir atrás de suas presas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 114},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'aranha-cacadora-gigante',
  'jp': '6',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Aranha Caçadora Gigante',
  'picture': None,
  'pv': '20',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/aranha-cacadora-gigante.json',
  'variant': False,
  'xp': '150'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8 + Veneno',
               'description': 'Mordida',
               'text': '1 × Mordida +3 (1d8 + Veneno)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'inseto',
  'description': '\n'
                 '\n'
                 '  * **Veneno**: causa morte em 1d3+1 turnos em caso de falha '
                 'em uma JPC.\n'
                 '  * **Surpresa**: surpreende seus inimigos com um resultado '
                 'de 1 a 4 em 1d6 devido sua camuflagem.\n'
                 '\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Estas terríveis aranhas são capazes de se camuflar para atacar '
            'suas presas de surpresa.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 114},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas'],
  'id': 'aranha-camufladora-gigante',
  'jp': '5',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Aranha Camufladora Gigante',
  'picture': None,
  'pv': '10',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/aranha-camufladora-gigante.json',
  'variant': False,
  'xp': '50'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Aranhas caçadoras com 2,1m de comprimento e cheias de pelos. '
            'Assemelham-se a tarântulas.  Mágicas por natureza.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 58}],
  'habitats': ['desertos'],
  'id': 'aranha-gigante-do-deserto',
  'name': 'Aranha Gigante do Deserto',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/aranha-gigante-do-deserto.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6 + Veneno',
               'description': 'Picada',
               'text': '1 × Picada +4 (2d6 + Veneno)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'inseto',
  'description': '\n'
                 '\n'
                 '  * **Veneno**: causa morte em 1d4+1 turnos em caso de falha '
                 'em uma JPC.\n'
                 '  * **Teia**: criaturas presas na teia são considerados '
                 'alvos enredados e incapazes de se mover até serem '
                 'bem-sucedidos em um teste de Força Difícil.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Aranha tecedora de teias gigantescas. É feroz e uma exímia '
            'caçadora das florestas e subterrâneos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 114},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas', 'subterraneos'],
  'id': 'aranha-negra-gigante',
  'jp': '6',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': 9,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Aranha Negra Gigante',
  'picture': None,
  'pv': '15',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/aranha-negra-gigante.json',
  'variant': False,
  'xp': '95'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'inseto',
  'flavor': 'Sorrateira e assustadora, esta criatura está entre as melhores '
            'caçadoras de suas regiões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 133}],
  'habitats': ['subterraneos', 'florestas'],
  'id': 'aranha-onix',
  'name': 'Aranha Ônix',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/aranha-onix.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 97}],
  'habitats': ['qualquer'],
  'id': 'arenol-o-mestre-louco',
  'name': 'Arenol, o Mestre Louco',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/arenol-o-mestre-louco.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Senhores da magia e do rio Mantaro. Dominam a ARKHImancia, uma '
            'antiga e misteriosa arte capaz de dobrar a matéria de maneira '
            'incompreensível.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 58}],
  'habitats': ['desertos'],
  'id': 'arkhimancista-arkhimago',
  'name': 'ARKHImancista (ARKHImago)',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/arkhimancista-arkhimago.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Mais poderosos entre os ARKHImancistas e superiores aos '
            'ARKHImagos, os Sumo Sacerdotes são uma versão ainda mais '
            'perigosa.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 59}],
  'habitats': ['desertos'],
  'id': 'arkhimancista-sumo-sacerdote',
  'name': 'ARKHImancista (Sumo Sacerdote)',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/arkhimancista-sumo-sacerdote.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Arco curto',
               'text': '1 × Arco curto +1 (1d8)',
               'times': 1,
               'weapon': False},
              {'ba': 1,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Espada curta',
               'text': '1 × Espada curta +1 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': 'Estes soldados estão a serviço de algum senhor local ou '
                 'procurando algum trabalho remunerado para suas armas. '
                 'Fortemente armados e protegidos, são um grupo coeso em '
                 'combate e desafiador para enfrentar.\n'
                 '\n'
                 'Encontrados em grupos formados por: 2d6 soldados, onde 1 a '
                 'cada 5 é um Soldado Pesado atuando como um Sargento; 2d6 '
                 'Arqueiros; 1d6 Besteiros; 1d6 Piqueiros e 1d6 Cavaleiros '
                 'Leves.  A cada 20 homens, haverá adicionalmente um Cavaleiro '
                 'de Guerra onde um destes é o Líder do Grupo.\n'
                 '\n'
                 'Contratando: existe uma chance de 1-2 em 1d6 dos Mercenários '
                 'estarem disponíveis para contratação.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Custo**: 2PO por mês.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 76},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 188},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'arqueiro-mercenario',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Arqueiro (Mercenário)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/soldado-leve-mercenario.json',
  'picture': 'https://public.olddragon.com.br/hysrm9x4j6l66mzz6ny46rxqjei4',
  'pv': '5',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/jgipoxwh8albycdbb1hrb032e8v1',
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/arqueiro-mercenario.json',
  'variant': True,
  'variant_modifications': ['Custo: 4 PO por mês.'],
  'xp': '15'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Arquidemônios poderosos, conhecidos por invadirem o Plano '
            'Material. Costumam ser invocados por cultistas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 12}],
  'habitats': ['qualquer'],
  'id': 'arquipossuido',
  'name': 'Arquipossuído',
  'size': 'imenso',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/arquipossuido.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [],
  'ca': '16',
  'concept': 'besta',
  'description': 'Secas e enegrecidas, seus galhos lembram garras prestes a '
                 'segurar algum curioso incauto. Em seus troncos, ranhuras '
                 'lembram rostos distorcidos, sofridos e raivosos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Árvores Malditas não atacam diretamente seus alvos, usando '
                 'seus poderes para confundir e amedrontar as vítimas. Isto '
                 'facilita o ataque daqueles que controlam as Árvores, '
                 'tornando os alvos mais fáceis de serem abatidos.\n'
                 '\n'
                 'Fazem de tudo para evitar o fogo, usando seus poderes para '
                 'criar ilusões de forma a fazerem os portadores de tochas as '
                 'largarem, como se tivessem se transformado em cobras, '
                 'vermes, ou mesmo as apagarem.\n'
                 '\n'
                 '  * **Área Maldita**: uma criatura que se aproxima a pelo '
                 'menos 50m de uma Árvore Maldita deve ser bem-sucedida em uma '
                 'JPS ou se perde automaticamente. Se o alvo falhar em 3 '
                 'testes, começará a ter alucinações (vendo rostos nas '
                 'sombras, garras nos galhos, ouvindo sons fantasiosos e '
                 'imaginando perseguições que não estão ocorrendo de '
                 'verdade).\n'
                 '\n'
                 '  * **Fogo**: uma Árvore Maldita é especialmente suscetível '
                 'ao fogo. Todo dano causado pelo fogo deve ser ampliado em '
                 '50%.\n'
                 '\n'
                 '  * **Elo Telepático**: uma Árvore Maldita possui elo '
                 'telepático com seu senhor (normalmente uma Bruxa). Tudo o '
                 'que a árvore enxergar e ouvir também será visto e ouvido '
                 'pela Bruxa.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'O ritual para transformar uma árvore comum em uma versão '
                 'maldita é muito complexo, sendo reservado as poucas Bruxas '
                 'que se desventuram por este lado sombrio da magia.\n'
                 '\n'
                 'Estas Árvores possuem instinto maligno, mas pouca '
                 'inteligência. Contudo, apreciam e, até mesmo se alimentam, '
                 'do desespero e medo das vítimas, fazendo com que, às vezes, '
                 'usem seus poderes apenas para se divertirem e alimentarem.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A seiva de uma Árvore Maldita é um ingrediente importante na '
                 'confecção de itens mágicos ligados a telepatia, '
                 'clarividência e clariaudiência.',
  'dv': '7',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1',
  'flavor': 'Criadas por Bruxas insanas com o intuito de serem seus olhos e '
            'ouvidos nos pontos mais sombrios das florestas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 21},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas'],
  'id': 'arvore-maldita',
  'jp': '11',
  'mo': 9,
  'mv': 1,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Árvore Maldita',
  'picture': 'https://public.olddragon.com.br/eiyes3wsjh12xdyq2zc3jlhpdif6',
  'pv': '35',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/eevlhjmp6mva246mv3yj6173ag9k',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/arvore-maldita.json',
  'variant': False,
  'xp': '460'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 67}],
  'habitats': [],
  'id': 'assecla',
  'name': 'Assecla',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/assecla.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 31}],
  'habitats': [],
  'id': 'astronauta-moribundo',
  'name': 'Astronauta Moribundo',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/astronauta-moribundo.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Espada curta',
               'text': '1 × Espada curta +1 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': '\n\n\n\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday24.json',
              'page': 9}],
  'habitats': ['qualquer'],
  'id': 'aventureiro',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Aventureiro',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/aventureiro.json',
  'variant': False,
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 7,
               'damage': '2d10',
               'damage_bonus': None,
               'damage_description': '2d10',
               'description': 'Mordida',
               'text': '1 × Mordida +7 (2d10)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1d6',
  'flavor': 'Feroz e carnívora, é uma das maiores caçadoras dos oceanos',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 15},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['oceanos'],
  'id': 'baleia-assassina',
  'jp': '8',
  'mo': 7,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': 15,
  'mvo': None,
  'mvv': None,
  'name': 'Baleia Assassina',
  'picture': None,
  'pv': '30',
  'size': 'imenso',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/baleia-assassina.json',
  'variant': False,
  'xp': '270'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 16,
               'damage': '4d12',
               'damage_bonus': None,
               'damage_description': '4d12',
               'description': 'Mordida',
               'text': '1 × Mordida +16 (4d12)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '30',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1d3',
  'flavor': 'Maior mamífero dos oceanos, é pacífica e vive em mar aberto.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 15},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['oceanos'],
  'id': 'baleia-cachalote',
  'jp': '15',
  'mo': 7,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': 12,
  'mvo': None,
  'mvv': None,
  'name': 'Baleia Cachalote',
  'picture': None,
  'pv': '150',
  'size': 'colossal',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/baleia-cachalote.json',
  'variant': False,
  'xp': '8325'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Espada curta',
               'text': '1 × Espada curta +1 (1d6+1)',
               'times': 1,
               'weapon': False},
              {'ba': 1,
               'damage': '1d3',
               'damage_bonus': None,
               'damage_description': '1d3',
               'description': 'Funda',
               'text': '1 × Funda +1 (1d3)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': 'São fora-da-lei que se uniram em bando para atacar '
                 'viajantes, comerciantes ou fazendeiros nas áreas remotas ou '
                 'ermas nas quais a lei possui mais dificuldade em atuar.\n'
                 '\n'
                 'Além de bandidos das estradas, você pode usar as fichas de '
                 'bandidos para representar salteadores, escravagistas, '
                 'capangas ou qualquer outro tipo de fora-da-lei.\n'
                 '\n'
                 'Encontrados em bandos de 2d4 indivíduos, que formam '
                 'comunidades maiores com 2d10+10 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: um Bandido Campeão a cada 5 indivíduos e '
                 'um Bandido Líder por comunidade.\n'
                 '\n'
                 '  * **Prisioneiros**: há uma chance de 1-2 em 1d6 de um '
                 'acampamento de Bandidos ter até 1d3 prisioneiros. Estes '
                 'prisioneiros podem ser libertados ou entregues à sua '
                 'família.\n'
                 '\n'
                 '  * **Montado**: há 1-2 chances de estar montado em um '
                 'Cavalo de Montaria.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 68},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 183},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 15},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/tu1.json',
              'page': 25}],
  'habitats': ['qualquer'],
  'id': 'bandido',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Bandido',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/bandido.json',
  'variant': False,
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 6,
               'damage': '1d8',
               'damage_bonus': 4,
               'damage_description': '1d8+4',
               'description': 'Espada longa',
               'text': '1 × Espada longa +6 (1d8+4)',
               'times': 1,
               'weapon': False},
              {'ba': 6,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Arco curto',
               'text': '1 × Arco curto +6 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': 'São fora-da-lei que se uniram em bando para atacar '
                 'viajantes, comerciantes ou fazendeiros nas áreas remotas ou '
                 'ermas nas quais a lei possui mais dificuldade em atuar.\n'
                 '\n'
                 'Além de bandidos das estradas, você pode usar as fichas de '
                 'bandidos para representar salteadores, escravagistas, '
                 'capangas ou qualquer outro tipo de fora-da-lei.\n'
                 '\n'
                 'Encontrados em bandos de 2d4 indivíduos, que formam '
                 'comunidades maiores com 2d10+10 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: um Bandido Campeão a cada 5 indivíduos e '
                 'um Bandido Líder por comunidade.\n'
                 '\n'
                 '  * **Prisioneiros**: há uma chance de 1-2 em 1d6 de um '
                 'acampamento de Bandidos ter até 1d3 prisioneiros. Estes '
                 'prisioneiros podem ser libertados ou entregues à sua '
                 'família.\n'
                 '\n'
                 '  * **Montado**: há 1-2 chances de estar montado em um '
                 'Cavalo de Montaria.\n'
                 '\n',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 86},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 183},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 24},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'bandido-campeao',
  'jp': '6',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Bandido Campeão',
  'parent_monster_url': 'https://olddragon.com.br/monstros/bandido.json',
  'picture': None,
  'pv': '20',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/bandido-campeao.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '125'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Espada longa',
               'text': '1 × Espada longa +3 (1d8+2)',
               'times': 1,
               'weapon': False},
              {'ba': 3,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Besta',
               'text': '1 × Besta +3 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'humanoide',
  'description': 'São fora-da-lei que se uniram em bando para atacar '
                 'viajantes, comerciantes ou fazendeiros nas áreas remotas ou '
                 'ermas nas quais a lei possui mais dificuldade em atuar.\n'
                 '\n'
                 'Além de bandidos das estradas, você pode usar as fichas de '
                 'bandidos para representar salteadores, escravagistas, '
                 'capangas ou qualquer outro tipo de fora-da-lei.\n'
                 '\n'
                 'Encontrados em bandos de 2d4 indivíduos, que formam '
                 'comunidades maiores com 2d10+10 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: um Bandido Campeão a cada 5 indivíduos e '
                 'um Bandido Líder por comunidade.\n'
                 '\n'
                 '  * **Prisioneiros**: há uma chance de 1-2 em 1d6 de um '
                 'acampamento de Bandidos ter até 1d3 prisioneiros. Estes '
                 'prisioneiros podem ser libertados ou entregues à sua '
                 'família.\n'
                 '\n'
                 '  * **Montado**: há 1-2 chances de estar montado em um '
                 'Cavalo de Montaria.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 183},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/tu1.json',
              'page': 25}],
  'habitats': ['qualquer'],
  'id': 'bandido-lider',
  'jp': '6',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Bandido Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/bandido.json',
  'picture': None,
  'pv': '15',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/bandido-lider.json',
  'variant': True,
  'variant_modifications': ['Moral: enquanto o líder estiver em combate, todos '
                            'os bandidos fazem o teste de moral com um bônus '
                            'de +1.',
                            'Montado: há 1-3 chances de estar montado em um '
                            'Cavalo de Montaria.'],
  'xp': '75'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Espada curta',
               'text': '1 × Espada curta +1 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': '\n'
                 '\n'
                 '  * **Fanático**: Enquanto Saminther estiver em combate, '
                 'todos do seu Bando fazem o teste de moral com um bônus de '
                 '+1.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday22.json',
              'page': 13}],
  'habitats': ['qualquer'],
  'id': 'bando-de-saminther',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Bando de Saminther',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'p',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/bando-de-saminther.json',
  'variant': False,
  'xp': '15'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Os Bandorgos são cães monstruosos, criados pelos Orcs das '
            'Montanhas a partir de uma mistura insana de lobos atrozes e cães '
            'de guerra capturados dos reinos humanos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 14}],
  'habitats': ['colinas', 'florestas'],
  'id': 'bandorgo',
  'name': 'Bandorgo',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/bandorgo.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 7,
               'damage': '1d4',
               'damage_bonus': 6,
               'damage_description': '1d4+6',
               'description': 'Garras',
               'text': '2 × Garras +7 (1d4+6)',
               'times': 2,
               'weapon': False}],
  'ca': '20',
  'concept': 'morto_vivo',
  'description': 'Banshees são espíritos de elfos que morreram de forma '
                 'horrível e que, por algum motivo, se mantêm presos no local '
                 'no qual sofreram este trauma. Capazes de voar tão alto como '
                 'um pássaro, sobrevoam a área em noites escuras, lamuriando '
                 'seu trauma profundamente.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'De todas as formas de vida odiadas, a que lhes faz ignorar '
                 'tudo e atacar impetuosamente em primeiro lugar são os elfos. '
                 'Usam seu grito para afugentar intrusos e, quando conseguem '
                 'atingir e segurar o alvo com suas garras, mostram sua '
                 'verdadeira face: uma visão distorcida de morte e agonia, '
                 'matando a vítima de pavor.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Toque Mortal**: uma vez por noite, o Banshee pode '
                 'ativar seu toque mortal. O alvo atingido por um Banshee deve '
                 'ser bem sucedido em uma JPS ou morrerá imediatamente.  Um '
                 'alvo morto desta forma por um Banshee, retorna como um '
                 'Banshee em 1d4 horas.\n'
                 '\n'
                 '  * **Imunidades**: além das imunidades comuns aos '
                 'mortos-vivos, Banshees são feridos apenas por magia e armas '
                 'mágicas.\n'
                 '\n'
                 '  * **Grito**: um Banshee é capaz de emitir um grito '
                 'estridente e aterrorizador. Qualquer criatura a até 20 '
                 'metros do Banshee, capaz de ouvir o grito, é afetada pela '
                 'sua aura de medo. O grito irá afugentar todos de medo por '
                 '1d4 turnos. Uma JPS nega o efeito do grito do Banshee. Há '
                 '1-3 chances em 1d6 de uma pessoa, durante a fuga, largar '
                 'qualquer objeto que esteja segurando.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar '
                 'Mortos-Vivos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Não é muito comum encontrar mais de um Banshee no mesmo '
                 'lugar. Porém, quando ocorre, costumam fazer parte da mesma '
                 'família ou grupo. Sua morte horrenda passa em suas mentes o '
                 'tempo todo, levando-os à loucura. A única forma de lhes '
                 'trazer sossego é queimando seu corpo (onde quer que esteja), '
                 'abençoar as cinzas e enterrá-las. Neste caso, o espírito '
                 'maligno simplesmente desaparece em um feixe de luz.',
  'dv': '8',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Espírito maligno e atormentado que fica preso no local onde '
            'morreu. Busca destruir tudo que estiver vivo e próximo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 22},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 19},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'banshee',
  'jp': '11',
  'mo': 10,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 9,
  'name': 'Banshee',
  'picture': 'https://public.olddragon.com.br/m9pj0uf5w83raz0u6oy3lsss8bsu',
  'pv': '40',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/5h0jpls7agmvsbo9ikwxpnzj3cwn',
  'treasure': 'vx2',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/banshee.json',
  'variant': False,
  'xp': '740'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Machado',
               'text': '1 × Machado +2 (1d6)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Lança',
               'text': '1 × Lança +2 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': '\n'
                 '\n'
                 '  * **Camuflagem natural**: em ambientes naturais, como '
                 'vegetação rasteira ou árvores com uma chance de 1-2 em 1d6 '
                 'de conseguir se esconder.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '+3',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': 'Guerreiros de tribos bárbaras que habitantes de montanhas e '
            'lugares isolados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 15}],
  'habitats': ['montanhas', 'desertos'],
  'id': 'barbaro-guerreiro',
  'jp': '6',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Bárbaro Guerreiro',
  'picture': None,
  'pv': '8',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/barbaro-guerreiro.json',
  'variant': False,
  'xp': '25'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 6,
               'damage': '1d10',
               'damage_bonus': 2,
               'damage_description': '1d10+2',
               'description': 'Mordida',
               'text': '1 × Mordida +6 (1d10+2)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'besta',
  'description': 'Grande como um boi, o Basilisco é uma espécie de lagarto '
                 'gigante com 8 patas.  Extremamente agressivo, consegue ficar '
                 'imóvel, mesclando-se no ambiente.\n'
                 '\n'
                 'Seus olhos são amarelos e é dito que podem enxergar através '
                 'dos diferentes planos de existência, detectando seres '
                 'invisíveis.\n'
                 '\n'
                 'Possuem mandíbulas extremamente fortes e repletas de dentes '
                 'pontiagudos, assim como os inúmeros espinhos ósseos das suas '
                 'costas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Predador faminto, usa sua camuflagem para suas presas '
                 'passarem por ele, atacando por trás com sua poderosa '
                 'mordida.\n'
                 '\n'
                 'Quando acuado, consegue correr de costas, mantendo os olhos '
                 'nos seus perseguidores.\n'
                 '\n'
                 '  * **Detectar invisibilidade**: pode enxergar normalmente '
                 'qualquer alvo invisível, seja por magia ou habilidade.\n'
                 '\n'
                 '  * **Petrificação**: o alvo que tiver contato com seus '
                 'olhos deve ser bem-sucedido em uma JPC ou virará pedra, '
                 'voltando ao normal apenas por meios mágicos. O efeito do '
                 'olhar alcança 15 metros e, caso o basilisco veja o próprio '
                 'olhar, também pode ficar petrificado.\n'
                 '\n'
                 '  * **Camuflagem**: quando imóvel, surpreende o grupo em 1-4 '
                 'em 1d6.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Basiliscos não comem pedras, logo, desenvolveram métodos de '
                 'caça que os tornam praticamente invisíveis aos alvos.\n'
                 '\n'
                 'Atacando pelas costas, desviam o olhar de suas vítimas, '
                 'usando a técnica de petrificação apenas quando sentem que '
                 'estão em desvantagem.\n'
                 '\n'
                 'Em toda a sua vida, colocam no máximo 4 ou 5 ovos, tornando '
                 'tais itens muito valiosos no mercado negro.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além dos ovos valiosos, os olhos de Basilisco são usados por '
                 'Magos na produção de poções e estudo da petrificação.',
  'dv': '6',
  'dv_bonus': '+4',
  'encounters': '1d6',
  'encounters_lair': '1d6',
  'flavor': 'Este réptil gigantesco espreita suas vítimas, surpreendendo-as '
            'com seu olhar petrificante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 23},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/tu2.json',
              'page': 44}],
  'habitats': ['qualquer'],
  'id': 'basilisco',
  'jp': '9',
  'mo': 8,
  'mv': 3,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Basilisco',
  'picture': 'https://public.olddragon.com.br/qvu36lrjochpyhsuryow7b4uthpj',
  'pv': '34',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/pu2ftmqbenzqli5qfoqcb684k9mx',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/basilisco.json',
  'variant': False,
  'xp': '340'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'besta',
  'flavor': 'Lagarto serpentiforme, não-inteligente, mas muito mágico. Tem '
            'percepção às cegas e vive no Palácio da Noite.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 59}],
  'habitats': ['desertos'],
  'id': 'basilisco-do-deserto',
  'name': 'Basilisco do Deserto',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/basilisco-do-deserto.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Machado',
               'text': '1 × Machado +1 (1d8+1)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': 'Berserkers são pequenos grupos de guerreiros de culturas '
                 'nômades dos ermos, incapazes de viverem em comunidade e que '
                 'ficam loucos em batalha. Perambulam por regiões planas e '
                 'geladas em busca de saques e sobrevivência.  Jamais fazem '
                 'prisioneiros.\n'
                 '\n'
                 'Encontrados em grupos pequenos de 3d6 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 20 Berserkers, um deles será um '
                 'Berserker Líder.\n'
                 '\n'
                 '  * **Fúria**: entram em fúria quando perdem metade de seus '
                 'pontos de vida, realizando todos seus ataques como fáceis e '
                 'recebendo um bônus de +2 nos danos.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 183},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'berserker',
  'jp': '5',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Berserker',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': 'u',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/berserker.json',
  'variant': False,
  'xp': '25'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Machado',
               'text': '1 × Machado +3 (1d8+2)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'humanoide',
  'description': 'Berserkers são pequenos grupos de guerreiros de culturas '
                 'nômades dos ermos, incapazes de viverem em comunidade e que '
                 'ficam loucos em batalha. Perambulam por regiões planas e '
                 'geladas em busca de saques e sobrevivência.  Jamais fazem '
                 'prisioneiros.\n'
                 '\n'
                 'Encontrados em grupos pequenos de 3d6 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 20 Berserkers, um deles será um '
                 'Berserker Líder.\n'
                 '\n'
                 '  * **Fúria**: entram em fúria quando perdem metade de seus '
                 'pontos de vida, realizando todos seus ataques como fáceis e '
                 'recebendo um bônus de +2 nos danos.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 183},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'berserker-lider',
  'jp': '6',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Berserker Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/berserker.json',
  'picture': None,
  'pv': '15',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': 'u',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/berserker-lider.json',
  'variant': True,
  'variant_modifications': ['Fúria: entram em fúria quando perdem metade de '
                            'seus pontos de vida, realizando todos seus '
                            'ataques como fáceis e recebendo um bônus de +2 '
                            'nos danos.',
                            'Moral: enquanto o líder estiver em combate, todos '
                            'os berserkers fazem o teste de moral com um bônus '
                            'de +1.'],
  'xp': '95'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'inseto',
  'description': '\n'
                 '\n'
                 '  * **Spray Cáustico**: oponentes a até 3 metros, que '
                 'falharem em uma JPD são atingidos pelo spray de vapores, '
                 'ajustando nas próximas 24 horas, os ataques como difíceis.\n'
                 '\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '2d4',
  'flavor': 'Estes besouros das florestas atacam suas vítimas lançando um '
            'terrível spray de vapores tóxicos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 115},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas'],
  'id': 'besouro-bombardeiro-gigante',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Besouro Bombardeiro Gigante',
  'picture': None,
  'pv': '10',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/besouro-bombardeiro-gigante.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': 6,
               'damage_description': '1d6+6',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (1d6+6)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'inseto',
  'description': 'Besouros com mais ou menos um metro de altura, de casco '
                 'grosso e particularmente fedorentos. Sua cabeça possui '
                 'pequenos chifres que lembram pinças. Sua carapaça costuma '
                 'variar entre preto e tons escuros de verde ou marrom, e '
                 'cobrem um par de asas usadas para saltar pequenas '
                 'distâncias\n'
                 '\n'
                 '**Odor:** cheiro de matéria podre e dejetos.\n'
                 '\n'
                 '**Som:** passos abafados.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Costumam prender-se nas paredes ou no teto para, então, '
                 'saltar sobre os alvos com uma manobra de investida.\n'
                 '\n'
                 '  * **Investida**: se ainda não engajado em combate, pode '
                 'usar a manobra de investida para causar o dobro de dano do '
                 'ataque.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Costumam viver em lugares úmidos e escuros, como cavernas e '
                 'ruínas abandonadas. Alimentam-se de matéria em decomposição, '
                 'agindo como uma espécie de “lixeiros” da natureza. Consomem '
                 'cadáveres, fungos, comida podre, dejetos e o que mais '
                 'encontrarem.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A saliva dos Besouros Cascudos Gigantes é muito corrosiva, '
                 'podendo ser usada para confeccionar ácidos mais '
                 'concentrados.',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1d6',
  'flavor': 'Um besouro gigante que habita locais fétidos e cheios de lixo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday23.json',
              'page': 18}],
  'habitats': ['subterraneos'],
  'id': 'besouro-cascudo-gigante',
  'jp': '5',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': 6,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Besouro Cascudo Gigante',
  'picture': 'https://public.olddragon.com.br/d9r5oqerks8slw6cjy4ov335lcfa',
  'pv': '10',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/20mh8r690n5zd26mwqgtjt9tachd',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/besouro-cascudo-gigante.json',
  'variant': False,
  'xp': '50'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4',
               'description': 'Mordida',
               'text': '1 × Mordida +1 (2d4)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'inseto',
  'description': '\n\n\n\n',
  'dv': '1',
  'dv_bonus': '+2',
  'encounters': '1d8',
  'encounters_lair': '2d6',
  'flavor': 'Usados por criaturas do subterrâneo como montarias por conta da '
            'luz que emanam de seu corpo.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 72},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 115},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'besouro-de-fogo-gigante',
  'jp': '5',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Besouro de Fogo Gigante',
  'picture': None,
  'pv': '7',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/besouro-de-fogo-gigante.json',
  'variant': False,
  'xp': '15'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'inseto',
  'flavor': 'Usados por criaturas do subterrâneo como montarias por conta da '
            'luz que emanam de seu corpo.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 116}],
  'habitats': ['subterraneos'],
  'id': 'besouro-de-fogo-gigante-atroz',
  'name': 'Besouro de Fogo Gigante Atroz',
  'parent_monster_url': 'https://olddragon.com.br/monstros/besouro-de-fogo-gigante.json',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/besouro-de-fogo-gigante-atroz.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Uma versão gigante e poderosa de sua versão comum.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 59}],
  'habitats': ['desertos'],
  'id': 'besouro-gigante',
  'name': 'Besouro Gigante',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/besouro-gigante.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'planta',
  'flavor': 'Esta sorrateira criatura dos lagos subterrâneos é uma voraz '
            'comedora de tudo o que seus tentáculos puderem atrair.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/nc2.json',
              'page': 35}],
  'habitats': ['subterraneos'],
  'id': 'besta-tentacular',
  'name': 'Besta Tentacular',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/besta-tentacular.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Espada curta',
               'text': '1 × Espada curta +1 (1d6)',
               'times': 1,
               'weapon': False},
              {'ba': 1,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Besta',
               'text': '1 × Besta +1 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': 'Estes soldados estão a serviço de algum senhor local ou '
                 'procurando algum trabalho remunerado para suas armas. '
                 'Fortemente armados e protegidos, são um grupo coeso em '
                 'combate e desafiador para enfrentar.\n'
                 '\n'
                 'Encontrados em grupos formados por: 2d6 soldados, onde 1 a '
                 'cada 5 é um Soldado Pesado atuando como um Sargento; 2d6 '
                 'Arqueiros; 1d6 Besteiros; 1d6 Piqueiros e 1d6 Cavaleiros '
                 'Leves.  A cada 20 homens, haverá adicionalmente um Cavaleiro '
                 'de Guerra onde um destes é o Líder do Grupo.\n'
                 '\n'
                 'Contratando: existe uma chance de 1-2 em 1d6 dos Mercenários '
                 'estarem disponíveis para contratação.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Custo**: 2PO por mês.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 76},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 188},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'besteiro-mercenario',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Besteiro (Mercenário)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/soldado-leve-mercenario.json',
  'picture': 'https://public.olddragon.com.br/hysrm9x4j6l66mzz6ny46rxqjei4',
  'pv': '5',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/jgipoxwh8albycdbb1hrb032e8v1',
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/besteiro-mercenario.json',
  'variant': True,
  'variant_modifications': ['Custo: 5 PO por mês.'],
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 1,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Envolver',
               'description': 'Toque',
               'text': '1 × Toque +1 (Envolver)',
               'times': 1,
               'weapon': False}],
  'ca': '11',
  'concept': 'gosma',
  'description': '\n'
                 '\n'
                 '  * **Envolver**: o alvo faz uma JPD para esquivar de ter '
                 'seu rosto envolvido pela bolha. Em sua rodada o personagem '
                 'pode fazer um Teste de FOR para tentar retirar a gosma de '
                 'si. Um personagem envolvido pela bolha não consegue '
                 'respirar, podendo se manter assim por um número de minutos '
                 'igual a 1+ se Mod. de CON. Caso o Mod. seja negativo, o '
                 'valor segue sendo 1. Após passado o tempo, o personagem '
                 'morre sufocado.\n'
                 '\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '',
  'encounters_lair': '',
  'flavor': 'Uma bolha de gosma de coloração verde, que se movimenta sozinha, '
            'movida por magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday12.json',
              'page': 20}],
  'habitats': ['subterraneos'],
  'id': 'bolha-verde',
  'jp': '5',
  'mo': 8,
  'mv': 3,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Bolha Verde',
  'picture': None,
  'pv': '10',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/bolha-verde.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 12,
               'damage': '3d6',
               'damage_bonus': None,
               'damage_description': '3d6',
               'description': 'Chute',
               'text': '1 × Chute +12 (3d6)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '30',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1d4',
  'flavor': 'O maior dos dinossauros, vive nos pântanos comendo folhagens para '
            'sustentar seu corpo descomunal.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 42},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': [],
  'id': 'brontosaurus',
  'jp': '15',
  'mo': 9,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Brontosaurus',
  'picture': None,
  'pv': '150',
  'size': 'colossal',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/brontosaurus.json',
  'variant': False,
  'xp': '8250'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 8,
               'damage': '2d6',
               'damage_bonus': 5,
               'damage_description': '2d6+5',
               'description': 'Garra',
               'text': '1 × Garra +8 (2d6+5)',
               'times': 1,
               'weapon': False},
              {'ba': 8,
               'damage': '1d10',
               'damage_bonus': 7,
               'damage_description': '1d10+7',
               'description': 'Mordida',
               'text': '1 × Mordida +8 (1d10+7)',
               'times': 1,
               'weapon': False}],
  'ca': '19',
  'concept': 'humanoide_monstruoso',
  'description': 'Bruxas geralmente aparentam ser velhas corcundas e cheias de '
                 'ódio, mas, às vezes, se mostram como homens ou mulheres '
                 'jovens e atraentes. Sua força sobre-humana só é evidente '
                 'quando precisam se impor ou se proteger, mas podem muito bem '
                 'quebrar uma porta com um soco ou partir um fêmur com uma '
                 'mordida.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam de sua inteligência e sagacidade para atrair suas '
                 'vítimas a armadilhas ou situações colocando- as em '
                 'desvantagem. Atacam com garras e dentes apenas quando não '
                 'possuem mais outros recursos, ou quando já dominaram seus '
                 'alvos com suas magias. Podem usar suas vassouras voadoras '
                 'para fugir ou perseguir os inimigos.\n'
                 '\n'
                 '  * **Magias**: pode lançar magias como um Mago de 10º '
                 'nível, preferindo magia de Ilusão.\n'
                 '\n'
                 '  * **Amaldiçoar**: podem lançar uma maldição no alvo. Esta '
                 'só pode ser desfeita por magias que lidam com maldições ou '
                 'pela vontade da Bruxa que a lançou.\n'
                 '\n'
                 '  * **Transformar**: pode se transformar a vontade em '
                 'qualquer criatura humanoide desejada, pelo tempo que quiser. '
                 'Sua sombra, contudo, permanece a mesma.\n'
                 '\n'
                 '  * **Resistência à magia**: qualquer magia lançada contra '
                 'uma Bruxa possui 1-2 chances em 1d6 de ser completamente '
                 'ignorada.\n'
                 '\n'
                 '  * **Água cristalina**: água vinda de uma fonte pura e '
                 'sagrada pode lhe causar dano como se fosse ácido, mas '
                 'infringindo 1d10 pontos regressivos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem isoladamente, atendendo a encontros raros nos quais '
                 'várias Bruxas se reúnem para confabular e renovar seus '
                 'poderes com entidades de outros planos. Alimentam-se de '
                 'carne, capturando as vítimas e trancando-as em gaiolas para '
                 'o engorde. Dizem que Bruxas são criadas em caldeirões '
                 'gigantescos de ferro, mas isso nunca foi presenciado.\n'
                 '\n'
                 '## Tesouro\n'
                 '\n'
                 'V (35% de itens mágicos)',
  'dv': '8',
  'dv_bonus': '+10',
  'encounters': '0',
  'encounters_lair': '1',
  'flavor': 'Ligadas à forças sobrenaturais, capazes de lançar terríveis '
            'maldições e destruir ossos com suas garras e dentes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 24},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'bruxa',
  'jp': '11',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Bruxa',
  'picture': 'https://public.olddragon.com.br/2q5p4mgtvbaloi84oktskjerpp01',
  'pv': '50',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/t6561qjahsqempaux3u4ldepatuh',
  'treasure': 'especial',
  'treasure_lair': 'f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/bruxa.json',
  'variant': False,
  'xp': '740'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '1d4',
               'damage_bonus': 3,
               'damage_description': '1d4+3',
               'description': 'Porrete',
               'text': '1 × Porrete +4 (1d4+3)',
               'times': 1,
               'weapon': False},
              {'ba': 4,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Garra',
               'text': '1 × Garra +4 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': '\n'
                 '\n'
                 '  * **Infravisão**: 9 metros.\n'
                 '\n'
                 '  * **Magias**: pode lançar magias como um Mago de 5º nível, '
                 'preferindo magias de Ilusão. (Sono, Ilusão, Aterrorizar, '
                 'Invisibilidade, Voo).\n'
                 '\n'
                 '  * **Resistência a magia**: qualquer magia lançada contra '
                 'uma Bruxa Iniciante possui 1 chance em 1d6 de ser '
                 'completamente ignorada.\n'
                 '\n',
  'dv': '5',
  'dv_bonus': '+10',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': 'Com a aparência inofensiva de uma mulher de meia-idade, seus '
            'olhos, no entanto, escondem uma fome cruel por novas vítimas e '
            'por poder.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 18}],
  'habitats': ['qualquer'],
  'id': 'bruxa-iniciante',
  'jp': '7',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Bruxa Iniciante',
  'picture': None,
  'pv': '35',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/bruxa-iniciante.json',
  'variant': False,
  'xp': '150'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Coice',
               'text': '1 × Coice +3 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Adaptado**: tratam terrenos pantanosos como se fossem '
                 'planícies para qualquer cálculo de deslocamento.\n'
                 '  * **Carga**: carrega ou puxa até 5.000 moedas.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '3d10',
  'flavor': 'Grande bovino que vive em grandes rebanhos nas planícies ou '
            'pântanos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 15},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['colinas', 'pantanos', 'planicies'],
  'id': 'bufalo',
  'jp': '6',
  'mo': 5,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Búfalo',
  'picture': None,
  'pv': '15',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/bufalo.json',
  'variant': False,
  'xp': '75'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': None,
               'damage_bonus': 1,
               'damage_description': 'Arma +1',
               'description': 'Arma',
               'text': '1 × Arma +4 (Arma +1)',
               'times': 1,
               'weapon': True}],
  'ca': '13/15',
  'concept': 'humanoide',
  'description': 'Estas criaturas altas e fortes são parentes distantes dos '
                 'Goblins, fato dificilmente admitido por elas. São ótimos '
                 'guerreiros e sabem proteger seus lares.\n'
                 '\n'
                 'Territorialistas, não gostam de outras criaturas invadindo '
                 'sua área, em especial monstros mais fortes e errantes.\n'
                 '\n'
                 'Não costumam fazer alianças com outras criaturas, e poucos '
                 'são os que servem como mercenários (geralmente, os que '
                 'tiveram o clã destruído).\n'
                 '\n'
                 '**Som**: Passos\n'
                 '\n'
                 '**Odor**: Suor\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Bugbears são ótimos combatentes. Defendem seus lares com '
                 'boas táticas de escaramuça, usando o terreno a sua volta em '
                 'seu favor.\n'
                 '\n'
                 'O olfato apurado lhes ajuda a emboscar as vítimas, colhendo '
                 'informações importantes sobre o grupo adversário antes de '
                 'atacá-los.\n'
                 '\n'
                 'Não são orgulhosos como os Hobgoblins, e preferem recuar '
                 'para lutar outro dia do que perecer inutilmente.\n'
                 '\n'
                 '  * **Classe de armadura**: Bugbears possuem CA 13 ou 15 '
                 'quando usam armadura de couro.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros\n'
                 '\n'
                 '  * **Emboscar**: surpreende seus inimigos com um resultado '
                 'de 1-3 em 1d6, realizando seus ataques como ataques fáceis '
                 'na primeira rodada.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em cavernas complexas e labirínticas. Às vezes, '
                 'permitem que Goblins vivam próximos, ou mesmo juntos, pois '
                 'os consideram batedores convenientes (dizem que é fácil '
                 'ouvir um Goblin morrendo de longe).\n'
                 '\n'
                 'As fêmeas são exímias lutadoras, ensinando as crianças a '
                 'lutar, a caçar e a proteger o clã.\n'
                 ' \n'
                 'Os chefes da tribo geralmente são fêmeas grandes e fortes, '
                 'respeitadas por todos.',
  'dv': '3',
  'dv_bonus': '+1',
  'encounters': '2d4',
  'encounters_lair': '5d4',
  'flavor': 'Parentes dos Goblins, mas maiores e perigosos. Preferem emboscar '
            'suas vítimas e atacá-las de surpresa.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 171},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 25},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'bugbear',
  'jp': '6',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Bugbear',
  'picture': 'https://public.olddragon.com.br/808i70b5jt2xk3oos0t2nk4rwslk',
  'pv': '16',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/cnlgfdeu7y0ki50q9dzhgictome9',
  'treasure': 'sx2',
  'treasure_lair': 'f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/bugbear.json',
  'variant': False,
  'xp': '75'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 5,
               'damage': '1d8',
               'damage_bonus': 3,
               'damage_description': '1d8+3',
               'description': 'Espada longa',
               'text': '1 × Espada longa +5 (1d8+3)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Estas criaturas altas e fortes são parentes distantes dos '
                 'Goblins, fato dificilmente admitido por elas. São ótimos '
                 'guerreiros e sabem proteger seus lares.\n'
                 '\n'
                 'Territorialistas, não gostam de outras criaturas invadindo '
                 'sua área, em especial monstros mais fortes e errantes.\n'
                 '\n'
                 'Não costumam fazer alianças com outras criaturas, e poucos '
                 'são os que servem como mercenários (geralmente, os que '
                 'tiveram o clã destruído).\n'
                 '\n'
                 '**Som**: Passos\n'
                 '\n'
                 '**Odor**: Suor\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Bugbears são ótimos combatentes. Defendem seus lares com '
                 'boas táticas de escaramuça, usando o terreno a sua volta em '
                 'seu favor.\n'
                 '\n'
                 'O olfato apurado lhes ajuda a emboscar as vítimas, colhendo '
                 'informações importantes sobre o grupo adversário antes de '
                 'atacá-los.\n'
                 '\n'
                 'Não são orgulhosos como os Hobgoblins, e preferem recuar '
                 'para lutar outro dia do que perecer inutilmente.\n'
                 '\n'
                 '  * **Classe de armadura**: Bugbears possuem CA 13 ou 15 '
                 'quando usam armadura de couro.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros\n'
                 '\n'
                 '  * **Emboscar**: surpreende seus inimigos com um resultado '
                 'de 1-3 em 1d6, realizando seus ataques como ataques fáceis '
                 'na primeira rodada.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em cavernas complexas e labirínticas. Às vezes, '
                 'permitem que Goblins vivam próximos, ou mesmo juntos, pois '
                 'os consideram batedores convenientes (dizem que é fácil '
                 'ouvir um Goblin morrendo de longe).\n'
                 '\n'
                 'As fêmeas são exímias lutadoras, ensinando as crianças a '
                 'lutar, a caçar e a proteger o clã.\n'
                 ' \n'
                 'Os chefes da tribo geralmente são fêmeas grandes e fortes, '
                 'respeitadas por todos.',
  'dv': '4',
  'dv_bonus': '+1',
  'encounters': '2d4',
  'encounters_lair': '5d4',
  'flavor': 'Parentes dos Goblins, mas maiores e perigosos. Preferem emboscar '
            'suas vítimas e atacá-las de surpresa.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 25}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'bugbear-lider',
  'jp': '6',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Bugbear Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/bugbear.json',
  'picture': 'https://public.olddragon.com.br/808i70b5jt2xk3oos0t2nk4rwslk',
  'pv': '21',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/cnlgfdeu7y0ki50q9dzhgictome9',
  'treasure': 'sx2',
  'treasure_lair': 'f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/bugbear-lider.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '125'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 9,
               'damage': '4d10',
               'damage_bonus': None,
               'damage_description': '4d10',
               'description': 'Mordida',
               'text': '1 × Mordida +9 (4d10)',
               'times': 1,
               'weapon': False},
              {'ba': 10,
               'damage': '3d6',
               'damage_bonus': None,
               'damage_description': '3d6',
               'description': 'Garras',
               'text': '2 × Garras +10 (3d6)',
               'times': 2,
               'weapon': False}],
  'ca': '22',
  'concept': 'besta',
  'description': 'Esta terrível criatura de carapaça duríssima é um escavador '
                 'faminto, destruindo completamente áreas habitadas e '
                 'devorando tudo o que encontrar, mesmo que não seja '
                 'nutritivo.\n'
                 '\n'
                 'Sua cabeça e as partes traseiras do seu corpo, são azuladas '
                 'ou levemente castanhas e são cobertas por placas de mesma '
                 'cor.\n'
                 '\n'
                 'Suas garras, próprias para escavar na terra e na pedra '
                 'possuem o tom do marfim opaco dos velhos elefantes, assim '
                 'como seus grandes dentes pontudos.\n'
                 '\n'
                 'Muitos os chamam de “tubarão do deserto”.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Escondido em seu esconderijo subterrâneo, ataca como uma '
                 'aranha saltadora, pulando em cima das vítimas.\n'
                 '\n'
                 'Um Bulette ataca sem pensar, tentando devorar tudo o que '
                 'conseguir, mesmo estando gravemente ferido.\n'
                 '\n'
                 'Sua casca de proteção e sua poderosa mandíbula fazem com que '
                 'seja um caçador incauto, confiante em suas armas naturais.\n'
                 '\n'
                 '  * **Salto**: ao sair da toca, salta 3 metros de altura, '
                 'forçando seus oponentes a realizarem seus testes de '
                 'Iniciativa como testes difíceis.\n'
                 '\n'
                 '  * **Ponto fraco**: sua barriga é um ponto fraco, tendo CA '
                 '10.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Acredita-se que os Bulettes sejam a cria mágica da cruza de '
                 'animais com sangue de demônio.\n'
                 '\n'
                 'Adoram comer cavalos e halflings, mas evitam devorar anões '
                 'por questão de paladar.\n'
                 '\n'
                 'Provocam imensa destruição. Não é incomum ver lares de '
                 'habitantes das cavernas abandonados, pois é mais sábio '
                 'deixar suas coisas para trás do que enfrentar tal criatura '
                 'faminta.\n'
                 '\n'
                 'Aventureiros mais experientes aprenderam a evitar áreas que '
                 'tenham duas ou mais crateras próximas, um sinal inequívoca '
                 'de quem um Bulete está próximo.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Couro de sua barriga, flexível e resistente, pode ser usado '
                 'na confecção de armaduras mágicas.\n'
                 '\n'
                 'É dito também que a terra da toca de um Bullete pode '
                 'derreter rochas, no entanto isso poder apenas uma '
                 'conjectura.',
  'dv': '9',
  'dv_bonus': '',
  'encounters': '1d2',
  'encounters_lair': '1d2',
  'flavor': 'Conhecido como tubarão da terra, esta criatura surge do solo para '
            'devorar cavalos e o que quer que esteja em cima deles.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 26},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'bulette',
  'jp': '11',
  'mo': 12,
  'mv': 12,
  'mvc': 9,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Bulette',
  'picture': 'https://public.olddragon.com.br/uj0j4kb00x3y4dnvuzs6u69vd5ds',
  'pv': '45',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/l3o33r4sv1uugp2t5oc8ephh2z3w',
  'treasure': None,
  'treasure_lair': 'e',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/bulette.json',
  'variant': False,
  'xp': '925'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide',
  'flavor': 'Um aventureiro e combatente experiente e preparado, retirando o '
            'melhor proveito das situações em que se coloca. Nem sempre um '
            'Caçador vai agir da forma mais usual: sendo contratado e pago '
            'pelo serviço ou correndo atrás de tesouros perigosos. Podem ser '
            'terríveis rivais, ou incríveis aliados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 59}],
  'habitats': ['desertos'],
  'id': 'cacador-de-recompensas',
  'name': 'Caçador de Recompensas',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cacador-de-recompensas.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 8,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4',
               'description': 'Pancada',
               'text': '1 × Pancada +8 (2d4)',
               'times': 1,
               'weapon': False},
              {'ba': 8,
               'damage': '4d4',
               'damage_bonus': None,
               'damage_description': '4d4',
               'description': 'Encontrão',
               'text': '1 × Encontrão +8 (4d4)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'humanoide_monstruoso',
  'description': 'Criaturas do plano Elemental do Ar, os Caçadores Invisíveis '
                 'espreitam e buscam seus alvos incansavelmente, até cumprirem '
                 'seu objetivo.\n'
                 '\n'
                 'Apesar de invisível em nosso plano de existência, o Caçador '
                 'Invisível possui um formato humanoide, variando entre 1,50m '
                 'a 2m, mesmo que não se conheça precisamente suas feições.\n'
                 '\n'
                 'No plano Elemental do Ar, ele aparenta a sombra de um '
                 'humano, sem definição de rosto ou quaisquer outros detalhes, '
                 'a não ser o seu contorno.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Caçadores Invisíveis não têm seus próprios motivos para '
                 'atacar, pois seguem ordens de quem os invocou.\n'
                 '\n'
                 'Utilizam golpes simples, como empurrões e pancadas, atacando '
                 'de forma implacável até os alvos (ou eles mesmos) serem '
                 'destruídos.\n'
                 '\n'
                 '  * **Surpresa**: surpreende seus inimigos com um resultado '
                 'de 1 a 5 em 1d6, a não ser que o alvo consiga detectar '
                 'invisibilidade.\n'
                 '\n'
                 '  * **Invisibilidade**: o Caçador Invisível consegue '
                 'manter-se invisível até mesmo durante um combate.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Sua motivação em seu plano original é desconhecida.  Parecem '
                 'vagar a esmo, esperando serem invocados por algum conjurador '
                 'poderoso.\n'
                 '\n'
                 'Surgem de forma espontânea do corpo de um Elemental do Ar '
                 'que tenha acabado de morrer, e não mantêm grupos ou '
                 'vínculos. Em casos raros, lutam uns contra os outros, '
                 'absorvendo o perdedor da contenda.\n'
                 '\n'
                 'Acredita-se que, ao absorverem muitos Caçadores Invisíveis, '
                 'conseguem se manifestar no plano físico por vontade própria, '
                 'agindo de forma caótica e desordenada.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A pele e o sangue dos Caçadores Invisíveis estão ligados a '
                 'confecção de itens mágicos os quais produzem invisibilidade.',
  'dv': '8',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Criatura invisível do plano Elemental do Ar. É invocada para '
            'realizar uma tarefa específica no Plano Material.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 27},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['extraplanar'],
  'id': 'cacador-invisivel',
  'jp': '10',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Caçador Invisível',
  'picture': 'https://public.olddragon.com.br/1rjs52d7tf9qx23hkuz3scmomxwz',
  'pv': '40',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/9mq4uxdw6d8ie59k7sq3p4qc3qcr',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cacador-invisivel.json',
  'variant': False,
  'xp': '695'},
 {'access': 'limited',
  'alignment': 'ordeiro',
  'concept': 'humanoide_monstruoso',
  'flavor': 'Humanoides gigantes (2 a 3m) semelhantes a cactos.  Vagam pelo '
            'deserto. Preocupam-se apenas em proteger as plantas de sua terra. '
            'Falam seu próprio idioma oblíquo e arrastado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 59}],
  'habitats': ['desertos'],
  'id': 'cactoide-gigante',
  'name': 'Cactoide Gigante',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cactoide-gigante.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Imenso camaleão, domado pelo esquadrão militar Jaonída. Por cima '
            'de suas costas, uma sela sustenta uma espécie de barraca que '
            'oferece um teto, sombra e assentos para os soldados. Viaja em '
            'grande velocidade, apesar de seu tamanho. Sua pele se mistura à '
            'cor da areia tanto de dia na Xadra quanto à noite no Lumien.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 60}],
  'habitats': ['desertos'],
  'id': 'camaleao-jaonida',
  'name': 'Camaleão Jaonída',
  'size': 'imenso',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/camaleao-jaonida.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Adaptado**: tratam terrenos desérticos como se fossem '
                 'planícies para qualquer cálculo de deslocamento.\n'
                 '  * **Carga**: carrega até 3.000 moedas ou 1.500 moedas e um '
                 'montador.\n'
                 '\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '2d4',
  'flavor': 'Montaria resistente a climas desérticos e quentes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 15},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['desertos'],
  'id': 'camelo',
  'jp': '5',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Camelo',
  'picture': None,
  'pv': '10',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/camelo.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Mordida',
               'text': '1 × Mordida +1 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Inteligente**: podem aprender até 4 truques se '
                 'ensinado corretamente.\n'
                 '\n',
  'dv': '½',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1d6',
  'flavor': 'Animal de companhia e caça de diversos portes e tamanhos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 16},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 8},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'cao',
  'jp': '4',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cão',
  'picture': None,
  'pv': '2',
  'size': 'pequeno',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cao.json',
  'variant': False,
  'xp': '5'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'morto_vivo',
  'flavor': 'Cães que outrora foram cães mastiff, mas que agora são seres '
            'espectrais, sombrios e perigosos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 60}],
  'habitats': ['desertos'],
  'id': 'cao-espectral',
  'name': 'Cão Espectral',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cao-espectral.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 5,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Mordidas',
               'text': '2 × Mordidas +5 (1d6+2)',
               'times': 2,
               'weapon': False},
              {'ba': 3,
               'damage': '1d10',
               'damage_bonus': None,
               'damage_description': '1d10',
               'description': 'Baforada',
               'text': '1 × Baforada +3 (1d10)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'besta',
  'description': 'Da altura de um potro, os Cães Infernais costumam ser '
                 'avermelhados, mas espécimes raras podem ter o pelo negro ou '
                 'ainda mais raramente, branco.\n'
                 '\n'
                 'São agressivos, apesar de se submeterem aos cuidados de '
                 'Gigantes do Fogo, quando não estão em seu habitat natural.\n'
                 '\n'
                 'De suas bocarras grotescas e de dentes assustadores, saem '
                 'constantes labaredas de fogo, fato que ajuda a serem '
                 'identificados à noite.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Em matilha, possuem técnicas de caça muito eficazes, como '
                 'usar um dos membros como isca, atacando o alvo pelas '
                 'costas.\n'
                 '\n'
                 'Usam de formação em círculo para encurralar suas presas. Seu '
                 'uivo é grave, usado para chamar outros de sua raça que '
                 'estejam na região.\n'
                 '\n'
                 '  * **Sopro de fogo**: podem usar a vontade.  Causa 1d10 de '
                 'dano. Quando mordem o alvo e tiram um 20 no dado, causam '
                 'automaticamente 1d10 de dano extra pelo sopro.\n'
                 '\n'
                 '  * **Imunidade**: são imunes a qualquer fogo normal, '
                 'recebendo metade do dano caso a origem do fogo seja mágica.\n'
                 '\n'
                 '  * **Visão extradimensional**: possuem 50% de chance de ver '
                 'alvos invisíveis ou em viagem planar.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em matilhas bem organizadas, com o integrante mais '
                 'feroz como líder. Este posto pode trocar de tempos em '
                 'tempos, quando um jovem sente que pode tomá-lo.\n'
                 '\n'
                 'Relacionam-se muito bem com Gigantes do Fogo, que cuidam '
                 'deles como animais domésticos, apesar de muitas vezes, '
                 'também os usarem como armas/aliados auxiliares.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'O sangue e os pulmões dos Cães Infernais podem ser usados '
                 'para confeccionar itens mágicos ligados ao fogo.',
  'dv': '4',
  'dv_bonus': '+8',
  'encounters': '2d4',
  'encounters_lair': '2d4',
  'flavor': 'Cão gigantesco que solta fogo pela boca. Pode ser visto com '
            'Gigantes do Fogo ou em perigosas matilhas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 28},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['planicies', 'colinas', 'montanhas'],
  'id': 'cao-infernal',
  'jp': '7',
  'mo': 10,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cão Infernal',
  'picture': 'https://public.olddragon.com.br/q3t5e0hd3qjvgf6qt0pne0lie44v',
  'pv': '28',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/nplubahsz7alotr662f5y2m2zw6d',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cao-infernal.json',
  'variant': False,
  'xp': '175'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Espada curta',
               'text': '1 × Espada curta +1 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': '\n\n\n\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday22.json',
              'page': 13}],
  'habitats': ['qualquer'],
  'id': 'capanga-de-yaris',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Capanga de Yaris',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'p',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/capanga-de-yaris.json',
  'variant': False,
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Espada longa',
               'text': '1 × Espada longa +1 (1d8+1)',
               'times': 1,
               'weapon': False},
              {'ba': 1,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Lança longa',
               'text': '1 × Lança longa +1 (1d8+1)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'humanoide',
  'description': 'Estes homens formam o corpo da guarda ou do exército de um '
                 'nobre local e fazem parte de um destacamento de patrulha '
                 'urbana ou dos ermos.  Vivem para vigiar e resguardar a lei e '
                 'a ordem em nome do nobre local.\n'
                 '\n'
                 '**Pedidos de socorro**: Patrulhas/Milícias possuem uma '
                 'chance básica de 1-2 em 1d6 de ouvir um pedido de socorro em '
                 'agrupamentos urbanos iguais a uma cidade ou metrópole.\n'
                 '\n'
                 '**Encontrados**: as patrulhas são formadas por 2d6 Guardas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: toda patrulha possui um Chefe da Guarda. '
                 'Há ainda uma chance de 1-2 em 1d6 do Capitão da Guarda estar '
                 'presente.\n'
                 '\n'
                 '## Reforços\n'
                 '\n'
                 'Sempre que uma ocorrência ocorre e uma patrulha se encontra '
                 'com um grupo que impõe resistência a prisão, há 1-2 chances '
                 'em 1d6 de um dos guardas deixar o local do encontro para '
                 'buscar reforços.\n'
                 '\n'
                 '**Ermos**: se o encontro for realizado em um ermo, o guarda '
                 'procurará a base da guarda para avisar do encontro e trazer '
                 'reforços para o local. Use a contagem de tempo e viagem até '
                 'o local apropriado ou se em necessidade, um reforço demorará '
                 '1d4+2 turnos para chegar. O reforço usa as mesmas regras '
                 'para sua formação que uma patrulha normal, mas existirá '
                 'apenas um único Capitão da Guarda.\n'
                 '\n'
                 '**Urbanos**: reforços urbanos são mais rápidos de se obter. '
                 'Mesmo que nenhum guarda abandone o local para chamá-los há '
                 '1-3 chances de um reforço surgir no local do encontro após '
                 '2d6 rodadas, simplesmente pela confusão, gritos e barulho de '
                 'batalha. Depois que este primeiro grupo de reforço chegar ao '
                 'local, um novo grupo de reforço chegará ao local em ondas de '
                 'patrulhas a cada 1d6+2 rodadas.\n'
                 '\n'
                 '## Pedindo Socorro\n'
                 '\n'
                 'Se a intenção é gritar por ajuda da guarda, as chances de se '
                 'obter ajuda são pequenas e dependem exclusivamente do local '
                 'onde se está.\n'
                 '\n'
                 '**Ermos**: a não ser que haja um forte, castelo, agrupamento '
                 'urbano no hexágono em questão nenhuma patrulha ouvirá um '
                 'pedido de socorro.  Caso haja, há apenas 1 chance em 1d6 de '
                 'uma patrulha estar passando subhex no momento do pedido de '
                 'socorro e apenas 1 chance em 1d6 deste ser ouvido.\n'
                 '\n'
                 '**Urbanos**: nas cidades, vilas e povoados a chance está '
                 'ligada ao tamanho da cidade e do tipo de distrito onde o '
                 'pedido de socorro é proferido. Em aldeias ou Bairros Pobres, '
                 'a chance é de 1 em 1d6. Em Vilas ou Bairros Ricos e '
                 'Comerciais, a chance é de 1-3 em 1d6.\n'
                 '\n'
                 '## Corrupção\n'
                 '\n'
                 'Se durante o encontro com uma patrulha, houver negociação e '
                 'necessidade de argumentar uma passagem livre, os personagens '
                 'podem sentir necessidade de negociar alguma vantagem para '
                 'serem deixados em paz.\n'
                 '\n'
                 'Se houver uma tentativa de corromper os guardas, com o '
                 'oferecimento de uma vantagem ilícita, há 1-2 chances em 1d6 '
                 'do efeito ser o contrário e isso enfurecer ainda mais a '
                 'patrulha. Neste caso, um teste de reação deve ser realizado '
                 'para saber qual a reação da patrulha à tentativa de '
                 'corrupção.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 190},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'capitao-da-guarda-patrulha-milicia',
  'jp': '5',
  'mo': 9,
  'mv': 18,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Capitão da Guarda (Patrulha/Milícia)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/guarda-patrulha-milicia.json',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/capitao-da-guarda-patrulha-milicia.json',
  'variant': True,
  'variant_modifications': ['Montado: Cavalo de Guerra.'],
  'xp': '25'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 6,
               'damage': '1d4',
               'damage_bonus': 3,
               'damage_description': '1d4+3',
               'description': 'Adaga',
               'text': '1 × Adaga +6 (1d4+3)',
               'times': 1,
               'weapon': False},
              {'ba': 6,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Besta',
               'text': '1 × Besta +6 (1d6)',
               'times': 1,
               'weapon': False},
              {'ba': 6,
               'damage': '1d6',
               'damage_bonus': 3,
               'damage_description': '1d6+3',
               'description': 'Cimitarra',
               'text': '1 × Cimitarra +6 (1d6+3)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'humanoide',
  'description': 'Piratas são bandidos dos mares que vivem de saques a cidades '
                 'costeiras e a outras embarcações.  Podem viver de crimes e '
                 'do submundo, realizando contrabando, tráfico ou '
                 'escravizações. São famosos pela crueldade e pela forma '
                 'intensa com a qual vivem e gastam o butim de seu trabalho.\n'
                 '\n'
                 'Encontrados: piratas são encontrados em uma quantidade de '
                 'acordo com o tipo de embarcação utilizado. Jogue 1d6 para '
                 'determinar qual a embarcação encontrada: 1-3. Galeão com 40 '
                 'Piratas; 4-5. Trirreme com 20 Piratas; 6. Navio à Vela com '
                 '20 Piratas.\n'
                 '\n'
                 'Escravos Remadores: uma embarcação do tipo Trirreme possui '
                 '150 Escravos Remadores os quais lutarão contra os piratas se '
                 'forem resgatados\n'
                 '\n'
                 'Mapa do Tesouro: há uma chance de 1-3 em 1d6 do tesouro da '
                 'embarcação (A) não estar a bordo, e sim enterrado em um '
                 'esconderijo.  Neste caso, será encontrado na embarcação, um '
                 'mapa com a localização do tesouro.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 10 Piratas, um deles será um '
                 'Pirata Campeão. Além disso, toda embarcação pirata é '
                 'comandada por um Capitão.\n'
                 '\n',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 191},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'capitao-pirata',
  'jp': '6',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Capitão Pirata',
  'parent_monster_url': 'https://olddragon.com.br/monstros/pirata.json',
  'picture': None,
  'pv': '20',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': 'a',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/capitao-pirata.json',
  'variant': True,
  'variant_modifications': ['Moral: enquanto o Capitão estiver em combate, '
                            'todos os piratas fazem o teste de moral com um '
                            'bônus de +1.'],
  'xp': '125'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'besta',
  'flavor': 'Uma monstruosidade bizarra que se enterra nas dunas e usa seu '
            'rabo de cobra coral como uma antena para detectar a presença de '
            'predadores e vítimas.  Movimenta-se muito rápido e pode atacar '
            'com suas pinças, presas e o veneno de sua cauda é poderosíssimo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 60}],
  'habitats': ['desertos'],
  'id': 'caranguejo-cabeca',
  'name': 'Caranguejo Cabeça',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/caranguejo-cabeca.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (1d4)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Garras',
               'text': '2 × Garras +2 (1d4)',
               'times': 2,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1d4',
  'flavor': 'Mamífero feroz e onívoro que ataca criaturas muito maiores e mais '
            'fortes em busca de comida.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 16},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas', 'geleiras'],
  'id': 'carcaju',
  'jp': '5',
  'mo': 11,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Carcaju',
  'picture': None,
  'pv': '5',
  'size': 'pequeno',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/carcaju.json',
  'variant': False,
  'xp': '75'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 0,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': 'Dano por rodada',
               'description': 'Mordida',
               'text': '1 × Mordida (Dano por rodada)',
               'times': 1,
               'weapon': False}],
  'ca': '10',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Dano por rodada**: o Cardume causa dano automático em '
                 'quem estiver na mesma área que ele. Esse dano varia de '
                 'acordo com o estágio da aventura, sendo 1d4 no estágio 1, '
                 '2d4 no estágio 2 e 3d4 no estágio 3.\n'
                 '\n',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 18}],
  'habitats': ['oceanos'],
  'id': 'cardume-de-piranhas',
  'jp': '3',
  'mo': 10,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cardume de Piranhas',
  'picture': None,
  'pv': '20',
  'size': 'pequeno',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cardume-de-piranhas.json',
  'variant': False,
  'xp': '35'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Carnissombras são demônios flutuantes de corpos negros maleáveis, '
            'bocarras de dentes afiados e oito tentáculos com armas diversas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 16}],
  'habitats': ['extraplanar'],
  'id': 'carnissombra',
  'name': 'Carnissombra',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/carnissombra.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide',
  'flavor': 'Criaturas hominídeas, recolhidas no interior das montanhas e em '
            'monólitos esquecidos do deserto. Atacam ferozmente, não se '
            'importando com as leis Jaônicas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 60}],
  'habitats': ['desertos'],
  'id': 'castanho-guerreiro',
  'name': 'Castanho Guerreiro',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/castanho-guerreiro.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'ordeiro',
  'concept': 'humanoide',
  'flavor': 'Entre os Castanhos, no interior das Montanhas, vivem alguns '
            'Xamãs. Sua tradição antiga evoca os elementos mais antigos do '
            'arcanismo Lumniano. Geralmente usam colares de crânios, penas de '
            'pássaros da Morte-Alva, e carregam bastões ou cajados de pedra '
            'com gemas e símbolos sagrados Castanhos amarrados à cintura.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 61}],
  'habitats': ['desertos'],
  'id': 'castanho-xama',
  'name': 'Castanho Xamã',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/castanho-xama.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 9,
               'damage': '1d8',
               'damage_bonus': 6,
               'damage_description': '1d8+6 + Fogo',
               'description': 'Espadas longas',
               'text': '2 × Espadas longas +9 (1d8+6 + Fogo)',
               'times': 2,
               'weapon': False}],
  'ca': '14/21',
  'concept': 'morto_vivo',
  'description': 'De armadura enegrecida e decadente, os Cavaleiros da Morte '
                 'são sombras do que já foram, corrompidos por poderes '
                 'malignos. Usam, em sinal de respeito, os crânios dos '
                 'inimigos mais valorosos como adorno como prova da sua '
                 'própria habilidade em combate.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Seu passado militar faz com que sejam temíveis adversários. '
                 'Ao liderarem mortos-vivos, deixam estes desgastarem o '
                 'inimigo antes de entrarem em combate.\n'
                 '\n'
                 'Não usam ataques com arcos, lanças de arremesso ou '
                 'semelhantes, preferindo sempre um combate corpo a corpo com '
                 'os que consideram valorosos (ou seja, aqueles que não '
                 'fugiram de medo).\n'
                 '\n'
                 '  * **Classe de armadura**: Cavaleiros da Morte possuem CA '
                 '14 ou 21 quando usam armadura completa.\n'
                 '\n'
                 '  * **Medo**: sua aura de morte amedronta todos dentro de um '
                 'raio de 10 metros e que tenham falhado em uma JPS. Os alvos '
                 'devem fugir por 1d3 turnos e têm 50% de chance de soltarem '
                 'qualquer objeto que estejam segurando.\n'
                 '\n'
                 '  * **Neblina das tumbas**: o Cavaleiro da Morte dificulta o '
                 'efeito de um Afastar Mortos-Vivos de um Clérigo. Todo '
                 'morto-vivo a até 20 metros deve ser tratado como se tivesse '
                 'um dado de vida a mais para ser afetado.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a magias mentais de manipulação, '
                 'controle ou ilusão, ou demais formas mágicas de interferir '
                 'na mente de seres vivos.\n'
                 '\n'
                 '  * **Fogo Profano**: a espada longa do Cavaleiro da Morte '
                 'arde em chamas causando 1d6 de dano adicional pelo fogo.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Acredita-se que os primeiros Cavaleiros da Morte eram os '
                 'grandes campeões dos reinos, que se reuniram para banir o '
                 'próprio Orcus.\n'
                 '\n'
                 'Sua investida fora infrutífera, corrompendo-os pelas mãos do '
                 'Demônio Rei e dando origem a um legado terrível.\n'
                 '\n'
                 'Vivem em fortes e castelos deteriorados, acumulando poderes '
                 'por meio de magias, exércitos e artefatos sinistros, sempre '
                 'repletos de mortos-vivos que os servem por simples domínio '
                 'da vontade.',
  'dv': '9',
  'dv_bonus': '+16',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Paladinos caídos e subvertidos que cederam ao chamado do poder e '
            'da corrupção.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 29},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'cavaleiro-da-morte',
  'jp': '12',
  'mo': 12,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cavaleiro da Morte',
  'picture': 'https://public.olddragon.com.br/qxnbpnitipakzqu9s02hpl85xpfq',
  'pv': '61',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/q10kasgo0ocvc33owcmse5ynmjnp',
  'treasure': None,
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cavaleiro-da-morte.json',
  'variant': False,
  'xp': '740'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Espada bastarda',
               'text': '1 × Espada bastarda +2 (1d8+1)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Lança longa',
               'text': '1 × Lança longa +2 (1d8+1)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'humanoide',
  'description': 'Estes soldados estão a serviço de algum senhor local ou '
                 'procurando algum trabalho remunerado para suas armas. '
                 'Fortemente armados e protegidos, são um grupo coeso em '
                 'combate e desafiador para enfrentar.\n'
                 '\n'
                 'Encontrados em grupos formados por: 2d6 soldados, onde 1 a '
                 'cada 5 é um Soldado Pesado atuando como um Sargento; 2d6 '
                 'Arqueiros; 1d6 Besteiros; 1d6 Piqueiros e 1d6 Cavaleiros '
                 'Leves.  A cada 20 homens, haverá adicionalmente um Cavaleiro '
                 'de Guerra onde um destes é o Líder do Grupo.\n'
                 '\n'
                 'Contratando: existe uma chance de 1-2 em 1d6 dos Mercenários '
                 'estarem disponíveis para contratação.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Custo**: 2PO por mês.\n'
                 '\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 76},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 188},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 5},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'cavaleiro-de-guerra-mercenario',
  'jp': '5',
  'mo': 9,
  'mv': 16,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cavaleiro de Guerra (Mercenário)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/soldado-leve-mercenario.json',
  'picture': 'https://public.olddragon.com.br/hysrm9x4j6l66mzz6ny46rxqjei4',
  'pv': '10',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/jgipoxwh8albycdbb1hrb032e8v1',
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cavaleiro-de-guerra-mercenario.json',
  'variant': True,
  'variant_modifications': ['Montado: Cavalo de Guerra.',
                            'Custo: 20 PO por mês.'],
  'xp': '50'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Espada bastarda',
               'text': '1 × Espada bastarda +2 (1d8+1)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Lança longa',
               'text': '1 × Lança longa +2 (1d8+1)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'humanoide',
  'description': 'Homens poderosos (como Barões e Duques) ou mesmo membros da '
                 'Corte (como Conselheiros, Magistrados, Diplomatas e outros '
                 'funcionários do Lorde local). São encontrados também '
                 'residindo em seus castelos e fortalezas, ou em viagem '
                 'durante alguma missão especial.\n'
                 '\n'
                 'Encontrados: quando fora de seus castelos, 1d3 nobres são '
                 'encontrados, escoltados por 2d4 Soldados Leves e 1d4 '
                 'Cavaleiros Leves. Toda a escolta é liderada por um Cavaleiro '
                 'de Guerra que faz o papel de Comandante de Guerra.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Montado**: cavalo de guerra.\n'
                 '\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 189},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'cavaleiro-de-guerra-nobre',
  'jp': '5',
  'mo': 9,
  'mv': 16,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cavaleiro de Guerra (Nobre)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/nobre.json',
  'picture': None,
  'pv': '10',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'vx3',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cavaleiro-de-guerra-nobre.json',
  'variant': True,
  'variant_modifications': ['Montado: Cavalo de Guerra.'],
  'xp': '50'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Lança longa',
               'text': '1 × Lança longa +1 (1d8+1)',
               'times': 1,
               'weapon': False},
              {'ba': 1,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Espada longa',
               'text': '1 × Espada longa +1 (1d8+1)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'humanoide',
  'description': 'Estes soldados estão a serviço de algum senhor local ou '
                 'procurando algum trabalho remunerado para suas armas. '
                 'Fortemente armados e protegidos, são um grupo coeso em '
                 'combate e desafiador para enfrentar.\n'
                 '\n'
                 'Encontrados em grupos formados por: 2d6 soldados, onde 1 a '
                 'cada 5 é um Soldado Pesado atuando como um Sargento; 2d6 '
                 'Arqueiros; 1d6 Besteiros; 1d6 Piqueiros e 1d6 Cavaleiros '
                 'Leves.  A cada 20 homens, haverá adicionalmente um Cavaleiro '
                 'de Guerra onde um destes é o Líder do Grupo.\n'
                 '\n'
                 'Contratando: existe uma chance de 1-2 em 1d6 dos Mercenários '
                 'estarem disponíveis para contratação.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Custo**: 2PO por mês.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 76},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 188},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'cavaleiro-leve-mercenario',
  'jp': '5',
  'mo': 9,
  'mv': 18,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cavaleiro Leve (Mercenário)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/soldado-leve-mercenario.json',
  'picture': 'https://public.olddragon.com.br/hysrm9x4j6l66mzz6ny46rxqjei4',
  'pv': '5',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/jgipoxwh8albycdbb1hrb032e8v1',
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cavaleiro-leve-mercenario.json',
  'variant': True,
  'variant_modifications': ['Montado: Cavalo de Guerra.',
                            'Custo: 10 PO por mês.'],
  'xp': '25'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Lança longa',
               'text': '1 × Lança longa +1 (1d8+1)',
               'times': 1,
               'weapon': False},
              {'ba': 1,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Espada longa',
               'text': '1 × Espada longa +1 (1d8+1)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'humanoide',
  'description': 'Homens poderosos (como Barões e Duques) ou mesmo membros da '
                 'Corte (como Conselheiros, Magistrados, Diplomatas e outros '
                 'funcionários do Lorde local). São encontrados também '
                 'residindo em seus castelos e fortalezas, ou em viagem '
                 'durante alguma missão especial.\n'
                 '\n'
                 'Encontrados: quando fora de seus castelos, 1d3 nobres são '
                 'encontrados, escoltados por 2d4 Soldados Leves e 1d4 '
                 'Cavaleiros Leves. Toda a escolta é liderada por um Cavaleiro '
                 'de Guerra que faz o papel de Comandante de Guerra.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Montado**: cavalo de guerra.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 189},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'cavaleiro-leve-nobre',
  'jp': '5',
  'mo': 9,
  'mv': 18,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cavaleiro Leve (Nobre)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/nobre.json',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'vx3',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cavaleiro-leve-nobre.json',
  'variant': True,
  'variant_modifications': ['Montado: Cavalo de Guerra.'],
  'xp': '25'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Coice',
               'text': '2 × Coice +3 (1d6)',
               'times': 2,
               'weapon': False}],
  'ca': '13',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Correr**: pode correr com movimento 15 durante 1 '
                 'turno.\n'
                 '  * **Preparado**: pode ser usado em combate e é treinado no '
                 'uso de armaduras.\n'
                 '  * **Investida**: se ainda não engajado em combate, pode '
                 'usar a manobra de investida para aumentar o dano do ataque '
                 'do seu cavaleiro.\n'
                 '  * **Combatente**: é capaz de atacar no mesmo turno que seu '
                 'combatente.\n'
                 '  * **Carga**: carrega até 4.000 moedas ou 2.000 moedas e um '
                 'montador.\n'
                 '\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '0',
  'flavor': 'Domesticados e treinados para carregar cavaleiros em combates.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 170},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 16},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'cavalo-de-guerra',
  'jp': '5',
  'mo': 9,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cavalo de Guerra',
  'picture': None,
  'pv': '10',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cavalo-de-guerra.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Coice',
               'text': '1 × Coice +2 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Correr**: pode correr com movimento 18 durante 1 turno '
                 'ou 15 durante 2 turnos\n'
                 '  * **Carga**: carrega até 3.000 moedas ou 1.500 moedas e um '
                 'montador.\n'
                 '\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '0',
  'flavor': 'Domesticado e treinado para carregar cavaleiros por terrenos '
            'acidentados por longas distâncias.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 170},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 16},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'cavalo-de-montaria',
  'jp': '5',
  'mo': 7,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cavalo de Montaria',
  'picture': None,
  'pv': '10',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cavalo-de-montaria.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Coice',
               'text': '1 × Coice +2 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Medroso**: precisa ser bem-sucedido em um teste de '
                 'moral toda vez que é atacado.\n'
                 '  * **Carga**: carrega ou puxa até 4.500 moedas.\n'
                 '\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '0',
  'flavor': 'Domesticado e criado para o trabalho, puxando arados, moinhos, '
            'carroças ou carruagens.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 16},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 16},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'cavalo-de-tracao',
  'jp': '5',
  'mo': 6,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cavalo de Tração',
  'picture': None,
  'pv': '10',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cavalo-de-tracao.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Coice',
               'text': '1 × Coice +2 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'morto_vivo',
  'description': 'Criados por forças dos planos negativos, os Esqueletos lutam '
                 'instintivamente atacando seus alvos de forma incansável.  '
                 'Esqueletos podem ser criados a partir de qualquer criatura '
                 'viva.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Não se sabe ao certo de onde vem a habilidade de luta de um '
                 'Esqueleto, visto que nem todos foram combatentes quando '
                 'vivos.\n'
                 '\n'
                 'De qualquer forma, por sua falta de medo e de emoções, '
                 'Esqueletos lutam friamente com as armas que lhes foram '
                 'dadas, sejam espadas, lanças ou arcos.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar-se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Corpo de Osso**: armas impactantes causam o dobro de '
                 'dano nos Esqueletos, mas, em contrapartida, armas '
                 'perfurantes causam metade do ano.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar '
                 'Mortos-Vivos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'O motivo de sua existência é servir ao seu criador, seja '
                 'este um necromante ou qualquer outra criatura capaz de '
                 'criá-los. Quando seu criador perde o controle sobre os '
                 'Esqueletos, estes se tornam errantes e sem propósito, a não '
                 'ser matar todos os seres encontrados. Esqueletos geralmente '
                 'estão em grupos, pois não são fortes o suficiente para '
                 'atuarem sozinhos como guardas.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os ossos dos Esqueletos triturados são base de várias poções '
                 'e venenos, além de tornarem os campos inférteis se '
                 'espalhados sobre a terra.',
  'dv': '2',
  'dv_bonus': '+1',
  'encounters': '3d4',
  'encounters_lair': '3d10',
  'flavor': 'Mortos-vivos normalmente usados como guardiões de locais antigos '
            'e esquecidos. Sem medo, atacam até caírem aos pedaços.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 76}],
  'habitats': ['qualquer'],
  'id': 'cavalo-esqueleto',
  'jp': '5',
  'mo': 10,
  'mv': 17,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cavalo Esqueleto',
  'parent_monster_url': 'https://olddragon.com.br/monstros/esqueleto.json',
  'picture': 'https://public.olddragon.com.br/tkskg2j4sowg5uvnv57v40jcu5h2',
  'pv': '11',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/d01ibazu0zbf8i7de2eyw8d17zxt',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cavalo-esqueleto.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '35'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Cavalos de composição leve, adaptados para atingirem altas '
            'velocidades. Podem sobreviver apenas de grama.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 61}],
  'habitats': ['desertos'],
  'id': 'cavalo-selvagem',
  'name': 'Cavalo Selvagem',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cavalo-selvagem.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Coice',
               'text': '1 × Coice +2 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'morto_vivo',
  'description': 'Zumbis são criaturas lentas que servem a entidades malignas, '
                 'após serem reanimados de seus túmulos.\n'
                 '\n'
                 'Diferente dos Esqueletos, matam não apenas por ordem, mas '
                 'porque desejam devorar suas vítimas. Quando criados por meio '
                 'de animais, normalmente se encontram presos a coleiras, pois '
                 'a fome pelos vivos é enorme.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usados como soldados, os Zumbis não costumam trabalhar com '
                 'criaturas vivas, pois são uma ameaça a sua segurança.\n'
                 '\n'
                 'O desejo incontrolável por devorar a carne dos vivos faz com '
                 'que sejam colocados com outros mortos-vivos ou criaturas '
                 'incorpóreas. Quando atacam, usam suas garras para puxar e '
                 'para tentar morder seus alvos, mas só conseguirão caso a '
                 'vítima esteja lutando sem armas ou com armas pequenas como '
                 'adagas.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a magias mentais de manipulação, '
                 'controle ou ilusão, ou demais formas mágicas de interferir '
                 'na mente de seres vivos. Sofre 1d6 de dano ácido por frasco '
                 'de água benta.\n'
                 '\n'
                 '  * **Lento**: sempre perde a Iniciativa num combate. Um '
                 'Zumbi sempre ataca por último.\n'
                 '\n'
                 '  * **Infecção**: personagens mordidos devem passar em uma '
                 'JPC ou se tornarão Zumbis em 1d4 dias, a não ser que uma '
                 'magia de Curar Doenças ou Curar Ferimentos seja usada no '
                 'alvo infectado.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral a '
                 'não ser quando sofrem o efeito de um Afastar Mortos-Vivos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Zumbis não se relacionam com nenhuma outra criatura, assim '
                 'como a maioria dos mortos-vivos que não possuem '
                 'inteligência.\n'
                 '\n'
                 'Quando estão em grupos grandes, devoram as vítimas até não '
                 'sobrar mais nada, por isso novos Zumbis surgem destes '
                 'ataques apenas quando o bando é menor e quando resta alguma '
                 'integridade no corpo para que possa se locomover e atacar.\n'
                 '\n'
                 'Além de Magos e Clérigos, existem casos em que energias '
                 'muito malignas acabam criando estes mortos-vivos de forma '
                 'espontânea pela simples emanação energética de planos '
                 'negativos.\n'
                 '\n'
                 '## Variações\n'
                 '\n'
                 'Os acontecimentos que desencadeiam a criação de um Zumbi '
                 'ainda estão longe de serem dominados pelos maiores '
                 'estudiosos da necromancia. Não sendo uma espécie única, os '
                 'Zumbis possuem as mais diferentes origens, comportamentos e '
                 'características, dando origem a diferentes tipos, com '
                 'propósitos e meios de agir únicos.\n'
                 '\n'
                 '### Zumbi do Sal\n'
                 '\n'
                 'Criado pela horrenda experiência de morrer de sede em '
                 'desertos. Desidratados e desesperados, perseguem os vivos '
                 'pela água em seus corpos.  São capazes de se transformarem '
                 'em criaturas realmente determinadas pelo seu objetivo único '
                 'de se hidratar a todo o custo.\n'
                 '\n'
                 'Mantém todas as estatísticas e habilidades de um Zumbi '
                 'comum, mas troca sua habilidade de Infecção pela habilidade '
                 'a seguir:\n'
                 '\n'
                 '  * **Sugar**: se o ataque de mordida for bem-sucedido, ele '
                 'agarra sua vítima e começa a sugar o seu sangue, causando '
                 '1d6 de dano por rodada até ser morta. A única forma de '
                 'soltá-lo da vítima é destruindo sua cabeça, reduzindo seus '
                 'PV a zero ou menos.\n'
                 '\n'
                 '### Zumbi Afogado\n'
                 '\n'
                 'Criado por pessoas afogadas. Seu corpo é inchado, gotejante '
                 'e deformado, como as vítimas de afogamentos.  Sua carne tem '
                 'aspecto de ter sido comida por peixes e outros seres do '
                 'mar.\n'
                 '\n'
                 'Mantém todas as estatísticas e habilidades de um Zumbi '
                 'comum, mas troca sua habilidade de Infecção pela habilidade '
                 'a seguir:\n'
                 '\n'
                 '  * **Explodir**: ao sofrer dano, há uma chance de 1 em 1d6 '
                 'do seu corpo estourar, espalhando em todos dentro de uma '
                 'área de 3m uma onda de dejetos pútridos e purulentos, '
                 'repletos de doenças e infecção. Um alvo atingido deve ser '
                 'bem-sucedido numa JPC ou sofrerá os efeitos do contágio, '
                 'deixando o doente com Constituição 1 durante 1d6 dias.  Há '
                 'uma chance de 1 em 1d6 do doente morrer.\n'
                 '\n'
                 '### Esporo-Zumbi\n'
                 '\n'
                 'Resultado imprevisível de mortos-vivos atacados por fungos '
                 'desconhecidos dos subterrâneos.\n'
                 '\n'
                 'Os esporos se desenvolvem nos corpos contaminados pelo ar ou '
                 'por alimentos e líquidos contaminados. Passam a controlar o '
                 'cérebros de seus hospedeiros, transformando-os em criaturas '
                 'assassinas e agressivas, que perseguem suas vítimas para '
                 'passar a infecção adiante.\n'
                 '\n'
                 'Possui diferentes habilidades à medida que a infecção cresce '
                 'e toma conta de seu corpo:\n'
                 '\n'
                 '  * **Infectado**: durante os primeiros dias da infecção e '
                 'por toda esta fase, o Esporo-Zumbi troca suas habilidades '
                 'Silencioso e Lento pela habilidade de Correr, tendo o '
                 'movimento de quando era vivo.\n'
                 '\n'
                 '  * **Fendido**: após os primeiros dias de infecção, seu '
                 'crânio fica fendido por vários fungos que brotam de seu '
                 'interior. Nesta fase, ele troca sua habilidade de Correr '
                 'pela habilidade de Perseguir, usando uma espécie de '
                 'ecolocalização para saber precisamente onde todo ser vivo '
                 'está num raio de 30m.\n'
                 '\n'
                 '  * **Rei**: aproximadamente um mês após a infecção, têm seu '
                 'corpo completamente tomado pelo fungo, tornando-se uma '
                 'máquina de propagar seus esporos. Durante um combate, todos '
                 'em até 9m de um Esporo-Zumbi Rei que receberem um ataque '
                 'bem-sucedido, possuem uma chance de 1 em 1d6 de serem '
                 'infectados pelos esporos, tornando-se um Infectado, '
                 'reiniciando todo o processo.',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '4d6',
  'flavor': 'Morto-vivo sem inteligência. Avança para cima de suas vítimas com '
            'o único intuito de destroçá-las com garras e dentes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 178}],
  'habitats': ['qualquer'],
  'id': 'cavalo-zumbi',
  'jp': '5',
  'mo': 7,
  'mv': 15,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cavalo Zumbi',
  'parent_monster_url': 'https://olddragon.com.br/monstros/zumbi.json',
  'picture': 'https://public.olddragon.com.br/cz4xa87qz93imyvxgtmjrpst2zrk',
  'pv': '10',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/6yi5o3kte4bwdldij0z092zdsk4x',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cavalo-zumbi.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '35'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide_monstruoso',
  'flavor': 'Humanoides esqueléticos e brutos, de inteligência baixa.  São '
            'conhecidos por atacar assentamentos humanos para roubar tesouros '
            'e itens poderosos. Essas malditas caveiras gigantes morreram, mas '
            'o seu delírio por ouro manteve-se mesmo após a sua morte '
            'amaldiçoada.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 61}],
  'habitats': ['desertos'],
  'id': 'caveira-gigante',
  'name': 'Caveira-Gigante',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/caveira-gigante.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'besta',
  'flavor': 'Raça de anjos e arcanjos dracônicos e poderosos.  Têm por dever '
            'proteger os Jardins das Delícias.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 18}],
  'habitats': ['extraplanar'],
  'id': 'celestial',
  'name': 'Celestial',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/celestial.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 5,
               'damage': '2d6',
               'damage_bonus': 3,
               'damage_description': '2d6+3',
               'description': 'Corrente',
               'text': '1 × Corrente +5 (2d6+3)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide_monstruoso',
  'description': 'Cenobitas são humanoides vindos de diversas raças. Usam '
                 'roupas pretas de couro, com pregos e espinhos fincados no '
                 'corpo e vestes. Além de pálidos, têm deformidades horrendas '
                 'e emitem sons hediondos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam com suas correntes de longe, tentando prender o '
                 'inimigo (que pode estar tentando fugir de medo). Evitam o '
                 'combate a curta distância, mas podem usar as correntes da '
                 'mesma forma.\n'
                 '\n'
                 '  * **Assustador**: alvos que falharem em uma JPS irão '
                 'tentar fugir de medo, com uma chance de 1-2 em 1d6 de '
                 'soltarem qualquer objeto que estejam segurando.\n'
                 '\n'
                 '  * **Correntes**: possuem 1d4 correntes presas no corpo, '
                 'que obedecem seus comandos.  Elas podem se mover até 20 '
                 'metros, dando voltas, fazendo curvas e quaisquer outras '
                 'manobras desejada pelo Cenobita.\n'
                 '\n'
                 '  * **Rasgar**: quando o alvo for atingido pela corrente com '
                 'um resultado de “20” no dado, ele deve fazer uma JPD. Caso '
                 'falhe, receberá +2d6 de dano e -1 na DES, mas, se for '
                 'bem-sucedido, receberá apenas +2d6 de dano. A DES pode ser '
                 'recuperada como se fosse um ferimento normal.\n'
                 '\n'
                 '  * **Resistência à magia**: qualquer magia lançada contra '
                 'um Cenobita possui 1-2 chances em 1d6 de ser completamente '
                 'ignorada.\n'
                 '\n'
                 '  * **Excomungar**: eles podem ser expulsos por meio do '
                 'quebra-cabeças usado para trazê-los.  Se o personagem tentar '
                 'resolver o enigma, deve fazer um teste de INT difícil. Assim '
                 'que resolvido, todos os Cenobitas próximos serão '
                 'excomungados.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Criados pelo Demogorgon, os Cenobitas são agentes infernais '
                 'buscando se alimentar da dor daqueles que os invocam na '
                 'ilusão de que receberão grandes tesouros e terão desejos '
                 'atendidos.\n'
                 '\n'
                 'Apenas meios muito específicos podem ser usados para invocar '
                 'estes seres, como runas e glifos complexos como '
                 'quebra-cabeças. Após lidar com quem o invocou, um Cenobita '
                 'pode ficar ainda até 7 dias vagando pelo plano material em '
                 'busca de vítimas. Um evento raro (para o bem de todos) é o '
                 'encontro entre Cenobitas e Cavaleiros da Morte, inimigos '
                 'jurados por seus mestres. Estes confrontos podem aniquilar '
                 'povoados inteiros e profanar a terra ao redor.',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '0',
  'flavor': 'Criaturas torturadoras do abismo. Alimentam-se da dor de suas '
            'vítimas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 30},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'cenobita',
  'jp': '9',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cenobita',
  'picture': 'https://public.olddragon.com.br/ng9xelqfpsqlyp0kclvk3oi45s4m',
  'pv': '30',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/enhnplhirn64jh9ch8rcqo0qqjtz',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cenobita.json',
  'variant': False,
  'xp': '340'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Cascos',
               'text': '2 × Cascos +4 (1d6)',
               'times': 2,
               'weapon': False},
              {'ba': 4,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma +4 (Arma)',
               'times': 1,
               'weapon': True}],
  'ca': '15',
  'concept': 'besta',
  'description': 'Centauros são uma raça de homens-equinos, fortes por '
                 'natureza que adoram cavalgar livremente pelos ermos.\n'
                 '\n'
                 'Alguns usam tranças, tatuagens ou adornos tribais que '
                 'demonstrem pertencimento a alguma tribo em específico.\n'
                 '\n'
                 'Sua pelagem varia independentemente da cor de sua pele, '
                 'possibilitando muitas combinações.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam de sua velocidade para atacar com arcos e lanças, '
                 'atacando e fugindo para fora do alcance de uma resposta do '
                 'inimigo.\n'
                 '\n'
                 'Uma de suas formações de batalha é fazer um círculo mantendo '
                 'seus alvos bem ao centro, já que devido a sua altura, atiram '
                 'em um ângulo, de cima para baixo, que torna difícil '
                 'acertarem algum aliado.\n'
                 '\n'
                 '  * **Correr**: pode correr com movimento 15 durante 1 '
                 'turno.\n'
                 '\n'
                 '  * **Investida**: se ainda não engajado em combate, pode '
                 'usar a manobra de investida para aumentar o dano do seu '
                 'ataque com armas corpo-a-corpo.\n'
                 '\n'
                 '  * **Carga**: carrega até 4.000 moedas ou 2.000 moedas e um '
                 'montador.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em tribos escondidas em clareiras, nas florestas, '
                 'morando em grandes cabanas típicas de povos nômades.\n'
                 '\n'
                 'Respeitam muito os integrantes mais velhos, ensinando os '
                 'mais novos a respeitarem a natureza e a sua caça.\n'
                 '\n'
                 'Não gostam de se misturar em ambientes muito urbanos, de '
                 'modo que apenas os mais jovens costumam interagir com '
                 'cidades, geralmente para troca de mercadorias julgadas como '
                 'interessantes.\n'
                 '\n'
                 'Adoram bebidas alcóolicas e as consideram moeda de troca com '
                 'alguns povos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Criaturas inteligentes dos subterrâneos pagam boas quantias '
                 'pela carne de Centauros. Uma iguaria rara e deliciosa para '
                 'eles.',
  'dv': '4',
  'dv_bonus': '+4',
  'encounters': '0',
  'encounters_lair': '2d10',
  'flavor': 'Guardiões das florestas. Mestres na arte da perseguição, caça e '
            'arco. Atacam invasores sem avisar.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 31},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas'],
  'id': 'centauro',
  'jp': '6',
  'mo': 10,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Centauro',
  'picture': 'https://public.olddragon.com.br/ctyrs95l0n2q1fc8kjqx7ujkw92z',
  'pv': '24',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/mihh266wbg17da431ndxkx4n7jhp',
  'treasure': 's',
  'treasure_lair': 'e',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/centauro.json',
  'variant': False,
  'xp': '125'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6 + Veneno',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (1d6 + Veneno)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'inseto',
  'description': '\n'
                 '\n'
                 '  * **Veneno**: causa a perda de 1d4+2 pontos de '
                 'Constituição em caso de falha em uma JPC.\n'
                 '\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Esta criatura feroz dos subterrâneos usa seu tamanho e mobilidade '
            'para desferir seus venenos em suas vítimas.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/ja1.json',
              'page': 40},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 115},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'centopeia-gigante',
  'jp': '5',
  'mo': 9,
  'mv': 12,
  'mvc': None,
  'mve': 9,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Centopeia Gigante',
  'picture': 'https://public.olddragon.com.br/itdoi34h3cfpuuwzuoee09695m6j',
  'pv': '10',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/vo9a2x2rnblj801m89qzz5u97iia',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/centopeia-gigante.json',
  'variant': False,
  'xp': '50'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 10,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4 + Veneno',
               'description': 'Cauda',
               'text': '1 × Cauda +10 (2d4 + Veneno)',
               'times': 1,
               'weapon': False},
              {'ba': 16,
               'damage': '2d6',
               'damage_bonus': 8,
               'damage_description': '2d6+8',
               'description': 'Mordidas',
               'text': '2 × Mordidas +16 (2d6+8)',
               'times': 2,
               'weapon': False}],
  'ca': '20',
  'concept': 'besta',
  'description': 'Gigantesco, este monstro possui três cabeças caninas e uma '
                 'cauda pontiaguda, farpada e perigosa.\n'
                 '\n'
                 'Suas bocas com dentes descrenhados e assustadoramente '
                 'afiados secretam constantemente uma saliva pútrida e mal '
                 'cheirosa, sinal de sua raiva e ferocidade.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Acostumado a proteger os portões dos Planos do Caos, o '
                 'Cérbero luta de forma defensiva, aguardando o primeiro '
                 'movimento do inimigo como uma forma de medir sua força.\n'
                 '\n'
                 'Suas mandíbulas selvagens mordem e distraem o oponente '
                 'enquanto sua cauda dá um golpe fatal.\n'
                 '\n'
                 '  * **Vigia**: um Cérbero está sempre vigilante e não pode '
                 'ser surpreendido.\n'
                 '\n'
                 '  * **Desmorte**: uma criatura morta pelo Cérbero retorna '
                 'como um Ghoul sob seu controle em 1d3 turnos.\n'
                 '\n'
                 '  * **Veneno**: a cauda perfurante do Cérbero inocula Veneno '
                 'Paralisante. Uma JPC evita qualquer efeito deste veneno. Uma '
                 'falha no teste causa a perda de 1d6 pontos de Destreza por '
                 'turno até o alvo perder todos os pontos de Destreza e '
                 'morrer.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Solitário, vive nos arredores dos portões infernais os quais '
                 'está destinado a guardar.\n'
                 '\n'
                 'Algumas criaturas o cultuam como um tipo de deus lobo, '
                 'associando cada uma de suas cabeças a um tempo: passado, '
                 'presente e futuro.\n'
                 '\n'
                 'Ao contrário do que alguns estudiosos dizem, ele não vive '
                 'preso em uma corrente, e sim ao seu juramento de guardar os '
                 'portões.\n'
                 '\n'
                 'Quando sente necessidade de caçar, Cérbero vaga pelos '
                 'arredores podendo inclusive viajar aos planos materiais em '
                 'busca de alimento.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Assim que morre, o corpo sem vida de um Cérbero começa a '
                 'derreter formando uma enorme poça de lodo pegajoso e '
                 'fumegante em um processo rápido de decomposição que leva 1d4 '
                 'turnos.',
  'dv': '20',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Cão Infernal imenso com três cabeças. Guarda a entrada dos Planos '
            'do Caos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 32},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['extraplanar'],
  'id': 'cerbero',
  'jp': '12',
  'mo': 10,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cérbero',
  'picture': 'https://public.olddragon.com.br/jc42b0b6shfl7jhndguxl82mu60n',
  'pv': '100',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/aj4qk5fpw5er0m3etpmns17hma4u',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cerbero.json',
  'variant': False,
  'xp': '2100'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Espada longa',
               'text': '1 × Espada longa +2 (1d8+1)',
               'times': 1,
               'weapon': False},
              {'ba': 1,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Besta de mão',
               'text': '1 × Besta de mão +1 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'humanoide',
  'description': 'Organizados em caravanas percorrendo as estradas, levam seus '
                 'produtos em grandes carroças, vendendo e comprando '
                 'mercadorias para as mais diferentes e distantes '
                 'localizações.\n'
                 '\n'
                 'Encontrados em caravanas de 4d6 + 10 indivíduos.\n'
                 '\n'
                 'Caravana: há duas carroças repletas de mercadorias para cada '
                 'mercador, descontados os guarda-costas e Chefe da Guarda. '
                 'Cada carroça é puxada por uma parelha de dois cavalos de '
                 'tração.\n'
                 '\n'
                 'Mercadorias: jogue 1d6 para determinar o que a caravana '
                 'transporta. O resultado do dado significa que a caravana '
                 'transporta aquele tipo de item e os de valor menor: 1. '
                 'Alimentos, 2. Utilidades Domésticas, 3. Especiarias, 4. '
                 'Equipamentos Gerais, 5. Armas e Armaduras e 6. Objetos de '
                 'Valor.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 4 Mercadores, um deles será um '
                 'Guarda-Costas. Além disso, há sempre um Chefe da Guarda por '
                 'caravana.\n'
                 '\n'
                 '  * **Montada**: cavalo de montaria.\n'
                 '\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 184},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'chefe-da-guarda-mercadores',
  'jp': '5',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Chefe da Guarda (Mercadores)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/mercador.json',
  'picture': None,
  'pv': '10',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'a',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/chefe-da-guarda-mercadores.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Espada longa',
               'text': '1 × Espada longa +1 (1d8+1)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'humanoide',
  'description': 'Estes homens formam o corpo da guarda ou do exército de um '
                 'nobre local e fazem parte de um destacamento de patrulha '
                 'urbana ou dos ermos.  Vivem para vigiar e resguardar a lei e '
                 'a ordem em nome do nobre local.\n'
                 '\n'
                 '**Pedidos de socorro**: Patrulhas/Milícias possuem uma '
                 'chance básica de 1-2 em 1d6 de ouvir um pedido de socorro em '
                 'agrupamentos urbanos iguais a uma cidade ou metrópole.\n'
                 '\n'
                 '**Encontrados**: as patrulhas são formadas por 2d6 Guardas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: toda patrulha possui um Chefe da Guarda. '
                 'Há ainda uma chance de 1-2 em 1d6 do Capitão da Guarda estar '
                 'presente.\n'
                 '\n'
                 '## Reforços\n'
                 '\n'
                 'Sempre que uma ocorrência ocorre e uma patrulha se encontra '
                 'com um grupo que impõe resistência a prisão, há 1-2 chances '
                 'em 1d6 de um dos guardas deixar o local do encontro para '
                 'buscar reforços.\n'
                 '\n'
                 '**Ermos**: se o encontro for realizado em um ermo, o guarda '
                 'procurará a base da guarda para avisar do encontro e trazer '
                 'reforços para o local. Use a contagem de tempo e viagem até '
                 'o local apropriado ou se em necessidade, um reforço demorará '
                 '1d4+2 turnos para chegar. O reforço usa as mesmas regras '
                 'para sua formação que uma patrulha normal, mas existirá '
                 'apenas um único Capitão da Guarda.\n'
                 '\n'
                 '**Urbanos**: reforços urbanos são mais rápidos de se obter. '
                 'Mesmo que nenhum guarda abandone o local para chamá-los há '
                 '1-3 chances de um reforço surgir no local do encontro após '
                 '2d6 rodadas, simplesmente pela confusão, gritos e barulho de '
                 'batalha. Depois que este primeiro grupo de reforço chegar ao '
                 'local, um novo grupo de reforço chegará ao local em ondas de '
                 'patrulhas a cada 1d6+2 rodadas.\n'
                 '\n'
                 '## Pedindo Socorro\n'
                 '\n'
                 'Se a intenção é gritar por ajuda da guarda, as chances de se '
                 'obter ajuda são pequenas e dependem exclusivamente do local '
                 'onde se está.\n'
                 '\n'
                 '**Ermos**: a não ser que haja um forte, castelo, agrupamento '
                 'urbano no hexágono em questão nenhuma patrulha ouvirá um '
                 'pedido de socorro.  Caso haja, há apenas 1 chance em 1d6 de '
                 'uma patrulha estar passando subhex no momento do pedido de '
                 'socorro e apenas 1 chance em 1d6 deste ser ouvido.\n'
                 '\n'
                 '**Urbanos**: nas cidades, vilas e povoados a chance está '
                 'ligada ao tamanho da cidade e do tipo de distrito onde o '
                 'pedido de socorro é proferido. Em aldeias ou Bairros Pobres, '
                 'a chance é de 1 em 1d6. Em Vilas ou Bairros Ricos e '
                 'Comerciais, a chance é de 1-3 em 1d6.\n'
                 '\n'
                 '## Corrupção\n'
                 '\n'
                 'Se durante o encontro com uma patrulha, houver negociação e '
                 'necessidade de argumentar uma passagem livre, os personagens '
                 'podem sentir necessidade de negociar alguma vantagem para '
                 'serem deixados em paz.\n'
                 '\n'
                 'Se houver uma tentativa de corromper os guardas, com o '
                 'oferecimento de uma vantagem ilícita, há 1-2 chances em 1d6 '
                 'do efeito ser o contrário e isso enfurecer ainda mais a '
                 'patrulha. Neste caso, um teste de reação deve ser realizado '
                 'para saber qual a reação da patrulha à tentativa de '
                 'corrupção.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 190},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'chefe-da-guarda-patrulha-milicia',
  'jp': '5',
  'mo': 8,
  'mv': 18,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Chefe da Guarda (Patrulha/Milícia)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/guarda-patrulha-milicia.json',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/chefe-da-guarda-patrulha-milicia.json',
  'variant': True,
  'variant_modifications': ['Montado: Cavalo de Montaria'],
  'xp': '15'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Selvagens e brutais, visam a expansão de seus territórios por '
            'meio de invasões e constantes ataques aos outros povos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 74}],
  'habitats': ['qualquer'],
  'id': 'chefe-orc',
  'name': 'Chefe Orc',
  'parent_monster_url': 'https://olddragon.com.br/monstros/orc.json',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/chefe-orc.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 8,
               'damage': '3d6',
               'damage_bonus': None,
               'damage_description': '3d6',
               'description': 'Pedrada',
               'text': '1 × Pedrada +8 (3d6)',
               'times': 1,
               'weapon': False},
              {'ba': 11,
               'damage': '2d6',
               'damage_bonus': 4,
               'damage_description': '2d6+4',
               'description': 'Clava',
               'text': '1 × Clava +11 (2d6+4)',
               'times': 1,
               'weapon': False}],
  'ca': '16/17',
  'concept': 'gigante',
  'description': 'Medindo por volta de 4 metros, estas criaturas gigantescas '
                 'andam a esmo com seus tacapes primitivos em busca de '
                 'alimento.\n'
                 '\n'
                 'Possuem cabelos pretos desgrenhados e opacos com aparência '
                 'de sujos e ensebados.\n'
                 '\n'
                 'No local de onde deveriam existir seus olhos, logo acima do '
                 'nariz, está o seu único olho.  Grande, vermelho e '
                 'ameaçador.\n'
                 '\n'
                 'Suas vestes são de peles costuradas umas nas outras, e '
                 'exalam um terrível odor, de couro mal curtido, sendo '
                 'percebido a uma boa distância.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Arremessam pedras quando estão longe e partem para cima do '
                 'oponente com seu tacape quando estão no alcance correto.\n'
                 '\n'
                 'Não são muito corajosos, então preferem atacar os alvos '
                 'considerados “vitória certa”.\n'
                 '\n'
                 '  * **Classe de armadura**: Ciclopes possuem CA 16 ou 17 '
                 'quando usam armadura acolchoada.\n'
                 '\n'
                 '  * **Golpe potente**: se causar, com uma clava ou pedrada, '
                 'uma quantidade de dano maior do que a força do alvo, este é '
                 'arremessado 1d4 metros para trás.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Quando vivem em grupos, são liderados pelas fêmeas, enquanto '
                 'os machos cuidam dos filhos.\n'
                 '\n'
                 'Sozinhos ou em pequenos grupos, são nômades e carregam '
                 'consigo rebanhos de ovelhas ou cabras, protegendo-as com '
                 'suas vidas para garantir o sustento do dia seguinte.\n'
                 '\n'
                 'Apesar de violentos e pouco inteligentes, não são '
                 'gananciosos e mantêm algum tesouro mais por questão estética '
                 'do que pelo valor em si.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'O olho do Ciclope é usado em estudos de itens mágicos '
                 'ligados a visão verdadeira.',
  'dv': '10',
  'dv_bonus': '+5',
  'encounters': '1',
  'encounters_lair': '1d4',
  'flavor': 'Brutal ao defender o que é seu, um Ciclope ataca com pedras '
            'gigantescas e com poderosos golpes de tacape.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 33},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['planicies', 'colinas', 'montanhas'],
  'id': 'ciclope',
  'jp': '12',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Ciclope',
  'picture': 'https://public.olddragon.com.br/anye9t6cq35473a7jdtiae1dzjk3',
  'pv': '55',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/gwyyr1kahbjk28pypnrgc3p4jizj',
  'treasure': 't',
  'treasure_lair': 'd',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/ciclope.json',
  'variant': False,
  'xp': '1250'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'gigante',
  'flavor': 'Sua pele tem um tom marrom esverdeado e produz barulhos terríveis '
            'enquanto caminha ou descansa.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 61}],
  'habitats': ['desertos'],
  'id': 'ciclope-alienigena',
  'name': 'Ciclope Alienígena',
  'size': 'imenso',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/ciclope-alienigena.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 5,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Pancada',
               'text': '1 × Pancada +5 (1d6+2)',
               'times': 1,
               'weapon': False},
              {'ba': 5,
               'damage': '1d6',
               'damage_bonus': 3,
               'damage_description': '1d6+3',
               'description': 'Clava',
               'text': '1 × Clava +5 (1d6+3)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Ciclorcs são criaturas mágicas oriundas dos Orcs misturadas '
                 'com uma criatura mística, o bode negro Zraxius, resultado de '
                 'uma antiga maldição.\n'
                 '\n'
                 'Odeiam elfos e humanos, considerando ambos culpados pela sua '
                 'condição, além de todos os Orcs, porque os consideram '
                 'traidores.\n'
                 '\n'
                 '**Som**: passos leves e constantes.\n'
                 '\n'
                 '**Odor**: estrume de animal de rebanho.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Por ainda manterem parte de seus poderes divinos xamânicos, '
                 'atacam usando uma mistura de força bruta com a inteligência '
                 'dos seus poderes divinos.\n'
                 '\n'
                 '  * **Infravisão**: 15 metros.\n'
                 '\n'
                 '  * **Bode Sagrado**: durante um combate e enquanto os '
                 'Ciclorcs não precisarem realizar um teste de moral, todos os '
                 'Ciclorcs realizam seus ataques corpo a corpo como ataques '
                 'fáceis devido a sua ligação mística com o grande Bode Negro '
                 'Zraxius. Quando um teste de moral for realizado para os '
                 'Ciclorcs, esta habilidade não pode ser mais utilizada até o '
                 'final do combate.\n'
                 '\n'
                 '  * **Cura Totêmica**: um Ciclorc pode se curar, ou curar um '
                 'alvo tocado, em 1d8 pontos de vida. Esta habilidade pode ser '
                 'usada até uma vez ao dia.\n'
                 '\n'
                 '  * **Magia**: um Ciclorc pode lançar magias como se fosse '
                 'um Clérigo Xamã de 3º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em tribos, cultuando seu Animal Místico, o Bode Negro '
                 'Zraxius e destruindo todos que encontram pela frente ou que '
                 'invadam seus territórios nos ermos.\n'
                 '\n'
                 'Escolhem sempre regiões desabitadas e isoladas exatamente '
                 'para evitar contato com outras criaturas e civilizações.\n'
                 '\n'
                 'Reza a lenda que estas criaturas eram xamãs Orcs que '
                 'tentaram trair Orcus ao cultuar Zraxius.\n'
                 '\n'
                 'Orcus se incomodou com o crescimento do fanatismo e resolveu '
                 'punir estes xamãs, retirando- lhes um olho e transformando '
                 'seus corpos num amalgama grotesco entre Orcs e bode.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Carcaças de Ciclorcs são ótimos presentes diplomáticos para '
                 'negociações com tribos Orcs mais racionais.',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '1d4x3',
  'flavor': 'Amaldiçoadas pelo deus Orcus, estas criaturas descendem dos Orcs '
            'e usam seus poderes mágicos contra seus inimigos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 34},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas', 'subterraneos'],
  'id': 'ciclorc',
  'jp': '7',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Ciclorc',
  'picture': 'https://public.olddragon.com.br/imxr1g01byuvv50x0j9q4z3nbrlq',
  'pv': '15',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/s2zt5hi801y9tfctiniocb3hj6p1',
  'treasure': 's',
  'treasure_lair': 'b+c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/ciclorc.json',
  'variant': False,
  'xp': '135'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4 + Constrição',
               'description': 'Mordida',
               'text': '1 × Mordida +4 (1d4 + Constrição)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Agarrar**: Quando um ataque de mordida é bem-sucedido, '
                 'a Cobra Constritora agarra a vítima causando 2d4 de dano por '
                 'rodada.  Um teste de força bem-sucedido livra da '
                 'constrição.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '1d6',
  'flavor': 'Típica dos pântanos, a Cobra Constritora é forte e perigosa.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 170},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 16},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['pantanos'],
  'id': 'cobra-constritora',
  'jp': '6',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cobra Constritora',
  'picture': None,
  'pv': '15',
  'size': 'pequeno',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cobra-constritora.json',
  'variant': False,
  'xp': '75'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Típica dos pântanos, a Cobra Constritora é forte e perigosa.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 35}],
  'habitats': ['pantanos'],
  'id': 'cobra-constritora-guardia',
  'name': 'Cobra Constritora Guardiã',
  'parent_monster_url': 'https://olddragon.com.br/monstros/cobra-constritora.json',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cobra-constritora-guardia.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Cegueira',
               'description': 'Cuspe',
               'text': '1 × Cuspe +2 (Cegueira)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': '1d2',
               'damage_bonus': None,
               'damage_description': '1d2',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (1d2)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Cegueira**: causa cegueira por 1d6 rodadas nos alvos '
                 'atingidos que falharem em um teste de JPD.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Negra e reclusa, ataca quando confrontada com seu cuspe venenoso.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 16},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['desertos', 'florestas'],
  'id': 'cobra-cuspidora',
  'jp': '4',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cobra Cuspidora',
  'picture': None,
  'pv': '5',
  'size': 'miudo',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cobra-cuspidora.json',
  'variant': False,
  'xp': '25'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Negra e reclusa, ataca quando confrontada com seu cuspe venenoso.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 30}],
  'habitats': ['desertos', 'florestas'],
  'id': 'cobra-cuspidora-guardia',
  'name': 'Cobra Cuspidora Guardiã',
  'parent_monster_url': 'https://olddragon.com.br/monstros/cobra-cuspidora.json',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cobra-cuspidora-guardia.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'constructo',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 31}],
  'habitats': [],
  'id': 'cobra-de-metal',
  'name': 'Cobra de Metal',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cobra-de-metal.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'constructo',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 34}],
  'habitats': [],
  'id': 'cobra-de-metal-ancestral',
  'name': 'Cobra de Metal Ancestral',
  'parent_monster_url': 'https://olddragon.com.br/monstros/cobra-de-metal.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cobra-de-metal-ancestral.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'constructo',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 34}],
  'habitats': [],
  'id': 'cobra-de-metal-superior',
  'name': 'Cobra de Metal Superior',
  'parent_monster_url': 'https://olddragon.com.br/monstros/cobra-de-metal.json',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cobra-de-metal-superior.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d2',
               'damage_bonus': None,
               'damage_description': '1d2 + Veneno',
               'description': 'Mordida',
               'text': '1 × Mordida +1 (1d2 + Veneno)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Veneno**: causa morte em 1d10 turnos em caso de falha '
                 'em um teste de JPC.\n'
                 '\n',
  'dv': '½',
  'dv_bonus': '',
  'encounters': '1d3',
  'encounters_lair': '1d3',
  'flavor': 'Ágil e traiçoeira, esta serpente vive em quase todos os ambientes '
            'e climas, menos nos mais extremos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 16},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['colinas',
               'desertos',
               'florestas',
               'montanhas',
               'pantanos',
               'planicies'],
  'id': 'cobra-venenosa',
  'jp': '4',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cobra Venenosa',
  'picture': None,
  'pv': '2',
  'size': 'miudo',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cobra-venenosa.json',
  'variant': False,
  'xp': '10'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Ágil e traiçoeira, esta serpente vive em quase todos os ambientes '
            'e climas, menos nos mais extremos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 32}],
  'habitats': ['colinas',
               'desertos',
               'florestas',
               'montanhas',
               'pantanos',
               'planicies'],
  'id': 'cobra-venenosa-guardia',
  'name': 'Cobra Venenosa Guardiã',
  'parent_monster_url': 'https://olddragon.com.br/monstros/cobra-venenosa.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cobra-venenosa-guardia.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1 + Confusão',
               'description': 'Garra',
               'text': '1 × Garra +3 (1d4+1 + Confusão)',
               'times': 1,
               'weapon': False},
              {'ba': 5,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4 + Petrificação',
               'description': 'Bicada',
               'text': '1 × Bicada +5 (1d4 + Petrificação)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'besta',
  'description': 'Esta criatura monstruosa, uma mistura entre uma galinha e um '
                 'réptil possui o tamanho de um peru grande, ou mesmo de um '
                 'pavão.\n'
                 '\n'
                 'São criaturas muito feias que emitem um som estranho, '
                 'parecido com um cacarejar serpentino.\n'
                 '\n'
                 'Dizem que muitos cavaleiros já morreram ao enfrentar a '
                 'criatura, e que elas originalmente, nos tempos ancestrais, '
                 'possuiam o assustador tamanho de um cavalo.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Feroz, o Cocatriz ataca pulando no rosto da vítima, '
                 'rasgando-a com suas garras enquanto bate as asas.\n'
                 '\n'
                 'Este efeito geralmente causa confusão no alvo que, logo em '
                 'seguida, é atingido por uma bicada capaz de transformá-lo em '
                 'pedra.\n'
                 '\n'
                 'Cocatrizes são muito territorialistas e protetores de seus '
                 'ninhos.\n'
                 '\n'
                 '  * **Petrificação**: quando acerta com seu bico, o alvo '
                 'deve passar em uma JPC ou ficará petrificado até alguma '
                 'magia pertinente desfazer o efeito.\n'
                 '\n'
                 '  * **Imunidade**: a Cocatriz é imune a qualquer tipo de '
                 'petrificação, seja esta mágica ou não.\n'
                 '\n'
                 '  * **Confusão**: quando acerta com suas garras, o alvo deve '
                 'passar em uma JPD ou perderá a sua ação. Caso o alvo fique '
                 'confuso, o próximo ataque do Cocatriz é realizado como um '
                 'ataque muito fácil.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Solitários, é muito raro encontrar mais de um no mesmo '
                 'lugar, pois não necessitam de um parceiro para procriar.\n'
                 '\n'
                 'Dão 1 ou 2 ovos a cada ano, e os filhotes lutam entre si até '
                 'ficar apenas um. Este será criado até ter idade para devorar '
                 'sua genitora.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Seu sangue é usado na forja de metais na confecção de armas '
                 'mágicas, enquanto os olhos e saliva são usados para '
                 'confeccionar itens ligados a paralisia.',
  'dv': '5',
  'dv_bonus': '+3',
  'encounters': '1d4',
  'encounters_lair': '1d8',
  'flavor': 'Criatura irritadiça, que pode transformar carne em pedra. Pulam '
            'no rosto dos oponentes, causando confusão e caos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 35},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['planicies', 'colinas'],
  'id': 'cocatriz',
  'jp': '9',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cocatriz',
  'picture': 'https://public.olddragon.com.br/8m48hlb49xr4ik2u3a853lptu12j',
  'pv': '28',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/g8ebbno2gyvyso4d3k1o5zgtcfan',
  'treasure': None,
  'treasure_lair': 'j',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cocatriz.json',
  'variant': False,
  'xp': '235'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1',
               'description': 'Mordida',
               'text': '1 × Mordida +1 (1d4+1)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '1',
  'dv_bonus': '+2',
  'encounters': '1',
  'encounters_lair': '1d4',
  'flavor': 'Canídeos pequenos e carnívoros que vivem em montanhas, florestas, '
            'planícies e desertos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 17},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['desertos', 'florestas', 'montanhas', 'planicies'],
  'id': 'coiote',
  'jp': '4',
  'mo': 7,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Coiote',
  'picture': None,
  'pv': '7',
  'size': 'pequeno',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/coiote.json',
  'variant': False,
  'xp': '15'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Canídeos pequenos e carnívoros comuns em desertos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 62}],
  'habitats': ['desertos'],
  'id': 'coiote-do-deserto',
  'name': 'Coiote do Deserto',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/coiote-do-deserto.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'As Coisas Insetos são monstros insetoides enormes, com formas '
            'variadas que infestam as Infinitas Cavernas na região das '
            'Montanhas Centrais.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 20}],
  'habitats': ['subterraneos'],
  'id': 'coisa-inseto',
  'name': 'Coisa-Inseto',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/coisa-inseto.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'constructo',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 87}],
  'habitats': ['qualquer'],
  'id': 'constructo-da-cozinha',
  'name': 'Constructo da Cozinha',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/constructo-da-cozinha.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide_monstruoso',
  'flavor': 'Monstruosidade vinda dos abismos do mar. Possui uma bocarra, '
            'barbatanas, pés e mãos membranosas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday18.json',
              'page': 14}],
  'habitats': ['oceanos'],
  'id': 'cria-de-dagon',
  'name': 'Cria de Dagon',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cria-de-dagon.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 6,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Lança',
               'text': '1 × Lança +6 (1d6+2)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Criaturas abissais lembram peixes abissais humanoides, '
                 'podendo variar muito no aspecto físico, estilos de '
                 'barbatanas e até mesmo nas cores de suas escamas.\n'
                 '\n'
                 'O mais comum lembra um rosto de piranha, mas sabe-se de '
                 'alguns semelhantes a tubarões, ouriços ou mesmo polvos.\n'
                 '\n'
                 'Vivem úmidos e algumas espécies conseguem se mesclar em '
                 'cidades, quando bem encobertos por casacos e chapéus.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Muitas vezes atacam portos e cidades marítimas, atraindo o '
                 'combate para a água, onde podem agarrar o oponente e levá-lo '
                 'para o fundo o mar.\n'
                 '\n'
                 'Usam lanças ou arpões, e às vezes redes, para lutar e '
                 'capturar mais vítimas.\n'
                 '\n'
                 '  * **Aquática**: respiram embaixo d’água salgada e vivem a '
                 'maior parte do tempo submersos na mesma. Usam estas '
                 'vantagens para atacar e surpreender seus inimigos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em grupos de tamanho grande, mas apenas alguns poucos '
                 'se juntam para caçar.\n'
                 '\n'
                 'Atacam vilas e cidades com pouca defesa, ou mesmo '
                 'embarcações, que julguem terem o que precisam.\n'
                 '\n'
                 'Além de se alimentarem da caça, possuem grande desejo por '
                 'moedas de ouro e pérolas, usadas como adorno apenas entre os '
                 'melhores caçadores.\n'
                 '\n'
                 'Nem sempre capturam seus alvos para servirem de alimento: '
                 'existem casos em que os alvos são oferecidos como oferendas '
                 'a entidades antigas, cultuadas como deuses.',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '2d10 x 10',
  'flavor': 'Peixe humanoide com pele úmida e presas assustadoras. Articulam '
            'reviver seu deus antigo e esquecido no Plano Material.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 36},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['oceanos'],
  'id': 'criatura-abissal',
  'jp': '8',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': 9,
  'mvo': None,
  'mvv': None,
  'name': 'Criatura Abissal',
  'picture': 'https://public.olddragon.com.br/jyq38rjyw14k18m61vqk8vgu0341',
  'pv': '30',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/rgnsi7ucesikz0nrzgbml1456cx3',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/criatura-abissal.json',
  'variant': False,
  'xp': '270'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Olhos vermelhos e esbugalhados, pele marrom e oleosa, com três '
            'protuberâncias sobre a cabeça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 62}],
  'habitats': ['desertos'],
  'id': 'criatura-alienigena',
  'name': 'Criatura Alienígena',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/criatura-alienigena.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Mordida',
               'text': '1 × Mordida +3 (1d8)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1d8',
  'flavor': 'Estes ferozes répteis de couro extremamente rígido vivem em rios '
            'e pântanos dos climas mais quentes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 17},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['pantanos'],
  'id': 'crocodilo',
  'jp': '5',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': 9,
  'mvo': None,
  'mvv': None,
  'name': 'Crocodilo',
  'picture': None,
  'pv': '10',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/crocodilo.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Cabeçada',
               'text': '1 × Cabeçada +3 (2d6)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Esconderijo**: ao se sentir muito ameaçado, pode se '
                 'retrair para dentro de sua carapaça, aumentando em +2 sua '
                 'CA. Não pode atacar enquanto estiver escondido.\n'
                 '  * **Camuflagem**: enquanto está escondido, pode ser '
                 'facilmente confundido com uma rocha qualquer.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '+1',
  'encounters': '',
  'encounters_lair': '',
  'flavor': 'Um crustáceo com uma carapaça feita de pedra. Costuma viver em '
            'regiões montanhosas e pedregosas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 16}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'crustaceo-de-pedra',
  'jp': '7',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Crustáceo de Pedra',
  'picture': None,
  'pv': '16',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/crustaceo-de-pedra.json',
  'variant': False,
  'xp': '95'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4 + Paralisia',
               'description': 'Toque',
               'text': '1 × Toque +4 (2d4 + Paralisia)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'gosma',
  'description': 'Como o nome sugere, seu corpo tem uma forma cúbica, mas '
                 'também podem existir em formatos cilíndricos ou mesmo '
                 'triangulares, dependendo do espaço ocupado por eles.\n'
                 '\n'
                 'São translúcidos, com tons levemente esverdeados ou '
                 'amarelados, sem impedir a visão através de seus corpos.\n'
                 '\n'
                 '**Som**: leve borbulhar gosmento.\n'
                 '\n'
                 '**Odor**: levemente cítrico misturado com vinagre.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Pacientes, os cubos aguardam em cantos de masmorras ou '
                 'cavernas, muitas vezes atraindo presas com tesouros ou '
                 'objetos interessantes, que parecem flutuar (estando, na '
                 'verdade, dentro de seus corpos).\n'
                 '\n'
                 'Possuem controle sobre o que seja mantido dentro de seus '
                 'corpos, de forma que podem deixar os itens na altura do solo '
                 'ou teto, por exemplo, mas sempre alguns centímetros acima ou '
                 'abaixo pra evitar que sejam facilmente arrancados ou '
                 'expelidos do seu corpo.\n'
                 '\n'
                 'Silenciosos, esperam a aproximação do alvo para paralisá-los '
                 'e devorá-los.\n'
                 '\n'
                 '  * **Surpresa**: surpreende seus inimigos com um resultado '
                 'de 1-4 em 1d6.\n'
                 '\n'
                 '  * **Paralisia**: o alvo deve ser bem-sucedido em uma JPC '
                 'ou ficará paralisado por 2d4 turnos.\n'
                 '\n'
                 '  * **Imunidades**: imune aos efeitos do frio e da '
                 'eletricidade.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Não se sabe ao certo de onde vieram, mas parecem fazer parte '
                 'de um sistema interessante de “limpeza” de masmorras, '
                 'cavernas e outros lugares abandonados.\n'
                 '\n'
                 'Devoram suas presas lenta e silenciosamente, pois seus '
                 'alvos, uma vez dentro de seus corpos, não podem ser '
                 'escutados do lado de fora.\n'
                 '\n'
                 'Acredita-se que tenham uma inteligência primitiva e que, de '
                 'forma inconsciente, servem aos propósitos de entidades '
                 'obscuras e conhecidas apenas por estudiosos ou pessoas '
                 'insanas.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Se destilado, o corpo liquefeito dos Cubos Gelatinosos é '
                 'muito eficiente na criação de frascos de ácido.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '0',
  'flavor': 'Move-se sorrateiramente nos corredores das masmorras absorvendo e '
            'dissolvendo tudo o que consegue fagocitar.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 171},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 37},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday24.json',
              'page': 19},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'cubo-gelatinoso',
  'jp': '6',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cubo Gelatinoso',
  'picture': 'https://public.olddragon.com.br/y47huiugp54ill9880e5hp6ftf54',
  'pv': '20',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/361kfktm23ow4u3fc4zs09ma0sg6',
  'treasure': 'v',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cubo-gelatinoso.json',
  'variant': False,
  'xp': '150'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Porrete',
               'text': '1 × Porrete +1 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '11',
  'concept': 'humanoide',
  'description': 'Cultistas são sacerdotes os quais abraçaram deuses '
                 'específicos e ocultos, frequentemente ligados à morte ou a '
                 'conhecimentos obscuros de forças ocultas que todos '
                 'deveríamos ignorar. São inimigos sagazes e devem ser '
                 'respeitados pela sua tenacidade e fanatismo.\n'
                 '\n'
                 'Encontrados em grupos de 2d4 cultistas.\n'
                 '\n'
                 'Divindade: jogue 1d6 para determinar a divindade seguida '
                 'pelos cultistas: 1-3. Orcus, 4-5. Arak-Takna, 6. '
                 'Demogorgon.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: 1 a cada 4 cultistas são Cultistas '
                 'Adeptos. Além disso, há sempre um Cultista Sacerdote por '
                 'grupo.\n'
                 '\n'
                 '  * **Magias memorizadas**: Escuridão e Santuário. Podem '
                 'trocar estas magias por um Causar Ferimentos.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 81},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 184},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 8},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'cultista',
  'jp': '6',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cultista',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cultista.json',
  'variant': False,
  'xp': '25'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Maça',
               'text': '1 × Maça +2 (1d8+1)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': 'Cultistas são sacerdotes os quais abraçaram deuses '
                 'específicos e ocultos, frequentemente ligados à morte ou a '
                 'conhecimentos obscuros de forças ocultas que todos '
                 'deveríamos ignorar. São inimigos sagazes e devem ser '
                 'respeitados pela sua tenacidade e fanatismo.\n'
                 '\n'
                 'Encontrados em grupos de 2d4 cultistas.\n'
                 '\n'
                 'Divindade: jogue 1d6 para determinar a divindade seguida '
                 'pelos cultistas: 1-3. Orcus, 4-5. Arak-Takna, 6. '
                 'Demogorgon.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: 1 a cada 4 cultistas são Cultistas '
                 'Adeptos. Além disso, há sempre um Cultista Sacerdote por '
                 'grupo.\n'
                 '\n'
                 '  * **Magias memorizadas**: Escuridão e Santuário. Podem '
                 'trocar estas magias por um Causar Ferimentos.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 82},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 184},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 8},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'cultista-adepto',
  'jp': '7',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cultista Adepto',
  'parent_monster_url': 'https://olddragon.com.br/monstros/cultista.json',
  'picture': None,
  'pv': '15',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cultista-adepto.json',
  'variant': True,
  'variant_modifications': ['Magias memorizadas: Escuridão, Profanar e '
                            'Santuário. Podem trocar estas magias por um '
                            'Causar Ferimentos.'],
  'xp': '95'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Cultistas são sacerdotes os quais abraçaram deuses '
                 'específicos e ocultos, frequentemente ligados à morte ou a '
                 'conhecimentos obscuros de forças ocultas que todos '
                 'deveríamos ignorar. São inimigos sagazes e devem ser '
                 'respeitados pela sua tenacidade e fanatismo.\n'
                 '\n'
                 'Encontrados em grupos de 2d4 cultistas.\n'
                 '\n'
                 'Divindade: jogue 1d6 para determinar a divindade seguida '
                 'pelos cultistas: 1-3. Orcus, 4-5. Arak-Takna, 6. '
                 'Demogorgon.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: 1 a cada 4 cultistas são Cultistas '
                 'Adeptos. Além disso, há sempre um Cultista Sacerdote por '
                 'grupo.\n'
                 '\n'
                 '  * **Magias memorizadas**: Escuridão e Santuário. Podem '
                 'trocar estas magias por um Causar Ferimentos.\n'
                 '\n',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 82},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 184},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 8},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'cultista-sacerdote',
  'jp': '7',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Cultista Sacerdote',
  'parent_monster_url': 'https://olddragon.com.br/monstros/cultista.json',
  'picture': None,
  'pv': '30',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/cultista-sacerdote.json',
  'variant': True,
  'variant_modifications': ['Magias memorizadas: Escuridão, Convocar Insetos, '
                            'Imobilizar Pessoas, Proteção contra Alinhamento '
                            '(Ordem), Profanar e Santuário. Podem trocar estas '
                            'magias por um Causar Ferimentos.'],
  'xp': '305'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Mordidas',
               'text': '2 × Mordidas +3 (1d6)',
               'times': 2,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': '  * **Infravisão**: 18 metros.',
  'dv': '3',
  'dv_bonus': '1',
  'encounters': '4d4',
  'encounters_lair': '6d10',
  'flavor': 'Humanoides pequenos e covardes que armam armadilhas para '
            'surpreenderem seus adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 17}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'dartok',
  'jp': '5',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Dartok',
  'parent_monster_url': 'https://olddragon.com.br/monstros/kobold.json',
  'pv': '16',
  'size': 'pequeno',
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dartok.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '75'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Demônio com aparência que lembra a de um abutre deformado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 64}],
  'habitats': ['desertos'],
  'id': 'demonio-abutre',
  'name': 'Demônio Abutre',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/demonio-abutre.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'São almas antigas de criaturas que pereceram no grande deserto e, '
            'desencontrados da consciência de sua morte, vagam em busca água '
            'de modo violento e macabro',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 64}],
  'habitats': ['desertos'],
  'id': 'demonio-do-deserto',
  'name': 'Demônio do Deserto',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/demonio-do-deserto.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Os Demônios Elementais são os demônios mais comuns dos Seis '
            'Infernos do Limiar e os que mais frequentemente se tornam '
            'Possuídos, depois de atravessar as Chagas Vermelhas Temporárias '
            'que costumam surgir nos quatro cantos de Ryanon.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 22}],
  'habitats': ['extraplanar'],
  'id': 'demonio-elemental',
  'name': 'Demônio Elemental',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/demonio-elemental.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 7,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4 + Veneno',
               'description': 'Besta de mão',
               'text': '1 × Besta de mão +7 (1d4 + Veneno)',
               'times': 1,
               'weapon': False},
              {'ba': 5,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8 + Veneno',
               'description': 'Pique pequena',
               'text': '1 × Pique pequena +5 (1d8 + Veneno)',
               'times': 1,
               'weapon': False}],
  'ca': '15/17',
  'concept': 'humanoide',
  'description': 'Aproximadamente do tamanho de um anão, seus corpos são mais '
                 'frágeis, de pele azulada e olhos brancos sem emoção. '
                 'Aguerridos, constantemente usam armaduras e portam armas '
                 'envenenadas.\n'
                 '\n'
                 '**Som**: passos.\n'
                 '\n'
                 '**Odor**: odor corporal (suor) forte e ureia.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Acostumados a lutar em túneis e lugares pequenos, mantêm '
                 'formação de combate com os piques à frente, e besteiros '
                 'atirando de terrenos mais elevados. Gostam de emboscar e '
                 'atacar por todos os lados, fugindo assim que possível, '
                 'acertando e correndo.\n'
                 '\n'
                 '  * **Classe de armadura**: Derros possuem CA 15 ou 17 '
                 'quando usam armadura de couro.\n'
                 '\n'
                 '  * **Infravisão**: 30 metros\n'
                 '\n'
                 '  * **Veneno**: usado nas lâminas e nos dardos de suas '
                 'armas, o veneno causa 1d6 de dano adicional caso o alvo '
                 'falhe em uma JPC ou metade disso em caso de sucesso.\n'
                 '\n'
                 '  * **Furtivos**: Derros são mestres em esconder- se nas '
                 'sombras dos subterrâneos com 1-2 chances em 1d6.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Derro perde um ponto de vida a '
                 'cada hora exposto à luz do sol.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Navegadores de túneis escuros, os Derros vivem\n'
                 'em cavernas subterrâneas nas quais mantêm suas comunidades, '
                 'pouco desenvolvidas culturalmente.\n'
                 '\n'
                 'Muitos optam por servirem mestres mais poderosos (outros são '
                 'obrigados), como Crias Estelares ou os Drow. Conhecedores de '
                 'venenos, Derros têm plantações de cogumelos extremamente '
                 'perigosos, capazes de matar ao serem ingeridos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os líquidos dos globos oculares dos Derros são usados como '
                 'ingredientes de poções para enxergar no escuro.',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '3d10',
  'flavor': 'Insanos e incansáveis vivem nas profundezas do mundo destilando '
            'sua crueldade para destruir tudo o que os opõe.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 38},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'derro',
  'jp': '6',
  'mo': 9,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Derro',
  'picture': 'https://public.olddragon.com.br/1us4yh2z37q1zp4mxlipni2bps8u',
  'pv': '15',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/nmcm72k8bhaj12negw5tfzysqpli',
  'treasure': 'q',
  'treasure_lair': 'f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/derro.json',
  'variant': False,
  'xp': '95'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 5,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2 + Veneno',
               'description': 'Pique pequena',
               'text': '1 × Pique pequena +5 (1d8+2 + Veneno)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'humanoide',
  'description': 'Aproximadamente do tamanho de um anão, seus corpos são mais '
                 'frágeis, de pele azulada e olhos brancos sem emoção. '
                 'Aguerridos, constantemente usam armaduras e portam armas '
                 'envenenadas.\n'
                 '\n'
                 '**Som**: passos.\n'
                 '\n'
                 '**Odor**: odor corporal (suor) forte e ureia.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Acostumados a lutar em túneis e lugares pequenos, mantêm '
                 'formação de combate com os piques à frente, e besteiros '
                 'atirando de terrenos mais elevados. Gostam de emboscar e '
                 'atacar por todos os lados, fugindo assim que possível, '
                 'acertando e correndo.\n'
                 '\n'
                 '  * **Classe de armadura**: Derros possuem CA 15 ou 17 '
                 'quando usam armadura de couro.\n'
                 '\n'
                 '  * **Infravisão**: 30 metros\n'
                 '\n'
                 '  * **Veneno**: usado nas lâminas e nos dardos de suas '
                 'armas, o veneno causa 1d6 de dano adicional caso o alvo '
                 'falhe em uma JPC ou metade disso em caso de sucesso.\n'
                 '\n'
                 '  * **Furtivos**: Derros são mestres em esconder- se nas '
                 'sombras dos subterrâneos com 1-2 chances em 1d6.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Derro perde um ponto de vida a '
                 'cada hora exposto à luz do sol.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Navegadores de túneis escuros, os Derros vivem\n'
                 'em cavernas subterrâneas nas quais mantêm suas comunidades, '
                 'pouco desenvolvidas culturalmente.\n'
                 '\n'
                 'Muitos optam por servirem mestres mais poderosos (outros são '
                 'obrigados), como Crias Estelares ou os Drow. Conhecedores de '
                 'venenos, Derros têm plantações de cogumelos extremamente '
                 'perigosos, capazes de matar ao serem ingeridos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os líquidos dos globos oculares dos Derros são usados como '
                 'ingredientes de poções para enxergar no escuro.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '3d10',
  'flavor': 'Insanos e incansáveis vivem nas profundezas do mundo destilando '
            'sua crueldade para destruir tudo o que os opõe.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 38}],
  'habitats': ['subterraneos'],
  'id': 'derro-lider',
  'jp': '6',
  'mo': 10,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Derro Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/derro.json',
  'picture': 'https://public.olddragon.com.br/1us4yh2z37q1zp4mxlipni2bps8u',
  'pv': '20',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/nmcm72k8bhaj12negw5tfzysqpli',
  'treasure': 'q',
  'treasure_lair': 'f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/derro-lider.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '150'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Maça',
               'text': '1 × Maça +3 (1d8)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'humanoide',
  'description': 'Aproximadamente do tamanho de um anão, seus corpos são mais '
                 'frágeis, de pele azulada e olhos brancos sem emoção. '
                 'Aguerridos, constantemente usam armaduras e portam armas '
                 'envenenadas.\n'
                 '\n'
                 '**Som**: passos.\n'
                 '\n'
                 '**Odor**: odor corporal (suor) forte e ureia.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Acostumados a lutar em túneis e lugares pequenos, mantêm '
                 'formação de combate com os piques à frente, e besteiros '
                 'atirando de terrenos mais elevados. Gostam de emboscar e '
                 'atacar por todos os lados, fugindo assim que possível, '
                 'acertando e correndo.\n'
                 '\n'
                 '  * **Classe de armadura**: Derros possuem CA 15 ou 17 '
                 'quando usam armadura de couro.\n'
                 '\n'
                 '  * **Infravisão**: 30 metros\n'
                 '\n'
                 '  * **Veneno**: usado nas lâminas e nos dardos de suas '
                 'armas, o veneno causa 1d6 de dano adicional caso o alvo '
                 'falhe em uma JPC ou metade disso em caso de sucesso.\n'
                 '\n'
                 '  * **Furtivos**: Derros são mestres em esconder- se nas '
                 'sombras dos subterrâneos com 1-2 chances em 1d6.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Derro perde um ponto de vida a '
                 'cada hora exposto à luz do sol.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Navegadores de túneis escuros, os Derros vivem\n'
                 'em cavernas subterrâneas nas quais mantêm suas comunidades, '
                 'pouco desenvolvidas culturalmente.\n'
                 '\n'
                 'Muitos optam por servirem mestres mais poderosos (outros são '
                 'obrigados), como Crias Estelares ou os Drow. Conhecedores de '
                 'venenos, Derros têm plantações de cogumelos extremamente '
                 'perigosos, capazes de matar ao serem ingeridos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os líquidos dos globos oculares dos Derros são usados como '
                 'ingredientes de poções para enxergar no escuro.',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '3d10',
  'flavor': 'Insanos e incansáveis vivem nas profundezas do mundo destilando '
            'sua crueldade para destruir tudo o que os opõe.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 38}],
  'habitats': ['subterraneos'],
  'id': 'derro-xama',
  'jp': '6',
  'mo': 9,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Derro Xamã',
  'parent_monster_url': 'https://olddragon.com.br/monstros/derro.json',
  'picture': 'https://public.olddragon.com.br/1us4yh2z37q1zp4mxlipni2bps8u',
  'pv': '15',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/nmcm72k8bhaj12negw5tfzysqpli',
  'treasure': 'q',
  'treasure_lair': 'f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/derro-xama.json',
  'variant': True,
  'variant_modifications': ['Magia como Clérigo de 3º nível.'],
  'xp': '115'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 10,
               'damage': '2d10',
               'damage_bonus': 5,
               'damage_description': '2d10+5',
               'description': 'Socos',
               'text': '2 × Socos +10 (2d10+5)',
               'times': 2,
               'weapon': False},
              {'ba': 10,
               'damage': '3d8',
               'damage_bonus': 10,
               'damage_description': '3d8+10',
               'description': 'Cauda',
               'text': '1 × Cauda +10 (3d8+10)',
               'times': 1,
               'weapon': False}],
  'ca': '24',
  'concept': 'besta',
  'description': 'O Destruidor se assemelha a um lagarto bípede gigantesco, '
                 'coberto por escamas escuras e placas ósseas, indo de sua '
                 'nuca até a ponta de sua longa cauda que também possui duas '
                 'fileiras paralelas de espinhos ósseos assustadoramente '
                 'pontiagudos.\n'
                 '\n'
                 'Seu rugido parece uma mistura do som de vários animais '
                 'ferozes juntos e de tão alto pode ser ouvido por quilômetros '
                 'de distância.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'A criatura surge para lutar contra forças que desequilibrem '
                 'a vida no planeta.\n'
                 '\n'
                 'Ela lutará com todas as suas forças e ferocidade, mesmo que '
                 'isso envolva tirar vidas inocentes como dano colateral.\n'
                 '\n'
                 '  * **Soco Destruidor**: caso o ataque de qualquer um dos '
                 'socos resulte em um 20 natural, o alvo é desintegrado.\n'
                 '\n'
                 '  * **Raio Ocular**: seus olhos podem disparar 3 vezes ao '
                 'dia raios que causam 3d10 pontos de dano.\n'
                 '\n'
                 '  * **Baforada**: 1 vez ao dia, o Destruidor pode expelir '
                 'uma poderosa baforada de 10d10 x2 pontos de dano.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'O Destruidor vive dentro de um tipo de pedra preciosa, '
                 'semelhante a um diamante do tamanho de um punho.\n'
                 '\n'
                 'Desmaterializado, sua consciência está dividida em vários '
                 'planos de existência, despertando apenas quando os rituais '
                 'certos para a quebra do diamante são concluídos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Dizem os livros antigos que, ao derrotar a criatura, esta se '
                 'desfaz em fumaça e volta ao seu estado imaterial.\n'
                 '\n'
                 'Contudo, deixa um pó que, se ingerido, permite ao usuário '
                 'ter a visão de qualquer plano que se queira visitar.',
  'dv': '70',
  'dv_bonus': '+150',
  'encounters': '1',
  'encounters_lair': '',
  'flavor': 'Criatura colossal que dizem servir a grandes propósitos e causas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 39},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['planicies', 'colinas', 'montanhas'],
  'id': 'destruidor',
  'jp': '18',
  'mo': 12,
  'mv': 15,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Destruidor',
  'picture': 'https://public.olddragon.com.br/n4l8bzz4pm2gzqp1t17otc4vgmsq',
  'pv': '500',
  'size': 'colossal',
  'thumb_picture': 'https://public.olddragon.com.br/xl7akl7hfyemyu2c18uj9oob4mqv',
  'treasure': 'v',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/destruidor.json',
  'variant': False,
  'xp': '22475'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Pancada',
               'text': '1 × Pancada +2 (1d6+2)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'humanoide_monstruoso',
  'description': 'Estes seres lembram humanos magros e altos, de membros '
                 'longos e dedos em garra. Sua cabeça octópode possui '
                 'tentáculos os quais escondem uma boca cheia de dentes '
                 'pontiagudos.\n'
                 '\n'
                 'Costumam se vestir com mantos adornados com adereços e '
                 'padrões altamente geométricos.\n'
                 '\n'
                 '**Som**: passos.\n'
                 '\n'
                 '**Odor**: amônia misturado com cloro.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'A principal estratégia é atordoar a vítima para depois '
                 'devorar seu cérebro.\n'
                 '\n'
                 '  * **Rajada Mental**: o Devorador de Cérebros pode emitir '
                 'um pulso de caos mental afetando todas as vítimas em um cone '
                 'de 18 metros de distância. As vítimas que não forem '
                 'bem-sucedidas em uma JPS, cairão inconscientes por 1d6 '
                 'turnos.\n'
                 '\n'
                 '  * **Devorar Mentes**: o Devorador agarra uma de suas '
                 'vítimas confusas e, ao introduzir seus tentáculos nos '
                 'ouvidos da vítima, suga e devora os seus miolos. A vítima '
                 'morre imediatamente.\n'
                 '\n'
                 '  * **Magias**: podem lançar magias como um Clérigo de 3º '
                 'nível.\n'
                 '\n'
                 '  * **Resistência à magia**: qualquer magia lançada contra o '
                 'Devorador de Cérebro tem 1-5 chances em 1d6 de ser '
                 'completamente ignorada.\n'
                 '\n'
                 '  * **Infravisão**: 20 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Oriundos de muito além das estrelas, estas criaturas '
                 'chegaram muito antes das primeiras civilizações se formarem, '
                 'e adotaram os subterrâneos como seu lar.\n'
                 '\n'
                 'Seus poderes mentais são incríveis, assim como a perspicácia '
                 'e estratégia de combate.\n'
                 '\n'
                 'Líderes natos, comandam vilas subterrâneas e até mesmo '
                 'impérios abaixo da terra.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de troféus valorizados por nobres, o sangue dos '
                 'Devoradores é usado em rituais proferidos por cultistas que '
                 'montam cultos com seguidores apenas para abastecê-los com a '
                 'substância.',
  'dv': '8',
  'dv_bonus': '+4',
  'encounters': '1d4',
  'encounters_lair': '4d4',
  'flavor': 'Maligno e temido, alimenta-se do cérebro de qualquer ser. '
            'Escraviza inimigos que atrapalhem os seus planos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 40},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'devorador-de-cerebro',
  'jp': '11',
  'mo': 10,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Devorador de Cérebro',
  'picture': 'https://public.olddragon.com.br/353ivdaizbqyfqg421wjqawdrjun',
  'pv': '44',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/uiao0mncz6cq6w8o5lt75jhq85b9',
  'treasure': 't',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/devorador-de-cerebro.json',
  'variant': False,
  'xp': '785'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Líder Supremo de todos os Diabos Brancos do Deserto.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 62}],
  'habitats': ['desertos'],
  'id': 'diabo-branco-maior-lider',
  'name': 'Diabo Branco Maior (Líder)',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/diabo-branco-maior-lider.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Apesar deste Diabo ser apenas um soldado errante de sua espécie, '
            'ele é maior e mais poderoso do que seus parentes menores. Possui '
            'as mesmas características de seus parentes soldados menores, '
            'porém com quase o dobro do tamanho, podendo chegar até a 4m de '
            'altura.  Seu lema é matar e levar para dentro da toca.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 62}],
  'habitats': ['desertos'],
  'id': 'diabo-branco-maior-soldado',
  'name': 'Diabo Branco Maior (Soldado)',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/diabo-branco-maior-soldado.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Possui escamas brancas, chifres longos, olhos grandes e '
            'vermelhos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 63}],
  'habitats': ['desertos'],
  'id': 'diabo-branco-menor-lider',
  'name': 'Diabo Branco Menor (Líder)',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/diabo-branco-menor-lider.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'É forte e perigoso, podendo decepar suas vítimas com suas garras '
            'enormes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 63}],
  'habitats': ['desertos'],
  'id': 'diabo-branco-menor-soldado',
  'name': 'Diabo Branco Menor (Soldado)',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/diabo-branco-menor-soldado.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6 + Veneno',
               'description': 'Ferrão',
               'text': '1 × Ferrão +4 (1d6 + Veneno)',
               'times': 1,
               'weapon': False}],
  'ca': '19',
  'concept': 'humanoide_monstruoso',
  'description': 'Aparentando pequenos gárgulas de pele lisa e úmida, os '
                 'Diabretes variam muito em cor.\n'
                 '\n'
                 'Quando assumem a forma de um animal ou criança, possuem uma '
                 'marca especial como uma tatuagem que os identifica, sempre '
                 'no meio das costas , mantida sempre coberta para evitar que '
                 'seu disfarce seja descoberto.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam sua habilidade de se transformar para enganar os '
                 'inimigos, atacando-os quando acharem mais oportuno.\n'
                 '\n'
                 'Grupos de Diabretes voam de forma desordenada, causando '
                 'muita confusão entre os grupos inimigos que os enfrentam .\n'
                 '\n'
                 '  * **Proteção à Magia**: 1-2 chances em 1d6 de anular '
                 'qualquer efeito mágico.\n'
                 '\n'
                 '  * **Veneno**: o veneno oriundo do ferrão de um Diabrete '
                 'causa 1d6 de dano adicional caso o alvo falhe em uma JPC ou '
                 'metade disso em caso de sucesso.\n'
                 '\n'
                 '  * **Alterar Forma**: um Diabrete pode alterar sua própria '
                 'forma assumindo a de qualquer criatura viva de tamanho '
                 'semelhante (como um porco, cachorro, ou até uma criança '
                 'pequena).\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Diabretes assumem naturalmente a posição de lacaios, de '
                 'servos e asseclas.\n'
                 '\n'
                 'Acostumados a serem conjurados, não são raros os casos em '
                 'que um Diabrete trai seu mestre por este não prestar total '
                 'atenção aos contratos assinados com estas criaturas.\n'
                 '\n'
                 'Vivem de forma caótica, sem se importar com o dia seguinte, '
                 'preocupando-se apenas com seus prazeres momentâneos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Muito valorizados por taxidermistas os quais chegam a vender '
                 'estas criaturas para colecionadores por centenas de peças de '
                 'ouro.',
  'dv': '2',
  'dv_bonus': '+2',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Pequenos lacaios das forças dos planos inferiores usados para '
            'funções de espionagem, pequenas trapaças e sabotagens.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 41},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['extraplanar'],
  'id': 'diabrete',
  'jp': '6',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 18,
  'name': 'Diabrete',
  'picture': 'https://public.olddragon.com.br/lv456vgdbmgo95viogfhq6j6xd2q',
  'pv': '12',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/vg1s594794p7vderfh9syihobpvo',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/diabrete.json',
  'variant': False,
  'xp': '65'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Mordida',
               'text': '1 × Mordida +4 (2d6)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide_monstruoso',
  'description': 'Doppleganger parece um humano de estatura média, acinzentado '
                 'e enrugado, com braços longos e sem pelo algum em todo o '
                 'corpo.\n'
                 '\n'
                 'Seu rosto é ienxpressivo e sua boca uma linha quase '
                 'imperceptível com total ausência de lábios.\n'
                 '\n'
                 'Não costuma andar na sua forma natural, preferindo '
                 'experimentar a pluralidade de formas dos seres humanos e '
                 'demais humanoide.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Em sua forma natural, possuem uma mandíbula capaz de se '
                 'distender, como a de uma cobra, cortando o oponente com seus '
                 'dentes afiados e pontiagudos.\n'
                 '\n'
                 'Contudo, preferem sempre usar seu poder de mudar de '
                 'aparência para confundir e enganar as vítimas, atacando-as '
                 'de forma traiçoeiramente precisa.\n'
                 '\n'
                 '  * **Roubar Forma**: pode assumir a forma de qualquer '
                 'criatura humanoide (P ou M). Um Doppelganger voltará a sua '
                 'forma normal caso seja morto.\n'
                 '\n'
                 '  * **Surpresa**: uma vez que esteja escondido na forma '
                 'roubada de uma vítima, atacará seu alvo surpreendendo em 1-5 '
                 'em 1d6.\n'
                 '\n'
                 '  * **Imunidade**: efeitos de encantamentos ou de uma magia '
                 'Sono.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'A mente de um doppleganger é um verdadeiro caos, uma '
                 'amálgama de suas lembranças de todas as formas que já '
                 'tiveram.\n'
                 '\n'
                 'Não se sabe muito sobre estas criaturas, apenas que são '
                 'assexuados e que seus filhos nascem por um tipo bizarro de '
                 'brotamento, de forma que o filhote faz parte do corpo do seu '
                 'genitor durante a transformação.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'O sangue do Doppelganger é um ingrediente básico e '
                 'necessário em itens mágicos de alteração de forma corporal.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '1d6',
  'flavor': 'Humanoide inteligente capaz de assumir a forma de qualquer '
            'criatura encontrada por ele.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 43},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['extraplanar'],
  'id': 'doppelganger',
  'jp': '7',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Doppelganger',
  'picture': 'https://public.olddragon.com.br/aywhg74ku72iuem5ec5q47f8kelq',
  'pv': '20',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/i6iikqtj815cixmue6vq409l2o3a',
  'treasure': 'v',
  'treasure_lair': 'e',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/doppelganger.json',
  'variant': False,
  'xp': '175'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 9,
               'damage': '3d10',
               'damage_bonus': None,
               'damage_description': '3d10',
               'description': 'Mordida',
               'text': '1 × Mordida +9 (3d10)',
               'times': 1,
               'weapon': False},
              {'ba': 10,
               'damage': '1d6',
               'damage_bonus': 5,
               'damage_description': '1d6+5',
               'description': 'Garras',
               'text': '2 × Garras +10 (1d6+5)',
               'times': 2,
               'weapon': False}],
  'ca': '20',
  'concept': 'dragao',
  'description': 'Apesar de ferozes quando necessário, os Dragões Azuis têm um '
                 'semblante mais sereno, como se estivessem analisando tudo e '
                 'a todos. O tom do azul indica a idade, sendo os tons mais '
                 'escuros uma marca dos mais antigos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Mesmo que não tenham afinidade mágica maior do que seus '
                 'irmãos de outras cores, os Dragões Azuis são mais eruditos, '
                 'usando magias com mais cautela e preparo, muitas vezes '
                 'preparando armadilhas e criando proteções antes de um '
                 'combate. Atacam Magos em primeiro lugar, ou aqueles que '
                 'julguem mais capazes de lidar com energias arcanas.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Azul pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de raios elétricos em uma linha de até 30 metros. O dano de '
                 'uma baforada é igual ao número de seus dados de vida em d8, '
                 'ou seja, um Dragão Azul causa 9d8 de dano em todos na área '
                 'de efeito da baforada. Um teste de JPD pode reduzir o dano '
                 'pela metade.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão Azul é imune a qualquer efeito '
                 'de eletricidade.\n'
                 '\n'
                 '  * **Magias**: um Dragão Azul pode conjurar magias como se '
                 'fosse um Mago de 7º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'A morada favorita dos Dragões Azuis é abaixo das areias, em '
                 'grandes desertos nos quais constroem cavernas gigantescas. '
                 'Mantêm vermes colossais próximos de sua toca, como se fossem '
                 'cães de guarda. Eruditos, guardam tomos sinistros os quais '
                 'apenas os estudiosos mais loucos ousam ler.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico. \n'
                 '\n'
                 'Especificamente do Dragão Azul, seu sangue pode ser usado '
                 'para confeccionar itens mágicos ligados à eletricidade.',
  'dv': '9',
  'dv_bonus': '+9',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis, '
            'inteligentemente escondidos nas planícies e nos desertos. '
            'Organizam emboscadas a viajantes e admiram seus tesouros '
            'acumulados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 46},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['planicies', 'desertos'],
  'id': 'dragao-azul',
  'jp': '12',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Dragão Azul',
  'picture': 'https://public.olddragon.com.br/j9hi28i6r05blgkwia0qjb35vnvt',
  'pv': '54',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/sqqej3oa48n7a1nwezfdbvrapguj',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-azul.json',
  'variant': False,
  'xp': '1075'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '2d10',
               'damage_bonus': None,
               'damage_description': '2d10',
               'description': 'Mordida',
               'text': '1 × Mordida +4 (2d10)',
               'times': 1,
               'weapon': False},
              {'ba': 5,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Garras',
               'text': '2 × Garras +5 (1d6+2)',
               'times': 2,
               'weapon': False}],
  'ca': '17',
  'concept': 'dragao',
  'description': 'Apesar de ferozes quando necessário, os Dragões Azuis têm um '
                 'semblante mais sereno, como se estivessem analisando tudo e '
                 'a todos. O tom do azul indica a idade, sendo os tons mais '
                 'escuros uma marca dos mais antigos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Mesmo que não tenham afinidade mágica maior do que seus '
                 'irmãos de outras cores, os Dragões Azuis são mais eruditos, '
                 'usando magias com mais cautela e preparo, muitas vezes '
                 'preparando armadilhas e criando proteções antes de um '
                 'combate. Atacam Magos em primeiro lugar, ou aqueles que '
                 'julguem mais capazes de lidar com energias arcanas.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Azul pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de raios elétricos em uma linha de até 30 metros. O dano de '
                 'uma baforada é igual ao número de seus dados de vida em d8, '
                 'ou seja, um Dragão Azul causa 9d8 de dano em todos na área '
                 'de efeito da baforada. Um teste de JPD pode reduzir o dano '
                 'pela metade.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão Azul é imune a qualquer efeito '
                 'de eletricidade.\n'
                 '\n'
                 '  * **Magias**: um Dragão Azul pode conjurar magias como se '
                 'fosse um Mago de 7º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'A morada favorita dos Dragões Azuis é abaixo das areias, em '
                 'grandes desertos nos quais constroem cavernas gigantescas. '
                 'Mantêm vermes colossais próximos de sua toca, como se fossem '
                 'cães de guarda. Eruditos, guardam tomos sinistros os quais '
                 'apenas os estudiosos mais loucos ousam ler.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico. \n'
                 '\n'
                 'Especificamente do Dragão Azul, seu sangue pode ser usado '
                 'para confeccionar itens mágicos ligados à eletricidade.',
  'dv': '4',
  'dv_bonus': '+9',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis, '
            'inteligentemente escondidos nas planícies e nos desertos. '
            'Organizam emboscadas a viajantes e admiram seus tesouros '
            'acumulados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 46}],
  'habitats': ['planicies', 'desertos'],
  'id': 'dragao-azul-jovem',
  'jp': '6',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Dragão Azul Jovem',
  'parent_monster_url': 'https://olddragon.com.br/monstros/dragao-azul.json',
  'picture': 'https://public.olddragon.com.br/j9hi28i6r05blgkwia0qjb35vnvt',
  'pv': '29',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/sqqej3oa48n7a1nwezfdbvrapguj',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-azul-jovem.json',
  'variant': True,
  'variant_modifications': ['Baforada: 4d8 de dano.',
                            'Magia como mago de 4° nível.'],
  'xp': '200'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 12,
               'damage': '1d6',
               'damage_bonus': 8,
               'damage_description': '1d6+8',
               'description': 'Garras',
               'text': '2 × Garras +12 (1d6+8)',
               'times': 2,
               'weapon': False},
              {'ba': 10,
               'damage': '4d10',
               'damage_bonus': None,
               'damage_description': '4d10',
               'description': 'Mordida',
               'text': '1 × Mordida +10 (4d10)',
               'times': 1,
               'weapon': False},
              {'ba': None,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Especial',
               'description': 'Varrer com a cauda',
               'text': '1 × Varrer com a cauda (Especial)',
               'times': 1,
               'weapon': False}],
  'ca': '20',
  'concept': 'dragao',
  'description': 'Apesar de ferozes quando necessário, os Dragões Azuis têm um '
                 'semblante mais sereno, como se estivessem analisando tudo e '
                 'a todos. O tom do azul indica a idade, sendo os tons mais '
                 'escuros uma marca dos mais antigos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Mesmo que não tenham afinidade mágica maior do que seus '
                 'irmãos de outras cores, os Dragões Azuis são mais eruditos, '
                 'usando magias com mais cautela e preparo, muitas vezes '
                 'preparando armadilhas e criando proteções antes de um '
                 'combate. Atacam Magos em primeiro lugar, ou aqueles que '
                 'julguem mais capazes de lidar com energias arcanas.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Azul pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de raios elétricos em uma linha de até 30 metros. O dano de '
                 'uma baforada é igual ao número de seus dados de vida em d8, '
                 'ou seja, um Dragão Azul causa 9d8 de dano em todos na área '
                 'de efeito da baforada. Um teste de JPD pode reduzir o dano '
                 'pela metade.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão Azul é imune a qualquer efeito '
                 'de eletricidade.\n'
                 '\n'
                 '  * **Magias**: um Dragão Azul pode conjurar magias como se '
                 'fosse um Mago de 7º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'A morada favorita dos Dragões Azuis é abaixo das areias, em '
                 'grandes desertos nos quais constroem cavernas gigantescas. '
                 'Mantêm vermes colossais próximos de sua toca, como se fossem '
                 'cães de guarda. Eruditos, guardam tomos sinistros os quais '
                 'apenas os estudiosos mais loucos ousam ler.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico. \n'
                 '\n'
                 'Especificamente do Dragão Azul, seu sangue pode ser usado '
                 'para confeccionar itens mágicos ligados à eletricidade.',
  'dv': '13',
  'dv_bonus': '+9',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis, '
            'inteligentemente escondidos nas planícies e nos desertos. '
            'Organizam emboscadas a viajantes e admiram seus tesouros '
            'acumulados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 46}],
  'habitats': ['planicies', 'desertos'],
  'id': 'dragao-azul-velho',
  'jp': '13',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Dragão Azul Velho',
  'parent_monster_url': 'https://olddragon.com.br/monstros/dragao-azul.json',
  'picture': 'https://public.olddragon.com.br/j9hi28i6r05blgkwia0qjb35vnvt',
  'pv': '74',
  'size': 'colossal',
  'thumb_picture': 'https://public.olddragon.com.br/sqqej3oa48n7a1nwezfdbvrapguj',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-azul-velho.json',
  'variant': True,
  'variant_modifications': ['Baforada: 13d8 de dano.',
                            'Magia como mago de 9° nível.'],
  'xp': '2525'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 6,
               'damage': '1d4',
               'damage_bonus': 3,
               'damage_description': '1d4+3',
               'description': 'Garras',
               'text': '2 × Garras +6 (1d4+3)',
               'times': 2,
               'weapon': False},
              {'ba': 5,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Mordida',
               'text': '1 × Mordida +5 (2d8)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'dragao',
  'description': 'Um pouco mais bestiais que seus parentes, os Dragões Brancos '
                 'se portam como grandes feras primitivas. Cristais de gelo '
                 'ficam pendurados em suas asas e focinho, de forma que, '
                 'quando parados, podem ser confundidos com um acidente '
                 'natural. Os mais velhos vão ficando semelhantes a cristais, '
                 'levemente translúcidos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Selvagens, atacam com baforadas ao encontrarem o alvo. Não '
                 'costumam usar muitas magias, mas fazem de modo instintivo e, '
                 'geralmente, visando a ofensiva.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Branco pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de gelo e frio extremo com a forma de cone com 9 metros de '
                 'largura e 20 metros de distância. O dano de uma baforada é '
                 'igual ao número de seus dados de vida em d6, ou seja, um '
                 'Dragão Branco causa 6d6 de dano em todos na área de efeito '
                 'da baforada. Um teste de JPD pode reduzir o dano pela '
                 'metade.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão Branco é imune a qualquer '
                 'efeito do frio.\n'
                 '\n'
                 '  * **Magias**: um Dragão Branco pode conjurar magias como '
                 'se fosse um Mago de 5º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivendo em geleiras e cavernas na superfície, evitam fazer '
                 'sua morada no subterrâneo onde é comum desmoronamentos. '
                 'Colocam seus ovos em grandes esquifes de gelo, de forma que '
                 'apenas os filhotes mais fortes conseguem sair.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico.\n'
                 '\n'
                 'Especificamente do Dragão Branco, seu sangue pode ser usado '
                 'para confeccionar itens mágicos ligados ao frio.',
  'dv': '6',
  'dv_bonus': '+6',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis '
            'escondidos em geleiras e planícies geladas. Organizam emboscadas '
            'a viajantes e admiram seus tesouros acumulados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 48},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['geleiras', 'planicies'],
  'id': 'dragao-branco',
  'jp': '9',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Dragão Branco',
  'picture': 'https://public.olddragon.com.br/6n5iu06tcz86umfndqqd09qmi8ik',
  'pv': '36',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/f7c7wj0quc2hbvyzkozb85ytdxuc',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-branco.json',
  'variant': False,
  'xp': '375'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '1d4',
               'damage_bonus': 2,
               'damage_description': '1d4+2',
               'description': 'Garras',
               'text': '2 × Garras +4 (1d4+2)',
               'times': 2,
               'weapon': False},
              {'ba': 4,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Mordida',
               'text': '1 × Mordida +4 (1d8)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'dragao',
  'description': 'Um pouco mais bestiais que seus parentes, os Dragões Brancos '
                 'se portam como grandes feras primitivas. Cristais de gelo '
                 'ficam pendurados em suas asas e focinho, de forma que, '
                 'quando parados, podem ser confundidos com um acidente '
                 'natural. Os mais velhos vão ficando semelhantes a cristais, '
                 'levemente translúcidos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Selvagens, atacam com baforadas ao encontrarem o alvo. Não '
                 'costumam usar muitas magias, mas fazem de modo instintivo e, '
                 'geralmente, visando a ofensiva.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Branco pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de gelo e frio extremo com a forma de cone com 9 metros de '
                 'largura e 20 metros de distância. O dano de uma baforada é '
                 'igual ao número de seus dados de vida em d6, ou seja, um '
                 'Dragão Branco causa 6d6 de dano em todos na área de efeito '
                 'da baforada. Um teste de JPD pode reduzir o dano pela '
                 'metade.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão Branco é imune a qualquer '
                 'efeito do frio.\n'
                 '\n'
                 '  * **Magias**: um Dragão Branco pode conjurar magias como '
                 'se fosse um Mago de 5º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivendo em geleiras e cavernas na superfície, evitam fazer '
                 'sua morada no subterrâneo onde é comum desmoronamentos. '
                 'Colocam seus ovos em grandes esquifes de gelo, de forma que '
                 'apenas os filhotes mais fortes conseguem sair.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico.\n'
                 '\n'
                 'Especificamente do Dragão Branco, seu sangue pode ser usado '
                 'para confeccionar itens mágicos ligados ao frio.',
  'dv': '3',
  'dv_bonus': '+6',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis '
            'escondidos em geleiras e planícies geladas. Organizam emboscadas '
            'a viajantes e admiram seus tesouros acumulados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 48}],
  'habitats': ['geleiras', 'planicies'],
  'id': 'dragao-branco-jovem',
  'jp': '6',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Dragão Branco Jovem',
  'parent_monster_url': 'https://olddragon.com.br/monstros/dragao-branco.json',
  'picture': 'https://public.olddragon.com.br/6n5iu06tcz86umfndqqd09qmi8ik',
  'pv': '21',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/f7c7wj0quc2hbvyzkozb85ytdxuc',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-branco-jovem.json',
  'variant': True,
  'variant_modifications': ['Baforada: 3d6 de dano.',
                            'Magia como mago de 4° nível.'],
  'xp': '135'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': None,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Especial',
               'description': 'Varrer com a cauda',
               'text': '1 × Varrer com a cauda (Especial)',
               'times': 1,
               'weapon': False},
              {'ba': 11,
               'damage': '1d4',
               'damage_bonus': 6,
               'damage_description': '1d4+6',
               'description': 'Garras',
               'text': '2 × Garras +11 (1d4+6)',
               'times': 2,
               'weapon': False},
              {'ba': 11,
               'damage': '3d8',
               'damage_bonus': None,
               'damage_description': '3d8',
               'description': 'Mordida',
               'text': '1 × Mordida +11 (3d8)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'dragao',
  'description': 'Um pouco mais bestiais que seus parentes, os Dragões Brancos '
                 'se portam como grandes feras primitivas. Cristais de gelo '
                 'ficam pendurados em suas asas e focinho, de forma que, '
                 'quando parados, podem ser confundidos com um acidente '
                 'natural. Os mais velhos vão ficando semelhantes a cristais, '
                 'levemente translúcidos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Selvagens, atacam com baforadas ao encontrarem o alvo. Não '
                 'costumam usar muitas magias, mas fazem de modo instintivo e, '
                 'geralmente, visando a ofensiva.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Branco pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de gelo e frio extremo com a forma de cone com 9 metros de '
                 'largura e 20 metros de distância. O dano de uma baforada é '
                 'igual ao número de seus dados de vida em d6, ou seja, um '
                 'Dragão Branco causa 6d6 de dano em todos na área de efeito '
                 'da baforada. Um teste de JPD pode reduzir o dano pela '
                 'metade.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão Branco é imune a qualquer '
                 'efeito do frio.\n'
                 '\n'
                 '  * **Magias**: um Dragão Branco pode conjurar magias como '
                 'se fosse um Mago de 5º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivendo em geleiras e cavernas na superfície, evitam fazer '
                 'sua morada no subterrâneo onde é comum desmoronamentos. '
                 'Colocam seus ovos em grandes esquifes de gelo, de forma que '
                 'apenas os filhotes mais fortes conseguem sair.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico.\n'
                 '\n'
                 'Especificamente do Dragão Branco, seu sangue pode ser usado '
                 'para confeccionar itens mágicos ligados ao frio.',
  'dv': '9',
  'dv_bonus': '+6',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis '
            'escondidos em geleiras e planícies geladas. Organizam emboscadas '
            'a viajantes e admiram seus tesouros acumulados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 48}],
  'habitats': ['geleiras', 'planicies'],
  'id': 'dragao-branco-velho',
  'jp': '11',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Dragão Branco Velho',
  'parent_monster_url': 'https://olddragon.com.br/monstros/dragao-branco.json',
  'picture': 'https://public.olddragon.com.br/6n5iu06tcz86umfndqqd09qmi8ik',
  'pv': '51',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/f7c7wj0quc2hbvyzkozb85ytdxuc',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-branco-velho.json',
  'variant': True,
  'variant_modifications': ['Baforada: 9d6 de dano.',
                            'Magia como mago de 7° nível.'],
  'xp': '1075'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'dragao',
  'flavor': 'Dragões selvagens, descendentes dos três Dragões Protetores: '
            'Ivenbarkos, o Dragão de Ouro Protetor da Igreja Patriarca; '
            'Farkisis, o Dragão de Esmeralda Protetor da Igreja Valedora; e '
            'Vortérius, o Dragão de Rubi Protetor da Igreja Vindita.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 27}],
  'habitats': ['montanhas'],
  'id': 'dragao-das-gemas-adulto',
  'name': 'Dragão das Gemas Adulto',
  'size': 'imenso',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-das-gemas-adulto.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'dragao',
  'flavor': 'Dragões selvagens, descendentes dos três Dragões Protetores: '
            'Ivenbarkos, o Dragão de Ouro Protetor da Igreja Patriarca; '
            'Farkisis, o Dragão de Esmeralda Protetor da Igreja Valedora; e '
            'Vortérius, o Dragão de Rubi Protetor da Igreja Vindita.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 26}],
  'habitats': ['montanhas'],
  'id': 'dragao-das-gemas-jovem',
  'name': 'Dragão das Gemas Jovem',
  'size': 'imenso',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-das-gemas-jovem.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 8,
               'damage': '1d8',
               'damage_bonus': 6,
               'damage_description': '1d8+6',
               'description': 'Garras',
               'text': '2 × Garras +8 (1d8+6)',
               'times': 2,
               'weapon': False},
              {'ba': 7,
               'damage': '3d8',
               'damage_bonus': None,
               'damage_description': '3d8',
               'description': 'Mordida',
               'text': '1 × Mordida +7 (3d8)',
               'times': 1,
               'weapon': False}],
  'ca': '20',
  'concept': 'dragao',
  'description': 'Diferentes dos Dragões Negros, os Dragões das Sombras não '
                 'são apenas pretos. Eles parecem ser feitos de fumaça escura, '
                 'ou de algo que mora no fundo de um poço profundo.  Ao '
                 'observar suas escamas, elas parecem até mesmo líquidas, como '
                 'se vivessem em movimento constante.  Os mais antigos perdem '
                 'o aspecto esfumaçado, assemelhando-se mais a uma noite sem '
                 'luar.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Traiçoeiros, evitam o combate quando podem, preferindo criar '
                 'armadilhas e instigar aliados e subalternos a lutarem.\n'
                 '\n'
                 '  * **Baforada**: o Dragão das Sombras pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de escuridão em forma de nuvem com 12 metros de largura, 15 '
                 'metros de distância e 6 metros de altura. As criaturas em '
                 'contato com esta nuvem ficarão cegas por 1d6 rodadas e '
                 'perderão metade de seus pontos vida.  Ou seja, um personagem '
                 'com 30 pontos de vida atingido pela nuvem de escuridão '
                 'perderá 15 pontos de vida pelo efeito da baforada. Um teste '
                 'de JPD pode reduzir o dano pela metade.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão das Sombras é imune a qualquer '
                 'efeito que envolva sombras e escuridão.\n'
                 '\n'
                 '  * **Magias**: um Dragão das Sombras pode conjurar magias '
                 'como se fosse um Mago de 6º nível.\n'
                 '\n'
                 '  * **Infravisão**: 30 metros\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Adaptados aos mais diversos ambientes, vivem na escuridão, '
                 'preferencialmente nos subterrâneos.  Controlam mortos-vivos '
                 'por meio de necromancia e vivem assim, entre mortos e vivos '
                 'de forma indiferente. Seus filhotes nascem de ovos feitos de '
                 'sombra e fumaça, e após o nascimento, devoram corpos '
                 'previamente colocados por perto para se tornarem materiais.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico.\n'
                 '\n'
                 'Especificamente do Dragão das Sombras, seu sangue pode ser '
                 'usado para confeccionar itens mágicos ligados à escuridão.',
  'dv': '8',
  'dv_bonus': '+8',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis '
            'escondidos de qualquer fonte de luz. Saem apenas para os '
            'subterrâneos ou durante a noite para organizar emboscadas a '
            'viajantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 50},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'dragao-das-sombras',
  'jp': '11',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Dragão das Sombras',
  'picture': 'https://public.olddragon.com.br/gsg9rubh82nbzx3t5bjxd5ela1q4',
  'pv': '48',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/wk72w6lvrsdgnbxu9jqu47vezecu',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-das-sombras.json',
  'variant': False,
  'xp': '785'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Mordida',
               'text': '1 × Mordida +3 (2d8)',
               'times': 1,
               'weapon': False},
              {'ba': 4,
               'damage': '1d8',
               'damage_bonus': 3,
               'damage_description': '1d8+3',
               'description': 'Garras',
               'text': '2 × Garras +4 (1d8+3)',
               'times': 2,
               'weapon': False}],
  'ca': '17',
  'concept': 'dragao',
  'description': 'Diferentes dos Dragões Negros, os Dragões das Sombras não '
                 'são apenas pretos. Eles parecem ser feitos de fumaça escura, '
                 'ou de algo que mora no fundo de um poço profundo.  Ao '
                 'observar suas escamas, elas parecem até mesmo líquidas, como '
                 'se vivessem em movimento constante.  Os mais antigos perdem '
                 'o aspecto esfumaçado, assemelhando-se mais a uma noite sem '
                 'luar.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Traiçoeiros, evitam o combate quando podem, preferindo criar '
                 'armadilhas e instigar aliados e subalternos a lutarem.\n'
                 '\n'
                 '  * **Baforada**: o Dragão das Sombras pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de escuridão em forma de nuvem com 12 metros de largura, 15 '
                 'metros de distância e 6 metros de altura. As criaturas em '
                 'contato com esta nuvem ficarão cegas por 1d6 rodadas e '
                 'perderão metade de seus pontos vida.  Ou seja, um personagem '
                 'com 30 pontos de vida atingido pela nuvem de escuridão '
                 'perderá 15 pontos de vida pelo efeito da baforada. Um teste '
                 'de JPD pode reduzir o dano pela metade.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão das Sombras é imune a qualquer '
                 'efeito que envolva sombras e escuridão.\n'
                 '\n'
                 '  * **Magias**: um Dragão das Sombras pode conjurar magias '
                 'como se fosse um Mago de 6º nível.\n'
                 '\n'
                 '  * **Infravisão**: 30 metros\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Adaptados aos mais diversos ambientes, vivem na escuridão, '
                 'preferencialmente nos subterrâneos.  Controlam mortos-vivos '
                 'por meio de necromancia e vivem assim, entre mortos e vivos '
                 'de forma indiferente. Seus filhotes nascem de ovos feitos de '
                 'sombra e fumaça, e após o nascimento, devoram corpos '
                 'previamente colocados por perto para se tornarem materiais.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico.\n'
                 '\n'
                 'Especificamente do Dragão das Sombras, seu sangue pode ser '
                 'usado para confeccionar itens mágicos ligados à escuridão.',
  'dv': '4',
  'dv_bonus': '+8',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis '
            'escondidos de qualquer fonte de luz. Saem apenas para os '
            'subterrâneos ou durante a noite para organizar emboscadas a '
            'viajantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 50}],
  'habitats': ['qualquer'],
  'id': 'dragao-das-sombras-jovem',
  'jp': '6',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Dragão das Sombras Jovem',
  'parent_monster_url': 'https://olddragon.com.br/monstros/dragao-das-sombras.json',
  'picture': 'https://public.olddragon.com.br/gsg9rubh82nbzx3t5bjxd5ela1q4',
  'pv': '28',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/wk72w6lvrsdgnbxu9jqu47vezecu',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-das-sombras-jovem.json',
  'variant': True,
  'variant_modifications': ['Baforada: Cega por 1d4 rodadas e causa a perda de '
                            '¼ dos pontos de vida atuais.',
                            'Magia como mago de 4° nível.'],
  'xp': '200'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 12,
               'damage': '1d8',
               'damage_bonus': 9,
               'damage_description': '1d8+9',
               'description': 'Garras',
               'text': '2 × Garras +12 (1d8+9)',
               'times': 2,
               'weapon': False},
              {'ba': None,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Especial',
               'description': 'Varrer com a cauda',
               'text': '1 × Varrer com a cauda (Especial)',
               'times': 1,
               'weapon': False},
              {'ba': 11,
               'damage': '4d8',
               'damage_bonus': None,
               'damage_description': '4d8',
               'description': 'Mordida',
               'text': '1 × Mordida +11 (4d8)',
               'times': 1,
               'weapon': False}],
  'ca': '20',
  'concept': 'dragao',
  'description': 'Diferentes dos Dragões Negros, os Dragões das Sombras não '
                 'são apenas pretos. Eles parecem ser feitos de fumaça escura, '
                 'ou de algo que mora no fundo de um poço profundo.  Ao '
                 'observar suas escamas, elas parecem até mesmo líquidas, como '
                 'se vivessem em movimento constante.  Os mais antigos perdem '
                 'o aspecto esfumaçado, assemelhando-se mais a uma noite sem '
                 'luar.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Traiçoeiros, evitam o combate quando podem, preferindo criar '
                 'armadilhas e instigar aliados e subalternos a lutarem.\n'
                 '\n'
                 '  * **Baforada**: o Dragão das Sombras pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de escuridão em forma de nuvem com 12 metros de largura, 15 '
                 'metros de distância e 6 metros de altura. As criaturas em '
                 'contato com esta nuvem ficarão cegas por 1d6 rodadas e '
                 'perderão metade de seus pontos vida.  Ou seja, um personagem '
                 'com 30 pontos de vida atingido pela nuvem de escuridão '
                 'perderá 15 pontos de vida pelo efeito da baforada. Um teste '
                 'de JPD pode reduzir o dano pela metade.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão das Sombras é imune a qualquer '
                 'efeito que envolva sombras e escuridão.\n'
                 '\n'
                 '  * **Magias**: um Dragão das Sombras pode conjurar magias '
                 'como se fosse um Mago de 6º nível.\n'
                 '\n'
                 '  * **Infravisão**: 30 metros\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Adaptados aos mais diversos ambientes, vivem na escuridão, '
                 'preferencialmente nos subterrâneos.  Controlam mortos-vivos '
                 'por meio de necromancia e vivem assim, entre mortos e vivos '
                 'de forma indiferente. Seus filhotes nascem de ovos feitos de '
                 'sombra e fumaça, e após o nascimento, devoram corpos '
                 'previamente colocados por perto para se tornarem materiais.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico.\n'
                 '\n'
                 'Especificamente do Dragão das Sombras, seu sangue pode ser '
                 'usado para confeccionar itens mágicos ligados à escuridão.',
  'dv': '12',
  'dv_bonus': '+8',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis '
            'escondidos de qualquer fonte de luz. Saem apenas para os '
            'subterrâneos ou durante a noite para organizar emboscadas a '
            'viajantes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 50}],
  'habitats': ['qualquer'],
  'id': 'dragao-das-sombras-velho',
  'jp': '12',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Dragão das Sombras Velho',
  'parent_monster_url': 'https://olddragon.com.br/monstros/dragao-das-sombras.json',
  'picture': 'https://public.olddragon.com.br/gsg9rubh82nbzx3t5bjxd5ela1q4',
  'pv': '68',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/wk72w6lvrsdgnbxu9jqu47vezecu',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-das-sombras-velho.json',
  'variant': True,
  'variant_modifications': ['Baforada: Cega por 2d6 rodadas e causa a perda de '
                            '¾ dos pontos de vida atuais.',
                            'Magia como mago de 8° nível'],
  'xp': '2175'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 10,
               'damage': '1d8',
               'damage_bonus': 6,
               'damage_description': '1d8+6',
               'description': 'Garras',
               'text': '2 × Garras +10 (1d8+6)',
               'times': 2,
               'weapon': False},
              {'ba': 9,
               'damage': '3d8',
               'damage_bonus': None,
               'damage_description': '3d8',
               'description': 'Mordida',
               'text': '1 × Mordida +9 (3d8)',
               'times': 1,
               'weapon': False}],
  'ca': '19',
  'concept': 'dragao',
  'description': 'Estas horrendas criaturas parecem enormes ossadas de dragão '
                 'animadas, sem pele ou carne. Seus olhos brilham de ódio, '
                 'animados por energias malignas. Suas asas ainda possuem '
                 'restos de quando era vivo.\n'
                 '\n'
                 '**Som**: pancadas ocas e ritmadas sobre o solo.\n'
                 '\n'
                 '**Odor**: decomposição.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam com raiva contra tudo que for vivo e estiver contra '
                 'os desejos do seu mestre. Apesar de não saberem usar magias, '
                 'sabem o quanto elas podem ser perigosas, atacando Magos e '
                 'Clérigos em primeiro lugar. Preferem usar sua baforada '
                 'necrótica, visando criar mais mortos-vivos no processo.\n'
                 '\n'
                 '  * **Baforada**: o Dragão de Ossos pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de energia necrótica com a forma de cone com 9 metros de '
                 'largura e 27 metros de distância. O dano de uma baforada é '
                 'igual ao número de seus dados de vida em d6. Ou seja, um '
                 'Dragão de Ossos causa 9d6 de dano em todos na área de efeito '
                 'da baforada. Um teste de JPD pode reduzir o dano pela '
                 'metade. Qualquer alvo morto por uma baforada necrótica '
                 'possui uma chance de 1-2 em 1d6 de se levantar como um Ghoul '
                 'a serviço do Dragão de Ossos.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a magias mentais de manipulação, '
                 'controle ou ilusão, ou demais formas mágicas de interferir '
                 'na mente de seres vivos.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão de Ossos é imune a um Afastar '
                 'Mortos-Vivos de um Clérigo.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Estas criaturas são solitárias, mas podem estar acompanhadas '
                 'de outros mortos-vivos os quais foram impostos a ficarem na '
                 'presença do dragão.  Dragões de ossos apresentam alguns '
                 'traços de quando eram vivos, mas odeiam tudo o que remete à '
                 'vida e aos seres vivos. Não se alimentam ou dormem, e são '
                 'adversários terríveis.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu, os ossos de um Dragão de Ossos '
                 'são esculpidos como marfim para criação de itens profanos '
                 'para rituais de necromantes e cultistas.',
  'dv': '9',
  'dv_bonus': '+9',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Resultado de experiências necromânticas, estes dragões '
            'mortos-vivos são umas das criaturas mais aterrorizantes já vistas '
            'pelo mundo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 52},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc2.json',
              'page': 31},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'dragao-de-ossos',
  'jp': '12',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Dragão de Ossos',
  'picture': 'https://public.olddragon.com.br/9qh4t3vlu9ofwo4jkv9yfbw9x2t4',
  'pv': '54',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/vqlklf5h80t2uz2psd8u1w8dge1e',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-de-ossos.json',
  'variant': False,
  'xp': '1075'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Mordida',
               'text': '1 × Mordida +4 (2d8)',
               'times': 1,
               'weapon': False},
              {'ba': 5,
               'damage': '1d8',
               'damage_bonus': 3,
               'damage_description': '1d8+3',
               'description': 'Garras',
               'text': '2 × Garras +5 (1d8+3)',
               'times': 2,
               'weapon': False}],
  'ca': '16',
  'concept': 'dragao',
  'description': 'Estas horrendas criaturas parecem enormes ossadas de dragão '
                 'animadas, sem pele ou carne. Seus olhos brilham de ódio, '
                 'animados por energias malignas. Suas asas ainda possuem '
                 'restos de quando era vivo.\n'
                 '\n'
                 '**Som**: pancadas ocas e ritmadas sobre o solo.\n'
                 '\n'
                 '**Odor**: decomposição.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam com raiva contra tudo que for vivo e estiver contra '
                 'os desejos do seu mestre. Apesar de não saberem usar magias, '
                 'sabem o quanto elas podem ser perigosas, atacando Magos e '
                 'Clérigos em primeiro lugar. Preferem usar sua baforada '
                 'necrótica, visando criar mais mortos-vivos no processo.\n'
                 '\n'
                 '  * **Baforada**: o Dragão de Ossos pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de energia necrótica com a forma de cone com 9 metros de '
                 'largura e 27 metros de distância. O dano de uma baforada é '
                 'igual ao número de seus dados de vida em d6. Ou seja, um '
                 'Dragão de Ossos causa 9d6 de dano em todos na área de efeito '
                 'da baforada. Um teste de JPD pode reduzir o dano pela '
                 'metade. Qualquer alvo morto por uma baforada necrótica '
                 'possui uma chance de 1-2 em 1d6 de se levantar como um Ghoul '
                 'a serviço do Dragão de Ossos.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a magias mentais de manipulação, '
                 'controle ou ilusão, ou demais formas mágicas de interferir '
                 'na mente de seres vivos.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão de Ossos é imune a um Afastar '
                 'Mortos-Vivos de um Clérigo.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Estas criaturas são solitárias, mas podem estar acompanhadas '
                 'de outros mortos-vivos os quais foram impostos a ficarem na '
                 'presença do dragão.  Dragões de ossos apresentam alguns '
                 'traços de quando eram vivos, mas odeiam tudo o que remete à '
                 'vida e aos seres vivos. Não se alimentam ou dormem, e são '
                 'adversários terríveis.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu, os ossos de um Dragão de Ossos '
                 'são esculpidos como marfim para criação de itens profanos '
                 'para rituais de necromantes e cultistas.',
  'dv': '4',
  'dv_bonus': '+9',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Resultado de experiências necromânticas, estes dragões '
            'mortos-vivos são umas das criaturas mais aterrorizantes já vistas '
            'pelo mundo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 52},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc2.json',
              'page': 29}],
  'habitats': ['subterraneos'],
  'id': 'dragao-de-ossos-jovem',
  'jp': '6',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Dragão de Ossos Jovem',
  'parent_monster_url': 'https://olddragon.com.br/monstros/dragao-de-ossos.json',
  'picture': 'https://public.olddragon.com.br/9qh4t3vlu9ofwo4jkv9yfbw9x2t4',
  'pv': '29',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/vqlklf5h80t2uz2psd8u1w8dge1e',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-de-ossos-jovem.json',
  'variant': True,
  'variant_modifications': ['Baforada: 4d6 de dano.'],
  'xp': '200'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 12,
               'damage': '1d8',
               'damage_bonus': 9,
               'damage_description': '1d8+9',
               'description': 'Garras',
               'text': '2 × Garras +12 (1d8+9)',
               'times': 2,
               'weapon': False},
              {'ba': 10,
               'damage': '4d8',
               'damage_bonus': None,
               'damage_description': '4d8',
               'description': 'Mordida',
               'text': '1 × Mordida +10 (4d8)',
               'times': 1,
               'weapon': False},
              {'ba': None,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Especial',
               'description': 'Varrer com a cauda',
               'text': '1 × Varrer com a cauda (Especial)',
               'times': 1,
               'weapon': False}],
  'ca': '19',
  'concept': 'dragao',
  'description': 'Estas horrendas criaturas parecem enormes ossadas de dragão '
                 'animadas, sem pele ou carne. Seus olhos brilham de ódio, '
                 'animados por energias malignas. Suas asas ainda possuem '
                 'restos de quando era vivo.\n'
                 '\n'
                 '**Som**: pancadas ocas e ritmadas sobre o solo.\n'
                 '\n'
                 '**Odor**: decomposição.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam com raiva contra tudo que for vivo e estiver contra '
                 'os desejos do seu mestre. Apesar de não saberem usar magias, '
                 'sabem o quanto elas podem ser perigosas, atacando Magos e '
                 'Clérigos em primeiro lugar. Preferem usar sua baforada '
                 'necrótica, visando criar mais mortos-vivos no processo.\n'
                 '\n'
                 '  * **Baforada**: o Dragão de Ossos pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de energia necrótica com a forma de cone com 9 metros de '
                 'largura e 27 metros de distância. O dano de uma baforada é '
                 'igual ao número de seus dados de vida em d6. Ou seja, um '
                 'Dragão de Ossos causa 9d6 de dano em todos na área de efeito '
                 'da baforada. Um teste de JPD pode reduzir o dano pela '
                 'metade. Qualquer alvo morto por uma baforada necrótica '
                 'possui uma chance de 1-2 em 1d6 de se levantar como um Ghoul '
                 'a serviço do Dragão de Ossos.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a magias mentais de manipulação, '
                 'controle ou ilusão, ou demais formas mágicas de interferir '
                 'na mente de seres vivos.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão de Ossos é imune a um Afastar '
                 'Mortos-Vivos de um Clérigo.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Estas criaturas são solitárias, mas podem estar acompanhadas '
                 'de outros mortos-vivos os quais foram impostos a ficarem na '
                 'presença do dragão.  Dragões de ossos apresentam alguns '
                 'traços de quando eram vivos, mas odeiam tudo o que remete à '
                 'vida e aos seres vivos. Não se alimentam ou dormem, e são '
                 'adversários terríveis.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu, os ossos de um Dragão de Ossos '
                 'são esculpidos como marfim para criação de itens profanos '
                 'para rituais de necromantes e cultistas.',
  'dv': '13',
  'dv_bonus': '+9',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Resultado de experiências necromânticas, estes dragões '
            'mortos-vivos são umas das criaturas mais aterrorizantes já vistas '
            'pelo mundo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 52},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc2.json',
              'page': 34}],
  'habitats': ['subterraneos'],
  'id': 'dragao-de-ossos-velho',
  'jp': '13',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Dragão de Ossos Velho',
  'parent_monster_url': 'https://olddragon.com.br/monstros/dragao-de-ossos.json',
  'picture': 'https://public.olddragon.com.br/9qh4t3vlu9ofwo4jkv9yfbw9x2t4',
  'pv': '74',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/vqlklf5h80t2uz2psd8u1w8dge1e',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-de-ossos-velho.json',
  'variant': True,
  'variant_modifications': ['Baforada: 13d6 de dano.'],
  'xp': '2525'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 11,
               'damage': '1d8',
               'damage_bonus': 6,
               'damage_description': '1d8+6',
               'description': 'Garras',
               'text': '2 × Garras +11 (1d8+6)',
               'times': 2,
               'weapon': False},
              {'ba': 8,
               'damage': '4d8',
               'damage_bonus': None,
               'damage_description': '4d8',
               'description': 'Mordida',
               'text': '1 × Mordida +8 (4d8)',
               'times': 1,
               'weapon': False}],
  'ca': '22',
  'concept': 'dragao',
  'description': 'Possuem um ar soberano e esnobe, olhando de cima as demais '
                 'criaturas.  Sendo o tipo mais raro de Dragão, apresentam uma '
                 'beleza em suas escamas, as quais se assemelham ao ouro. '
                 'Conforme ficam mais velhos, o brilho de suas escamas '
                 'aumenta.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Suas habilidades são de puro poder. Desta forma, são poucos '
                 'os que equiparam em uma luta com estes dragões. Usam magias '
                 'e baforadas de forma eficaz, aproveitando ao máximo suas '
                 'habilidades e o terreno no qual se encontram.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Dourado pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de fogo com a forma de cone com 9 metros de largura e 27 '
                 'metros de distância. O dano de uma baforada é igual ao '
                 'número de seus dados de vida em d10. Ou seja, um Dragão '
                 'Dourado causa 11d10 de dano em todos na área de efeito da '
                 'baforada. Um teste de JPD pode reduzir o dano pela metade.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão Dourado é imune a qualquer '
                 'efeito de fogo.\n'
                 '\n'
                 '  * **Magias**: um Dragão Dourado pode conjurar magias como '
                 'um Mago de 7º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Aliados das criaturas ordeiras, evitam se intrometer nos '
                 'assuntos dos outros, pois sabem que seu poder pode '
                 'desequilibrar a balança da ordem e do caos. Vivem nas '
                 'montanhas mais altas, ou mesmo em moradas acima das nuvens, '
                 'fazendo o acesso a essas criaturas algo extremamente '
                 'difícil. Colocam pouquíssimos ovos em toda sua vida, criando '
                 'os filhotes para assumirem postos de Observadores dos '
                 'assuntos divinos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de Dragões Dourados são usadas para '
                 'adorno e para confeccionar armaduras mágicas de rara beleza '
                 'e grande poder mágico.  No entanto, itens criados com partes '
                 'de Dragões Dourados são malvistos pela sociedade que '
                 'glorifica estes dragões como bondosos.',
  'dv': '11',
  'dv_bonus': '+11',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Estes dragões se destacam dos '
            'demais dragões pelo seu senso de justiça e ordem. São sábios, '
            'benevolentes e muito conscientes do seu poder e lugar na '
            'sociedade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 54},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['montanhas', 'colinas'],
  'id': 'dragao-dourado',
  'jp': '13',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 18,
  'name': 'Dragão Dourado',
  'picture': 'https://public.olddragon.com.br/683mdiiyt0k9lgy3bx5rt7b3hyh6',
  'pv': '66',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/ea9xs3wegoin2oz48lbzxbdzqjkp',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-dourado.json',
  'variant': False,
  'xp': '1825'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 5,
               'damage': '3d8',
               'damage_bonus': None,
               'damage_description': '3d8',
               'description': 'Mordida',
               'text': '1 × Mordida +5 (3d8)',
               'times': 1,
               'weapon': False},
              {'ba': 6,
               'damage': '1d8',
               'damage_bonus': 3,
               'damage_description': '1d8+3',
               'description': 'Garras',
               'text': '2 × Garras +6 (1d8+3)',
               'times': 2,
               'weapon': False}],
  'ca': '19',
  'concept': 'dragao',
  'description': 'Possuem um ar soberano e esnobe, olhando de cima as demais '
                 'criaturas.  Sendo o tipo mais raro de Dragão, apresentam uma '
                 'beleza em suas escamas, as quais se assemelham ao ouro. '
                 'Conforme ficam mais velhos, o brilho de suas escamas '
                 'aumenta.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Suas habilidades são de puro poder. Desta forma, são poucos '
                 'os que equiparam em uma luta com estes dragões. Usam magias '
                 'e baforadas de forma eficaz, aproveitando ao máximo suas '
                 'habilidades e o terreno no qual se encontram.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Dourado pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de fogo com a forma de cone com 9 metros de largura e 27 '
                 'metros de distância. O dano de uma baforada é igual ao '
                 'número de seus dados de vida em d10. Ou seja, um Dragão '
                 'Dourado causa 11d10 de dano em todos na área de efeito da '
                 'baforada. Um teste de JPD pode reduzir o dano pela metade.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão Dourado é imune a qualquer '
                 'efeito de fogo.\n'
                 '\n'
                 '  * **Magias**: um Dragão Dourado pode conjurar magias como '
                 'um Mago de 7º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Aliados das criaturas ordeiras, evitam se intrometer nos '
                 'assuntos dos outros, pois sabem que seu poder pode '
                 'desequilibrar a balança da ordem e do caos. Vivem nas '
                 'montanhas mais altas, ou mesmo em moradas acima das nuvens, '
                 'fazendo o acesso a essas criaturas algo extremamente '
                 'difícil. Colocam pouquíssimos ovos em toda sua vida, criando '
                 'os filhotes para assumirem postos de Observadores dos '
                 'assuntos divinos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de Dragões Dourados são usadas para '
                 'adorno e para confeccionar armaduras mágicas de rara beleza '
                 'e grande poder mágico.  No entanto, itens criados com partes '
                 'de Dragões Dourados são malvistos pela sociedade que '
                 'glorifica estes dragões como bondosos.',
  'dv': '5',
  'dv_bonus': '+11',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Estes dragões se destacam dos '
            'demais dragões pelo seu senso de justiça e ordem. São sábios, '
            'benevolentes e muito conscientes do seu poder e lugar na '
            'sociedade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 54}],
  'habitats': ['montanhas', 'colinas'],
  'id': 'dragao-dourado-jovem',
  'jp': '8',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Dragão Dourado Jovem',
  'parent_monster_url': 'https://olddragon.com.br/monstros/dragao-dourado.json',
  'picture': 'https://public.olddragon.com.br/683mdiiyt0k9lgy3bx5rt7b3hyh6',
  'pv': '36',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/ea9xs3wegoin2oz48lbzxbdzqjkp',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-dourado-jovem.json',
  'variant': True,
  'variant_modifications': ['Baforada: 5d10 de dano.',
                            'Magia como mago de 5° nível.'],
  'xp': '265'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 13,
               'damage': '5d8',
               'damage_bonus': None,
               'damage_description': '5d8',
               'description': 'Mordida',
               'text': '1 × Mordida +13 (5d8)',
               'times': 1,
               'weapon': False},
              {'ba': 14,
               'damage': '1d8',
               'damage_bonus': 9,
               'damage_description': '1d8+9',
               'description': 'Garras',
               'text': '2 × Garras +14 (1d8+9)',
               'times': 2,
               'weapon': False},
              {'ba': None,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Especial',
               'description': 'Varrer com a cauda',
               'text': '1 × Varrer com a cauda (Especial)',
               'times': 1,
               'weapon': False}],
  'ca': '22',
  'concept': 'dragao',
  'description': 'Possuem um ar soberano e esnobe, olhando de cima as demais '
                 'criaturas.  Sendo o tipo mais raro de Dragão, apresentam uma '
                 'beleza em suas escamas, as quais se assemelham ao ouro. '
                 'Conforme ficam mais velhos, o brilho de suas escamas '
                 'aumenta.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Suas habilidades são de puro poder. Desta forma, são poucos '
                 'os que equiparam em uma luta com estes dragões. Usam magias '
                 'e baforadas de forma eficaz, aproveitando ao máximo suas '
                 'habilidades e o terreno no qual se encontram.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Dourado pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de fogo com a forma de cone com 9 metros de largura e 27 '
                 'metros de distância. O dano de uma baforada é igual ao '
                 'número de seus dados de vida em d10. Ou seja, um Dragão '
                 'Dourado causa 11d10 de dano em todos na área de efeito da '
                 'baforada. Um teste de JPD pode reduzir o dano pela metade.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão Dourado é imune a qualquer '
                 'efeito de fogo.\n'
                 '\n'
                 '  * **Magias**: um Dragão Dourado pode conjurar magias como '
                 'um Mago de 7º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Aliados das criaturas ordeiras, evitam se intrometer nos '
                 'assuntos dos outros, pois sabem que seu poder pode '
                 'desequilibrar a balança da ordem e do caos. Vivem nas '
                 'montanhas mais altas, ou mesmo em moradas acima das nuvens, '
                 'fazendo o acesso a essas criaturas algo extremamente '
                 'difícil. Colocam pouquíssimos ovos em toda sua vida, criando '
                 'os filhotes para assumirem postos de Observadores dos '
                 'assuntos divinos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de Dragões Dourados são usadas para '
                 'adorno e para confeccionar armaduras mágicas de rara beleza '
                 'e grande poder mágico.  No entanto, itens criados com partes '
                 'de Dragões Dourados são malvistos pela sociedade que '
                 'glorifica estes dragões como bondosos.',
  'dv': '16',
  'dv_bonus': '+11',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Estes dragões se destacam dos '
            'demais dragões pelo seu senso de justiça e ordem. São sábios, '
            'benevolentes e muito conscientes do seu poder e lugar na '
            'sociedade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 54}],
  'habitats': ['montanhas', 'colinas'],
  'id': 'dragao-dourado-velho',
  'jp': '14',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 18,
  'name': 'Dragão Dourado Velho',
  'parent_monster_url': 'https://olddragon.com.br/monstros/dragao-dourado.json',
  'picture': 'https://public.olddragon.com.br/683mdiiyt0k9lgy3bx5rt7b3hyh6',
  'pv': '91',
  'size': 'colossal',
  'thumb_picture': 'https://public.olddragon.com.br/ea9xs3wegoin2oz48lbzxbdzqjkp',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-dourado-velho.json',
  'variant': True,
  'variant_modifications': ['Baforada: 16d10 de dano.',
                            'Magia como mago de 10° nível.'],
  'xp': '3575'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 6,
               'damage': '2d10',
               'damage_bonus': None,
               'damage_description': '2d10',
               'description': 'Mordida',
               'text': '1 × Mordida +6 (2d10)',
               'times': 1,
               'weapon': False},
              {'ba': 7,
               'damage': '1d4',
               'damage_bonus': 4,
               'damage_description': '1d4+4',
               'description': 'Garras',
               'text': '2 × Garras +7 (1d4+4)',
               'times': 2,
               'weapon': False}],
  'ca': '18',
  'concept': 'dragao',
  'description': 'Os Dragões Negros costumam viver em pântanos e, por isso, é '
                 'comum terem o corpo coberto por musgo, algas, lama e até '
                 'mesmo insetos e criaturas pantanosas diminutas.  Os mais '
                 'velhos ficam desbotados e muito magros, quase esqueléticos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Gostam de usar o ácido para derreter cavalos e empregados '
                 'contratados antes dos aventureiros, apenas para inspirar '
                 'medo. São cruéis e suas técnicas de luta demonstram bem '
                 'isso, pois sempre buscam o sofrimento dos alvos. Gostam de '
                 '“brincar” com os inimigos antes de devorá-los.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Negro pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de jato ácido com a forma de cone com 2 metros de largura e '
                 '20 metros de distância. O dano de uma baforada é igual ao '
                 'número de seus dados de vida em d4. Ou seja, um Dragão Negro '
                 'causa 7d4 de dano em todos na área de efeito da baforada. Um '
                 'teste de JPD pode reduzir o dano pela metade. Ao contrário '
                 'do ácido concentrado, a baforada de ácido do Dragão Negro '
                 'não causa o dano regressivo típico dos ácidos.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão Negro é imune a qualquer efeito '
                 'de ácido.\n'
                 '\n'
                 '  * **Magias**: um Dragão Negro pode conjurar magias como se '
                 'fosse um Mago de 6º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em pântanos e charcos, preferindo o calor e a umidade '
                 'para fazerem seus lares. Podem prender o fôlego por horas, '
                 'podendo então aguardar na água enquanto analisam sua vítima. '
                 'Os filhotes não são cuidados pela mãe, e sim por criaturas '
                 'escravizadas pelo Dragão Negro, como Trolls ou mesmo '
                 'Bruxas.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico.\n'
                 '\n'
                 'Especificamente do Dragão Negro, seu sangue pode ser usado '
                 'para confeccionar itens mágicos ligados ao ácido.',
  'dv': '7',
  'dv_bonus': '+7',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis, '
            'inteligentemente escondidos nos pântanos e áreas alagadas. '
            'Organizam emboscadas a viajantes e admiram seus tesouros '
            'acumulados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 56},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday14.json',
              'page': 22},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['pantanos'],
  'id': 'dragao-negro',
  'jp': '11',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Dragão Negro',
  'picture': 'https://public.olddragon.com.br/iqihbdmujiaoylpivdh1p1oofufk',
  'pv': '42',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/xb0hm5ukfq3jber0onb5w6lafdov',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-negro.json',
  'variant': False,
  'xp': '540'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d10',
               'damage_bonus': None,
               'damage_description': '1d10',
               'description': 'Mordida',
               'text': '1 × Mordida +3 (1d10)',
               'times': 1,
               'weapon': False},
              {'ba': 4,
               'damage': '1d4',
               'damage_bonus': 2,
               'damage_description': '1d4+2',
               'description': 'Garras',
               'text': '2 × Garras +4 (1d4+2)',
               'times': 2,
               'weapon': False}],
  'ca': '15',
  'concept': 'dragao',
  'description': 'Os Dragões Negros costumam viver em pântanos e, por isso, é '
                 'comum terem o corpo coberto por musgo, algas, lama e até '
                 'mesmo insetos e criaturas pantanosas diminutas.  Os mais '
                 'velhos ficam desbotados e muito magros, quase esqueléticos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Gostam de usar o ácido para derreter cavalos e empregados '
                 'contratados antes dos aventureiros, apenas para inspirar '
                 'medo. São cruéis e suas técnicas de luta demonstram bem '
                 'isso, pois sempre buscam o sofrimento dos alvos. Gostam de '
                 '“brincar” com os inimigos antes de devorá-los.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Negro pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de jato ácido com a forma de cone com 2 metros de largura e '
                 '20 metros de distância. O dano de uma baforada é igual ao '
                 'número de seus dados de vida em d4. Ou seja, um Dragão Negro '
                 'causa 7d4 de dano em todos na área de efeito da baforada. Um '
                 'teste de JPD pode reduzir o dano pela metade. Ao contrário '
                 'do ácido concentrado, a baforada de ácido do Dragão Negro '
                 'não causa o dano regressivo típico dos ácidos.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão Negro é imune a qualquer efeito '
                 'de ácido.\n'
                 '\n'
                 '  * **Magias**: um Dragão Negro pode conjurar magias como se '
                 'fosse um Mago de 6º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em pântanos e charcos, preferindo o calor e a umidade '
                 'para fazerem seus lares. Podem prender o fôlego por horas, '
                 'podendo então aguardar na água enquanto analisam sua vítima. '
                 'Os filhotes não são cuidados pela mãe, e sim por criaturas '
                 'escravizadas pelo Dragão Negro, como Trolls ou mesmo '
                 'Bruxas.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico.\n'
                 '\n'
                 'Especificamente do Dragão Negro, seu sangue pode ser usado '
                 'para confeccionar itens mágicos ligados ao ácido.',
  'dv': '3',
  'dv_bonus': '+7',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis, '
            'inteligentemente escondidos nos pântanos e áreas alagadas. '
            'Organizam emboscadas a viajantes e admiram seus tesouros '
            'acumulados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 56},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday14.json',
              'page': 18}],
  'habitats': ['pantanos'],
  'id': 'dragao-negro-jovem',
  'jp': '6',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Dragão Negro Jovem',
  'parent_monster_url': 'https://olddragon.com.br/monstros/dragao-negro.json',
  'picture': 'https://public.olddragon.com.br/iqihbdmujiaoylpivdh1p1oofufk',
  'pv': '22',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/xb0hm5ukfq3jber0onb5w6lafdov',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-negro-jovem.json',
  'variant': True,
  'variant_modifications': ['Baforada: 3d4 de dano.',
                            'Magia como mago de 4° nível.'],
  'xp': '135'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 10,
               'damage': '3d10',
               'damage_bonus': None,
               'damage_description': '3d10',
               'description': 'Mordida',
               'text': '1 × Mordida +10 (3d10)',
               'times': 1,
               'weapon': False},
              {'ba': 11,
               'damage': '1d4',
               'damage_bonus': 7,
               'damage_description': '1d4+7',
               'description': 'Garras',
               'text': '2 × Garras +11 (1d4+7)',
               'times': 2,
               'weapon': False},
              {'ba': None,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Especial',
               'description': 'Varrer com a cauda',
               'text': '1 × Varrer com a cauda (Especial)',
               'times': 1,
               'weapon': False}],
  'ca': '18',
  'concept': 'dragao',
  'description': 'Os Dragões Negros costumam viver em pântanos e, por isso, é '
                 'comum terem o corpo coberto por musgo, algas, lama e até '
                 'mesmo insetos e criaturas pantanosas diminutas.  Os mais '
                 'velhos ficam desbotados e muito magros, quase esqueléticos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Gostam de usar o ácido para derreter cavalos e empregados '
                 'contratados antes dos aventureiros, apenas para inspirar '
                 'medo. São cruéis e suas técnicas de luta demonstram bem '
                 'isso, pois sempre buscam o sofrimento dos alvos. Gostam de '
                 '“brincar” com os inimigos antes de devorá-los.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Negro pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de jato ácido com a forma de cone com 2 metros de largura e '
                 '20 metros de distância. O dano de uma baforada é igual ao '
                 'número de seus dados de vida em d4. Ou seja, um Dragão Negro '
                 'causa 7d4 de dano em todos na área de efeito da baforada. Um '
                 'teste de JPD pode reduzir o dano pela metade. Ao contrário '
                 'do ácido concentrado, a baforada de ácido do Dragão Negro '
                 'não causa o dano regressivo típico dos ácidos.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão Negro é imune a qualquer efeito '
                 'de ácido.\n'
                 '\n'
                 '  * **Magias**: um Dragão Negro pode conjurar magias como se '
                 'fosse um Mago de 6º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em pântanos e charcos, preferindo o calor e a umidade '
                 'para fazerem seus lares. Podem prender o fôlego por horas, '
                 'podendo então aguardar na água enquanto analisam sua vítima. '
                 'Os filhotes não são cuidados pela mãe, e sim por criaturas '
                 'escravizadas pelo Dragão Negro, como Trolls ou mesmo '
                 'Bruxas.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico.\n'
                 '\n'
                 'Especificamente do Dragão Negro, seu sangue pode ser usado '
                 'para confeccionar itens mágicos ligados ao ácido.',
  'dv': '10',
  'dv_bonus': '+7',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis, '
            'inteligentemente escondidos nos pântanos e áreas alagadas. '
            'Organizam emboscadas a viajantes e admiram seus tesouros '
            'acumulados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 56},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday14.json',
              'page': 26}],
  'habitats': ['pantanos'],
  'id': 'dragao-negro-velho',
  'jp': '11',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Dragão Negro Velho',
  'parent_monster_url': 'https://olddragon.com.br/monstros/dragao-negro.json',
  'picture': 'https://public.olddragon.com.br/iqihbdmujiaoylpivdh1p1oofufk',
  'pv': '57',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/xb0hm5ukfq3jber0onb5w6lafdov',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-negro-velho.json',
  'variant': True,
  'variant_modifications': ['Baforada: 10d4 de dano.',
                            'Magia como mago de 7° nível.'],
  'xp': '1475'},
 {'access': 'limited',
  'alignment': 'ordeiro',
  'concept': 'dragao',
  'flavor': 'Uma das criaturas mais poderosas do Plano Material, um colossal '
            'Dragão de três cabeças capaz de liberar três baforadas dragônicas '
            'diferentes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 28}],
  'habitats': ['extraplanar'],
  'id': 'dragao-protetor',
  'name': 'Dragão Protetor',
  'size': 'colossal',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-protetor.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 7,
               'damage': '3d8',
               'damage_bonus': None,
               'damage_description': '3d8',
               'description': 'Mordida',
               'text': '1 × Mordida +7 (3d8)',
               'times': 1,
               'weapon': False},
              {'ba': 8,
               'damage': '1d6',
               'damage_bonus': 4,
               'damage_description': '1d6+4',
               'description': 'Garras',
               'text': '2 × Garras +8 (1d6+4)',
               'times': 2,
               'weapon': False}],
  'ca': '19',
  'concept': 'dragao',
  'description': 'Estes dragões possuem escamas verdes que variam em '
                 'tonalidade, mas que se mantêm durante toda sua vida. A única '
                 'diferença marcante percebida para quando ficam mais velhos é '
                 'o tamanho adquirido. Mesmo assim, os Dragões Verdes estão '
                 'entre os menores dragões, pois seu tamanho é compatível com '
                 'a vida nas florestas e bosques.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam sua nuvem de gás venenoso antes dos ataques físicos, '
                 'podendo até mesmo bater suas asas para aumentar o alcance do '
                 'gás, caso necessário. São combatentes selvagens, lutando '
                 'principalmente com garras e dentes.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Verde pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de gás venenoso em forma de nuvem com 12 metros de largura, '
                 '15 metros de distância e 6 metros de altura. O dano de uma '
                 'baforada é igual ao número de seus dados de vida em d6. Ou '
                 'seja, um Dragão Verde causa 8d6 de dano em todos na área de '
                 'efeito da baforada. Um teste de JPD pode reduzir o dano pela '
                 'metade.  u Imunidade: um Dragão Verde é imune a qualquer '
                 'efeito de venenos.\n'
                 '\n'
                 '  * **Magias**: um Dragão Verde pode conjurar magias como se '
                 'fosse um Mago 6º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Dragões Verdes vivem em enormes florestas, muitas vezes sem '
                 'precisarem esconder-se em cavernas. Escolhem árvores bem '
                 'antigas e criam sua morada entre elas, em grandes clareiras '
                 'com as copas das árvores fechadas, criando um verdadeiro '
                 'domo vegetal. Seus filhotes se desenvolvem sozinhos e são '
                 'excelentes caçadores. Dragões Verdes são odiados por elfos, '
                 'pois muitas vezes escravizam povoados élficos inteiros.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico.\n'
                 '\n'
                 'Especificamente do Dragão Verde, seu sangue pode ser usado '
                 'para confeccionar venenos extremamente poderosos e mortais.',
  'dv': '8',
  'dv_bonus': '+8',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis, '
            'inteligentemente escondidos nas florestas e selvas. Organizam '
            'emboscadas a viajantes e admiram seus tesouros acumulados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 58},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas'],
  'id': 'dragao-verde',
  'jp': '11',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Dragão Verde',
  'picture': 'https://public.olddragon.com.br/cm3pxjohlqwo34lo11i3jy29uhim',
  'pv': '48',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/68ahmjcnecccyp3mmb1msaowxuq7',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-verde.json',
  'variant': False,
  'xp': '785'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 5,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Garras',
               'text': '2 × Garras +5 (1d6+2)',
               'times': 2,
               'weapon': False},
              {'ba': 4,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Mordida',
               'text': '1 × Mordida +4 (2d8)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'dragao',
  'description': 'Estes dragões possuem escamas verdes que variam em '
                 'tonalidade, mas que se mantêm durante toda sua vida. A única '
                 'diferença marcante percebida para quando ficam mais velhos é '
                 'o tamanho adquirido. Mesmo assim, os Dragões Verdes estão '
                 'entre os menores dragões, pois seu tamanho é compatível com '
                 'a vida nas florestas e bosques.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam sua nuvem de gás venenoso antes dos ataques físicos, '
                 'podendo até mesmo bater suas asas para aumentar o alcance do '
                 'gás, caso necessário. São combatentes selvagens, lutando '
                 'principalmente com garras e dentes.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Verde pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de gás venenoso em forma de nuvem com 12 metros de largura, '
                 '15 metros de distância e 6 metros de altura. O dano de uma '
                 'baforada é igual ao número de seus dados de vida em d6. Ou '
                 'seja, um Dragão Verde causa 8d6 de dano em todos na área de '
                 'efeito da baforada. Um teste de JPD pode reduzir o dano pela '
                 'metade.  u Imunidade: um Dragão Verde é imune a qualquer '
                 'efeito de venenos.\n'
                 '\n'
                 '  * **Magias**: um Dragão Verde pode conjurar magias como se '
                 'fosse um Mago 6º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Dragões Verdes vivem em enormes florestas, muitas vezes sem '
                 'precisarem esconder-se em cavernas. Escolhem árvores bem '
                 'antigas e criam sua morada entre elas, em grandes clareiras '
                 'com as copas das árvores fechadas, criando um verdadeiro '
                 'domo vegetal. Seus filhotes se desenvolvem sozinhos e são '
                 'excelentes caçadores. Dragões Verdes são odiados por elfos, '
                 'pois muitas vezes escravizam povoados élficos inteiros.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico.\n'
                 '\n'
                 'Especificamente do Dragão Verde, seu sangue pode ser usado '
                 'para confeccionar venenos extremamente poderosos e mortais.',
  'dv': '4',
  'dv_bonus': '+8',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis, '
            'inteligentemente escondidos nas florestas e selvas. Organizam '
            'emboscadas a viajantes e admiram seus tesouros acumulados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 58}],
  'habitats': ['florestas'],
  'id': 'dragao-verde-jovem',
  'jp': '6',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Dragão Verde Jovem',
  'parent_monster_url': 'https://olddragon.com.br/monstros/dragao-verde.json',
  'picture': 'https://public.olddragon.com.br/cm3pxjohlqwo34lo11i3jy29uhim',
  'pv': '28',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/68ahmjcnecccyp3mmb1msaowxuq7',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-verde-jovem.json',
  'variant': True,
  'variant_modifications': ['Baforada: 4d6 de dano.',
                            'Magia como mago de 4° nível.'],
  'xp': '200'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': None,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Especial',
               'description': 'Varrer com a cauda',
               'text': '1 × Varrer com a cauda (Especial)',
               'times': 1,
               'weapon': False},
              {'ba': 11,
               'damage': '4d8',
               'damage_bonus': None,
               'damage_description': '4d8',
               'description': 'Mordida',
               'text': '1 × Mordida +11 (4d8)',
               'times': 1,
               'weapon': False},
              {'ba': 12,
               'damage': '1d6',
               'damage_bonus': 7,
               'damage_description': '1d6+7',
               'description': 'Garras',
               'text': '2 × Garras +12 (1d6+7)',
               'times': 2,
               'weapon': False}],
  'ca': '19',
  'concept': 'dragao',
  'description': 'Estes dragões possuem escamas verdes que variam em '
                 'tonalidade, mas que se mantêm durante toda sua vida. A única '
                 'diferença marcante percebida para quando ficam mais velhos é '
                 'o tamanho adquirido. Mesmo assim, os Dragões Verdes estão '
                 'entre os menores dragões, pois seu tamanho é compatível com '
                 'a vida nas florestas e bosques.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam sua nuvem de gás venenoso antes dos ataques físicos, '
                 'podendo até mesmo bater suas asas para aumentar o alcance do '
                 'gás, caso necessário. São combatentes selvagens, lutando '
                 'principalmente com garras e dentes.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Verde pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de gás venenoso em forma de nuvem com 12 metros de largura, '
                 '15 metros de distância e 6 metros de altura. O dano de uma '
                 'baforada é igual ao número de seus dados de vida em d6. Ou '
                 'seja, um Dragão Verde causa 8d6 de dano em todos na área de '
                 'efeito da baforada. Um teste de JPD pode reduzir o dano pela '
                 'metade.  u Imunidade: um Dragão Verde é imune a qualquer '
                 'efeito de venenos.\n'
                 '\n'
                 '  * **Magias**: um Dragão Verde pode conjurar magias como se '
                 'fosse um Mago 6º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Dragões Verdes vivem em enormes florestas, muitas vezes sem '
                 'precisarem esconder-se em cavernas. Escolhem árvores bem '
                 'antigas e criam sua morada entre elas, em grandes clareiras '
                 'com as copas das árvores fechadas, criando um verdadeiro '
                 'domo vegetal. Seus filhotes se desenvolvem sozinhos e são '
                 'excelentes caçadores. Dragões Verdes são odiados por elfos, '
                 'pois muitas vezes escravizam povoados élficos inteiros.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico.\n'
                 '\n'
                 'Especificamente do Dragão Verde, seu sangue pode ser usado '
                 'para confeccionar venenos extremamente poderosos e mortais.',
  'dv': '12',
  'dv_bonus': '+8',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis, '
            'inteligentemente escondidos nas florestas e selvas. Organizam '
            'emboscadas a viajantes e admiram seus tesouros acumulados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 58}],
  'habitats': ['florestas'],
  'id': 'dragao-verde-velho',
  'jp': '12',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Dragão Verde Velho',
  'parent_monster_url': 'https://olddragon.com.br/monstros/dragao-verde.json',
  'picture': 'https://public.olddragon.com.br/cm3pxjohlqwo34lo11i3jy29uhim',
  'pv': '68',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/68ahmjcnecccyp3mmb1msaowxuq7',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-verde-velho.json',
  'variant': True,
  'variant_modifications': ['Baforada: 12d6 de dano.',
                            'Magia como mago de 8° nível.'],
  'xp': '2175'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 11,
               'damage': '1d8',
               'damage_bonus': 6,
               'damage_description': '1d8+6',
               'description': 'Garras',
               'text': '2 × Garras +11 (1d8+6)',
               'times': 2,
               'weapon': False},
              {'ba': 8,
               'damage': '4d8',
               'damage_bonus': None,
               'damage_description': '4d8',
               'description': 'Mordida',
               'text': '1 × Mordida +8 (4d8)',
               'times': 1,
               'weapon': False}],
  'ca': '21',
  'concept': 'dragao',
  'description': 'De postura orgulhosa, estes dragões são muito fortes e '
                 'inteligentes. Suas escamas vermelhas vão clareando conforme '
                 'envelhecem, chegando a um tom mais alaranjado nos mais '
                 'velhos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Astutos e ardilosos, evitam desperdiçar forças, analisando '
                 'bem os inimigos antes de combatê-los.  Ainda assim, são '
                 'arrogantes e podem deixar de usar golpes muito poderosos se '
                 'acharem que estão em vantagem.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Vermelho pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de fogo com a forma de cone com 9 metros de largura e 27 '
                 'metros de distância. O dano de uma baforada é igual ao '
                 'número de seus dados de vida em d10. Ou seja, um Dragão '
                 'Vermelho causa 10d10 de dano em todos na área de efeito da '
                 'baforada. Um teste de JPD pode reduzir o dano pela metade.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão Vermelho é imune a qualquer '
                 'efeito de fogo.\n'
                 '\n'
                 '  * **Magias**: um Dragão Vermelho pode conjurar magias como '
                 'se fosse um Mago de 7º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Talvez os mais famosos e poderosos de sua raça, os Dragões '
                 'Vermelhos podem liderar grupos de Gigantes do Fogo ou '
                 'criaturas afins. Acumulam riquezas e as guardam em fortes '
                 'muito bem protegidos por seus lacaios, preferindo usar '
                 'soldados do que construir armadilhas. Seus filhotes lutam '
                 'entre si até apenas um na ninhada sobreviver.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico.\n'
                 '\n'
                 'Especificamente do Dragão Vermelho, seu sangue pode ser '
                 'usado para confeccionar itens mágicos ligados ao fogo.',
  'dv': '10',
  'dv_bonus': '+10',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis, '
            'inteligentemente escondidos nas montanhas e colinas. Organizam '
            'emboscadas a viajantes e admiram seus tesouros acumulados.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 172},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 60},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['montanhas'],
  'id': 'dragao-vermelho',
  'jp': '12',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 18,
  'name': 'Dragão Vermelho',
  'picture': 'https://public.olddragon.com.br/6aeb7s2gdrni5whwh3h6225r9xn0',
  'pv': '60',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/qo6v3jit8hgecloiq0xuz3wyrlcr',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-vermelho.json',
  'variant': False,
  'xp': '1475'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 5,
               'damage': '3d8',
               'damage_bonus': None,
               'damage_description': '3d8',
               'description': 'Mordida',
               'text': '1 × Mordida +5 (3d8)',
               'times': 1,
               'weapon': False},
              {'ba': 6,
               'damage': '1d8',
               'damage_bonus': 3,
               'damage_description': '1d8+3',
               'description': 'Garras',
               'text': '2 × Garras +6 (1d8+3)',
               'times': 2,
               'weapon': False}],
  'ca': '18',
  'concept': 'dragao',
  'description': 'De postura orgulhosa, estes dragões são muito fortes e '
                 'inteligentes. Suas escamas vermelhas vão clareando conforme '
                 'envelhecem, chegando a um tom mais alaranjado nos mais '
                 'velhos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Astutos e ardilosos, evitam desperdiçar forças, analisando '
                 'bem os inimigos antes de combatê-los.  Ainda assim, são '
                 'arrogantes e podem deixar de usar golpes muito poderosos se '
                 'acharem que estão em vantagem.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Vermelho pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de fogo com a forma de cone com 9 metros de largura e 27 '
                 'metros de distância. O dano de uma baforada é igual ao '
                 'número de seus dados de vida em d10. Ou seja, um Dragão '
                 'Vermelho causa 10d10 de dano em todos na área de efeito da '
                 'baforada. Um teste de JPD pode reduzir o dano pela metade.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão Vermelho é imune a qualquer '
                 'efeito de fogo.\n'
                 '\n'
                 '  * **Magias**: um Dragão Vermelho pode conjurar magias como '
                 'se fosse um Mago de 7º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Talvez os mais famosos e poderosos de sua raça, os Dragões '
                 'Vermelhos podem liderar grupos de Gigantes do Fogo ou '
                 'criaturas afins. Acumulam riquezas e as guardam em fortes '
                 'muito bem protegidos por seus lacaios, preferindo usar '
                 'soldados do que construir armadilhas. Seus filhotes lutam '
                 'entre si até apenas um na ninhada sobreviver.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico.\n'
                 '\n'
                 'Especificamente do Dragão Vermelho, seu sangue pode ser '
                 'usado para confeccionar itens mágicos ligados ao fogo.',
  'dv': '5',
  'dv_bonus': '+10',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis, '
            'inteligentemente escondidos nas montanhas e colinas. Organizam '
            'emboscadas a viajantes e admiram seus tesouros acumulados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 60}],
  'habitats': ['montanhas'],
  'id': 'dragao-vermelho-jovem',
  'jp': '8',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Dragão Vermelho Jovem',
  'parent_monster_url': 'https://olddragon.com.br/monstros/dragao-vermelho.json',
  'picture': 'https://public.olddragon.com.br/6aeb7s2gdrni5whwh3h6225r9xn0',
  'pv': '35',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/qo6v3jit8hgecloiq0xuz3wyrlcr',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-vermelho-jovem.json',
  'variant': True,
  'variant_modifications': ['Baforada: 5d10 de dano.',
                            'Magia como mago de 5° nível.'],
  'xp': '265'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 12,
               'damage': '5d8',
               'damage_bonus': None,
               'damage_description': '5d8',
               'description': 'Mordida',
               'text': '1 × Mordida +12 (5d8)',
               'times': 1,
               'weapon': False},
              {'ba': None,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Especial',
               'description': 'Varrer com a cauda',
               'text': '1 × Varrer com a cauda (Especial)',
               'times': 1,
               'weapon': False},
              {'ba': 13,
               'damage': '1d8',
               'damage_bonus': 9,
               'damage_description': '1d8+9',
               'description': 'Garras',
               'text': '2 × Garras +13 (1d8+9)',
               'times': 2,
               'weapon': False}],
  'ca': '21',
  'concept': 'dragao',
  'description': 'De postura orgulhosa, estes dragões são muito fortes e '
                 'inteligentes. Suas escamas vermelhas vão clareando conforme '
                 'envelhecem, chegando a um tom mais alaranjado nos mais '
                 'velhos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Astutos e ardilosos, evitam desperdiçar forças, analisando '
                 'bem os inimigos antes de combatê-los.  Ainda assim, são '
                 'arrogantes e podem deixar de usar golpes muito poderosos se '
                 'acharem que estão em vantagem.\n'
                 '\n'
                 '  * **Baforada**: o Dragão Vermelho pode, 3 vezes ao dia, '
                 'abdicar dos seus ataques físicos para liberar uma baforada '
                 'de fogo com a forma de cone com 9 metros de largura e 27 '
                 'metros de distância. O dano de uma baforada é igual ao '
                 'número de seus dados de vida em d10. Ou seja, um Dragão '
                 'Vermelho causa 10d10 de dano em todos na área de efeito da '
                 'baforada. Um teste de JPD pode reduzir o dano pela metade.\n'
                 '\n'
                 '  * **Imunidade**: um Dragão Vermelho é imune a qualquer '
                 'efeito de fogo.\n'
                 '\n'
                 '  * **Magias**: um Dragão Vermelho pode conjurar magias como '
                 'se fosse um Mago de 7º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Talvez os mais famosos e poderosos de sua raça, os Dragões '
                 'Vermelhos podem liderar grupos de Gigantes do Fogo ou '
                 'criaturas afins. Acumulam riquezas e as guardam em fortes '
                 'muito bem protegidos por seus lacaios, preferindo usar '
                 'soldados do que construir armadilhas. Seus filhotes lutam '
                 'entre si até apenas um na ninhada sobreviver.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Além de servir como troféu e dos ovos que possuem valor '
                 'inestimável, as escamas de dragões são usadas para adorno e '
                 'para confeccionar armaduras mágicas de rara beleza e grande '
                 'poder mágico.\n'
                 '\n'
                 'Especificamente do Dragão Vermelho, seu sangue pode ser '
                 'usado para confeccionar itens mágicos ligados ao fogo.',
  'dv': '15',
  'dv_bonus': '+10',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Ancestrais, orgulhosos e poderosos. Vivem em seus covis, '
            'inteligentemente escondidos nas montanhas e colinas. Organizam '
            'emboscadas a viajantes e admiram seus tesouros acumulados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 60}],
  'habitats': ['montanhas'],
  'id': 'dragao-vermelho-velho',
  'jp': '14',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 18,
  'name': 'Dragão Vermelho Velho',
  'parent_monster_url': 'https://olddragon.com.br/monstros/dragao-vermelho.json',
  'picture': 'https://public.olddragon.com.br/6aeb7s2gdrni5whwh3h6225r9xn0',
  'pv': '85',
  'size': 'colossal',
  'thumb_picture': 'https://public.olddragon.com.br/qo6v3jit8hgecloiq0xuz3wyrlcr',
  'treasure': None,
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/dragao-vermelho-velho.json',
  'variant': True,
  'variant_modifications': ['Baforada: 15d10 de dano.',
                            'Magia como mago de 10° nível.'],
  'xp': '3225'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 1,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma +1 (Arma)',
               'times': 1,
               'weapon': True},
              {'ba': 2,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1',
               'description': 'Baforada',
               'text': '1 × Baforada +2 (1d4+1)',
               'times': 1,
               'weapon': False}],
  'ca': '12/14',
  'concept': 'humanoide',
  'description': 'Drakolds são muito semelhantes aos Kobolds, mas extremamente '
                 'destemidos, ferozes e lutam bravamente.  Alguns estudiosos '
                 'acreditam que os Drakolds são descendentes dos dragões, mas '
                 'ninguém foi ousado (ou tolo) o suficiente para defender e '
                 'investigar esta tese.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Costumam usar armaduras de couro, decoradas com o número de '
                 'criaturas já derrotadas por eles (normalmente não muitas). '
                 'Atacam em grandes números, mas de forma lógica, com '
                 'lanceiros flanqueando, arqueiros na retaguarda e demais '
                 'combatentes a frente. Quando em choque de escudos, ou '
                 'distâncias muito próximas, usam sua baforada para '
                 'surpreender o inimigo, mas preferem lutar com suas armas.\n'
                 '\n'
                 '  * **Classe de armadura**: Drakolds possuem CA 12 ou 14 '
                 'quando usam armadura de couro.\n'
                 '\n'
                 '  * **Baforada**: Drakolds podem usar uma forma primitiva de '
                 'baforada, semelhante à de alguns dragões. Este uso não tem '
                 'limitações, e se apresenta como uma pequena explosão de fogo '
                 'ou eletricidade.\n'
                 '\n'
                 '  * **Sacrifício**: se conseguirem ficar 1 minuto se '
                 'concentrando, conseguem explodir o próprio corpo ao '
                 'invocarem a baforada.  Causam 2d6+1 em um raio de 3 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Organizados em clãs, os Drakolds vivem em torno de grandes '
                 'dragões, ou ao menos onde acreditam que eles estejam. '
                 'Idolatrando-os como enviados divinos, tomam os dragões como '
                 'grandes líderes que um dia dominarão a todos.\n'
                 '\n'
                 'Lutam para conquistar territórios de acordo com o que seu '
                 'líder xamã lhes ordena, visando sempre expandir os '
                 'territórios que acreditam ser do dragão escolhido como '
                 'Protetor (mesmo que este não saiba disso).\n'
                 '\n'
                 'Seu compromisso com a causa é tão grande que os Drakolds '
                 'possuem a habilidade de se sacrificar em nome do dragão que '
                 'juraram servir por meio de uma autoexplosão.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Sopa de pulmão de Drakold, além de repugnante, pode conceder '
                 'uma baforada de fogo ou eletricidade, causando 1d2 de dano.',
  'dv': '½',
  'dv_bonus': '+1',
  'encounters': '4d4',
  'encounters_lair': '3d10',
  'flavor': 'Primitivos, vivem próximos a regiões onde dragões habitam. Atacam '
            'para defender seu território, lutando até o fim.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 62},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'drakold',
  'jp': '4',
  'mo': 12,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Drakold',
  'picture': 'https://public.olddragon.com.br/3i24ufyxmm7agrjb70wh78210s6t',
  'pv': '3',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/s2u85gml72xo8ocfgzp4pfu7oll6',
  'treasure': 'q',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/drakold.json',
  'variant': False,
  'xp': '10'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 1,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Bordão',
               'text': '1 × Bordão +1 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': 'Drakolds são muito semelhantes aos Kobolds, mas extremamente '
                 'destemidos, ferozes e lutam bravamente.  Alguns estudiosos '
                 'acreditam que os Drakolds são descendentes dos dragões, mas '
                 'ninguém foi ousado (ou tolo) o suficiente para defender e '
                 'investigar esta tese.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Costumam usar armaduras de couro, decoradas com o número de '
                 'criaturas já derrotadas por eles (normalmente não muitas). '
                 'Atacam em grandes números, mas de forma lógica, com '
                 'lanceiros flanqueando, arqueiros na retaguarda e demais '
                 'combatentes a frente. Quando em choque de escudos, ou '
                 'distâncias muito próximas, usam sua baforada para '
                 'surpreender o inimigo, mas preferem lutar com suas armas.\n'
                 '\n'
                 '  * **Classe de armadura**: Drakolds possuem CA 12 ou 14 '
                 'quando usam armadura de couro.\n'
                 '\n'
                 '  * **Baforada**: Drakolds podem usar uma forma primitiva de '
                 'baforada, semelhante à de alguns dragões. Este uso não tem '
                 'limitações, e se apresenta como uma pequena explosão de fogo '
                 'ou eletricidade.\n'
                 '\n'
                 '  * **Sacrifício**: se conseguirem ficar 1 minuto se '
                 'concentrando, conseguem explodir o próprio corpo ao '
                 'invocarem a baforada.  Causam 2d6+1 em um raio de 3 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Organizados em clãs, os Drakolds vivem em torno de grandes '
                 'dragões, ou ao menos onde acreditam que eles estejam. '
                 'Idolatrando-os como enviados divinos, tomam os dragões como '
                 'grandes líderes que um dia dominarão a todos.\n'
                 '\n'
                 'Lutam para conquistar territórios de acordo com o que seu '
                 'líder xamã lhes ordena, visando sempre expandir os '
                 'territórios que acreditam ser do dragão escolhido como '
                 'Protetor (mesmo que este não saiba disso).\n'
                 '\n'
                 'Seu compromisso com a causa é tão grande que os Drakolds '
                 'possuem a habilidade de se sacrificar em nome do dragão que '
                 'juraram servir por meio de uma autoexplosão.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Sopa de pulmão de Drakold, além de repugnante, pode conceder '
                 'uma baforada de fogo ou eletricidade, causando 1d2 de dano.',
  'dv': '1',
  'dv_bonus': '+1',
  'encounters': '4d4',
  'encounters_lair': '3d10',
  'flavor': 'Primitivos, vivem próximos a regiões onde dragões habitam. Atacam '
            'para defender seu território, lutando até o fim.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 62}],
  'habitats': ['qualquer'],
  'id': 'drakold-xama',
  'jp': '5',
  'mo': 12,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Drakold Xamã',
  'parent_monster_url': 'https://olddragon.com.br/monstros/drakold.json',
  'picture': 'https://public.olddragon.com.br/3i24ufyxmm7agrjb70wh78210s6t',
  'pv': '6',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/s2u85gml72xo8ocfgzp4pfu7oll6',
  'treasure': 'q',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/drakold-xama.json',
  'variant': True,
  'variant_modifications': ['Magia como Clérigo de 1º nível.'],
  'xp': '35'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide_monstruoso',
  'flavor': 'Espíritos pacíficos da areia, tímidos e desconfiados.  '
            'Manifestam-se como belas humanoides.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 64}],
  'habitats': ['desertos'],
  'id': 'driade-das-dunas',
  'name': 'Dríade das Dunas',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/driade-das-dunas.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 5,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4 + Veneno',
               'description': 'Ferrão',
               'text': '1 × Ferrão +5 (1d4 + Veneno)',
               'times': 1,
               'weapon': False},
              {'ba': 7,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Arco',
               'text': '1 × Arco +7 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'besta',
  'description': 'Essas criaturas amaldiçoadas lembram elfos deformados da '
                 'cintura para cima, com o resto do corpo o de uma gigantesca '
                 'aranha negra.\n'
                 '\n'
                 'As vítimas da maldição, são Drows machos que falham em '
                 'missões de Cultistas de Arak-Takna ou como punidos por '
                 'pecados ou trições.\n'
                 '\n'
                 '**Som**: passos rítmicos, baixos e abafados.\n'
                 '\n'
                 '**Odor**: ocre levemente ácido.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Por meio de suas habilidades mágicas, criam armadilhas, '
                 'barreiras e proteções antes de lutar.  Costumam ser usados '
                 'como frente de batalha pelos Drows.\n'
                 '\n'
                 '  * **Infravisão**: 20 metros\n'
                 '\n'
                 '  * **Veneno**: o ferrão perfurante do Drider inocula Veneno '
                 'Paralisante. Uma JPC evita qualquer efeito deste veneno. Uma '
                 'falha no teste causa a perda de 1d6 pontos de Destreza por '
                 'turno até que o valor chegue a 3.\n'
                 '\n'
                 '  * **Magias**: um Drider pode conjurar magias como se fosse '
                 'um sacerdote de 6º nível.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Drider fica completamente cego '
                 'quando exposto a luz do sol, além de perder um ponto de '
                 'Constituição a cada hora de exposição ao sol.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Estes seres amaldiçoados são estéreis, criados por meio de '
                 'horríveis rituais macabros que transformam Drows machos '
                 'nesta visão deturpada de aracnídeo.\n'
                 '\n'
                 'Considerados párias, vivem como escravos dos Drows, '
                 'servindo-lhes como guerreiros.\n'
                 '\n'
                 'Apesar de não se comunicarem verbalmente, apresentam usam '
                 'alguns sinais de cultura própria por meio de pinturas '
                 'corporais e escarificações tribais.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Sua vesícula venenosa, onde o veneno é guardado dentro do '
                 'ferrão, é muito procurada por assassinos e outras criaturas '
                 'caóticas.',
  'dv': '6',
  'dv_bonus': '+6',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Aberrações com torso de homem e corpo de aranha. São os temíveis '
            'soldados amaldiçoados da Arak-Takna.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 63},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'drider',
  'jp': '9',
  'mo': 10,
  'mv': 12,
  'mvc': None,
  'mve': 9,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Drider',
  'picture': 'https://public.olddragon.com.br/gawt4twd93lfsmmzsj78tyvwzbcz',
  'pv': '36',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/i3hhxrdzvfmvyuw7bs9hihnw8znc',
  'treasure': 'q',
  'treasure_lair': 'n',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/drider.json',
  'variant': False,
  'xp': '305'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 6,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Espada longa',
               'text': '1 × Espada longa +6 (1d8+2)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'humanoide',
  'description': 'De cabelos brancos ou prateados, de pele em tons escuros '
                 'variando do azeviche azul ao roxo. Suas armaduras e vestes '
                 'são foscas sem nenhum tipo de brilho, misturando- se '
                 'perfeitamente nas sombras do subterrâneo.\n'
                 '\n'
                 '**Som**: passos.\n'
                 '\n'
                 '**Odor**: cheiro excessivamente doce.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Mestres na fabricação de venenos, costumam usá-los em suas '
                 'armas, especialmente as bestas.  São ótimos combatentes, '
                 'táticos e mortais.\n'
                 '\n'
                 '  * **Classe de armadura**: Elfos Drow possuem CA 12 ou 16 '
                 'quando usam cota de malha.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '  * **Magia Inata**: Drows possuem a habilidade de conjurar, '
                 'uma vez ao dia, a magia Escuridão como um Mago de 2º nível.\n'
                 '\n'
                 '  * **Imunidades**: Drows precisam de apenas 4 horas de '
                 'meditação para descanso, além disso são imunes a magias ou '
                 'efeitos que envolvam sono e a paralisação causada por um '
                 'Ghoul.\n'
                 '\n'
                 '  * **Vulnerabilidade**: sob o sol ou luz forte, todos os '
                 'ataques e JP de um Drow são realizados com ajuste difícil.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Drows vivem em grandes sociedades Matriarcais no '
                 'subterrâneo. São tecnologicamente avançados e vivem sob um '
                 'forte sistemas de castas.\n'
                 '\n'
                 'Escravizam outras raças para que estas lhes sirvam em todos '
                 'os campos da sociedade drow.',
  'dv': '5',
  'dv_bonus': '',
  'encounters': '2d6',
  'encounters_lair': '4d6',
  'flavor': 'Elfos corrompidos dos subterrâneos. Destacam-se pela sociedade '
            'matriarcal e por serem os maiores cultuadores da Arak-Takna.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 70}],
  'habitats': ['subterraneos'],
  'id': 'drow-lider',
  'jp': '8',
  'mo': 11,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Drow Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/elfo-drow.json',
  'picture': 'https://public.olddragon.com.br/uilureekhpmxb4gevnsevwf19y8k',
  'pv': '25',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/8w12ddf8rnb9u1839xttwm2ojic8',
  'treasure': 'q',
  'treasure_lair': 'n',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/drow-lider.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '205'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Maça',
               'text': '1 × Maça +3 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'De cabelos brancos ou prateados, de pele em tons escuros '
                 'variando do azeviche azul ao roxo. Suas armaduras e vestes '
                 'são foscas sem nenhum tipo de brilho, misturando- se '
                 'perfeitamente nas sombras do subterrâneo.\n'
                 '\n'
                 '**Som**: passos.\n'
                 '\n'
                 '**Odor**: cheiro excessivamente doce.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Mestres na fabricação de venenos, costumam usá-los em suas '
                 'armas, especialmente as bestas.  São ótimos combatentes, '
                 'táticos e mortais.\n'
                 '\n'
                 '  * **Classe de armadura**: Elfos Drow possuem CA 12 ou 16 '
                 'quando usam cota de malha.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '  * **Magia Inata**: Drows possuem a habilidade de conjurar, '
                 'uma vez ao dia, a magia Escuridão como um Mago de 2º nível.\n'
                 '\n'
                 '  * **Imunidades**: Drows precisam de apenas 4 horas de '
                 'meditação para descanso, além disso são imunes a magias ou '
                 'efeitos que envolvam sono e a paralisação causada por um '
                 'Ghoul.\n'
                 '\n'
                 '  * **Vulnerabilidade**: sob o sol ou luz forte, todos os '
                 'ataques e JP de um Drow são realizados com ajuste difícil.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Drows vivem em grandes sociedades Matriarcais no '
                 'subterrâneo. São tecnologicamente avançados e vivem sob um '
                 'forte sistemas de castas.\n'
                 '\n'
                 'Escravizam outras raças para que estas lhes sirvam em todos '
                 'os campos da sociedade drow.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '2d6',
  'encounters_lair': '4d6',
  'flavor': 'Elfos corrompidos dos subterrâneos. Destacam-se pela sociedade '
            'matriarcal e por serem os maiores cultuadores da Arak-Takna.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 70}],
  'habitats': ['subterraneos'],
  'id': 'drow-sacerdotisa',
  'jp': '6',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Drow Sacerdotisa',
  'parent_monster_url': 'https://olddragon.com.br/monstros/elfo-drow.json',
  'picture': 'https://public.olddragon.com.br/uilureekhpmxb4gevnsevwf19y8k',
  'pv': '20',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/8w12ddf8rnb9u1839xttwm2ojic8',
  'treasure': 'q',
  'treasure_lair': 'n',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/drow-sacerdotisa.json',
  'variant': True,
  'variant_modifications': ['Magia como Clérigo de 4º nível.'],
  'xp': '175'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 1,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma +1 (Arma)',
               'times': 1,
               'weapon': True}],
  'ca': '14',
  'concept': 'humanoide_monstruoso',
  'description': 'Pequenos e carrancudos, os Duendes vestem roupas '
                 'tradicionais e gorros pontudos, mas se destacam '
                 'principalmente pelas peças que pregam nos outros.\n'
                 '\n'
                 'Também são reconhecidos pela inteligência e pela capacidade '
                 'de manipular seus oponentes para sempre conseguir o que '
                 'desejam.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Um Duende sempre evita ao máximo se engajar em combate '
                 'físico e direto com seus oponentes, fazendo-o apenas em '
                 'último caso.\n'
                 '\n'
                 'Preferem usar sua persuasão para colocar seus inimigos uns '
                 'contra os outros e se safar da maioria das confusões em que '
                 'se metem.\n'
                 '\n'
                 '  * **Faro de ouro**: podem farejar ouro a 1km de '
                 'distância.\n'
                 '\n'
                 '  * **Persuadir**: podem convencer alguém a tomar seu lado '
                 'em uma briga, defendendo-o.  O alvo deve ser bem-sucedido em '
                 'uma JPS para não ser influenciado. Esta habilidade funciona '
                 'como Enfeitiçar Pessoas lançada por um Mago de 10º nível.\n'
                 '\n'
                 '  * **Imunidades**: a magias mentais de manipulação, '
                 'controle ou ilusão, ou demais formas mágicas de interferir '
                 'na mente de seres vivos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Duendes vivem em clãs construídos dentro de árvores e em '
                 'túneis subterrâneos, mas, esporadicamente, podem habitar '
                 'casas antigas e construões rústicas como celeiros ou '
                 'fazendas, fazendo suas tocas dentro das paredes ocas.\n'
                 '\n'
                 'São briguentos e adoram apostar coisas.  Geralmente estão '
                 'alvoroçados, super enérgicos e falantes, dormindo apenas ao '
                 'tomar um copo de água límpida.\n'
                 '\n'
                 'Um Duende parece alimentar-se das confusões e das situações '
                 'que cria para obter vantagens.\n'
                 '\n'
                 'Demonstram não ter qualquer consideração ou respeito por '
                 'nada ou ninguém, além de si mesmos, e se tornam aliados '
                 'apenas de criaturas ordeiras ou neutras, sempre e apenas se '
                 'isso lhe trouxer alguma vantagem implícita.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os chapéus dos Duendes são considerados em algumas '
                 'comunidades um objeto repleto de simbologia e de bom agouro, '
                 'sendo usados como amuletos pelos afortunados que conseguem '
                 'obter um exemplar.',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1d20',
  'flavor': 'Pequenos homenzinhos persuasivos, gananciosos e adoradores de '
            'ouro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 64},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas'],
  'id': 'duende',
  'jp': '6',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Duende',
  'picture': 'https://public.olddragon.com.br/4efp9asytsqxghlgoh4jru6xreyz',
  'pv': '5',
  'size': 'miudo',
  'thumb_picture': 'https://public.olddragon.com.br/fj0ob8zlguevxqwnekq5fwrm6dul',
  'treasure': 'l+t',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/duende.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 11,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Pancada',
               'text': '1 × Pancada +11 (2d8)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'humanoide_monstruoso',
  'description': 'Esta criatura lembra um demônio feito de fogo, retratado em '
                 'algumas culturas como um tipo de guardião.\n'
                 '\n'
                 'Em alguns reinos isolados, são empregados como senhores da '
                 'guerra e comandantes cruéis de exércitos com propósitos '
                 'deturpados.\n'
                 '\n'
                 'Possuem corpos musculosos e de grande compleição física o '
                 'que lhes confere muito orgnulho. Adoram exibir seu físico e '
                 'por isso raramente usam roupas que cubram seu corpo por '
                 'inteiro por pura vaidade.\n'
                 '\n'
                 'Conspiram e tramam uns contra os outros com grande grau de '
                 'inteligência e sagacidade.\n'
                 '\n'
                 'Eles não costumam se importar com os humanos e geralmente '
                 'tentam corromper os indivíduos desta raça que consideram '
                 'mais corruptíveis. Sua arrogância, prepotência e sede pelo '
                 'poder, lhes rendem poucos amigos em qualquer lugar onde '
                 'atuem.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Costumam iniciar um ataque com golpes simples, como socos, '
                 'para atrair os inimigos para próximo de si.\n'
                 '\n'
                 'Ao perceberem que chegou a hora certa, usam sua explosão de '
                 'labaredas para atingir o maior número possível de '
                 'oponentes.\n'
                 '\n'
                 '  * **Imunidades**: um Efreeti é imune ao dano de qualquer '
                 'arma não mágica.\n'
                 '\n'
                 '  * **Magia**: um Efreeti pode lançar magias como se fosse '
                 'um Mago de 3º nível.\n'
                 '\n'
                 '  * **Explosão de Fogo**: o Efreeti pode, uma vez ao dia, '
                 'causar uma explosão de fogo ao seu redor semelhante à magia '
                 'Bola de Fogo.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem no plano elemental do fogo e atendem ao chamado mágico '
                 'de invocadores que os conjuram.  Muitos os confundem com '
                 'gênios, e pagam um alto preço por este equívoco.\n'
                 '\n'
                 'Alguns têm Salamandras ou mesmo Diabretes como bichos de '
                 'estimação.',
  'dv': '10',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Seres mágicos e inteligentes do Plano Elemental do Fogo, com '
            'faces demoníacas e corpos em brasa.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 65},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['extraplanar'],
  'id': 'efreeti',
  'jp': '12',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Efreeti',
  'picture': 'https://public.olddragon.com.br/msw6jjugbshubprxk5rch69bwk0k',
  'pv': '50',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/x615cr2edqz6xof7ebqjdnar1ash',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/efreeti.json',
  'variant': False,
  'xp': '1400'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 8,
               'damage': '4d8',
               'damage_bonus': None,
               'damage_description': '4d8',
               'description': 'Atropelar',
               'text': '1 × Atropelar +8 (4d8)',
               'times': 1,
               'weapon': False},
              {'ba': 10,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4',
               'description': 'Tromba',
               'text': '1 × Tromba +10 (2d4)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Investida**: se ainda não engajado em combate, pode '
                 'usar a manobra de investida para causar o dobro de dano com '
                 'sua tromba.\n'
                 '  * **Carga**: carrega ou puxa até 6.000 moedas ou 3.000 '
                 'moedas e até 3 montadores.\n'
                 '\n',
  'dv': '9',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1d20',
  'flavor': 'Estes animais vivem em áreas florestais e em planícies de clima '
            'quente, sempre em grandes grupos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 17},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas', 'planicies'],
  'id': 'elefante',
  'jp': '11',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Elefante',
  'picture': None,
  'pv': '45',
  'size': 'imenso',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elefante.json',
  'variant': False,
  'xp': '925'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 9,
               'damage': '2d8',
               'damage_bonus': 5,
               'damage_description': '2d8+5',
               'description': 'Pancadas',
               'text': '2 × Pancadas +9 (2d8+5)',
               'times': 2,
               'weapon': False}],
  'ca': '19',
  'concept': 'besta',
  'description': 'Seu corpo é fluído como a água, podendo mutar-se livremente '
                 'conforme a sua vontade e a emoção que deseja mostrar.\n'
                 '\n'
                 'Quando calmos, são esguios e suaves, porém, quando agitados, '
                 'produzem espuma e seus corpos ficam grandes e volumosos, '
                 'como se fossem umagrande onda prestes a quebrar a qualquer '
                 'instante.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Gostam de virar embarcações, tentando afogar os inimigos. '
                 'Como se misturam a grandes oceanos, podem ser alvos difíceis '
                 'em combate contra inimigos inexperientes.\n'
                 '\n'
                 '  * **Dependência**: um Elemental da Água precisa estar, no '
                 'máximo, a 20 metros de distância de uma fonte de água.\n'
                 '\n'
                 '  * **Potencializado**: um ataque realizado a um alvo dentro '
                 'de um corpo de água, submerso ou parcialmente submerso causa '
                 '1d8 de dano adicional.\n'
                 '\n'
                 '  * **Imunidades**: um Elemental da Água é imune ao dano de '
                 'qualquer arma não mágica e a qualquer dano proveniente da '
                 'água, ainda que mágico.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Elemental da Água leva dano '
                 'dobrado de qualquer ataque proveniente de uma fonte de ar.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Selvagens, são responsáveis pela vida e, portanto, se sentem '
                 'no direito de tirá-la sempre que julgarem necessário.\n'
                 '\n'
                 'Adaptam-se ao tempo no qual vivem, e seu temperamento é '
                 'instável (ora calmo, ora tempestuoso).\n'
                 '\n'
                 'Às vezes fazem pactos com feiticeiros, cobrando destes um '
                 'alto preço pelo auxílio.',
  'dv': '7',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Uma grande onda de água revolta, de forma amorfa. Flui para onde '
            'quer ir e assume qualquer forma desejada.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 66},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['extraplanar'],
  'id': 'elemental-da-agua',
  'jp': '11',
  'mo': 12,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': 12,
  'mvo': None,
  'mvv': None,
  'name': 'Elemental da Água',
  'picture': 'https://public.olddragon.com.br/rowui8arkzif4xfyfsey7ptelxdx',
  'pv': '35',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/9i047kppkkh7o4vivq2p684oqkw0',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elemental-da-agua.json',
  'variant': False,
  'xp': '460'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 11,
               'damage': '3d8',
               'damage_bonus': None,
               'damage_description': '3d8',
               'description': 'Pancadas',
               'text': '2 × Pancadas +11 (3d8)',
               'times': 2,
               'weapon': False}],
  'ca': '21',
  'concept': 'besta',
  'description': 'Seu corpo é fluído como a água, podendo mutar-se livremente '
                 'conforme a sua vontade e a emoção que deseja mostrar.\n'
                 '\n'
                 'Quando calmos, são esguios e suaves, porém, quando agitados, '
                 'produzem espuma e seus corpos ficam grandes e volumosos, '
                 'como se fossem umagrande onda prestes a quebrar a qualquer '
                 'instante.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Gostam de virar embarcações, tentando afogar os inimigos. '
                 'Como se misturam a grandes oceanos, podem ser alvos difíceis '
                 'em combate contra inimigos inexperientes.\n'
                 '\n'
                 '  * **Dependência**: um Elemental da Água precisa estar, no '
                 'máximo, a 20 metros de distância de uma fonte de água.\n'
                 '\n'
                 '  * **Potencializado**: um ataque realizado a um alvo dentro '
                 'de um corpo de água, submerso ou parcialmente submerso causa '
                 '1d8 de dano adicional.\n'
                 '\n'
                 '  * **Imunidades**: um Elemental da Água é imune ao dano de '
                 'qualquer arma não mágica e a qualquer dano proveniente da '
                 'água, ainda que mágico.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Elemental da Água leva dano '
                 'dobrado de qualquer ataque proveniente de uma fonte de ar.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Selvagens, são responsáveis pela vida e, portanto, se sentem '
                 'no direito de tirá-la sempre que julgarem necessário.\n'
                 '\n'
                 'Adaptam-se ao tempo no qual vivem, e seu temperamento é '
                 'instável (ora calmo, ora tempestuoso).\n'
                 '\n'
                 'Às vezes fazem pactos com feiticeiros, cobrando destes um '
                 'alto preço pelo auxílio.',
  'dv': '11',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Uma grande onda de água revolta, de forma amorfa. Flui para onde '
            'quer ir e assume qualquer forma desejada.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 66}],
  'habitats': ['extraplanar'],
  'id': 'elemental-da-agua-maior',
  'jp': '12',
  'mo': 10,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': 12,
  'mvo': None,
  'mvv': None,
  'name': 'Elemental da Água Maior',
  'parent_monster_url': 'https://olddragon.com.br/monstros/elemental-da-agua.json',
  'picture': 'https://public.olddragon.com.br/rowui8arkzif4xfyfsey7ptelxdx',
  'pv': '55',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/9i047kppkkh7o4vivq2p684oqkw0',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elemental-da-agua-maior.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '1675'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 5,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Pancadas',
               'text': '2 × Pancadas +5 (1d8)',
               'times': 2,
               'weapon': False}],
  'ca': '15',
  'concept': 'besta',
  'description': 'Seu corpo é fluído como a água, podendo mutar-se livremente '
                 'conforme a sua vontade e a emoção que deseja mostrar.\n'
                 '\n'
                 'Quando calmos, são esguios e suaves, porém, quando agitados, '
                 'produzem espuma e seus corpos ficam grandes e volumosos, '
                 'como se fossem umagrande onda prestes a quebrar a qualquer '
                 'instante.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Gostam de virar embarcações, tentando afogar os inimigos. '
                 'Como se misturam a grandes oceanos, podem ser alvos difíceis '
                 'em combate contra inimigos inexperientes.\n'
                 '\n'
                 '  * **Dependência**: um Elemental da Água precisa estar, no '
                 'máximo, a 20 metros de distância de uma fonte de água.\n'
                 '\n'
                 '  * **Potencializado**: um ataque realizado a um alvo dentro '
                 'de um corpo de água, submerso ou parcialmente submerso causa '
                 '1d8 de dano adicional.\n'
                 '\n'
                 '  * **Imunidades**: um Elemental da Água é imune ao dano de '
                 'qualquer arma não mágica e a qualquer dano proveniente da '
                 'água, ainda que mágico.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Elemental da Água leva dano '
                 'dobrado de qualquer ataque proveniente de uma fonte de ar.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Selvagens, são responsáveis pela vida e, portanto, se sentem '
                 'no direito de tirá-la sempre que julgarem necessário.\n'
                 '\n'
                 'Adaptam-se ao tempo no qual vivem, e seu temperamento é '
                 'instável (ora calmo, ora tempestuoso).\n'
                 '\n'
                 'Às vezes fazem pactos com feiticeiros, cobrando destes um '
                 'alto preço pelo auxílio.',
  'dv': '5',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Uma grande onda de água revolta, de forma amorfa. Flui para onde '
            'quer ir e assume qualquer forma desejada.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 66}],
  'habitats': ['extraplanar'],
  'id': 'elemental-da-agua-menor',
  'jp': '8',
  'mo': 10,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': 12,
  'mvo': None,
  'mvv': None,
  'name': 'Elemental da Água Menor',
  'parent_monster_url': 'https://olddragon.com.br/monstros/elemental-da-agua.json',
  'picture': 'https://public.olddragon.com.br/rowui8arkzif4xfyfsey7ptelxdx',
  'pv': '25',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/9i047kppkkh7o4vivq2p684oqkw0',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elemental-da-agua-menor.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '205'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 9,
               'damage': '2d8',
               'damage_bonus': 5,
               'damage_description': '2d8+5',
               'description': 'Pancadas',
               'text': '2 × Pancadas +9 (2d8+5)',
               'times': 2,
               'weapon': False}],
  'ca': '19',
  'concept': 'besta',
  'description': 'Vagamente humanoide, o Elemental da Terra gosta de se '
                 'mostrar com um misto de pedras e vegetações, com musgos ou '
                 'plantas em seu corpo.\n'
                 '\n'
                 'Seu rosto é mais bem definido do que dos outros elementais, '
                 'mas parece sempre estar com uma expressão “neutra”.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Buscam alvos que estejam no solo, derrubando e soterrando '
                 'aqueles capazes de gerar fogo, mesmo que por meio de '
                 'tochas.\n'
                 '\n'
                 'Seus golpes potentes quebram barreiras defensivas, buscando '
                 'quebrar os ossos de Magos e Clérigos capazes de invocar '
                 'fogo.\n'
                 '\n'
                 '  * **Bloqueio**: um Elemental da Terra não pode ultrapassar '
                 'uma fonte de água mais profunda que sua altura.\n'
                 '\n'
                 '  * **Potencializado**: um ataque realizado a um alvo que '
                 'esteja tocando o solo causa 1d8 de dano adicional.\n'
                 '\n'
                 '  * **Imunidades**: um Elemental da Terra é imune ao dano de '
                 'qualquer arma não mágica e a qualquer dano proveniente da '
                 'terra, ainda que mágico.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Elemental da Terra leva dano '
                 'dobrado de qualquer ataque proveniente de uma fonte de '
                 'fogo.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Estes elementais são sábios, mas muito lentos em suas '
                 'atitudes.\n'
                 '\n'
                 'Décadas podem ser necessárias para tomarem algumas ações. '
                 'São pacientes e calmos, mas podem ser muito perigosos quando '
                 'algo lhes tira da serenidade.\n'
                 '\n'
                 'Possuem qualidades acolhedoras e destrutivas ao mesmo tempo.',
  'dv': '7',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Um grande torrão de terra e pedras que formam uma massa amorfa '
            'levemente humanoide.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 67},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['extraplanar'],
  'id': 'elemental-da-terra',
  'jp': '11',
  'mo': 12,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Elemental da Terra',
  'picture': 'https://public.olddragon.com.br/313chwjny7ymhoy5oycphxzwof9a',
  'pv': '35',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/j2i9g6qfafhumroptpsd7bw5xzni',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elemental-da-terra.json',
  'variant': False,
  'xp': '460'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 11,
               'damage': '3d8',
               'damage_bonus': None,
               'damage_description': '3d8',
               'description': 'Pancadas',
               'text': '2 × Pancadas +11 (3d8)',
               'times': 2,
               'weapon': False}],
  'ca': '21',
  'concept': 'besta',
  'description': 'Vagamente humanoide, o Elemental da Terra gosta de se '
                 'mostrar com um misto de pedras e vegetações, com musgos ou '
                 'plantas em seu corpo.\n'
                 '\n'
                 'Seu rosto é mais bem definido do que dos outros elementais, '
                 'mas parece sempre estar com uma expressão “neutra”.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Buscam alvos que estejam no solo, derrubando e soterrando '
                 'aqueles capazes de gerar fogo, mesmo que por meio de '
                 'tochas.\n'
                 '\n'
                 'Seus golpes potentes quebram barreiras defensivas, buscando '
                 'quebrar os ossos de Magos e Clérigos capazes de invocar '
                 'fogo.\n'
                 '\n'
                 '  * **Bloqueio**: um Elemental da Terra não pode ultrapassar '
                 'uma fonte de água mais profunda que sua altura.\n'
                 '\n'
                 '  * **Potencializado**: um ataque realizado a um alvo que '
                 'esteja tocando o solo causa 1d8 de dano adicional.\n'
                 '\n'
                 '  * **Imunidades**: um Elemental da Terra é imune ao dano de '
                 'qualquer arma não mágica e a qualquer dano proveniente da '
                 'terra, ainda que mágico.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Elemental da Terra leva dano '
                 'dobrado de qualquer ataque proveniente de uma fonte de '
                 'fogo.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Estes elementais são sábios, mas muito lentos em suas '
                 'atitudes.\n'
                 '\n'
                 'Décadas podem ser necessárias para tomarem algumas ações. '
                 'São pacientes e calmos, mas podem ser muito perigosos quando '
                 'algo lhes tira da serenidade.\n'
                 '\n'
                 'Possuem qualidades acolhedoras e destrutivas ao mesmo tempo.',
  'dv': '11',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Um grande torrão de terra e pedras que formam uma massa amorfa '
            'levemente humanoide.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 67}],
  'habitats': ['extraplanar'],
  'id': 'elemental-da-terra-maior',
  'jp': '12',
  'mo': 10,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Elemental da Terra Maior',
  'parent_monster_url': 'https://olddragon.com.br/monstros/elemental-da-terra.json',
  'picture': 'https://public.olddragon.com.br/313chwjny7ymhoy5oycphxzwof9a',
  'pv': '55',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/j2i9g6qfafhumroptpsd7bw5xzni',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elemental-da-terra-maior.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '1675'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 5,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Pancadas',
               'text': '2 × Pancadas +5 (1d8)',
               'times': 2,
               'weapon': False}],
  'ca': '15',
  'concept': 'besta',
  'description': 'Vagamente humanoide, o Elemental da Terra gosta de se '
                 'mostrar com um misto de pedras e vegetações, com musgos ou '
                 'plantas em seu corpo.\n'
                 '\n'
                 'Seu rosto é mais bem definido do que dos outros elementais, '
                 'mas parece sempre estar com uma expressão “neutra”.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Buscam alvos que estejam no solo, derrubando e soterrando '
                 'aqueles capazes de gerar fogo, mesmo que por meio de '
                 'tochas.\n'
                 '\n'
                 'Seus golpes potentes quebram barreiras defensivas, buscando '
                 'quebrar os ossos de Magos e Clérigos capazes de invocar '
                 'fogo.\n'
                 '\n'
                 '  * **Bloqueio**: um Elemental da Terra não pode ultrapassar '
                 'uma fonte de água mais profunda que sua altura.\n'
                 '\n'
                 '  * **Potencializado**: um ataque realizado a um alvo que '
                 'esteja tocando o solo causa 1d8 de dano adicional.\n'
                 '\n'
                 '  * **Imunidades**: um Elemental da Terra é imune ao dano de '
                 'qualquer arma não mágica e a qualquer dano proveniente da '
                 'terra, ainda que mágico.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Elemental da Terra leva dano '
                 'dobrado de qualquer ataque proveniente de uma fonte de '
                 'fogo.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Estes elementais são sábios, mas muito lentos em suas '
                 'atitudes.\n'
                 '\n'
                 'Décadas podem ser necessárias para tomarem algumas ações. '
                 'São pacientes e calmos, mas podem ser muito perigosos quando '
                 'algo lhes tira da serenidade.\n'
                 '\n'
                 'Possuem qualidades acolhedoras e destrutivas ao mesmo tempo.',
  'dv': '5',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Um grande torrão de terra e pedras que formam uma massa amorfa '
            'levemente humanoide.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 67}],
  'habitats': ['extraplanar'],
  'id': 'elemental-da-terra-menor',
  'jp': '8',
  'mo': 10,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Elemental da Terra Menor',
  'parent_monster_url': 'https://olddragon.com.br/monstros/elemental-da-terra.json',
  'picture': 'https://public.olddragon.com.br/313chwjny7ymhoy5oycphxzwof9a',
  'pv': '25',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/j2i9g6qfafhumroptpsd7bw5xzni',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elemental-da-terra-menor.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '205'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Pancada',
               'text': '1 × Pancada +2 (1d8)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'besta',
  'description': 'Uma espécie de chama ambulante, mais ou menos do tamanho de '
                 'uma fogueira de acampamento. São Elementais do Fogo muito '
                 'jovens que só começaram a despertar sua consciência agora. '
                 'Por isso, costumam ser ainda mais imprevisíveis do que suas '
                 'versões adultas.\n'
                 '\n'
                 '**Odor:** cheiro de fumaça.\n'
                 '\n'
                 '**Som:** crepitar de uma fogueira.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Tentam incendiar o que houver de inflamável por perto, sendo '
                 'particularmente atraídos por madeira seca, papel e palha.\n'
                 '\n'
                 '  * **Bloqueio**: um Elemental das Chamas não pode '
                 'ultrapassar uma fonte de água mais profunda que sua altura.\n'
                 '\n'
                 '  * **Potencializado**: um ataque realizado a um alvo '
                 'formado ou ligado ao frio causa 1d8 de dano adicional.\n'
                 '\n'
                 '  * **Imunidades**: um Elemental das Chamas é imune ao dano '
                 'de qualquer arma não mágica e a qualquer dano proveniente de '
                 'fogo, ainda que mágico.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Elemental das Chamas leva dano '
                 'dobrado de qualquer ataque proveniente de uma fonte de '
                 'água.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Irritadiços e eufóricos como Elementais do Fogo, porém quase '
                 'sem mente ou consciência, estes seres caóticos geralmente '
                 'surgem espontaneamente em grandes incêndios e tentam '
                 'consumir tudo o que houver de inflamável ao seu alcance.',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '2d6',
  'flavor': 'Uma chama viva com um leve fio de consciência.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday23.json',
              'page': 19}],
  'habitats': ['subterraneos', 'extraplanar'],
  'id': 'elemental-das-chamas',
  'jp': '5',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Elemental das Chamas',
  'picture': 'https://public.olddragon.com.br/zrxir30gnankikwgu0xbss2i8tvp',
  'pv': '10',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/u98cqho64cusnxfr4bl75iht5t53',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elemental-das-chamas.json',
  'variant': False,
  'xp': '65'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'besta',
  'flavor': 'Gigantescas ondas de água.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 64}],
  'habitats': ['desertos'],
  'id': 'elemental-de-vapor',
  'name': 'Elemental de Vapor',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elemental-de-vapor.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 9,
               'damage': '2d8',
               'damage_bonus': 5,
               'damage_description': '2d8+5',
               'description': 'Pancadas',
               'text': '2 × Pancadas +9 (2d8+5)',
               'times': 2,
               'weapon': False}],
  'ca': '19',
  'concept': 'besta',
  'description': 'Sem forma definida, um Elemental do Ar se manifesta em uma '
                 'pluralidade de contornos, podendo se manifestar de acordo '
                 'com o espaço desejado ocupar.\n'
                 '\n'
                 'Quando calmos, são como uma nuvem amorfa e suave, porém, '
                 'quando agitados, emitem silvos e gemidos como o vento forte '
                 'e seus corpos assumem a cor nuvens negras e carregadas como '
                 'a de uma tempestade.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Elementais do ar tendem a manter os oponentes distantes, '
                 'usando seu vento para derrubá-los e tirar proveito da '
                 'vantagem de posicionamento.\n'
                 '\n'
                 '  * **Redemoinho**: criaturas com 2 DV ou menos precisam '
                 'passar em uma JPD ou serão arremessadas até 1d4+2 metros do '
                 'Elemental do Ar.\n'
                 '\n'
                 '  * **Potencializado**: um ataque realizado a um alvo que '
                 'esteja voando ou levitando causa 1d8 de dano adicional.\n'
                 '\n'
                 '  * **Imunidades**: um Elemental do Ar é imune ao dano de '
                 'qualquer arma não mágica e a qualquer dano proveniente de um '
                 'ataque de ar, ainda que mágico.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Elemental do Ar leva dano '
                 'dobrado de qualquer ataque proveniente de uma fonte de '
                 'terra.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivendo livres nos planos aéreos, estes elementais estão '
                 'ligados à clareza das ideias, sendo invocados muitas vezes '
                 'por Magos e eruditos para ajudarem em questões filosóficas '
                 'ou éticas.\n'
                 '\n'
                 'Seu tamanho, assim como os outros elementais, é proporcional '
                 'à sua ligação com o elemento raiz que lhe dá origem, em sua '
                 'forma mais pura.',
  'dv': '7',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Um grande redemoinho revoltoso, girando de forma amorfa e '
            'cambiante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 68},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['extraplanar'],
  'id': 'elemental-do-ar',
  'jp': '11',
  'mo': 12,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Elemental do Ar',
  'picture': 'https://public.olddragon.com.br/63dxhq91u4l1om7na1f9md8ijzqx',
  'pv': '35',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/fg5n17zh1tdt5el4wxnpbv7mq971',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elemental-do-ar.json',
  'variant': False,
  'xp': '460'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 11,
               'damage': '3d8',
               'damage_bonus': None,
               'damage_description': '3d8',
               'description': 'Pancadas',
               'text': '2 × Pancadas +11 (3d8)',
               'times': 2,
               'weapon': False}],
  'ca': '21',
  'concept': 'besta',
  'description': 'Sem forma definida, um Elemental do Ar se manifesta em uma '
                 'pluralidade de contornos, podendo se manifestar de acordo '
                 'com o espaço desejado ocupar.\n'
                 '\n'
                 'Quando calmos, são como uma nuvem amorfa e suave, porém, '
                 'quando agitados, emitem silvos e gemidos como o vento forte '
                 'e seus corpos assumem a cor nuvens negras e carregadas como '
                 'a de uma tempestade.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Elementais do ar tendem a manter os oponentes distantes, '
                 'usando seu vento para derrubá-los e tirar proveito da '
                 'vantagem de posicionamento.\n'
                 '\n'
                 '  * **Redemoinho**: criaturas com 2 DV ou menos precisam '
                 'passar em uma JPD ou serão arremessadas até 1d4+2 metros do '
                 'Elemental do Ar.\n'
                 '\n'
                 '  * **Potencializado**: um ataque realizado a um alvo que '
                 'esteja voando ou levitando causa 1d8 de dano adicional.\n'
                 '\n'
                 '  * **Imunidades**: um Elemental do Ar é imune ao dano de '
                 'qualquer arma não mágica e a qualquer dano proveniente de um '
                 'ataque de ar, ainda que mágico.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Elemental do Ar leva dano '
                 'dobrado de qualquer ataque proveniente de uma fonte de '
                 'terra.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivendo livres nos planos aéreos, estes elementais estão '
                 'ligados à clareza das ideias, sendo invocados muitas vezes '
                 'por Magos e eruditos para ajudarem em questões filosóficas '
                 'ou éticas.\n'
                 '\n'
                 'Seu tamanho, assim como os outros elementais, é proporcional '
                 'à sua ligação com o elemento raiz que lhe dá origem, em sua '
                 'forma mais pura.',
  'dv': '11',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Um grande redemoinho revoltoso, girando de forma amorfa e '
            'cambiante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 68}],
  'habitats': ['extraplanar'],
  'id': 'elemental-do-ar-maior',
  'jp': '12',
  'mo': 10,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Elemental do Ar Maior',
  'parent_monster_url': 'https://olddragon.com.br/monstros/elemental-do-ar.json',
  'picture': 'https://public.olddragon.com.br/63dxhq91u4l1om7na1f9md8ijzqx',
  'pv': '55',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/fg5n17zh1tdt5el4wxnpbv7mq971',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elemental-do-ar-maior.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '1675'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 5,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Pancadas',
               'text': '2 × Pancadas +5 (1d8)',
               'times': 2,
               'weapon': False}],
  'ca': '15',
  'concept': 'besta',
  'description': 'Sem forma definida, um Elemental do Ar se manifesta em uma '
                 'pluralidade de contornos, podendo se manifestar de acordo '
                 'com o espaço desejado ocupar.\n'
                 '\n'
                 'Quando calmos, são como uma nuvem amorfa e suave, porém, '
                 'quando agitados, emitem silvos e gemidos como o vento forte '
                 'e seus corpos assumem a cor nuvens negras e carregadas como '
                 'a de uma tempestade.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Elementais do ar tendem a manter os oponentes distantes, '
                 'usando seu vento para derrubá-los e tirar proveito da '
                 'vantagem de posicionamento.\n'
                 '\n'
                 '  * **Redemoinho**: criaturas com 2 DV ou menos precisam '
                 'passar em uma JPD ou serão arremessadas até 1d4+2 metros do '
                 'Elemental do Ar.\n'
                 '\n'
                 '  * **Potencializado**: um ataque realizado a um alvo que '
                 'esteja voando ou levitando causa 1d8 de dano adicional.\n'
                 '\n'
                 '  * **Imunidades**: um Elemental do Ar é imune ao dano de '
                 'qualquer arma não mágica e a qualquer dano proveniente de um '
                 'ataque de ar, ainda que mágico.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Elemental do Ar leva dano '
                 'dobrado de qualquer ataque proveniente de uma fonte de '
                 'terra.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivendo livres nos planos aéreos, estes elementais estão '
                 'ligados à clareza das ideias, sendo invocados muitas vezes '
                 'por Magos e eruditos para ajudarem em questões filosóficas '
                 'ou éticas.\n'
                 '\n'
                 'Seu tamanho, assim como os outros elementais, é proporcional '
                 'à sua ligação com o elemento raiz que lhe dá origem, em sua '
                 'forma mais pura.',
  'dv': '5',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Um grande redemoinho revoltoso, girando de forma amorfa e '
            'cambiante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 68}],
  'habitats': ['extraplanar'],
  'id': 'elemental-do-ar-menor',
  'jp': '8',
  'mo': 10,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Elemental do Ar Menor',
  'parent_monster_url': 'https://olddragon.com.br/monstros/elemental-do-ar.json',
  'picture': 'https://public.olddragon.com.br/63dxhq91u4l1om7na1f9md8ijzqx',
  'pv': '25',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/fg5n17zh1tdt5el4wxnpbv7mq971',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elemental-do-ar-menor.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '205'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 9,
               'damage': '2d8',
               'damage_bonus': 5,
               'damage_description': '2d8+5',
               'description': 'Pancadas',
               'text': '2 × Pancadas +9 (2d8+5)',
               'times': 2,
               'weapon': False}],
  'ca': '19',
  'concept': 'besta',
  'description': 'Apesar de não terem forma definida, é possível ver um par de '
                 'olhos bruxuleando constantemente.\n'
                 '\n'
                 'São bem expressivos, moldando seu corpo de acordo com a '
                 'emoção sentida por eles, variando de uma chama lânguida de '
                 'uma vela a até as chamas caóticas de um incêndio '
                 'descontrolado, quando irritados.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Lutam de maneira frenética, muitas vezes ateando fogo nas '
                 'coisas ou até mesmo fechando áreas com paredes de fogo, '
                 'impedindo seus inimigos de escaparem.\n'
                 '\n'
                 '  * **Bloqueio**: um Elemental do Fogo não pode ultrapassar '
                 'uma fonte de água mais profunda que sua altura.\n'
                 '\n'
                 '  * **Potencializado**: um ataque realizado a um alvo '
                 'formado ou ligado ao frio causa 1d8 de dano adicional.\n'
                 '\n'
                 '  * **Imunidades**: um Elemental do Fogo é imune ao dano de '
                 'qualquer arma não mágica e a qualquer dano proveniente de '
                 'fogo, ainda que mágico.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Elemental do Fogo leva dano '
                 'dobrado de qualquer ataque proveniente de uma fonte de '
                 'água.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Entusiasmados e eufóricos, estes elementais sentem prazer em '
                 'provar suas habilidades.\n'
                 '\n'
                 'Quanto mais ligados ao elemento raiz, mais selvagens e '
                 'caóticos. Os mais jovens podem causar incêndios ou mesmo '
                 'atear fogo em pessoas apenas por diversão.',
  'dv': '7',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Uma grande chama de fogo, erguendo-se na forma de uma coluna '
            'amorfa.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 69},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['extraplanar'],
  'id': 'elemental-do-fogo',
  'jp': '11',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Elemental do Fogo',
  'picture': 'https://public.olddragon.com.br/2h2aix9zi4ei5x9e4cw49ysxh7br',
  'pv': '35',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/t6491udkcbrrrxhhma7afe2w5ygt',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elemental-do-fogo.json',
  'variant': False,
  'xp': '460'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 11,
               'damage': '3d8',
               'damage_bonus': None,
               'damage_description': '3d8',
               'description': 'Pancadas',
               'text': '2 × Pancadas +11 (3d8)',
               'times': 2,
               'weapon': False}],
  'ca': '21',
  'concept': 'besta',
  'description': 'Apesar de não terem forma definida, é possível ver um par de '
                 'olhos bruxuleando constantemente.\n'
                 '\n'
                 'São bem expressivos, moldando seu corpo de acordo com a '
                 'emoção sentida por eles, variando de uma chama lânguida de '
                 'uma vela a até as chamas caóticas de um incêndio '
                 'descontrolado, quando irritados.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Lutam de maneira frenética, muitas vezes ateando fogo nas '
                 'coisas ou até mesmo fechando áreas com paredes de fogo, '
                 'impedindo seus inimigos de escaparem.\n'
                 '\n'
                 '  * **Bloqueio**: um Elemental do Fogo não pode ultrapassar '
                 'uma fonte de água mais profunda que sua altura.\n'
                 '\n'
                 '  * **Potencializado**: um ataque realizado a um alvo '
                 'formado ou ligado ao frio causa 1d8 de dano adicional.\n'
                 '\n'
                 '  * **Imunidades**: um Elemental do Fogo é imune ao dano de '
                 'qualquer arma não mágica e a qualquer dano proveniente de '
                 'fogo, ainda que mágico.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Elemental do Fogo leva dano '
                 'dobrado de qualquer ataque proveniente de uma fonte de '
                 'água.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Entusiasmados e eufóricos, estes elementais sentem prazer em '
                 'provar suas habilidades.\n'
                 '\n'
                 'Quanto mais ligados ao elemento raiz, mais selvagens e '
                 'caóticos. Os mais jovens podem causar incêndios ou mesmo '
                 'atear fogo em pessoas apenas por diversão.',
  'dv': '11',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Uma grande chama de fogo, erguendo-se na forma de uma coluna '
            'amorfa.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 69}],
  'habitats': ['extraplanar'],
  'id': 'elemental-do-fogo-maior',
  'jp': '12',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Elemental do Fogo Maior',
  'parent_monster_url': 'https://olddragon.com.br/monstros/elemental-do-fogo.json',
  'picture': 'https://public.olddragon.com.br/2h2aix9zi4ei5x9e4cw49ysxh7br',
  'pv': '55',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/t6491udkcbrrrxhhma7afe2w5ygt',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elemental-do-fogo-maior.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '1675'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 5,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Pancadas',
               'text': '2 × Pancadas +5 (1d8)',
               'times': 2,
               'weapon': False}],
  'ca': '15',
  'concept': 'besta',
  'description': 'Apesar de não terem forma definida, é possível ver um par de '
                 'olhos bruxuleando constantemente.\n'
                 '\n'
                 'São bem expressivos, moldando seu corpo de acordo com a '
                 'emoção sentida por eles, variando de uma chama lânguida de '
                 'uma vela a até as chamas caóticas de um incêndio '
                 'descontrolado, quando irritados.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Lutam de maneira frenética, muitas vezes ateando fogo nas '
                 'coisas ou até mesmo fechando áreas com paredes de fogo, '
                 'impedindo seus inimigos de escaparem.\n'
                 '\n'
                 '  * **Bloqueio**: um Elemental do Fogo não pode ultrapassar '
                 'uma fonte de água mais profunda que sua altura.\n'
                 '\n'
                 '  * **Potencializado**: um ataque realizado a um alvo '
                 'formado ou ligado ao frio causa 1d8 de dano adicional.\n'
                 '\n'
                 '  * **Imunidades**: um Elemental do Fogo é imune ao dano de '
                 'qualquer arma não mágica e a qualquer dano proveniente de '
                 'fogo, ainda que mágico.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Elemental do Fogo leva dano '
                 'dobrado de qualquer ataque proveniente de uma fonte de '
                 'água.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Entusiasmados e eufóricos, estes elementais sentem prazer em '
                 'provar suas habilidades.\n'
                 '\n'
                 'Quanto mais ligados ao elemento raiz, mais selvagens e '
                 'caóticos. Os mais jovens podem causar incêndios ou mesmo '
                 'atear fogo em pessoas apenas por diversão.',
  'dv': '5',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Uma grande chama de fogo, erguendo-se na forma de uma coluna '
            'amorfa.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 69}],
  'habitats': ['extraplanar'],
  'id': 'elemental-do-fogo-menor',
  'jp': '8',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Elemental do Fogo Menor',
  'parent_monster_url': 'https://olddragon.com.br/monstros/elemental-do-fogo.json',
  'picture': 'https://public.olddragon.com.br/2h2aix9zi4ei5x9e4cw49ysxh7br',
  'pv': '25',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/t6491udkcbrrrxhhma7afe2w5ygt',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elemental-do-fogo-menor.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '205'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Cimitarra',
               'text': '1 × Cimitarra +1 (1d6+1)',
               'times': 1,
               'weapon': False},
              {'ba': 1,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Arco longo',
               'text': '1 × Arco longo +1 (1d8+2)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': 'Elfos podem ser encontrados em grupos de batedores que fazem '
                 'a proteção de suas comunidades, sobretudo dentro de '
                 'florestas. Fora deste habitat, podem ser grupos de escolta '
                 'de nobres e diplomatas.\n'
                 '\n'
                 'Encontrados em grupos pequenos de 2d4 indivíduos ou em '
                 'grupos maiores como um acampamento com 2d12 indivíduos.\n'
                 '\n'
                 'Liderança: há 1-2 chances em 1d6 de um Elfo Aventureiro de '
                 '3º Nível estar liderando o grupo em vez de um Elfo Líder.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 15 elfos, um deles será um Elfo '
                 'Líder.\n'
                 '\n'
                 '  * **Imunidades**: sono e paralisação do Ghoul.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '+1',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 185},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'elfo',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Elfo',
  'picture': None,
  'pv': '6',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elfo.json',
  'variant': False,
  'xp': '25'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '1d6',
               'damage_bonus': 4,
               'damage_description': '1d6+4',
               'description': 'Cimitarra',
               'text': '1 × Cimitarra +4 (1d6+4)',
               'times': 1,
               'weapon': False},
              {'ba': 4,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Arco longo',
               'text': '1 × Arco longo +4 (1d8+2)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Elfos podem ser encontrados em grupos de batedores que fazem '
                 'a proteção de suas comunidades, sobretudo dentro de '
                 'florestas. Fora deste habitat, podem ser grupos de escolta '
                 'de nobres e diplomatas.\n'
                 '\n'
                 'Encontrados em grupos pequenos de 2d4 indivíduos ou em '
                 'grupos maiores como um acampamento com 2d12 indivíduos.\n'
                 '\n'
                 'Liderança: há 1-2 chances em 1d6 de um Elfo Aventureiro de '
                 '3º Nível estar liderando o grupo em vez de um Elfo Líder.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 15 elfos, um deles será um Elfo '
                 'Líder.\n'
                 '\n'
                 '  * **Imunidades**: sono e paralisação do Ghoul.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 185},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'elfo-aventureiro',
  'jp': '7',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Elfo Aventureiro',
  'parent_monster_url': 'https://olddragon.com.br/monstros/elfo.json',
  'picture': None,
  'pv': '15',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elfo-aventureiro.json',
  'variant': True,
  'variant_modifications': ['Imunidades: sono e paralisação do Ghoul.',
                            'Infravisão: 18 metros.',
                            'Magias memorizadas: Mísseis Mágicos.'],
  'xp': '155'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Espada longa',
               'text': '1 × Espada longa +3 (1d8)',
               'times': 1,
               'weapon': False},
              {'ba': 3,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Besta de mão',
               'text': '1 × Besta de mão +3 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '12/16',
  'concept': 'humanoide',
  'description': 'De cabelos brancos ou prateados, de pele em tons escuros '
                 'variando do azeviche azul ao roxo. Suas armaduras e vestes '
                 'são foscas sem nenhum tipo de brilho, misturando- se '
                 'perfeitamente nas sombras do subterrâneo.\n'
                 '\n'
                 '**Som**: passos.\n'
                 '\n'
                 '**Odor**: cheiro excessivamente doce.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Mestres na fabricação de venenos, costumam usá-los em suas '
                 'armas, especialmente as bestas.  São ótimos combatentes, '
                 'táticos e mortais.\n'
                 '\n'
                 '  * **Classe de armadura**: Elfos Drow possuem CA 12 ou 16 '
                 'quando usam cota de malha.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '  * **Magia Inata**: Drows possuem a habilidade de conjurar, '
                 'uma vez ao dia, a magia Escuridão como um Mago de 2º nível.\n'
                 '\n'
                 '  * **Imunidades**: Drows precisam de apenas 4 horas de '
                 'meditação para descanso, além disso são imunes a magias ou '
                 'efeitos que envolvam sono e a paralisação causada por um '
                 'Ghoul.\n'
                 '\n'
                 '  * **Vulnerabilidade**: sob o sol ou luz forte, todos os '
                 'ataques e JP de um Drow são realizados com ajuste difícil.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Drows vivem em grandes sociedades Matriarcais no '
                 'subterrâneo. São tecnologicamente avançados e vivem sob um '
                 'forte sistemas de castas.\n'
                 '\n'
                 'Escravizam outras raças para que estas lhes sirvam em todos '
                 'os campos da sociedade drow.',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '2d6',
  'encounters_lair': '4d6',
  'flavor': 'Elfos corrompidos dos subterrâneos. Destacam-se pela sociedade '
            'matriarcal e por serem os maiores cultuadores da Arak-Takna.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 70},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'elfo-drow',
  'jp': '5',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Elfo Drow',
  'picture': 'https://public.olddragon.com.br/uilureekhpmxb4gevnsevwf19y8k',
  'pv': '10',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/8w12ddf8rnb9u1839xttwm2ojic8',
  'treasure': 'q',
  'treasure_lair': 'n',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elfo-drow.json',
  'variant': False,
  'xp': '50'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Arco longo',
               'text': '1 × Arco longo +3 (1d8+2)',
               'times': 1,
               'weapon': False},
              {'ba': 3,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Cimitarra',
               'text': '1 × Cimitarra +3 (1d6+2)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Elfos podem ser encontrados em grupos de batedores que fazem '
                 'a proteção de suas comunidades, sobretudo dentro de '
                 'florestas. Fora deste habitat, podem ser grupos de escolta '
                 'de nobres e diplomatas.\n'
                 '\n'
                 'Encontrados em grupos pequenos de 2d4 indivíduos ou em '
                 'grupos maiores como um acampamento com 2d12 indivíduos.\n'
                 '\n'
                 'Liderança: há 1-2 chances em 1d6 de um Elfo Aventureiro de '
                 '3º Nível estar liderando o grupo em vez de um Elfo Líder.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 15 elfos, um deles será um Elfo '
                 'Líder.\n'
                 '\n'
                 '  * **Imunidades**: sono e paralisação do Ghoul.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '+1',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 185},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'elfo-lider',
  'jp': '6',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Elfo Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/elfo.json',
  'picture': None,
  'pv': '16',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/elfo-lider.json',
  'variant': True,
  'variant_modifications': ['Imunidades: sono e paralisação do Ghoul.',
                            'Infravisão: 18 metros.',
                            'Moral: enquanto o líder estiver em combate, todos '
                            'os elfos fazem o teste de moral com um bônus de '
                            '+1.'],
  'xp': '95'},
 {'access': 'partial',
  'alignment': 'neutro',
  'attacks': [{'ba': 0,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Ataque automático',
               'description': 'Picada',
               'text': '1 × Picada (Ataque automático)',
               'times': 1,
               'weapon': False}],
  'ca': '11',
  'concept': 'inseto',
  'description': '  * **Imunidade**: um enxame é imune aos efeitos de '
                 'encantamentos ou efeitos que tenham como alvo um único '
                 'indivíduo.\n'
                 '\n'
                 '  * **Ataque automático**: um enxame causa dano '
                 'automaticamente a todos dentro de sua nuvem. Se o alvo se '
                 'limitar a evitar as picadas dos insetos e não fazer mais '
                 'nada na rodada, recebe 1 ponto de dano. Se o alvo procurar '
                 'agir sem se importar com os insetos, o dano automático é de '
                 '1d3 pontos de dano.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um enxame recebe o dobro de dano de '
                 'fogo, frio extremo, ataques com gases (fumaças) ou venenos '
                 'em área.\n'
                 '\n'
                 '  * **Moral**: um enxame precisa ser bem-sucedido em um '
                 'teste de moral quando perder metade dos seus pontos de vida. '
                 'Em caso de falha, a nuvem vai se dispersar, procurando fugir '
                 'do local o mais rápido possível.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Nuvens de vários tipos de insetos. Ameaçam qualquer ser '
            'encontrado no caminho.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 16}],
  'habitats': ['planicies', 'colinas', 'florestas'],
  'id': 'enxame-de-abelhas',
  'jp': '5',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Enxame de Abelhas',
  'parent_monster_url': 'https://olddragon.com.br/monstros/enxame-de-insetos.json',
  'pv': '20',
  'size': 'imenso',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/enxame-de-abelhas.json',
  'variant': True,
  'variant_modifications': ['Um grupo de abelhas furiosas que atacam de forma '
                            'indistinta a todos que estão próximos.'],
  'xp': '125'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [],
  'ca': '12',
  'concept': 'inseto',
  'description': 'Estas nuvens podem ser formadas por diversos tipos de '
                 'insetos, aglomerados de forma homogênea (como gafanhotos, '
                 'vespas ou aranhas), ou mais raramente com uma mistura de '
                 'criaturas formando nuvens fatais.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Evitam o combate, a menos que estejam defendendo seu ninho.\n'
                 '\n'
                 'Caso necessário, ordenam ao inconsciente coletivo para '
                 'coordenarem um ataque fatal a seres vivos.\n'
                 '\n'
                 '  * **Imunidade**: um enxame é imune aos efeitos de '
                 'encantamentos ou efeitos que tenham como alvo um único '
                 'indivíduo.\n'
                 '\n'
                 '  * **Ataque automático**: um enxame causa dano '
                 'automaticamente a todos dentro de sua nuvem. Se o alvo se '
                 'limitar a evitar as picadas dos insetos e não fazer mais '
                 'nada na rodada, recebe 1 ponto de dano. Se o alvo procurar '
                 'agir sem se importar com os insetos, o dano automático é de '
                 '1d3 pontos de dano.\n'
                 '\n'
                 '  * **Vulnerabilidade**: um enxame recebe o dobro de dano de '
                 'fogo, frio extremo, ataques com gases (fumaças) ou venenos '
                 'em área.\n'
                 '\n'
                 '  * **Moral**: um enxame precisa ser bem-sucedido em um '
                 'teste de moral quando perder metade dos seus pontos de vida. '
                 'Em caso de falha, a nuvem vai se dispersar, procurando fugir '
                 'do local o mais rápido possível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem ciclos curtos em suas vidas, sendo rapidamente '
                 'substituídos por outros integrantes do mesmo grupo.\n'
                 '\n'
                 'Atacam plantações e lavouras, mas podem atacar o gado ou '
                 'outras criaturas semelhantes.\n'
                 '\n'
                 '## Especial\n'
                 '\n'
                 'Caso seja necessário determinar o tipo de inseto presente na '
                 'nuvem, jogue 1d6: 1-3, gafanhotos; 4, abelhas e vespas; 5, '
                 'besouros; 6, todos os insetos anteriores misturados.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Nuvens de vários tipos de insetos. Ameaçam qualquer ser '
            'encontrado no caminho.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 71},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['planicies', 'colinas', 'florestas'],
  'id': 'enxame-de-insetos',
  'jp': '6',
  'mo': 6,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Enxame de Insetos',
  'picture': 'https://public.olddragon.com.br/gvziok88nd5pjet8mknb05owxhrz',
  'pv': '20',
  'size': 'colossal',
  'thumb_picture': 'https://public.olddragon.com.br/nyxpnnv4x4xiaoc3vgpoqgq7tmgz',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/enxame-de-insetos.json',
  'variant': False,
  'xp': '125'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 0,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Dano por rodada',
               'description': 'Ferrão',
               'text': '1 × Ferrão (Dano por rodada)',
               'times': 1,
               'weapon': False}],
  'ca': '10',
  'concept': 'inseto',
  'description': '\n'
                 '\n'
                 '  * **Dano por rodada**: o Enxame causa dano automático em '
                 'quem estiver na mesma área que ele. Esse dano varia de '
                 'acordo com o estágio da aventura, sendo 1d4 no estágio 1, '
                 '2d4 no estágio 3 e 3d4 no estágio 3.\n'
                 '\n',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '',
  'encounters_lair': '',
  'flavor': 'Um grupo de vespas furiosas que atacam de forma indistinta a '
            'todos que estão próximos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 15}],
  'habitats': ['florestas'],
  'id': 'enxame-de-vespas',
  'jp': '3',
  'mo': 11,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Enxame de Vespas',
  'picture': None,
  'pv': '20',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/enxame-de-vespas.json',
  'variant': False,
  'xp': '35'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Besouros de 90cm de comprimento que se enterram e, às vezes, são '
            'encontrados abaixo do solo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 64}],
  'habitats': ['desertos'],
  'id': 'escaravelho',
  'name': 'Escaravelho',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/escaravelho.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Uma mistura de coruja humanoide e escorpião gigante, semelhante a '
            'um centauro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 65}],
  'habitats': ['desertos'],
  'id': 'escorpiao-coruja',
  'name': 'Escorpião Coruja',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/escorpiao-coruja.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4 + Veneno',
               'description': 'Ferrão',
               'text': '1 × Ferrão +4 (1d4 + Veneno)',
               'times': 1,
               'weapon': False},
              {'ba': 4,
               'damage': '1d10',
               'damage_bonus': None,
               'damage_description': '1d10',
               'description': 'Pinças',
               'text': '2 × Pinças +4 (1d10)',
               'times': 2,
               'weapon': False}],
  'ca': '18',
  'concept': 'inseto',
  'description': '\n'
                 '\n'
                 '  * **Veneno**: causa morte em 1d3+1 turnos em caso de falha '
                 'em uma JPC.\n'
                 '\n',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '1d6',
  'flavor': 'Estes aracnídeos ferozes e encouraçados virem nos desertos e '
            'planícies caçando suas presas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 115},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['desertos', 'planicies'],
  'id': 'escorpiao-gigante',
  'jp': '6',
  'mo': 11,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Escorpião Gigante',
  'picture': 'https://public.olddragon.com.br/lhxd1t0ah72iix5q0rvn3zcay2c4',
  'pv': '20',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/rpxasnvw5mutkwcxwtm9b877ci2s',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/escorpiao-gigante.json',
  'variant': False,
  'xp': '150'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'animal',
  'flavor': 'Aracnídeos tão grandes quanto um cavalo, com pinças e ferrões '
            'mortais. Vagam em cavernas, ruínas e desertos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 65}],
  'habitats': ['desertos'],
  'id': 'escorpiao-gigante-do-deserto',
  'name': 'Escorpião Gigante do Deserto',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/escorpiao-gigante-do-deserto.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'gigante',
  'flavor': 'Escorpiões brancos gigantes. Vivem sob as areias do deserto e '
            'projetam uma luz ofuscante, atacando os incautos de forma '
            'sorrateira. Sua carapaça brilhante como a lua possui valor '
            'inestimável na fabricação de armaduras de qualidade superior e na '
            'joalheria entre a nobreza. Hoje, são raros e extremamente letais.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 65}],
  'habitats': ['desertos'],
  'id': 'escorpiao-lunar',
  'name': 'Escorpião Lunar',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/escorpiao-lunar.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 0,
               'damage': '1d3',
               'damage_bonus': None,
               'damage_description': '1d3',
               'description': 'Soco',
               'text': '1 × Soco (1d3)',
               'times': 1,
               'weapon': False},
              {'ba': 0,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Arma improvisada',
               'text': '1 × Arma improvisada (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '10',
  'concept': 'humanoide',
  'description': 'Piratas são bandidos dos mares que vivem de saques a cidades '
                 'costeiras e a outras embarcações.  Podem viver de crimes e '
                 'do submundo, realizando contrabando, tráfico ou '
                 'escravizações. São famosos pela crueldade e pela forma '
                 'intensa com a qual vivem e gastam o butim de seu trabalho.\n'
                 '\n'
                 'Encontrados: piratas são encontrados em uma quantidade de '
                 'acordo com o tipo de embarcação utilizado. Jogue 1d6 para '
                 'determinar qual a embarcação encontrada: 1-3. Galeão com 40 '
                 'Piratas; 4-5. Trirreme com 20 Piratas; 6. Navio à Vela com '
                 '20 Piratas.\n'
                 '\n'
                 'Escravos Remadores: uma embarcação do tipo Trirreme possui '
                 '150 Escravos Remadores os quais lutarão contra os piratas se '
                 'forem resgatados\n'
                 '\n'
                 'Mapa do Tesouro: há uma chance de 1-3 em 1d6 do tesouro da '
                 'embarcação (A) não estar a bordo, e sim enterrado em um '
                 'esconderijo.  Neste caso, será encontrado na embarcação, um '
                 'mapa com a localização do tesouro.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 10 Piratas, um deles será um '
                 'Pirata Campeão. Além disso, toda embarcação pirata é '
                 'comandada por um Capitão.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 191},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'escravo-remador-pirata',
  'jp': '4',
  'mo': 6,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Escravo Remador (Pirata)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/pirata.json',
  'picture': None,
  'pv': '15',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': 'a',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/escravo-remador-pirata.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '5'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 0,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Especial',
               'description': 'Toque',
               'text': '1 × Toque (Especial)',
               'times': 1,
               'weapon': False}],
  'ca': 'Especial',
  'concept': 'besta',
  'description': 'Esta esfera parece bidimensional, como se fosse um buraco '
                 'negro, com ausência total de brilhos que se move no ar, '
                 'flutuando não mais do que 2 metros de altura.\n'
                 '\n'
                 'Parece ser uma força de destruição sem propósito, um agente '
                 'entrópico do universo que consome, ao acaso, tudo por onde '
                 'passa.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'A Esfera da Aniquilação apenas busca a forma de vida '
                 'inteligente mais próxima, desintegrando tudo o que toca como '
                 'paredes, portas, armas, animais, itens mágicos, etc.\n'
                 '\n'
                 'Tudo que entrar em contato com a esfera é automaticamente '
                 'desintegrado.\n'
                 '\n'
                 '  * **Desintegrar**: tudo o que for tocado pela esfera será '
                 'desintegrado, sem direito a uma Jogada de Proteção.\n'
                 '\n'
                 '  * **Imunidade à magia**: não é afetada por nenhuma magia, '
                 'exceto Portal e Desejo.\n'
                 '\n'
                 '  * **Especial**: não possui nenhuma estatística de combate, '
                 'não possui dados de vida, nem pontos de vida. Não realiza '
                 'testes de ataque nem Jogadas de Proteção.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Ninguém sabe a origem desta misteriosa criatura, nem se ao '
                 'menos é única.\n'
                 '\n'
                 'Dizem que até os deuses a temem e que, apesar de poderem '
                 'controlá-la com alguma dificuldade, não podem destruí-la.\n'
                 '\n'
                 'Quando longe de vida inteligente, permanece inerte e '
                 'adormecida sem emitir sinal de existência, sons, odores ou '
                 'energias.\n'
                 '\n'
                 'A magia Portal pode levá-la a outro lugar, afastando-as em '
                 'segurança, e a magia Desejo, se bem formulada, pode causar '
                 'nela o mesmo efeito, mas sem causar nenhuma espécie de dano '
                 'e obviamente não lhe aprisionar para o local transportado.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Alguns sábios defendem que a Esfera da Aniquilação não seria '
                 'uma forma de vida, e sim um objeto místico gerado por alguma '
                 'ocorrência que tenha criado um buraco na continuidade do '
                 'universo e dos planos.\n'
                 '\n'
                 'No entanto, todas as tentativas de responder a esta pergunta '
                 'resultaram na desintegração de tais sábios.',
  'dv': 'Especial',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Esfera negra. Move-se flutuando lentamente, desintegrando tudo o '
            'que toca.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 72},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'esfera-da-aniquilacao',
  'jp': 'Especial',
  'mo': 12,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 3,
  'name': 'Esfera da Aniquilação',
  'picture': 'https://public.olddragon.com.br/4sutt3e4a4yy4aa9gb40lwx47v3w',
  'pv': 'Especial',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/1tf8rzv4bgq6jzhfs15weh13hlwb',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/esfera-da-aniquilacao.json',
  'variant': False,
  'xp': 'Especial'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 8,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Mordida',
               'text': '1 × Mordida +8 (2d8)',
               'times': 1,
               'weapon': False},
              {'ba': 11,
               'damage': '3d6',
               'damage_bonus': None,
               'damage_description': '3d6',
               'description': 'Garras',
               'text': '2 × Garras +11 (3d6)',
               'times': 2,
               'weapon': False}],
  'ca': '19',
  'concept': 'besta',
  'description': 'Possui o corpo de um grande leão e um rosto humano, de belos '
                 'traços físicos, além de asas poderosas e intimidadoras.\n'
                 '\n'
                 'São seres de extrema inteligência e conhecimento.  Por isso, '
                 'procuram ruínas e locais místicos para viver e atuar como '
                 'guardiãs.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'A Esfinge permite que seus inimigos se aproximem quando '
                 'deseja enfrentá-los, desafiando-os e testando suas '
                 'inteligências.\n'
                 '\n'
                 'Ela confia em suas próprias imunidades naturais e combate os '
                 'inimigos a curta distância. Porém, também pode usar seu '
                 'rugido para afugentar curiosos.\n'
                 '\n'
                 '  * **Rugido**: duas vezes por dia, a Esfinge pode rugir e '
                 'qualquer vítima até 36 metros dela deve ser bem-sucedida em '
                 'uma JPS com uma penalidade de 4 ou fugirá com medo por 1d6 '
                 'turnos.\n'
                 '\n'
                 '  * **Magia**: uma esfigie pode conjurar magias como se '
                 'fosse um Mago de 6º nível.\n'
                 '\n'
                 '  * **Imunidade à magia**: não é afetada por nenhuma magia '
                 'de 1º, 2º e 3º círculos.\n'
                 '\n'
                 '  * **Resistência**: só pode ser atingida por armas de '
                 'prata, armas mágicas +1 ou superiores.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Cultuadas como avatares dos deuses em tempos remotos, hoje '
                 'as Esfinges são encaradas como guardiãs de segredos e '
                 'passagens ocultas, impedindo que certos caminhos e '
                 'informações sejam de livre acesso.\n'
                 '\n'
                 'Solitárias, encontram seu par apenas para acasalar, '
                 'abandonando-os assim quando o filhote atinge a capacidade de '
                 'caça.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Senhores escravocratas usam a imagem da Esfinge como símbolo '
                 'de seu negócio.\n'
                 '\n'
                 'Desta forma, o corpo empalhado de uma Esfinge abatida pode '
                 'ser vendido por altos preços a estes senhores prepotentes e '
                 'orgulhosos de seus malfeitos.',
  'dv': '10',
  'dv_bonus': '+10',
  'encounters': '1d2',
  'encounters_lair': '1d4',
  'flavor': 'Guardiã de caminhos e passagens, esta criatura é uma mistura de '
            'leão com homem e asas totalmente funcionais.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 73},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['planicies', 'colinas', 'desertos'],
  'id': 'esfinge',
  'jp': '11',
  'mo': 10,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 21,
  'name': 'Esfinge',
  'picture': 'https://public.olddragon.com.br/uyx8eu9txh4dz4zo3wglnivb2xj3',
  'pv': '60',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/imc2uw9t9d6iub7b3znpygrdkfr9',
  'treasure': None,
  'treasure_lair': 'e',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/esfinge.json',
  'variant': False,
  'xp': '1325'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 6,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8 + Dreno',
               'description': 'Toque',
               'text': '1 × Toque +6 (1d8 + Dreno)',
               'times': 1,
               'weapon': False}],
  'ca': '18',
  'concept': 'morto_vivo',
  'description': 'Estas criaturas possuem um corpo mesclado entre névoas e '
                 'geralmente usam mantos esfarrapados ou restos incorpóreos de '
                 'armadura.\n'
                 '\n'
                 'Seus olhos sempre brilham com intenso ódio, podendo ser '
                 'avistados até mesmo no escuro.\n'
                 '\n'
                 'São mortos-vivos poderosos que assombram os lugares mais '
                 'desolados e desertos que puderem, odiando toda forma de vida '
                 'e, principalmente, qualquer forma de luz.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Irredutíveis, os Espectros atacam sem estratégias, fazendo '
                 'uso de sua raiva aos seres vivos para destruí-los e sugar '
                 'suas energias.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Imunidades**: além das imunidades comuns aos '
                 'mortos-vivos, Espectros são feridos apenas por magia e armas '
                 'mágicas.\n'
                 '\n'
                 '  * **Dreno**: o ataque de um Espectro, além do dano normal, '
                 'drena 2 níveis do alvo caso este não passe em uma JPC. Um '
                 'alvo que tenha todos os seus níveis drenados por um Espectro '
                 'retorna como um Espectro sob o controle daquele que o '
                 'criou.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar '
                 'Mortos-vivos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Espectros são guerreiros caídos dos mais diversos povos, '
                 'vagando entre as sombras e entre os mundos dos vivos e dos '
                 'mortos.\n'
                 '\n'
                 'Subalternos à criaturas mais poderosas como Aparições, não '
                 'possuem nenhum desejo além o de destruir a vida.',
  'dv': '7',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '1d8',
  'flavor': 'Seres incorpóreos e poderosos. Carregam a alma atormentada para '
            'trazer o mal e o caos para os vivos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 74},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'espectro',
  'jp': '11',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Espectro',
  'picture': 'https://public.olddragon.com.br/ti2h83a4zdz1ow7j90p5o3abmbfe',
  'pv': '35',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/yvhhall6q1hk7cnsl4qn2q3xlqfm',
  'treasure': None,
  'treasure_lair': 'e',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/espectro.json',
  'variant': False,
  'xp': '500'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Assim como Aparições Sombrias, são poderosos humanos que '
            'sucumbiram a forças obscuras, e agora se alimentam do espírito e '
            'da vontade de viver de suas vítimas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 66}],
  'habitats': ['desertos'],
  'id': 'espectro-do-caos',
  'name': 'Espectro do Caos',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/espectro-do-caos.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 30}],
  'habitats': [],
  'id': 'espirito-antigo',
  'name': 'Espírito Antigo',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/espirito-antigo.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 32}],
  'habitats': [],
  'id': 'espirito-antigo-ancestral',
  'name': 'Espírito Antigo Ancestral',
  'parent_monster_url': 'https://olddragon.com.br/monstros/espirito-antigo.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/espirito-antigo-ancestral.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [],
  'ca': '12',
  'concept': 'planta',
  'description': 'Esta criatura é um tipo de fungo flutuante, aparentando ser '
                 'uma versão menor de um Observador. De cor levemente azulada, '
                 'tem o corpo encaroçado e denso.\n'
                 '\n'
                 'Existe uma chance de 1-5 em 1d6 de ser confundido com um '
                 'Observador a qualquer distância superior a 3 metros. Numa '
                 'distância inferior a 3 metros, a chance cai para 1-2 em '
                 '1d6.\n'
                 '\n'
                 '**Som**: escape de ar rítmico e lento.\n'
                 '\n'
                 '**Odor**: enxofre.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Seu objetivo é espalhar seus esporos da melhor forma '
                 'possível, mantendo sua espécie e propagando sua genética, e '
                 'por isso, se jogam inconsequentemente contra todos os '
                 'oponentes que encontram para liberarem os esporos.\n'
                 '\n'
                 '  * **Esporos**: quando um alvo chega a até 6 metros de '
                 'distância de um Esporo de Gás, este lança uma nuvem de '
                 'esporos contagiosos os quais aderem a tudo o que tocam. Cada '
                 'vítima tocada por estes esporos deve ser bem-sucedida em uma '
                 'JPC ou será infectada.  Estes esporos crescem dentro do '
                 'hospedeiro, levando-o a morte em 1d6 dias ao fazer com que '
                 'seu corpo exploda. Após isso, 1d6 novos esporos nascem para '
                 'continuar o ciclo.\n'
                 '\n'
                 '  * **Explosão**: quando um Esporo de Gás é ferido, ele '
                 'causa 6d6 de dano a todos dentro de uma área de 6 metros. '
                 'Cada vítima deve ser bem-sucedida em uma JPD para receber '
                 'metade do dano. Este ataque não espalha esporos nas vítimas '
                 'como um ataque normal faria.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'A vida de um esporo é procriar e multiplicar, não tendo '
                 'qualquer outro objetivo.\n'
                 '\n'
                 'Seu corpo possui um “olho”, que na verdade não enxerga nada, '
                 'sendo apenas um adereço da criatura distrair e enganar seus '
                 'alvos.\n'
                 'Os esporos são cegos, e detectam as vibrações das vítimas '
                 'mesmo no mais leve deslocamento do ar.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Se aprisionados e acondicionados com cuidado, são usados '
                 'como ferramenta de tortura.\n'
                 '\n'
                 'Até o mais resiliente prisioneiro ficará tentado a falar o '
                 'que sabe e o que não sabe ao ser aprisionado junto de uma '
                 'criatura desta dentro da cela.',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Estes fungos em forma de bola de gás flutuam e, pela sua '
            'aparência, são confundidos com Observadores.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 77},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 75},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'esporo-de-gas',
  'jp': '4',
  'mo': 9,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 6,
  'name': 'Esporo de Gás',
  'picture': 'https://public.olddragon.com.br/e4mkh4usad3n09ul8e6xktnpsd1i',
  'pv': '1',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/54tmdexj8uej0jkil4xvp05q0jur',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/esporo-de-gas.json',
  'variant': False,
  'xp': '10'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Morto-vivo sem inteligência. Avança para cima de suas vítimas com '
            'o único intuito de destroçá-las com garras e dentes.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 33}],
  'habitats': ['qualquer'],
  'id': 'esporo-zumbi-fendido',
  'name': 'Esporo-Zumbi Fendido',
  'parent_monster_url': 'https://olddragon.com.br/monstros/zumbi.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/esporo-zumbi-fendido.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Morto-vivo sem inteligência. Avança para cima de suas vítimas com '
            'o único intuito de destroçá-las com garras e dentes.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 31}],
  'habitats': ['qualquer'],
  'id': 'esporo-zumbi-infectado',
  'name': 'Esporo-Zumbi Infectado',
  'parent_monster_url': 'https://olddragon.com.br/monstros/zumbi.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/esporo-zumbi-infectado.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Morto-vivo sem inteligência. Avança para cima de suas vítimas com '
            'o único intuito de destroçá-las com garras e dentes.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 36}],
  'habitats': ['qualquer'],
  'id': 'esporo-zumbi-rei',
  'name': 'Esporo-Zumbi Rei',
  'parent_monster_url': 'https://olddragon.com.br/monstros/zumbi.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/esporo-zumbi-rei.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma +2 (Arma)',
               'times': 1,
               'weapon': True}],
  'ca': '13',
  'concept': 'morto_vivo',
  'description': 'Criados por forças dos planos negativos, os Esqueletos lutam '
                 'instintivamente atacando seus alvos de forma incansável.  '
                 'Esqueletos podem ser criados a partir de qualquer criatura '
                 'viva.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Não se sabe ao certo de onde vem a habilidade de luta de um '
                 'Esqueleto, visto que nem todos foram combatentes quando '
                 'vivos.\n'
                 '\n'
                 'De qualquer forma, por sua falta de medo e de emoções, '
                 'Esqueletos lutam friamente com as armas que lhes foram '
                 'dadas, sejam espadas, lanças ou arcos.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar-se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Corpo de Osso**: armas impactantes causam o dobro de '
                 'dano nos Esqueletos, mas, em contrapartida, armas '
                 'perfurantes causam metade do ano.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar '
                 'Mortos-Vivos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'O motivo de sua existência é servir ao seu criador, seja '
                 'este um necromante ou qualquer outra criatura capaz de '
                 'criá-los. Quando seu criador perde o controle sobre os '
                 'Esqueletos, estes se tornam errantes e sem propósito, a não '
                 'ser matar todos os seres encontrados. Esqueletos geralmente '
                 'estão em grupos, pois não são fortes o suficiente para '
                 'atuarem sozinhos como guardas.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os ossos dos Esqueletos triturados são base de várias poções '
                 'e venenos, além de tornarem os campos inférteis se '
                 'espalhados sobre a terra.',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '3d4',
  'encounters_lair': '3d10',
  'flavor': 'Mortos-vivos normalmente usados como guardiões de locais antigos '
            'e esquecidos. Sem medo, atacam até caírem aos pedaços.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 66},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 78},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 172},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 76},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 12},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday12.json',
              'page': 19},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday16.json',
              'page': 15},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday24.json',
              'page': 19},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/tu2.json',
              'page': 14}],
  'habitats': ['qualquer'],
  'id': 'esqueleto',
  'jp': '6',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Esqueleto',
  'picture': 'https://public.olddragon.com.br/tkskg2j4sowg5uvnv57v40jcu5h2',
  'pv': '5',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/d01ibazu0zbf8i7de2eyw8d17zxt',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/esqueleto.json',
  'variant': False,
  'xp': '15'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Mortos-vivos normalmente usados como guardiões de locais antigos '
            'e esquecidos. Sem medo, atacam até caírem aos pedaços.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 99}],
  'habitats': ['qualquer'],
  'id': 'esqueleto-com-placas',
  'name': 'Esqueleto com Placas',
  'parent_monster_url': 'https://olddragon.com.br/monstros/esqueleto.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/esqueleto-com-placas.json',
  'variant': True},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '2d4',
               'damage_bonus': 2,
               'damage_description': '2d4+2',
               'description': 'Raio Ocular',
               'text': '1 × Raio Ocular +4 (2d4+2)',
               'times': 1,
               'weapon': False},
              {'ba': 4,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Pancadas',
               'text': '2 × Pancadas +4 (1d6+2)',
               'times': 2,
               'weapon': False}],
  'ca': '14',
  'concept': 'morto_vivo',
  'description': '  * **Silencioso**: não produz som algum ao movimentar-se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Corpo de Osso**: armas impactantes causam o dobro de '
                 'dano nos Esqueletos, mas, em contrapartida, armas '
                 'perfurantes causam metade do ano.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar Mortos-Vivos.',
  'dv': '5',
  'dv_bonus': '+2',
  'encounters': '3d4',
  'encounters_lair': '3d10',
  'flavor': 'Mortos-vivos normalmente usados como guardiões de locais antigos '
            'e esquecidos. Sem medo, atacam até caírem aos pedaços.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 19}],
  'habitats': ['qualquer'],
  'id': 'esqueleto-de-aco',
  'jp': '7',
  'mo': 11,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Esqueleto de Aço',
  'parent_monster_url': 'https://olddragon.com.br/monstros/esqueleto.json',
  'pv': '27',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/esqueleto-de-aco.json',
  'variant': True,
  'variant_modifications': ['Um esqueleto metálico feito de aço, que solta '
                            'raios de energia pelos olhos. Ficam aprisionados '
                            'pois atacam a todos quando estão livres.',
                            'Raio Ocular: o raio que sai dos olhos do '
                            'Esqueleto atinge todas as criaturas numa linha '
                            'reta de 9 metros. Se dois personagens estiverem '
                            'em fila e a rolagem de ataque do esqueleto for '
                            'maior que suas CAs, ambos recebem o dano.',
                            'Explosão: ao chegar a zero PV, o corpo do '
                            'esqueleto explode. Personagens num raio de 3 '
                            'metros devem fazer uma JPD para reduzir 2d6 de '
                            'dano. Após a explosão sobra apenas o crânio do '
                            'esqueleto. Trata-se do item mágico Crânio da '
                            'Visão.'],
  'xp': '150'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Raio Ocular',
               'text': '1 × Raio Ocular +2 (1d6+2)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Pancada',
               'text': '1 × Pancada +2 (1d6+2)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'morto_vivo',
  'description': '  * **Silencioso**: não produz som algum ao movimentar-se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Corpo de Osso**: armas impactantes causam o dobro de '
                 'dano nos Esqueletos, mas, em contrapartida, armas '
                 'perfurantes causam metade do ano.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar Mortos-Vivos.',
  'dv': '2',
  'dv_bonus': '+2',
  'encounters': '3d4',
  'encounters_lair': '3d10',
  'flavor': 'Mortos-vivos normalmente usados como guardiões de locais antigos '
            'e esquecidos. Sem medo, atacam até caírem aos pedaços.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 16}],
  'habitats': ['qualquer'],
  'id': 'esqueleto-de-ferro',
  'jp': '5',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Esqueleto de Ferro',
  'parent_monster_url': 'https://olddragon.com.br/monstros/esqueleto.json',
  'pv': '12',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/esqueleto-de-ferro.json',
  'variant': True,
  'variant_modifications': ['Um esqueleto metálico feito de ferro, que solta '
                            'raios de energia pelos olhos. Ficam aprisionados '
                            'pois atacam a todos quando estão livres.',
                            'Raio Ocular: o raio que sai dos olhos do '
                            'Esqueleto atinge todas as criaturas numa linha '
                            'reta de 9 metros. Se dois personagens estiverem '
                            'em fila e a rolagem de ataque do esqueleto for '
                            'maior que suas CAs, ambos recebem o dano.',
                            'Explosão: ao chegar a zero PV, o corpo do '
                            'esqueleto explode. Personagens num raio de 3 '
                            'metros devem fazer uma JPD para reduzir 2d6 de '
                            'dano. Após a explosão sobra apenas o crânio do '
                            'esqueleto. Trata-se do item mágico Crânio da '
                            'Visão.'],
  'xp': '35'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 8,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Pancadas',
               'text': '2 × Pancadas +8 (1d6+2)',
               'times': 2,
               'weapon': False},
              {'ba': 8,
               'damage': '2d6',
               'damage_bonus': 4,
               'damage_description': '2d6+4',
               'description': 'Raios Oculares',
               'text': '2 × Raios Oculares +8 (2d6+4)',
               'times': 2,
               'weapon': False}],
  'ca': '17',
  'concept': 'morto_vivo',
  'description': '  * **Silencioso**: não produz som algum ao movimentar-se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Corpo de Osso**: armas impactantes causam o dobro de '
                 'dano nos Esqueletos, mas, em contrapartida, armas '
                 'perfurantes causam metade do ano.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar Mortos-Vivos.',
  'dv': '9',
  'dv_bonus': '+2',
  'encounters': '3d4',
  'encounters_lair': '3d10',
  'flavor': 'Mortos-vivos normalmente usados como guardiões de locais antigos '
            'e esquecidos. Sem medo, atacam até caírem aos pedaços.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 22}],
  'habitats': ['qualquer'],
  'id': 'esqueleto-de-titanio',
  'jp': '11',
  'mo': 11,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Esqueleto de Titânio',
  'parent_monster_url': 'https://olddragon.com.br/monstros/esqueleto.json',
  'pv': '47',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/esqueleto-de-titanio.json',
  'variant': True,
  'variant_modifications': ['Um esqueleto metálico feito de titânio, que solta '
                            'raios de energia pelos olhos. Ficam aprisionados '
                            'pois atacam a todos quando estão livres.',
                            'Raio Ocular: o raio que sai dos olhos do '
                            'Esqueleto atinge todas as criaturas numa linha '
                            'reta de 9 metros. Se dois personagens estiverem '
                            'em fila e a rolagem de ataque do esqueleto for '
                            'maior que suas CAs, ambos recebem o dano.',
                            'Explosão: ao chegar a zero PV, o corpo do '
                            'esqueleto explode. Personagens num raio de 3 '
                            'metros devem fazer uma JPD para reduzir 2d6 de '
                            'dano. Após a explosão sobra apenas o crânio do '
                            'esqueleto. Trata-se do item mágico Crânio da '
                            'Visão.'],
  'xp': '900'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Um ARKHImancista morto. Seu corpo é um conjunto de ossos escuros, '
            'coberto por um manto negro.  O crânio é grande e alongado.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 66}],
  'habitats': ['desertos'],
  'id': 'esqueleto-do-velho-mestre',
  'name': 'Esqueleto do Velho Mestre',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/esqueleto-do-velho-mestre.json',
  'variant': False},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1 + Explosão',
               'description': 'Picareta',
               'text': '1 × Picareta +2 (1d6+1 + Explosão)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'morto_vivo',
  'description': '  * **Silencioso**: não produz som algum ao movimentar-se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Corpo de Osso**: armas impactantes causam o dobro de '
                 'dano nos Esqueletos, mas, em contrapartida, armas '
                 'perfurantes causam metade do ano.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar Mortos-Vivos.',
  'dv': '1',
  'dv_bonus': '+3',
  'encounters': '3d4',
  'encounters_lair': '3d10',
  'flavor': 'Mortos-vivos normalmente usados como guardiões de locais antigos '
            'e esquecidos. Sem medo, atacam até caírem aos pedaços.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday12.json',
              'page': 20}],
  'habitats': ['qualquer'],
  'id': 'esqueleto-explosivo',
  'jp': '6',
  'mo': 9,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Esqueleto Explosivo',
  'parent_monster_url': 'https://olddragon.com.br/monstros/esqueleto.json',
  'pv': '8',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/esqueleto-explosivo.json',
  'variant': True,
  'variant_modifications': ['Explosão: sempre que faz ou recebe um ataque com '
                            'armas de metal, há 3 chances em 1d6 de engatilhar '
                            'uma explosão. Caso ocorra, todos os personagens '
                            'num raio de 3 metros devem fazer uma JPD para '
                            'reduzir 2d6 de dano pela metade, além de evitar '
                            'ficarem cegos. Criaturas cegas fazem rolagens de '
                            'ataque ou que incluam visão como Muito Difícil. '
                            'Ao explodir, o morto-vivo se desintegra, morrendo '
                            'de vez.'],
  'xp': '35'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Espada curta',
               'text': '1 × Espada curta +2 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'morto_vivo',
  'description': '  * **Silencioso**: não produz som algum ao movimentar-se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Corpo de Osso**: armas impactantes causam o dobro de '
                 'dano nos Esqueletos, mas, em contrapartida, armas '
                 'perfurantes causam metade do ano.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar Mortos-Vivos.',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '3d4',
  'encounters_lair': '3d10',
  'flavor': 'Mortos-vivos normalmente usados como guardiões de locais antigos '
            'e esquecidos. Sem medo, atacam até caírem aos pedaços.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday24.json',
              'page': 19}],
  'habitats': ['qualquer'],
  'id': 'esqueleto-guardiao',
  'jp': '6',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Esqueleto Guardião',
  'parent_monster_url': 'https://olddragon.com.br/monstros/esqueleto.json',
  'pv': '5',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/esqueleto-guardiao.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 0,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Efeito',
               'description': 'Empurrar',
               'text': '1 × Empurrar (Efeito)',
               'times': 1,
               'weapon': False},
              {'ba': 3,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Sabre',
               'text': '1 × Sabre +3 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'morto_vivo',
  'description': '\n'
                 '\n'
                 '  * **Empurrar**: acostumado a se equilibrar nos movimentos '
                 'do navios, o Esqueleto Marinheiro empurra o alvo para '
                 'forçá-lo cair no chão ou na água. O alvo deve ser '
                 'bem-sucedido em uma JPD ou é derrubado ao chão. Se estiver '
                 'sobre um barco e houver água atrás, o alvo cai na água.\n'
                 '  * **Silencioso**: não produz som algum ao movimentar-se e '
                 'se mantém silencioso até atacar.\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '  * **Corpo de Osso**: armas impactantes causam o dobro de '
                 'dano nos Esqueletos, mas, em contrapartida, armas '
                 'perfurantes causam metade do ano.\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar '
                 'Mortos-Vivos.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '',
  'encounters': None,
  'encounters_lair': None,
  'flavor': 'Um esqueleto morto-vivo do que um dia foi um marinheiro. Guarda '
            'em seus ossos memórias dos tempos em vida.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday16.json',
              'page': 19}],
  'habitats': ['qualquer'],
  'id': 'esqueleto-marinheiro',
  'jp': '6',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Esqueleto Marinheiro',
  'picture': None,
  'pv': '15',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/esqueleto-marinheiro.json',
  'variant': False,
  'xp': '45'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 6,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Sabre',
               'text': '2 × Sabre +6 (1d8+2)',
               'times': 2,
               'weapon': False},
              {'ba': 0,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Efeito',
               'description': 'Empurrar',
               'text': '1 × Empurrar (Efeito)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'morto_vivo',
  'description': '\n'
                 '\n'
                 '  * **Empurrar**: acostumado a se equilibrar nos movimentos '
                 'do navios, o Esqueleto Pirata empurra o alvo para forçá-lo '
                 'cair no chão ou na água. O alvo deve ser bem-sucedido em uma '
                 'JPD ou é derrubado ao chão. Se estiver sobre um barco e '
                 'houver água atrás, o alvo cai na água.\n'
                 '  * **Ganância Pirata**: se o Esqueleto Pirata perceber que '
                 'um alvo carrega ou veste algo aparentemente valioso, ele o '
                 'atacará prioritariamente. Todos os seus testes contra esse '
                 'alvo são realizados como um teste Fácil.\n'
                 '  * **Silencioso**: não produz som algum ao movimentar-se e '
                 'se mantém silencioso até atacar.\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '  * **Corpo de Osso**: armas impactantes causam o dobro de '
                 'dano nos Esqueletos, mas, em contrapartida, armas '
                 'perfurantes causam metade do ano.\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar '
                 'Mortos-Vivos.\n'
                 '\n',
  'dv': '7',
  'dv_bonus': '',
  'encounters': None,
  'encounters_lair': None,
  'flavor': 'Um esqueleto morto-vivo do que um dia foi um pirata. Guarda em '
            'seus ossos memórias dos tempos em vida.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday16.json',
              'page': 23}],
  'habitats': ['qualquer'],
  'id': 'esqueleto-pirata',
  'jp': '8',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Esqueleto Pirata',
  'picture': None,
  'pv': '35',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/esqueleto-pirata.json',
  'variant': False,
  'xp': '420'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Espada curta',
               'text': '1 × Espada curta +2 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'morto_vivo',
  'description': '  * **Silencioso**: não produz som algum ao movimentar-se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Corpo de Osso**: armas impactantes causam o dobro de '
                 'dano nos Esqueletos, mas, em contrapartida, armas '
                 'perfurantes causam metade do ano.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar Mortos-Vivos.',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '3d4',
  'encounters_lair': '3d10',
  'flavor': 'Mortos-vivos normalmente usados como guardiões de locais antigos '
            'e esquecidos. Sem medo, atacam até caírem aos pedaços.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/tu2.json',
              'page': 42}],
  'habitats': ['qualquer'],
  'id': 'esqueleto-sibilante',
  'jp': '4',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Esqueleto Sibilante',
  'parent_monster_url': 'https://olddragon.com.br/monstros/esqueleto.json',
  'pv': '5',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/esqueleto-sibilante.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 11,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Cauda',
               'text': '1 × Cauda +11 (2d8)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '10',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1d4',
  'flavor': 'Lagartos quadrúpedes, estes herbívoros são conhecidos pelas '
            'placas no dorso e o rabo repleto de espinhos ósseos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 42},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': [],
  'id': 'estegossauro',
  'jp': '11',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Estegossauro',
  'picture': 'https://public.olddragon.com.br/t922r3dewxed8aytk0pxtvidm1r9',
  'pv': '50',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/9ocgr8tqzx5ma3wlaliei4jswq7r',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/estegossauro.json',
  'variant': False,
  'xp': '1250'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 12,
               'damage': '2d4',
               'damage_bonus': 2,
               'damage_description': '2d4+2',
               'description': 'Pancadas',
               'text': '2 × Pancadas +12 (2d4+2)',
               'times': 2,
               'weapon': False},
              {'ba': 11,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Clavas gigantes',
               'text': '2 × Clavas gigantes +11 (2d6)',
               'times': 2,
               'weapon': False}],
  'ca': '18',
  'concept': 'gigante',
  'description': 'Todas as duas cabeças de um Ettin parecem com uma mistura de '
                 'homem pre-histórico com a de um símio, mas com aspecto '
                 'tosco, às vezes cadavérico e com dentes pontiagudos e '
                 'serrilhados.\n'
                 '\n'
                 'Seu corpo é musculoso e de pele branca, quase albina, que '
                 'cobrem com farrapos sujos e malcheirosos de peles e de couro '
                 'extraídos de suas próprias vítimas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam de sua habilidade de enxergar no escuro proporcionada '
                 'pela infravisão para realizarem emboscadas simples contra '
                 'seus inimigos.\n'
                 '\n'
                 'Às vezes capturam outros humanoides para servirem de isca, '
                 'atacando então de surpresa os grupos que se aproximam.\n'
                 '\n'
                 '  * **Duas Cabeças**: por terem duas cabeças estão sempre '
                 'atentos. O teste de surpresa é realizado com 1d10 e são '
                 'surpreendidos apenas com um resultado de 1 em 1d10.\n'
                 '\n'
                 '  * **Golpe Potente**: se conseguir causar, com uma pancada '
                 'ou arma, uma quantidade de dano superior a força do alvo, '
                 'este é arremessado 1d4 metros para trás.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Ettins vivem em grupos pequenos. Sua grande fome faz com que '
                 'consumam muita carne e, por isso, formam pequenos bandos '
                 'para não precisarem dividir muito alimento entre os seus.\n'
                 '\n'
                 'Seus filhotes já nascem muito agressivos, mas '
                 'espantosamente, os idosos conseguem ser ainda mais '
                 'agressivos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Cérebros de Ettin são usados para criação de itens mágicos '
                 'ligados à confusão mental.',
  'dv': '10',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1d4',
  'flavor': 'Estes gigantes cruéis de duas cabeças percorrem longas distâncias '
            'atrás da sua iguaria favorita: carne humana!',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 77},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday14.json',
              'page': 20},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['colinas', 'montanhas'],
  'id': 'ettin',
  'jp': '12',
  'mo': 10,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Ettin',
  'picture': 'https://public.olddragon.com.br/hv4663y9oeqrc2atb8lqw2hv3e3f',
  'pv': '50',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/uririwzgtekly4r8d8bd7cifah1y',
  'treasure': 't',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/ettin.json',
  'variant': False,
  'xp': '1250'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Espada curta',
               'text': '1 × Espada curta +1 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': 'Fanáticos são seguidores nômades de filosofias religiosas '
                 'nem sempre compreensíveis. Possuem uma fé cega em seus '
                 'líderes e doutrinas, percorrendo os ermos isolados de toda a '
                 'civilização para cultuar seus etos enquanto desenvolvem uma '
                 'intolerância por outras visões religiosas.\n'
                 '\n'
                 'Vivem em um estado de guerra santa autodeclarada contra os '
                 'hereges, ou seja, pessoas que não possuem a mesma ideologia '
                 'religiosa. Ao capturarem alguém, forçam seus prisioneiros a '
                 'uma conversão a qual, caso negada, pode resultar em '
                 'escravização ou, quase sempre, na morte do prisioneiro.\n'
                 '\n'
                 'Encontrados em comunidades de 1d6+1 x 10 fanáticos, quase '
                 'sempre erguidas em torno de pequenos templos ou altares '
                 'sagrados.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: um acampamento fanático é sempre liderado '
                 'por um Fanático Líder.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 185},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'fanatico',
  'jp': '5',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Fanático',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'p',
  'treasure_lair': 'e',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/fanatico.json',
  'variant': False,
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '2d4',
               'damage_bonus': 1,
               'damage_description': '2d4+1',
               'description': 'Martelo',
               'text': '1 × Martelo +3 (2d4+1)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Fanáticos são seguidores nômades de filosofias religiosas '
                 'nem sempre compreensíveis. Possuem uma fé cega em seus '
                 'líderes e doutrinas, percorrendo os ermos isolados de toda a '
                 'civilização para cultuar seus etos enquanto desenvolvem uma '
                 'intolerância por outras visões religiosas.\n'
                 '\n'
                 'Vivem em um estado de guerra santa autodeclarada contra os '
                 'hereges, ou seja, pessoas que não possuem a mesma ideologia '
                 'religiosa. Ao capturarem alguém, forçam seus prisioneiros a '
                 'uma conversão a qual, caso negada, pode resultar em '
                 'escravização ou, quase sempre, na morte do prisioneiro.\n'
                 '\n'
                 'Encontrados em comunidades de 1d6+1 x 10 fanáticos, quase '
                 'sempre erguidas em torno de pequenos templos ou altares '
                 'sagrados.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: um acampamento fanático é sempre liderado '
                 'por um Fanático Líder.\n'
                 '\n',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 185},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'fanatico-lider',
  'jp': '9',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Fanático Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/fanatico.json',
  'picture': None,
  'pv': '30',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'p',
  'treasure_lair': 'e',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/fanatico-lider.json',
  'variant': True,
  'variant_modifications': ['Magias memorizadas: Escuridão, Convocar Insetos, '
                            'Imobilizar Pessoas, Proteção contra Alinhamento '
                            '(Ordem), Profanar e Santuário. Podem trocar estas '
                            'magias por um Causar Ferimentos.',
                            'Moral: enquanto o líder estiver em combate, todos '
                            'os fanáticos fazem o teste de moral com um bônus '
                            'de +1.'],
  'xp': '305'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 11,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8 + Dreno',
               'description': 'Toque',
               'text': '1 × Toque +11 (1d8 + Dreno)',
               'times': 1,
               'weapon': False}],
  'ca': '21',
  'concept': 'morto_vivo',
  'description': 'São mortos-vivos sem propósito definido, movidos pela raiva '
                 'contra tudo o que é vivo. Sua forma pode variar, sendo a '
                 'mais comum a de uma pessoa translúcida, de vestes rasgadas e '
                 'aparência abatida. Podem, contudo, se mostrar como formas '
                 'vagamente humanoides, mas ainda assim próximas a uma ameba '
                 'gigantesca.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Fantasmas são mortos-vivos raivosos, com diferentes '
                 'propósitos que aterrorizam as vítimas antes de atacar para '
                 'depois drenar sua força vital.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Imunidades**: além das imunidades comuns aos '
                 'mortos-vivos, Fantasmas são feridos apenas por magia e armas '
                 'mágicas.\n'
                 '\n'
                 '  * **Dreno**: o toque de um Fantasma drena 1 ponto de '
                 'Constituição do personagem sem direito a jogada de proteção. '
                 'Um alvo que tenha todos os seus pontos de Constituição '
                 'drenados, ficará permanentemente morto.\n'
                 '\n'
                 '  * **Possessão**: um Fantasma pode entrar dentro do corpo '
                 'de um alvo que falhe em uma JPS, possuindo-o. Um alvo '
                 'possuído é controlado inteiramente pelo fantasma enquanto '
                 'este estiver em seu corpo ou até o fantasma ser removido por '
                 'uma magia Remover Maldição. Enquanto possuir um alvo, o '
                 'Fantasma não pode usar nenhuma de suas habilidades '
                 'sobrenaturais, mas pode atacar usando todas as habilidades e '
                 'estatísticas de combate do alvo possuído.\n'
                 '\n'
                 '  * **Aura Aterrorizante**: qualquer criatura a até 20 '
                 'metros do Fantasma, capaz de ver ou percebê-lo, é afetada '
                 'pela aura de medo do Fantasma que afugenta todos por 1d4 '
                 'turnos.  Uma JPS nega o efeito da Aura Aterrorizante do '
                 'Fantasma. Há 1-3 chances em 1d6 de uma pessoa em fuga deixar '
                 'cair o que estiver carregando. Clérigos com 6 níveis ou mais '
                 'são imunes a Aura Aterrorizante do Fantasma.\n'
                 '\n'
                 '  * **Regeneração**: ao causar dano pelo toque, o Fantasma '
                 'regenera a mesma quantidade de dano causado em pontos de '
                 'vida.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar '
                 'Mortos-Vivos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Fantasmas são fruto de mortes não naturais, ou pelo menos '
                 'muito mal resolvidas. Costumam ser vingativos e, às vezes, '
                 'violentos, atirando coisas nas pessoas como forma de '
                 'zombaria e ameaça. Dizem que só descansam de verdade quando '
                 'seu corpo físico for encontrado, queimado e purificado.\n'
                 '\n'
                 '## Variações\n'
                 '\n'
                 'Os acontecimentos que desencadeiam a criação de um fantasma '
                 'são um enigma e extremamente variados. Algumas ocorrências '
                 'distintas durante e, quase sempre, no fim da vida de uma '
                 'criatura podem desencadear tipos de fantasmas diferentes e '
                 'com propósitos únicos.\n'
                 '\n'
                 '### Assombração\n'
                 '\n'
                 'A Assombração é um fantasma criado e movido pelo senso de '
                 'dever que não se esgota nem com a morte. Normalmente são '
                 'pessoas que quando viviam detinham um grande senso de dever, '
                 'de proteção, de guarda ou de responsabilidade e, mesmo '
                 'mortas, sentem que falharam em sua missão.\n'
                 '\n'
                 'Uma Assombração jamais se afasta mais de 30 metros do local '
                 'onde realizava sua tarefa e busca incessantemente proteger o '
                 'que guardava em vida sobre todas as outras coisas.\n'
                 '\n'
                 'Uma Assombração mantém todas as estatísticas e habilidades '
                 'de um fantasma comum, mas troca sua habilidade de Possessão '
                 'pela habilidade a seguir:\n'
                 '\n'
                 '  * **Esganar**: se a Assombração acertar seu ataque de '
                 'toque no alvo, agarrará a vítima causando, nas próximas '
                 'rodadas, 2d4 pontos de dano por sufocamento enquanto esganar '
                 'o alvo. O dano do esganamento não regenera os pontos de vida '
                 'da Assombração.\n'
                 '\n'
                 '### Poltergeist\n'
                 '\n'
                 'O Poltergeist é um fantasma totalmente incorpóreo e '
                 'invisível, movido por uma imensa sensação de ódio e vingança '
                 'por tudo o que era vivo.\n'
                 '\n'
                 'Perturbado, não consegue descansar. Retorna a um local onde '
                 'teve forte ligação quando vivo para se vingar, pois culpa os '
                 'vivos pela sua condição.\n'
                 '\n'
                 'Um Poltergeist mantém todas as estatísticas e habilidades de '
                 'um fantasma comum, mas troca sua habilidade de Possessão '
                 'pela habilidade a seguir:\n'
                 '\n'
                 '  * **Telecinesia**: um Poltergeist é capaz de manipular '
                 'objetos no plano material, arremessando-os ou simplesmente '
                 'usando- os contra os inimigos. Objetos pequenos arremessados '
                 'causam 1d4 de dano; médios, 1d6; grandes, 1d8; e maiores, '
                 '2d6 de dano.\n'
                 '\n'
                 '### Espírito\n'
                 '\n'
                 'O Espírito é um fantasma totalmente incorpóreo e invisível, '
                 'com uma relação insana e doentia com algum objeto de uso '
                 'próximo de quando era vivo. Pinturas, espadas, casas, joias, '
                 'armaduras, enfim, qualquer objeto que passa a ser a forma do '
                 'Espírito no plano material.\n'
                 '\n'
                 'Um Espírito culpa todos os vivos por estar morto e os inveja '
                 'por ainda poderem estar junto de seus tesouros corpóreos, '
                 'por isso, usa o objeto de sua adoração para se vingar.\n'
                 '\n'
                 'Um Espírito mantém todas as estatísticas e habilidades de um '
                 'fantasma comum, mas troca sua habilidade de Possessão e a '
                 'habilidade de Dreno pela habilidade a seguir:\n'
                 '\n'
                 '  * **Enlouquecer**: o Espírito entra em contato com a '
                 'vítima sussurrando desejos ardilosos em sua mente com o '
                 'objetivo de enlouquecê-la, levando-a a cometer suicídio.  '
                 'Qualquer ser vivo que toque ou possua o objeto possuído pelo '
                 'Espírito por mais de 24 horas, deve realizar uma JPS ou '
                 'perder 1d4 pontos de Sabedoria a cada 24 horas. Um alvo que '
                 'perca assim todos os seus pontos de Sabedoria enlouquece e '
                 'tira a própria vida em um acesso de fúria.',
  'dv': '10',
  'dv_bonus': '+10',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Espíritos incapazes de descansar porque estão presos entre o '
            'Plano Material e o etéreo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 78},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'fantasma',
  'jp': '12',
  'mo': 11,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Fantasma',
  'picture': 'https://public.olddragon.com.br/yuqxevmyujrcgbmly8exr6hk3ypx',
  'pv': '60',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/ltcbmqjbdduarlib4xs7vqw1r2fw',
  'treasure': 's',
  'treasure_lair': 'e',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/fantasma.json',
  'variant': False,
  'xp': '1400'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Mortos-vivos sem propósito definido, movidos pela raiva contra '
            'tudo o que é vivo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 66}],
  'habitats': ['desertos'],
  'id': 'fantasma-meggista',
  'name': 'Fantasma Meggista',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/fantasma-meggista.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Uma alma que, apesar de estar livre para o descanso, não sabe de '
            'sua própria morte. Vive vagando pelos corredores, a fim de '
            'encontrar sua vida pregressa.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 67}],
  'habitats': ['desertos'],
  'id': 'fantasma-perdido',
  'name': 'Fantasma Perdido',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/fantasma-perdido.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Um fantasma aconselhado por Magos das trevas ou ARKHImancistas, '
            'compelido a atacar, a fazer o mal, acumular poder e nunca '
            'desistir.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 67}],
  'habitats': ['desertos'],
  'id': 'fantasma-violento',
  'name': 'Fantasma Violento',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/fantasma-violento.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Tridente',
               'text': '1 × Tridente +2 (1d6+2)',
               'times': 1,
               'weapon': False},
              {'ba': 3,
               'damage': '1d4',
               'damage_bonus': 2,
               'damage_description': '1d4+2',
               'description': 'Chicote',
               'text': '1 × Chicote +3 (1d4+2)',
               'times': 1,
               'weapon': False}],
  'ca': '13/15',
  'concept': 'humanoide',
  'description': 'De pele esverdeada, as Feras do Pântano se parecem com sapos '
                 'humanoides, com longos e finos dedos e uma papada que incha '
                 'quando emitem sua fala levemente próxima a um coaxar.\n'
                 '\n'
                 'Vestem armaduras de couro ou trapos feitos de peles de '
                 'animais pantanosos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Violentas e caóticas, perseguem suas vítimas até onde lhes '
                 'for possível, abatendo-as com crueldade e eficiência.\n'
                 '\n'
                 'Se estiverem em inferioridade numérica, preferirão emboscar '
                 'suas vítimas, aguardando escondidos ou submersos para atacar '
                 'com a máxima vantagem.\n'
                 '\n'
                 '  * **Classe de armadura**: possuem CA 13 ou 15 quando usam '
                 'armadura de couro.\n'
                 '\n'
                 '  * **Emboscar**: podem prender a respiração por até 10 '
                 'minutos sob a água, atacando de surpresa e ganhando a '
                 'iniciativa.\n'
                 '\n'
                 '  * **Saliva paralisante**: 1 vez por combate podem lançar '
                 'um cuspe à 5 metros de distância capaz de paralisar a vítima '
                 'por 1d4-2 rodadas, a menos que esta passe em uma JPD.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Estas criaturas se nominam em seu próprio idioma como '
                 'Bullywugs ou sapos que pensam.  Vivem em tribos primitivas '
                 'onde a violência é uma forma comum de resolver as coisas.\n'
                 '\n'
                 'Costumam se estabelecem em locais úmidos e selvagens, de '
                 'preferência longe de qualquerr assentamento humano, em '
                 'pântanos, charcos e\n'
                 '\n'
                 'São temerosos à magia, com sentimentos mistos entre '
                 'admiração e ódio e isso fará com que ataques conjuradores '
                 'arcanos sempre antes dos demais inimigos.\n'
                 '\n'
                 'Os filhotes são criados e protegidos em lagos, por fêmeas '
                 'guerreiras. Se for preciso, estas guerreiras lutarão até a '
                 'morte para proteger os girinos da tribo.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Sábios costumam comprar as bolsas excretoras de saliva de '
                 'uma Fera do Pântano com o objetivo de estudar seu veneno '
                 'paralisante.',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '4d6',
  'flavor': 'Sapos antropomórficos cruéis. Costumam caçar suas vítimas em '
            'bandos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 80},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao.json',
              'page': 314},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao-od2.json',
              'page': None},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday24.json',
              'page': 15},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['pantanos'],
  'id': 'fera-do-pantano',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': 12,
  'mvo': None,
  'mvv': None,
  'name': 'Fera do Pântano',
  'picture': 'https://public.olddragon.com.br/j1wwh46cov6879bl3vo1n4s3ayed',
  'pv': '10',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/5co0u0fyunh2ezuzlg80xz8esiot',
  'treasure': 'q',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/fera-do-pantano.json',
  'variant': False,
  'xp': '25'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Cimitarra',
               'text': '1 × Cimitarra +1 (1d6+1)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Arco curto',
               'text': '1 × Arco curto +2 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': '  * **Classe de armadura**: possuem CA 13 ou 15 quando usam '
                 'armadura de couro.\n'
                 '\n'
                 '  * **Emboscar**: podem prender a respiração por até 10 '
                 'minutos sob a água, atacando de surpresa e ganhando a '
                 'iniciativa.\n'
                 '\n'
                 '  * **Saliva paralisante**: 1 vez por combate podem lançar '
                 'um cuspe à 5 metros de distância capaz de paralisar a vítima '
                 'por 1d4-2 rodadas, a menos que esta passe em uma JPD.',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '4d6',
  'flavor': 'Sapos antropomórficos cruéis. Costumam caçar suas vítimas em '
            'bandos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday24.json',
              'page': 16}],
  'habitats': ['pantanos'],
  'id': 'fera-do-pantano-tribo-anura',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': 12,
  'mvo': None,
  'mvv': None,
  'name': "Fera do Pântano - Tribo Anur'a",
  'parent_monster_url': 'https://olddragon.com.br/monstros/fera-do-pantano.json',
  'pv': '10',
  'size': 'medio',
  'treasure': 'q',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/fera-do-pantano-tribo-anura.json',
  'variant': True,
  'variant_modifications': ['Tocaia: habituados a ficarem longos períodos em '
                            'tocaia, a chance de atacar o grupo e os '
                            'surpreender é de 1-4 em 1d6.'],
  'xp': '25'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Tridente',
               'text': '1 × Tridente +2 (1d6+2)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': '  * **Classe de armadura**: possuem CA 13 ou 15 quando usam '
                 'armadura de couro.\n'
                 '\n'
                 '  * **Emboscar**: podem prender a respiração por até 10 '
                 'minutos sob a água, atacando de surpresa e ganhando a '
                 'iniciativa.\n'
                 '\n'
                 '  * **Saliva paralisante**: 1 vez por combate podem lançar '
                 'um cuspe à 5 metros de distância capaz de paralisar a vítima '
                 'por 1d4-2 rodadas, a menos que esta passe em uma JPD.',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '4d6',
  'flavor': 'Sapos antropomórficos cruéis. Costumam caçar suas vítimas em '
            'bandos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday24.json',
              'page': 16}],
  'habitats': ['pantanos'],
  'id': 'fera-do-pantano-xama',
  'jp': '7',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': 12,
  'mvo': None,
  'mvv': None,
  'name': 'Fera do Pântano Xamã',
  'parent_monster_url': 'https://olddragon.com.br/monstros/fera-do-pantano.json',
  'pv': '15',
  'size': 'medio',
  'treasure': 'q',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/fera-do-pantano-xama.json',
  'variant': True,
  'variant_modifications': ['Magia como Clérigo de 2º nível',
                            'Transe: enquanto estiver em combate, todos seus '
                            'aliados realizam seus ataques com dificuldade '
                            'Fácil.'],
  'xp': '115'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 6,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4',
               'description': 'Tentáculos',
               'text': '2 × Tentáculos +6 (2d4)',
               'times': 2,
               'weapon': False}],
  'ca': '16',
  'concept': 'besta',
  'description': 'Aparentam ser como uma grande pantera negra, apresentando '
                 'inclusive a graça deste felino, com sua característica '
                 'pelagem escura e lustrosa e os penetrantes e vivazes olhos '
                 'esverdeados\n'
                 '\n'
                 'Seus tentáculos balançam como a cauda de um gato, indicando '
                 'seu estado de humor.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Ferozes e selvagens, estas criaturas odeiam todas as formas '
                 'de vida, reagindo com agressividade, mas com inteligência e '
                 'paciência sempre que encontram um oponente.\n'
                 '\n'
                 'Se necessário, espreitam sua vítima e atacam quando esta '
                 'menos esperar, ampliando suas chances de ser bem-sucedida, '
                 'usando seus tentáculos de maneira a manter seus inimigos à '
                 'maior distância possível.\n'
                 '\n'
                 '  * **Refração**: a fera possui uma habilidade sobrenatural '
                 'de esconder sua real posição, como se estivesse refratando '
                 'sua imagem.  Na prática, uma Fera Refratora está sempre a ao '
                 'menos um metro da posição onde sua imagem demonstra estar. '
                 'Isso causa uma penalidade de 2 nos ataques de todos os seus '
                 'oponentes.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em grupos nos quais os machos vigiam e as fêmeas '
                 'caçam. São territorialistas e podem atacar caso se sintam '
                 'ameaçados, algo bem comum.\n'
                 '\n'
                 'Magos tentam capturar estas criaturas para estudar os '
                 'efeitos de sua refração, aperfeiçoando magias de teleporte e '
                 'deslocamento.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os tentáculos refratores da fera são usados como '
                 'ingredientes de poções ligadas ao teleporte ou que camuflem '
                 'a real localização do usuário.\n'
                 '\n'
                 '## Especial\n'
                 '\n'
                 'Caso seja necessário determinar a verdadeira posição da Fera '
                 'em relação a sua ilusão, jogue 1d6: 1-3, a ilusão está na '
                 'frente da Fera; 4, está à esquerda; 5, está à direita; 6, '
                 'está por trás da posição real da Fera.',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Felino com pelagem negra e dois tentáculos nas costas que '
            'terminam com uma hacha repleta de espinhos!',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 81},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['montanhas'],
  'id': 'fera-refratora',
  'jp': '9',
  'mo': 8,
  'mv': 10,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Fera Refratora',
  'picture': 'https://public.olddragon.com.br/4brpscyw44zhu74whdlqujtp6a1v',
  'pv': '30',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/qvnixkm0a5ae7slk5ihxpa8vzkbn',
  'treasure': None,
  'treasure_lair': 'd',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/fera-refratora.json',
  'variant': False,
  'xp': '305'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 0,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Especial',
               'description': 'Especial',
               'text': '1 × Especial (Especial)',
               'times': 1,
               'weapon': False}],
  'ca': '10',
  'concept': 'besta',
  'description': 'Estes pequenos vermes carnívoros, com aproximadamente 3 cm '
                 'de comprimento, vivem em ambientes úmidos dos subterrâneos '
                 'ou em lodaçais pantanosos alimentando-se de todo tipo de '
                 'criatura viva que encontrem.\n'
                 '\n'
                 'Com exceção da pequena bocarra circular repleta de dentes em '
                 'forma de ganchos escavadores de carne, normalmente são '
                 'confundidos com um verme comum com 1-4 chances em 1d6.\n'
                 '\n'
                 '**Som**: inaudível.\n'
                 '\n'
                 '**Odor**: carne podre.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Não possuem nenhum poder de ataque, mas 5d4 acertam o ataque '
                 'automaticamente, infestando a vítima ao entrarem em contato '
                 'com a pele nua.\n'
                 '\n'
                 'Se houver dúvida se os 5d4 Flagelos tocaram ou não a carne '
                 'nua de uma vítima, determine que existe uma chance de 1-4 em '
                 '1d6 dos Flagelos tocarem uma vítima caso ela possua uma CA '
                 '16 ou menor, e uma chance de 1-3 em 1d6 caso a vítima possua '
                 'uma CA 17 ou maior.\n'
                 '\n'
                 'No primeiro turno após a infestação, os Flagelos podem ser '
                 'mortos se a região por onde entraram for queimada ou '
                 'cauterizada. A queimadura ou cauterização causa 1d6 de dano, '
                 'mas mata imediatamente 2d10 Flagelos.\n'
                 '\n'
                 'Após o fim do 1º turno, os Flagelos estão profundo o '
                 'suficiente para não receberem mais dano do fogo ou da '
                 'cauterização. Deste ponto em diante, apenas uma magia de '
                 'Curar Doenças será capaz de evitar a morte da vítima.\n'
                 '\n'
                 'No final do 3º turno, os Flagelos chegarão ao coração do '
                 'hospedeiro que morrerá imediatamente, sem direito a nenhuma '
                 'JP.\n'
                 '\n'
                 '\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Uma vez que a vítima morre após a infestação, os Flagelos '
                 'usam o corpo sem vida como local apropriado para colocarem '
                 'seus ovos. Quando o ninho estiver concluído e os ovos '
                 'postos, os Flagelos morrem.\n'
                 '\n'
                 'É possível encontrar mortos-vivos, sobretudo zumbis, com '
                 'Flagelos infestando seus cadáveres.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Flagelos da Podridão são comprados no submundo a peso de '
                 'ouro por assassinos. Eles usam essas criaturas como um '
                 'método eficiente de eliminar suas vítimas.',
  'dv': '1',
  'dv_bonus': '-1',
  'encounters': '5d4',
  'encounters_lair': '',
  'flavor': 'Pequenas criaturas nojentas que se alimentam de carne viva, '
            'levando uma morte lenta às suas vítimas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 82},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['pantanos', 'subterraneos'],
  'id': 'flagelo-da-podridao',
  'jp': '3',
  'mo': 6,
  'mv': 1,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Flagelo da Podridão',
  'picture': 'https://public.olddragon.com.br/baq1nxs7rh69751ha9fuizbos86o',
  'pv': '1',
  'size': 'miudo',
  'thumb_picture': 'https://public.olddragon.com.br/lm7f3juc7f8r7lqpkdjpen96mvyr',
  'treasure': 'q',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/flagelo-da-podridao.json',
  'variant': False,
  'xp': '5'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 10,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Toque',
               'text': '1 × Toque +10 (2d8)',
               'times': 1,
               'weapon': False}],
  'ca': '23',
  'concept': 'besta',
  'description': 'Estas esferas aparentemente inofensivas e parecem sumir e '
                 'reaparecer enquanto brilham, levitando sobre ás águas '
                 'paradas dos pântanos e banhados.\n'
                 '\n'
                 'Muitos acham que são um bom sinal, mas, ao se aproximar, é '
                 'possível sentir uma sensação perturbadora de morte.\n'
                 '\n'
                 'O Fogo Fátuo é uma entidade malévola que sobrevive atraindo '
                 'criaturas inocentes para a morte em meio aos perigos '
                 'naturais do local, e alimentando-se das energias liberadas '
                 'por suas lutas contra a morte.\n'
                 '\n'
                 'Eles podem alterar sua própria cor, forma e tamanho até '
                 'certo ponto, sendo facilmente confundidos com lanternas, '
                 'feitiços de luz e fontes semelhantes de iluminação '
                 'artificial.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Ficam parados onde se alimentam de energia do ambiente, '
                 'esperando alguém chegar perto para lançar uma descarga '
                 'elétrica.\n'
                 '\n'
                 'Às vezes se juntam para atacar alvos maiores, mas, como '
                 'criaturas de puro instinto, não formam planos de ataque que '
                 'não lhes pareça uma ação natural de defesa.\n'
                 '\n'
                 '  * **Imunidade**: aos efeitos de encantamentos, de magias '
                 'de Sono e de outros efeitos mentais.  Também são imunes a '
                 'venenos ou ácidos.\n'
                 '\n'
                 '  * **Descarga elétrica**: o Fogo Fátuo pode acumular '
                 'energia elétrica em seu interior. Esta criatura ataca '
                 'procurando tocar suas vítimas enquanto descarrega a energia '
                 'acumulada em forma de um grande choque.\n'
                 '\n'
                 '  * **Invisibilidade**: o Fogo Fátuo pode apagar sua luz '
                 'conscientemente e, assim, ficar invisível a todos por até '
                 '2d4 rodadas. Enquanto apagados, um Fogo Fátuo não é capaz de '
                 'atacar seus inimigos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Apesar de muitos viverem em pântanos, existe uma boa '
                 'quantidade habitando cemitérios.\n'
                 '\n'
                 'Eles parecem atraídos a lugares onde os mortos estão, de '
                 'forma que encontrar um Fogo Fátuo pode ser um mau presságio.',
  'dv': '9',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1d3',
  'flavor': 'Pequenas esferas brilhantes que pulsam luzes amarelas enquanto '
            'dançam sobre as águas paradas dos pântanos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 83},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['pantanos'],
  'id': 'fogo-fatuo',
  'jp': '11',
  'mo': 12,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Fogo Fátuo',
  'picture': 'https://public.olddragon.com.br/88b1w63iiq8gn0gpur6zzqzm369e',
  'pv': '45',
  'size': 'miudo',
  'thumb_picture': 'https://public.olddragon.com.br/43mls2q0s2p88hszbie4754syzqk',
  'treasure': 'u',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/fogo-fatuo.json',
  'variant': False,
  'xp': '1025'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (2d6)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'inseto',
  'description': '\n\n\n\n',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '4d6',
  'flavor': 'Estas formigas gigantes podem ser encontradas em qualquer '
            'ambiente e são perigosas quando famintas.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/ja1.json',
              'page': 38},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 115},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas', 'pantanos', 'planicies', 'subterraneos'],
  'id': 'formiga-gigante',
  'jp': '6',
  'mo': 12,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Formiga Gigante',
  'picture': None,
  'pv': '20',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/formiga-gigante.json',
  'variant': False,
  'xp': '125'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'planta',
  'flavor': 'Amarelo e fétido. É capaz de lançar esporos, envenenar e até '
            'matar. Presente em estruturas de madeira, couro e em construções '
            'de pedra pouco ventiladas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 67}],
  'habitats': ['desertos'],
  'id': 'fungo-amarelo',
  'name': 'Fungo Amarelo',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/fungo-amarelo.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [],
  'ca': '14',
  'concept': 'planta',
  'description': 'Estas criaturas são grandes para um cogumelo normal, medindo '
                 'quase a estatura de um humano, mas a verdadeira '
                 'característica que os diferem dos outros fungos são seus '
                 'pequenos pseudópodes capazes de fazer com que se locomovam, '
                 'ainda que lentamente.\n'
                 '\n'
                 'Os Gritadores podem sentir o movimento do ar ao redor de '
                 'seus corpos e a luz, fazendo com que despertem e emitam seu '
                 'grito característico.\n'
                 '\n'
                 '**Som**: eco de gritos leves e agudos misturados com '
                 'gorgolejos graves e abafados.\n'
                 '\n'
                 '**Odor**: terra molhada, mofo e cerveja derramada por vários '
                 'dias.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Apesar de não causar dano, seu grito é muito alto e pode '
                 'desconcentrar Magos ou qualquer um que necessite estar '
                 'focado. Além disso, alerta todas as criaturas errante que '
                 'estejam a até 36 metros em volta de onde o fungo está.\n'
                 '\n'
                 'O Fungo Gritador não ataca ou causa danos, mas seu grito é '
                 'um catalizador de complicações nos subterrâneos.\n'
                 '\n'
                 'Ao detectar a presença do invasor de seu território, grita e '
                 'acaba, assim, atraindo monstros errantes que estejam nas '
                 'redondezas.\n'
                 '\n'
                 '  * **Grito**: quando incomodado no seu território de raio '
                 'de 3 metros do Fungo por invasão, luz ou ruídos, o Fungo '
                 'Gritador emitirá um som alto e estridente por 1d3+1 rodadas. '
                 'O som é inofensivo para aqueles que o escutam, mas há uma '
                 'chance de 1-3 no d6 de atrair monstros na masmorra.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Mesmo vivendo isolados, criaturas do subterrâneo (as que '
                 'desejam proteger seus covis), cultivam este fungo como '
                 'alarme contra invasores.\n'
                 '\n'
                 'Multiplicam-se com certa facilidade, mas tendem a devorar '
                 'uns aos outros quando o alimento se torna escasso.\n'
                 '\n'
                 'O seu habitat ideal são as cavernas escuras úmidas e quentes '
                 'quando procuram viver próximos aos Fungos Violetas. Seus '
                 'gritos ensurdecedores atraem curiosos que são atacados pelo '
                 'Fungo Violeta. Esta relação quase simbiótica acaba '
                 'favorecendo ambas espécies.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os esporos de um Fungo Gritador são apreciados por '
                 'habitantres do subterrâneo como uma especiaria de sabor '
                 'exótico. Além disso, também são um importante ingrediente '
                 'para a confecção de poções mágicas que envolvam plantas.',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '1d8',
  'encounters_lair': '0',
  'flavor': 'Possuem pequenos pseudópodes e pequenas bocas que emitem som para '
            'assustar e afastar intrusos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 84},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'fungo-gritador',
  'jp': '6',
  'mo': 12,
  'mv': 3,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Fungo Gritador',
  'picture': 'https://public.olddragon.com.br/y7ww29dglkktfwyy70t7jxwvjwle',
  'pv': '15',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/7oz9frs1uychh1ml4se31ygm3cwh',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/fungo-gritador.json',
  'variant': False,
  'xp': '75'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma +3 (Arma)',
               'times': 1,
               'weapon': True}],
  'ca': '13',
  'concept': 'planta',
  'description': 'De altura semelhante a um Kobold, os Fungos Pigmeus parecem '
                 'pequenos homens feitos de planta ou de fungos.  Vivendo em '
                 'sociedades primitivas, protegem os Fungos Violetas, pois é '
                 'deles que se origina.\n'
                 '\n'
                 'Adoram deuses desconhecidos e costumeiramente fazem '
                 'sacrifícios em seus nomes.\n'
                 '\n'
                 '**Som**: passos e farfalhar de palha seca.\n'
                 '\n'
                 '**Odor**: cânhamo e grama recém-cortada.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Suas táticas de combate são simplórias, quase desordenadas. '
                 'Atacam primeiro quem estiver portando tochas ou outras '
                 'fontes de fogo, pois o fogo é sua grande fraqueza.\n'
                 '\n'
                 'Os batedores ficam mesclados com árvores ou paredes cobertas '
                 'de fungos, preferindo levar a informação sobre os invasores '
                 'aos seus companheiros do que atacar o grupo sozinhos.\n'
                 '\n'
                 '  * **Mesclar**: podem mesclar-se em áreas cobertas com '
                 'fungos, tornando-se invisíveis.  São detectados apenas com 1 '
                 'chance em 1d6.\n'
                 '\n'
                 '  * **Esporos**: ao morrerem, explodem numa nuvem de esporos '
                 'atingindo 9 metros de raio.  Alvos devem ser bem-sucedidos '
                 'numa JPC ou ficarão com muita tosse, impedidos de agir por '
                 '1d4 rodadas.\n'
                 '\n'
                 '  * **Inflamáveis**: fogo causa dano dobrado nestas '
                 'criaturas.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Fungos Pigmeus não buscam expandir seus territórios, a menos '
                 'que a colônia tenha crescido o suficiente para ser '
                 'necessário. Não possuem machos ou fêmeas, e nascem por meio '
                 'dos Fungos Violetas.\n'
                 '\n'
                 'A mentalidade deles é quase animal, e adoram grandes '
                 'estátuas de deuses desconhecidos, às vezes adornando-as com '
                 'algumas moedas que guardam após matar algum invasor.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os cabelos do Fungo Pigmeu atingem alto valor de mercado '
                 'como uma exótica erva de fumo com propriedades relaxantes.',
  'dv': '1',
  'dv_bonus': '+1',
  'encounters': '1d12',
  'encounters_lair': '3d10 x 10',
  'flavor': 'Conhecidos como povo bolor, vivem em cavernas úmidas ou florestas '
            'escuras, sempre caçando para sobreviver.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 173},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 85},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['pantanos', 'florestas', 'subterraneos'],
  'id': 'fungo-pigmeu',
  'jp': '5',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Fungo Pigmeu',
  'picture': 'https://public.olddragon.com.br/xohziz3sfo2mbia4ulhts9jygc3i',
  'pv': '6',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/l1wtthorsd6ekrxvo2b2zdm2bo3o',
  'treasure': None,
  'treasure_lair': 'k',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/fungo-pigmeu.json',
  'variant': False,
  'xp': '25'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 5,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2 + Veneno',
               'description': 'Pique pequena',
               'text': '1 × Pique pequena +5 (1d8+2 + Veneno)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'planta',
  'description': 'De altura semelhante a um Kobold, os Fungos Pigmeus parecem '
                 'pequenos homens feitos de planta ou de fungos.  Vivendo em '
                 'sociedades primitivas, protegem os Fungos Violetas, pois é '
                 'deles que se origina.\n'
                 '\n'
                 'Adoram deuses desconhecidos e costumeiramente fazem '
                 'sacrifícios em seus nomes.\n'
                 '\n'
                 '**Som**: passos e farfalhar de palha seca.\n'
                 '\n'
                 '**Odor**: cânhamo e grama recém-cortada.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Suas táticas de combate são simplórias, quase desordenadas. '
                 'Atacam primeiro quem estiver portando tochas ou outras '
                 'fontes de fogo, pois o fogo é sua grande fraqueza.\n'
                 '\n'
                 'Os batedores ficam mesclados com árvores ou paredes cobertas '
                 'de fungos, preferindo levar a informação sobre os invasores '
                 'aos seus companheiros do que atacar o grupo sozinhos.\n'
                 '\n'
                 '  * **Mesclar**: podem mesclar-se em áreas cobertas com '
                 'fungos, tornando-se invisíveis.  São detectados apenas com 1 '
                 'chance em 1d6.\n'
                 '\n'
                 '  * **Esporos**: ao morrerem, explodem numa nuvem de esporos '
                 'atingindo 9 metros de raio.  Alvos devem ser bem-sucedidos '
                 'numa JPC ou ficarão com muita tosse, impedidos de agir por '
                 '1d4 rodadas.\n'
                 '\n'
                 '  * **Inflamáveis**: fogo causa dano dobrado nestas '
                 'criaturas.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Fungos Pigmeus não buscam expandir seus territórios, a menos '
                 'que a colônia tenha crescido o suficiente para ser '
                 'necessário. Não possuem machos ou fêmeas, e nascem por meio '
                 'dos Fungos Violetas.\n'
                 '\n'
                 'A mentalidade deles é quase animal, e adoram grandes '
                 'estátuas de deuses desconhecidos, às vezes adornando-as com '
                 'algumas moedas que guardam após matar algum invasor.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os cabelos do Fungo Pigmeu atingem alto valor de mercado '
                 'como uma exótica erva de fumo com propriedades relaxantes.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1d12',
  'encounters_lair': '3d10 x 10',
  'flavor': 'Conhecidos como povo bolor, vivem em cavernas úmidas ou florestas '
            'escuras, sempre caçando para sobreviver.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 85}],
  'habitats': ['pantanos', 'florestas', 'subterraneos'],
  'id': 'fungo-pigmeu-lider',
  'jp': '6',
  'mo': 10,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Fungo Pigmeu Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/fungo-pigmeu.json',
  'picture': 'https://public.olddragon.com.br/xohziz3sfo2mbia4ulhts9jygc3i',
  'pv': '20',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/l1wtthorsd6ekrxvo2b2zdm2bo3o',
  'treasure': None,
  'treasure_lair': 'k',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/fungo-pigmeu-lider.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '150'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '1d4',
               'damage_bonus': 4,
               'damage_description': '1d4+4',
               'description': 'Tentáculos',
               'text': '4 × Tentáculos +4 (1d4+4)',
               'times': 4,
               'weapon': False}],
  'ca': '16',
  'concept': 'planta',
  'description': 'Medindo aproximadamente 1,5m, os fungos violeta agem por '
                 'instinto, procriando e sobrevivendo.  Encontrados em lugares '
                 'de difícil acesso, capturam presas para gerar novos Fungos '
                 'Pigmeus, que lhes servem de guardiões.\n'
                 '\n'
                 '**Som**: leve rugido como o metal aquecido jogado na água.\n'
                 '\n'
                 '**Odor**: palha mofada misturada com massa de pão '
                 'fermentada.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Seus tentáculos costumam ficar escondidos junto ao tronco, '
                 'fazendo com que pareçam apenas um grande cogumelo inerte.\n'
                 '\n'
                 'Este truque serve para atrair suas presas, atacando- as '
                 'quando estiverem ao alcance.\n'
                 '\n'
                 'Em algumas ocasiões, se fixa ao teto de cavernas ou em '
                 'galhos bem altos, jogando-se em cima dos aventureiros, '
                 'surpreendendo-os.\n'
                 '\n'
                 '  * **Mordida**: se acertar 4 ataques contra o mesmo '
                 'personagem, causará mais 3d4 de dano por mordida. O alvo só '
                 'conseguirá se soltar se receber ajuda externa ou se passar '
                 'em 4 testes de Força consecutivos.\n'
                 '\n'
                 '  * **Inflamáveis**: fogo causa dano dobrado nestas '
                 'criaturas.\n'
                 '\n'
                 '  * **Proliferar**: ao acertar dois ataques de Mordida no '
                 'mesmo alvo, o Fungo Violeta liberará esporos que entrarão no '
                 'corpo da vítima que, por sua vez, morrerá em dois dias após '
                 'dar vida a um Fungo Pigmeu.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'O Fungo Violeta pouco faz em sua vida além de comer e '
                 'procriar. Conseguindo digerir quase toda a matéria orgânica, '
                 'às vezes é possível encontrar pedras preciosas ou objetos '
                 'semelhantes, ao menos quando os Fungos Pigmeus não levam '
                 'estes tesouros para adornar suas estátuas sagradas.\n'
                 '\n'
                 'Vivem em grupos pequenos e esparsos, pois são vorazes com '
                 'seu alimento e não são muito colaborativos entre si.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'O sangue do Fungo Violeta pode ser usado como elemento '
                 'tingidor para tecidos nobres devido à dificuldade de se '
                 'obter tons vivos de violeta.',
  'dv': '2',
  'dv_bonus': '+4',
  'encounters': '1d8',
  'encounters_lair': '1d4',
  'flavor': 'De inteligência primitiva, é capaz de se fixar em superfícies, '
            'caindo de surpresa em aventureiros desavisados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 86},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['pantanos', 'florestas', 'subterraneos'],
  'id': 'fungo-violeta',
  'jp': '5',
  'mo': 10,
  'mv': 3,
  'mvc': None,
  'mve': 1,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Fungo Violeta',
  'picture': 'https://public.olddragon.com.br/clf53fmcajm7dxhmjsmvvvz57qyt',
  'pv': '14',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/z38j1gfmn54xosjeefpbmiqzetdm',
  'treasure': None,
  'treasure_lair': 'i',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/fungo-violeta.json',
  'variant': False,
  'xp': '50'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 5,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Mordida',
               'text': '1 × Mordida +5 (1d6)',
               'times': 1,
               'weapon': False},
              {'ba': 5,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Garras',
               'text': '2 × Garras +5 (1d4)',
               'times': 2,
               'weapon': False}],
  'ca': '16',
  'concept': 'humanoide_monstruoso',
  'description': 'Gárgulas lembram estátuas, carrancas semelhantes a demônios '
                 'de pedra. Suas cores variam nas mesmas tonalidades que as '
                 'pedras mais comuns usadas em construções naquela região.\n'
                 '\n'
                 'São predadores ferozes e de natureza mágica, normalmente '
                 'encontrados em ruínas ou morando em cavernas subterrâneas.\n'
                 '\n'
                 'Vivem em pequenos grupos com outros de sua espécie, '
                 'interessados em encontrar outras criaturas para ferir.\n'
                 '\n'
                 'Animais menores dificilmente valem a pena para esses '
                 'monstros hediondos, que preferem atacar humanos ou outras '
                 'criaturas inteligentes para acumular seus tesouros em seus '
                 'covis.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam de forma surpresa, atirando-se contra os adversários '
                 'e cortando os alvos com suas poderosas garras.\n'
                 '\n'
                 'Destemidas, lutam em grupos inteligentemente cercando suas '
                 'vítimas.\n'
                 '\n'
                 '  * **Surpresa**: pela sua aparência de pedra e sua '
                 'habilidade de ficarem imóveis, uma Gárgula pode surpreender '
                 'seus inimigos com 1-4 chances em 1d6.\n'
                 '\n'
                 '  * **Imunidades**: Gárgulas são feridas apenas por magia e '
                 'armas mágicas.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Criadas por feiticeiros antigos, as Gárgulas vivem em '
                 'pequenos grupos, mas ao escolherem um parceiro, permanecem '
                 'em dupla até terem suas crias.\n'
                 '\n'
                 'Sábias, observam muito do que se passa no mundo, mas não '
                 'costumam compartilhar com os outros.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os ossos macerados das Gárgulas podem ser usados como '
                 'ingrediente de poções envolvendo invulnerabilidades ou '
                 'petrificação.\n'
                 '\n'
                 'Algumas Gárgulas (1-2 chances em 1d6) possuem um coração de '
                 'pedra dentro de seus corpos maciços do qual é possível '
                 'produzir Poções de Voo.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '2d4',
  'flavor': 'Assemelhadas a estátuas e de aparência demoníaca, misturam- se em '
            'construções antigas para atacarem seus inimigos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/ja1.json',
              'page': 41},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 87},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'gargula',
  'jp': '6',
  'mo': 11,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Gárgula',
  'picture': 'https://public.olddragon.com.br/azb98hcnv64mr4fushawllbs2fri',
  'pv': '20',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/wx0u7dq08iam8riif2e6k4hxy0oi',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gargula.json',
  'variant': False,
  'xp': '175'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Garra',
               'text': '1 × Garra +2 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'morto_vivo',
  'description': '\n'
                 '\n'
                 '* **Estrangular**: se uma Garra Mumificada acertar um '
                 'ataque, além do dano, consegue agarrar a vítima. A cada '
                 'rodada a Garra Mumificada estrangulará a vítima, causando '
                 '1d6 de dano adicional, até ser removida.\n'
                 '\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': None,
  'encounters_lair': None,
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/tu2.json',
              'page': 42}],
  'habitats': [],
  'id': 'garra-mumificada',
  'jp': '3',
  'mo': 12,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Garra Mumificada',
  'picture': None,
  'pv': '10',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/garra-mumificada.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 8,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Pancada',
               'text': '1 × Pancada +8 (2d8)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'besta',
  'description': 'Aparentando um misto de humano com elfo, os Gênios são belos '
                 'e carismáticos, usando adornos valiosos.\n'
                 '\n'
                 'Costumam se mostrar com pernas no formato de um pequeno '
                 'tufão, uma vez que são oriundos do Plano Elemental do Ar.\n'
                 '\n'
                 'Às vezes, os gênios são encontrados no plano material e '
                 'muitas vezes são convocados especificamente para realizar '
                 'algum serviço para um poderoso mago ou sacerdote.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam primeiro suas magias e forma de redemoinho para causar '
                 'o máximo de dano em um grande número de oponentes, evitando '
                 'entrar em combate corpo a corpo.\n'
                 '\n'
                 '  * **Imunidades**: um Gênio é imune ao dano de qualquer '
                 'arma não mágica.\n'
                 '\n'
                 '  * **Redemoinho**: um Gênio pode se transformar em um '
                 'enorme redemoinho quantas vezes desejar. Nesta forma, é '
                 'capaz de causar 2d6 de dano a todos que estejam até 3 '
                 'metros.\n'
                 '\n'
                 '  * **Magia**: um Gênio pode lançar as seguintes magias como '
                 'se fosse um Mago de 3º nível: Invisibilidade, Ilusão e Criar '
                 'Alimentos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Muitos acreditam que os Gênios podem conceder desejos, mas '
                 'este é um grande erro que já trouxe ruína a muitas pessoas.\n'
                 '\n'
                 'Isso acontece porque apenas uma pequena parcela dos Gênios '
                 'são capazes de conceder desejos aos seus "mestres".\n'
                 '\n'
                 'Estes Gênios são chamados de Djinni (literalmente gênios '
                 'nobres em seu idioma), e ocupam uma casta superior entre '
                 'todos os Gênios.\n'
                 '\n'
                 'Existe apenas 1 chance em 1d6 de um Gênio encontrado ser um '
                 'Djinni. Ao conceder todos os três desejos, ele desaparecerá, '
                 'retornando ao Plano Elemental do Ar, sem realizar nenhum '
                 'outro serviço ou favor ao seu mestre.',
  'dv': '7',
  'dv_bonus': '+1',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Humanoides do plano elemental do ar. São conhecidos por sua '
            'sagacidade e perspicácia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 88},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['extraplanar'],
  'id': 'genio',
  'jp': '11',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Gênio',
  'picture': 'https://public.olddragon.com.br/nos4h4nj4wybxdzr2z4xs60519gp',
  'pv': '36',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/0uppiia1pid2tlpbjzq3v846o2fw',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/genio.json',
  'variant': False,
  'xp': '460'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Seres altamente mágicos, inteligentes e munidos de livre-arbítrio '
            'oriundos do plano elemental do fogo.  Manifestam-se como um homem '
            'gigante de face demoníaca, com uma aura de calor e fumaça.  '
            'Tornam-se tangíveis através de nuvens de fumaça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 68}],
  'habitats': ['desertos'],
  'id': 'genio-areisco',
  'name': 'Gênio Areísco',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/genio-areisco.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d3',
               'damage_bonus': None,
               'damage_description': '1d3 + Paralisia',
               'description': 'Mordida',
               'text': '1 × Mordida +3 (1d3 + Paralisia)',
               'times': 1,
               'weapon': False},
              {'ba': 3,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4 + Paralisia',
               'description': 'Garras',
               'text': '2 × Garras +3 (1d4 + Paralisia)',
               'times': 2,
               'weapon': False}],
  'ca': '14',
  'concept': 'morto_vivo',
  'description': 'Criaturas odiosas e mortas-vivas de pele rígida opaca e '
                 'necrosada, geralmente acinzentadas ou mesmo pálidas.\n'
                 '\n'
                 'São formados apenas por humanos mortos, o que faz com que '
                 'desejem sobremaneira a carne de semi-humanos como elfos, '
                 'meio-elfos, halflings, gnomos ou anões.\n'
                 '\n'
                 'Possuem unhas e dentes quebrados, cabelos desgrenhados e '
                 'roupas esfarrapadas que demonstram bem a decadência destes '
                 'seres.\n'
                 '\n'
                 'Uma característica física incomum e marcante é a existência '
                 'de uma imensa língua, imunda e enegrecida, sempre pendente '
                 'para fora da boca, ideal para lamber e sugar as medulas dos '
                 'ossos rachados pelas sua mordida feroz.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Ghouls priorizam atacar os alvos que julguem mais fáceis de '
                 'paralisar, diminuindo assim o número de oponentes ativos.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar-se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Paralisia**: alvo atingido por um Ghoul deve ser '
                 'bem-sucedido em uma JPC ou ficará paralisado por até 1d6 '
                 'turnos. Elfos são imunes à habilidade de Paralisia de um '
                 'Ghoul.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar '
                 'Mortos-Vivos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Necrófagos, os Ghouls buscam carne em cemitérios ou campos '
                 'de batalha, mas não se opõem em matar seres vivos para se '
                 'alimentar.\n'
                 '\n'
                 'Não comem por necessidade biológica, e sim para apaziguar o '
                 'caos de suas mentes distorcidas pelas energias negativas.\n'
                 '\n'
                 'A carne favorita deles é a dos elfos e, por não conseguirem '
                 'usar sua habilidade de paralisar nestes alvos, os perseguem '
                 'com especial atenção.',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '2d8',
  'flavor': 'Morto-vivo grotesco. Passa todo o tempo procurando carne de '
            'semi-humanos para se alimentar.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 68},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 77},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 173},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 89},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 12},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday17.json',
              'page': 25},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'ghoul',
  'jp': '7',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Ghoul',
  'picture': 'https://public.olddragon.com.br/8qmi5x9y0nanfs0wdj9jukczft93',
  'pv': '15',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/5hse39gr6cqd2vy3qfi21qk59b4b',
  'treasure': None,
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/ghoul.json',
  'variant': False,
  'xp': '95'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Morto-vivo grotesco. Passa todo o tempo procurando carne de '
            'semi-humanos para se alimentar.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 122}],
  'habitats': ['qualquer'],
  'id': 'ghoul-antigo',
  'name': 'Ghoul Antigo',
  'parent_monster_url': 'https://olddragon.com.br/monstros/ghoul.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/ghoul-antigo.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 11,
               'damage': None,
               'damage_bonus': 6,
               'damage_description': 'Arma +6',
               'description': 'Arma',
               'text': '1 × Arma +11 (Arma +6)',
               'times': 1,
               'weapon': True},
              {'ba': 11,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Pedrada',
               'text': '1 × Pedrada +11 (2d8)',
               'times': 1,
               'weapon': False}],
  'ca': '16/17',
  'concept': 'gigante',
  'description': 'Menores que os outros tipos, os Gigantes da Colina usam '
                 'peles de grandes animais costuradas para fazer casacos '
                 'grossos e fedidos.\n'
                 '\n'
                 'Seu corpo e aparência lembram os de um homem primitivo, com '
                 'crânio de testa larga, barriga proeminente e muitos pelos '
                 'desgrenhados.\n'
                 '\n'
                 'Muitos são os escravizados pelos Gigantes da Colina, o que '
                 'faz com que tenham muitos inimigos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Não possuem táticas específicas, preferindo ataques diretos '
                 'e violentos com as armas que possuem à mão. Possuem '
                 'predileção por usar grandes clavas, às vezes com pedras e '
                 'metais encrostadas como se fossem espinhos.\n'
                 '\n'
                 'Sua habilidade em arremessar pedras não é tão boa quanto a '
                 'dos outros gigantes mas ainda assim, capaz de grandes '
                 'estragos.\n'
                 '\n'
                 '  * **Classe de armadura**: possuem CA 16 ou 17 quando usam '
                 'armadura acolchoada.\n'
                 '\n'
                 '  * **Golpe Potente**: se conseguir causar, com uma pancada '
                 'ou arma, uma quantidade de dano superior a força do alvo, '
                 'este é arremessado 1d6 metros para trás.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em cabanas feitas de couro e madeira com suas '
                 'numerosas famílias.\n'
                 '\n'
                 'Apesar de uma tenda abrigar apenas uma família, elas ocupam '
                 'um bom espaço, por isso preferem regiões amplas para '
                 'acomodar todos.\n'
                 '\n'
                 'Não possuem xamãs, mas o líder, normalmente o mais forte e '
                 'menos estúpido, é tido como um escolhido pelos deuses, '
                 'demonstrando sempre muita força e violência.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Testículos de Gigante da Colina são muito apreciados na '
                 'pouco convidativa culinária dos povos do norte.',
  'dv': '11',
  'dv_bonus': '+6',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Com 4 metros de altura, estes gigantes aterrorizam comunidades '
            'vizinhas com seus ataques em grupo.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 174},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 90},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday14.json',
              'page': 24},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['colinas', 'montanhas'],
  'id': 'gigante-da-colina',
  'jp': '13',
  'mo': 10,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Gigante da Colina',
  'picture': 'https://public.olddragon.com.br/ij0c31qdiuubz57upqg8qooz4ne6',
  'pv': '61',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/0c5329ut8kqq3pc6itp6384rsaoz',
  'treasure': 'rx4',
  'treasure_lair': 'f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gigante-da-colina.json',
  'variant': False,
  'xp': '1600'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 7,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Pancada',
               'text': '1 × Pancada +7 (1d8)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'gigante',
  'description': '  * **Classe de armadura**: possuem CA 16 ou 17 quando usam '
                 'armadura acolchoada.\n'
                 '\n'
                 '  * **Golpe Potente**: se conseguir causar, com uma pancada '
                 'ou arma, uma quantidade de dano superior a força do alvo, '
                 'este é arremessado 1d6 metros para trás.',
  'dv': '7',
  'dv_bonus': '+2',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Com 4 metros de altura, estes gigantes aterrorizam comunidades '
            'vizinhas com seus ataques em grupo.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday17.json',
              'page': 22}],
  'habitats': ['colinas', 'montanhas'],
  'id': 'gigante-da-colina-moribundo-estagio-1',
  'jp': '10',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Gigante da Colina Moribundo (Estágio 1)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/gigante-da-colina.json',
  'pv': '37',
  'size': 'imenso',
  'treasure': 'rx4',
  'treasure_lair': 'f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gigante-da-colina-moribundo-estagio-1.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '420'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 9,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Pancada',
               'text': '1 × Pancada +9 (2d6)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'gigante',
  'description': '  * **Classe de armadura**: possuem CA 16 ou 17 quando usam '
                 'armadura acolchoada.\n'
                 '\n'
                 '  * **Golpe Potente**: se conseguir causar, com uma pancada '
                 'ou arma, uma quantidade de dano superior a força do alvo, '
                 'este é arremessado 1d6 metros para trás.',
  'dv': '9',
  'dv_bonus': '+5',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Com 4 metros de altura, estes gigantes aterrorizam comunidades '
            'vizinhas com seus ataques em grupo.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday17.json',
              'page': 25}],
  'habitats': ['colinas', 'montanhas'],
  'id': 'gigante-da-colina-moribundo-estagio-2',
  'jp': '11',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Gigante da Colina Moribundo (Estágio 2)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/gigante-da-colina.json',
  'pv': '50',
  'size': 'imenso',
  'treasure': 'rx4',
  'treasure_lair': 'f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gigante-da-colina-moribundo-estagio-2.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '1000'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 10,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Pancadas',
               'text': '2 × Pancadas +10 (2d8)',
               'times': 2,
               'weapon': False}],
  'ca': '16',
  'concept': 'gigante',
  'description': '  * **Classe de armadura**: possuem CA 16 ou 17 quando usam '
                 'armadura acolchoada.\n'
                 '\n'
                 '  * **Golpe Potente**: se conseguir causar, com uma pancada '
                 'ou arma, uma quantidade de dano superior a força do alvo, '
                 'este é arremessado 1d6 metros para trás.',
  'dv': '11',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Com 4 metros de altura, estes gigantes aterrorizam comunidades '
            'vizinhas com seus ataques em grupo.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday17.json',
              'page': 30}],
  'habitats': ['colinas', 'montanhas'],
  'id': 'gigante-da-colina-moribundo-estagio-3',
  'jp': '12',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Gigante da Colina Moribundo (Estágio 3)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/gigante-da-colina.json',
  'pv': '55',
  'size': 'imenso',
  'treasure': 'rx4',
  'treasure_lair': 'f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gigante-da-colina-moribundo-estagio-3.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '1600'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 13,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Pancadas',
               'text': '2 × Pancadas +13 (1d8+2)',
               'times': 2,
               'weapon': False},
              {'ba': 9,
               'damage': '2d10',
               'damage_bonus': None,
               'damage_description': '2d10',
               'description': 'Pedrada',
               'text': '1 × Pedrada +9 (2d10)',
               'times': 1,
               'weapon': False},
              {'ba': 8,
               'damage': None,
               'damage_bonus': 10,
               'damage_description': 'Arma +10',
               'description': 'Arma',
               'text': '1 × Arma +8 (Arma +10)',
               'times': 1,
               'weapon': True}],
  'ca': '17',
  'concept': 'gigante',
  'description': 'Estas criaturas medem por volta de 5 metros de altura, '
                 'possuindo um corpo denso e poderoso.\n'
                 '\n'
                 'Lembrando humanos altos, magros e fortes, os Gigantes da '
                 'Montanha são ferozes e destemidos, desde que estejam com '
                 'clara vantagem bélica sobre o inimigo.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Preferem atacar com grandes pedras de longe, sem se '
                 'preocupar em se proteger.\n'
                 '\n'
                 'Sua potência combativa é revelada quando engajam em combate '
                 'corpo a corpo, destruindo os inimigos com incrível força dos '
                 'golpes de suas clavas, feitas de árvores duríssimas.  '
                 'Subjugam e fazem acordos com Trolls e Ogros, usando-os como '
                 'guardas ou soldados em suas campanhas de expansão de '
                 'território.\n'
                 '\n'
                 'Muitos assentamentos humanos desistiram da luta apenas com a '
                 'visão destes terríveis bandos de guerrilheiros.\n'
                 '\n'
                 '  * **Golpe Potente**: se conseguir causar, com uma pancada, '
                 'pedrada ou arma, uma quantidade de dano maior que a força do '
                 'alvo, este é arremessado 1d4 metros para trás.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Comandados por poderosos xamãs, os gigantes da montanha se '
                 'relacionam com diversas raças, geralmente em acordos '
                 'impostos.\n'
                 '\n'
                 'Constroem fortes de pedra e madeira, onde vivem com suas '
                 'famílias e animais.\n'
                 '\n'
                 'Não dominam o fogo, portanto é raro o uso do aço ou ferro em '
                 'suas construções e dia a dia.\n'
                 '\n'
                 'Guardam alguns tesouros para usarem de barganha, quando '
                 'necessário, mas geralmente resolvem tudo com força e '
                 'imposição.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os cabelos dos Gigantes da Montanha são valorizados na '
                 'confecção de tapeçarias pelo seu brilho e resistência.',
  'dv': '14',
  'dv_bonus': '+15',
  'encounters': '1d2',
  'encounters_lair': '1d3',
  'flavor': 'Com 5 metros de altura, estes gigantes primitivo preferem atacar '
            'à distância qualquer um que cruze seu caminho.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 91},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['montanhas'],
  'id': 'gigante-da-montanha',
  'jp': '14',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Gigante da Montanha',
  'picture': 'https://public.olddragon.com.br/yndv0lc1qa18vm0pu93tno49wgyl',
  'pv': '85',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/z02g1ytecv8g69hpk2pjtxyrp2xx',
  'treasure': 't',
  'treasure_lair': 'd',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gigante-da-montanha.json',
  'variant': False,
  'xp': '2650'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 12,
               'damage': '2d6',
               'damage_bonus': 2,
               'damage_description': '2d6+2',
               'description': 'Pancadas',
               'text': '2 × Pancadas +12 (2d6+2)',
               'times': 2,
               'weapon': False},
              {'ba': 14,
               'damage': None,
               'damage_bonus': 12,
               'damage_description': 'Arma +12',
               'description': 'Arma',
               'text': '1 × Arma +14 (Arma +12)',
               'times': 1,
               'weapon': True}],
  'ca': '21',
  'concept': 'gigante',
  'description': 'Gigantes da Tempestade são os maiores e certamente os mais '
                 'poderosos dentre todos os gigantes conhecidos.\n'
                 '\n'
                 'Usam roupas leves como togas, adornadas com cintos e '
                 'braceletes metálicos no dia a dia, mas quando se vestem para '
                 'a guerra, dão preferência a peça de couro como gibões e '
                 'armaduras bem feitas e reforçadas\n'
                 '\n'
                 'Possuem tons de pele e cabelo bem variados, do verde oliva '
                 'ou violeta, mas sem importar a cor, sua pele parece chispar '
                 'eletricidade.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Em batalha, apesar de não recorrerem a golpes como socos e '
                 'chutes, sua espada é capaz de destroçar a maioria dos '
                 'alvos.\n'
                 '\n'
                 'Não arremessam pedras, pois este ataque não costuma ser '
                 'muito útil onde vivem.\n'
                 '\n'
                 '  * **Magias**: 3 vezes ao dia podem lançar uma das '
                 'seguintes magias: Levitação, Relâmpago e Convocar Relâmpagos '
                 'como se fossem Magos de 15º nível.\n'
                 '\n'
                 '  * **Imunidade**: imunes a toda forma de eletricidade.\n'
                 '\n'
                 '  * **Respirar embaixo d’água**: normalmente, sem '
                 'restrições.\n'
                 '\n'
                 '  * **Golpe Potente**: se conseguir causar, com uma pancada '
                 'ou arma, uma quantidade de dano maior que a força do alvo, '
                 'este é arremessado 1d8 metros para trás.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Fazem suas moradas em suntuosos castelos nas profundezas do '
                 'mar ou nas mais altas nuvens, mantendo vários tipos de '
                 'animais locais perigosos como guardiões.\n'
                 '\n'
                 'São essencialmente solitários, mas podem viver em pequenos '
                 'grupos da mesma família.\n'
                 '\n'
                 'Podem ficar pensativos por anos, quase como se estivessem '
                 'paralizados, totalmente perdidos em seus devaneios e '
                 'absortos em suas ideias.',
  'dv': '17',
  'dv_bonus': '+10',
  'encounters': '1',
  'encounters_lair': '1d3',
  'flavor': 'Com 8 metros de altura, estes gigantes habitam tanto as nuvens '
            'quanto as profundezas dos oceanos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 92},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'gigante-da-tempestade',
  'jp': '15',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Gigante da Tempestade',
  'picture': 'https://public.olddragon.com.br/6aojab7yoepbaix1dayldypctaio',
  'pv': '95',
  'size': 'colossal',
  'thumb_picture': 'https://public.olddragon.com.br/soyiji5kshu66g07uhesm3cvgcga',
  'treasure': 'vx3',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gigante-da-tempestade.json',
  'variant': False,
  'xp': '3850'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'gigante',
  'flavor': 'Humanoides peludos e brutos de 3,6m de altura e baixa '
            'inteligência. Vivem nos sopés de dunas e são conhecidos por '
            'atacar assentamentos humanos para roubar comida.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 68}],
  'habitats': ['desertos'],
  'id': 'gigante-do-deserto',
  'name': 'Gigante do Deserto',
  'size': 'imenso',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gigante-do-deserto.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 12,
               'damage': None,
               'damage_bonus': 8,
               'damage_description': 'Arma +8',
               'description': 'Arma',
               'text': '1 × Arma +12 (Arma +8)',
               'times': 1,
               'weapon': True},
              {'ba': 9,
               'damage': '2d10',
               'damage_bonus': None,
               'damage_description': '2d10',
               'description': 'Pedrada',
               'text': '1 × Pedrada +9 (2d10)',
               'times': 1,
               'weapon': False},
              {'ba': 13,
               'damage': '1d8',
               'damage_bonus': 4,
               'damage_description': '1d8+4',
               'description': 'Pancadas',
               'text': '2 × Pancadas +13 (1d8+4)',
               'times': 2,
               'weapon': False}],
  'ca': '16/20',
  'concept': 'gigante',
  'description': 'Medindo quase 6 metros, os Gigantes do Fogo são cruéis e '
                 'incansáveis.  Lutam com ferocidade e sem clemência, pilhando '
                 'tudo que lhes for interessante, como tesouros, animais ou '
                 'escravos.\n'
                 '\n'
                 '**Som**: farfalhar do fogo e um ritmado respirar como '
                 'maçarico.\n'
                 '\n'
                 '**Odor**: fumaça.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Gigantes do Fogo são terríveis adversários.  Arremessam '
                 'pedras gigantescas contra os oponentes, muitas vezes '
                 'preparadas com óleo para incendiá-las (+1d6 de dano).\n'
                 '\n'
                 'Usam armas mal esculpidas e lâminas cegas, pois confiam na '
                 'força bruta para destruir seus alvos. Imunes ao fogo comum, '
                 'podem manusear livremente armas em chamas caso julguem uma '
                 'boa estratégia.\n'
                 '\n'
                 '  * **Classe de armadura**: possuem CA 16 ou 20 quando usam '
                 'cota de malha.\n'
                 '\n'
                 '  * **Imunidade ao fogo**: imunidade total ao fogo e ao '
                 'calor oriundos de fontes naturais.  Fogos mágicos causam '
                 'metade do dano e efeito.\n'
                 '\n'
                 '  * **Golpe Potente**: se conseguir causar, com uma pancada, '
                 'pedrada ou arma, uma quantidade de dano maior que a força do '
                 'alvo, este é arremessado 1d6 metros para trás.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em locais quentes e abafados como próximo de vulcões, '
                 'onde constroem suas fortalezas e forjas.\n'
                 '\n'
                 'São odiados pelos anões, e o sentimento é recíproco, devido '
                 'as incontáveis guerras que estes dois povos já travaram ao '
                 'longo das eras.\n'
                 '\n'
                 'Vivem sob o comando de um poderoso líder, o qual muitas '
                 'vezes se alia a dragões ou mesmo criaturas dos subterrâneos, '
                 'como elfos negros, visando a proteção e soberania de seu '
                 'reino.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Leite das fêmeas pode ser usado como óleo combustível na '
                 'queima de tochas ou lanternas.',
  'dv': '14',
  'dv_bonus': '+10',
  'encounters': '1d2',
  'encounters_lair': '1d3',
  'flavor': 'Com 6 metros de altura, estes gigantes militarizados são brutais '
            'em seus ataques contra as defesas inimigas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 93},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['montanhas', 'subterraneos'],
  'id': 'gigante-do-fogo',
  'jp': '14',
  'mo': 10,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Gigante do Fogo',
  'picture': 'https://public.olddragon.com.br/glquogbj5dhlc05r5fg69d37m8q6',
  'pv': '80',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/rdc1bo3uenbxa6t8f27792vkip8f',
  'treasure': 'v',
  'treasure_lair': 'gx2',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gigante-do-fogo.json',
  'variant': False,
  'xp': '2725'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 7,
               'damage': '2d10',
               'damage_bonus': None,
               'damage_description': '2d10',
               'description': 'Pedrada',
               'text': '1 × Pedrada +7 (2d10)',
               'times': 1,
               'weapon': False},
              {'ba': 9,
               'damage': None,
               'damage_bonus': 8,
               'damage_description': 'Arma +8',
               'description': 'Arma',
               'text': '1 × Arma +9 (Arma +8)',
               'times': 1,
               'weapon': True},
              {'ba': 12,
               'damage': '1d8',
               'damage_bonus': 6,
               'damage_description': '1d8+6',
               'description': 'Pancadas',
               'text': '2 × Pancadas +12 (1d8+6)',
               'times': 2,
               'weapon': False}],
  'ca': '16/18',
  'concept': 'gigante',
  'description': 'Os gigantes do gelo têm constituições musculosas, quase '
                 'humanas e uma aparência que lembra em muito os povos humanos '
                 'que vivem próximo aos árticos.\n'
                 '\n'
                 'Sua pele se destaca pelos váriados tons de azul claro, assim '
                 'como o gelo, e seus cabelos longos, são quase sempre, loiros '
                 'ou brancos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Gostam de atacar surpreendendo suas vítimas, deixando-as '
                 'passar e atacando-as pelas costas.\n'
                 '\n'
                 'Assim que as vítimas se viram para se defender, a segunda '
                 'leva de gigantes ataca de outro ponto, e assim '
                 'sucessivamente, até que o inimigo pereça ou se renda.\n'
                 '\n'
                 '  * **Classe de armadura**: possuem CA 16 ou 18 quando usam '
                 'armadura de couro.\n'
                 '\n'
                 '  * **Camuflagem**: quando enterrados sob a neve, '
                 'surpreendem seus inimigos com 1-4 chances em 1d6.\n'
                 '\n'
                 '  * **Resistência ao frio**: imunidade total ao frio oriundo '
                 'de fontes naturais ou mágicas.  Frio mágico pode causar '
                 'outros efeitos que não seja de dano.\n'
                 '\n'
                 '  * **Golpe Potente**: se conseguir causar, com uma pancada, '
                 'pedrada ou arma, uma quantidade de dano maior que a força do '
                 'alvo, este é arremessado 1d6 metros para trás.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Gigantes do Gelo vivem em tribos primitivas, praticamente '
                 'sem conhecimento de forja.  Apesar disso, alguns líderes '
                 'conseguem armaduras metalicas feitas por raças '
                 'escravizadas.\n'
                 '\n'
                 'As fêmeas são caçadoras, exímias patrulheiras.  Os machos '
                 'são soldados e usam a brutalidade, mesmo entre si, para '
                 'assegurar hierarquia.\n'
                 '\n'
                 'Algumas tribos domesticam ursos polares, usando-os como '
                 '“cães de caça”. Estes ursos são extremamente violentos e '
                 'leais aos seus mestres.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'O sangue do Gigante do Gelo é usado como elemento congelante '
                 'nos laboratórios alquímicos.  Na culinária, é usado na '
                 'conservação de alimentos.',
  'dv': '12',
  'dv_bonus': '+8',
  'encounters': '1d2',
  'encounters_lair': '1d4',
  'flavor': 'Com 7 metros de altura, estes gigantes estúpidos das terras '
            'geladas adoram emboscar seus inimigos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 94},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['geleiras'],
  'id': 'gigante-do-gelo',
  'jp': '13',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Gigante do Gelo',
  'picture': 'https://public.olddragon.com.br/dgrlcdiu29d52v4lj1ljiu5bejwf',
  'pv': '68',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/ane5kzc4orz43ji75356vyeqlnqg',
  'treasure': 'ux2, fx2',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gigante-do-gelo.json',
  'variant': False,
  'xp': '2025'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'gigante',
  'flavor': 'Humanoides de 4,8m de altura, com barbas negras e pele '
            'avermelhada. Vestem armaduras ornamentadas com metais dourados. '
            'Vivem em lugares muito quentes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 69}],
  'habitats': ['desertos'],
  'id': 'gigante-igneo',
  'name': 'Gigante Ígneo',
  'size': 'imenso',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gigante-igneo.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Os Girallons Ibonianos são uma raça inteligente de gorilas de '
            'quatro braços, dentes afiados como navalhas, garras compridas, '
            'possuem um chifre na testa e pelagem branca ou rajada com manchas '
            'negras.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 30}],
  'habitats': ['florestas'],
  'id': 'girallon-iboniano',
  'name': 'Girallon Iboniano',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/girallon-iboniano.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide_monstruoso',
  'flavor': 'Humanoides grandes de pele negra, escamosa e brilhante com cabeça '
            'de polvo. Bizarros e alienígenas, só podem ser vistos no Assombro '
            'ou em Eclipses. Só atacam em caso extremo de violência contra '
            'eles.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 69}],
  'habitats': ['desertos'],
  'id': 'glamerios',
  'name': 'Glamérios',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/glamerios.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (1d4+1)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma +2 (Arma)',
               'times': 1,
               'weapon': True}],
  'ca': '12/15',
  'concept': 'humanoide',
  'description': 'Altos e esguios, os Gnolls não apenas possuem uma cabeça e '
                 'corpo semelhante a uma hiena humanoide, como mantêm alguns '
                 'hábitos parecidos.\n'
                 '\n'
                 'Quando em patrulha, o Mestre da Caça costuma levar hienas ou '
                 'lobos consigo, usando-os como ferramenta de caça e busca.\n'
                 '\n'
                 '**Som**: passos e rosnados leves.\n'
                 '\n'
                 '**Odor**: odor corporal (suor) misturado com carniça.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Não possuem estratégia clara, preferindo atacar em grandes '
                 'números.\n'
                 '\n'
                 'Parecem seguir alguma lógica apenas quando usam seus animais '
                 'treinados, soltando as criaturas na frente antes de atacar.\n'
                 '\n'
                 '  * **Classe de armadura**: Gnolls possuem CA 12 ou 15 '
                 'quando usam armadura de couro batido.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Os Gnolls vivem em bandos desorganizados, brigando por '
                 'aquilo que consideram precioso ou que lhes traga algum '
                 'status.\n'
                 '\n'
                 'Seus líderes precisam ser não apenas os melhores '
                 'combatentes, como também os mais espertos e os que '
                 'necessitam do menor número de horas de sono para o '
                 'descanso.\n'
                 '\n'
                 'Comem carne em qualquer tipo de estado de conservação, crua, '
                 'podre ou mesmo viva, facilitando a exploração de novos '
                 'territórios.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A pele de Gnoll possui muito valor como tapeçaria de luxo.',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '3d6',
  'flavor': 'Humanoide cruel. Organizam-se em bandos de salteadores, roubando '
            'tudo o que julgarem ser lucrativo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 95},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['planicies', 'florestas', 'subterraneos'],
  'id': 'gnoll',
  'jp': '5',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Gnoll',
  'picture': 'https://public.olddragon.com.br/ejytilqkkl1ld7uzzmbdh95tnk4f',
  'pv': '10',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/m72ei6zhyhnb69xdt509sk9y240m',
  'treasure': 'r',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gnoll.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Lança longa',
               'text': '1 × Lança longa +4 (1d8+2)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'humanoide',
  'description': 'Altos e esguios, os Gnolls não apenas possuem uma cabeça e '
                 'corpo semelhante a uma hiena humanoide, como mantêm alguns '
                 'hábitos parecidos.\n'
                 '\n'
                 'Quando em patrulha, o Mestre da Caça costuma levar hienas ou '
                 'lobos consigo, usando-os como ferramenta de caça e busca.\n'
                 '\n'
                 '**Som**: passos e rosnados leves.\n'
                 '\n'
                 '**Odor**: odor corporal (suor) misturado com carniça.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Não possuem estratégia clara, preferindo atacar em grandes '
                 'números.\n'
                 '\n'
                 'Parecem seguir alguma lógica apenas quando usam seus animais '
                 'treinados, soltando as criaturas na frente antes de atacar.\n'
                 '\n'
                 '  * **Classe de armadura**: Gnolls possuem CA 12 ou 15 '
                 'quando usam armadura de couro batido.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Os Gnolls vivem em bandos desorganizados, brigando por '
                 'aquilo que consideram precioso ou que lhes traga algum '
                 'status.\n'
                 '\n'
                 'Seus líderes precisam ser não apenas os melhores '
                 'combatentes, como também os mais espertos e os que '
                 'necessitam do menor número de horas de sono para o '
                 'descanso.\n'
                 '\n'
                 'Comem carne em qualquer tipo de estado de conservação, crua, '
                 'podre ou mesmo viva, facilitando a exploração de novos '
                 'territórios.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A pele de Gnoll possui muito valor como tapeçaria de luxo.',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '3d6',
  'flavor': 'Humanoide cruel. Organizam-se em bandos de salteadores, roubando '
            'tudo o que julgarem ser lucrativo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 95}],
  'habitats': ['planicies', 'florestas', 'subterraneos'],
  'id': 'gnoll-lider',
  'jp': '6',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Gnoll Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/gnoll.json',
  'picture': 'https://public.olddragon.com.br/ejytilqkkl1ld7uzzmbdh95tnk4f',
  'pv': '15',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/m72ei6zhyhnb69xdt509sk9y240m',
  'treasure': 'r',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gnoll-lider.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '75'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Martelo',
               'text': '1 × Martelo +1 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'humanoide',
  'description': 'Normalmente são encontrados como um grupo de mineradores ou '
                 'comerciantes que estejam próximos às suas terras ou em '
                 'viagem, em alguma missão.\n'
                 '\n'
                 'Encontrados em grupos pequenos de 1d6 indivíduos ou em '
                 'grupos maiores como um acampamento com 5d8 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 20 gnomos, um deles será um Gnomo '
                 'Líder.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '+1',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 186},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'gnomo',
  'jp': '6',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Gnomo',
  'picture': None,
  'pv': '6',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gnomo.json',
  'variant': False,
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'martelo',
               'text': '1 × martelo +3 (1d6+2)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Normalmente são encontrados como um grupo de mineradores ou '
                 'comerciantes que estejam próximos às suas terras ou em '
                 'viagem, em alguma missão.\n'
                 '\n'
                 'Encontrados em grupos pequenos de 1d6 indivíduos ou em '
                 'grupos maiores como um acampamento com 5d8 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 20 gnomos, um deles será um Gnomo '
                 'Líder.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '+1',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 186},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'gnomo-lider',
  'jp': '7',
  'mo': 10,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Gnomo Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/gnomo.json',
  'picture': None,
  'pv': '16',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gnomo-lider.json',
  'variant': True,
  'variant_modifications': ['Moral: enquanto o líder estiver em combate, todos '
                            'os gnomos fazem o teste de moral com um bônus de '
                            '+1.',
                            'Montado: há 1-4 chances de estar montado em um '
                            'Pônei de Guerra.'],
  'xp': '75'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma +2 (Arma)',
               'times': 1,
               'weapon': True}],
  'ca': '11/13',
  'concept': 'humanoide',
  'description': 'Goblins são criaturas tão antigas quanto os anões, nutrindo '
                 'um ódio profundo por esta raça.\n'
                 '\n'
                 'Espalhados por todos os cantos possíveis, muitas vezes são '
                 'contratados (ou escravizados) por outras raças para servirem '
                 'na vanguarda de exércitos e na frente de batalha.\n'
                 '\n'
                 'Em seus clãs, são liderados pelo maior e mais forte Goblin '
                 'da tribo, e temem seus xamãs como figuras de grande '
                 'conhecimento e poder.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Acreditam na força dos números e preferem emboscar seus '
                 'alvos ou atacar primeiramente de longe, enfraquecendo as '
                 'vítimas.\n'
                 '\n'
                 'Costumam debandar quando entendem que a luta não é mais '
                 'favorável a eles, deixando os feridos para trás.\n'
                 '\n'
                 '  * **Classe de armadura**: Goblins possuem CA 11 ou 13 '
                 'quando usam armadura de couro.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em grandes tribos ou grupos errantes, mas sempre '
                 'coletivamente. Preferem uma vida mais selvagem, caçando para '
                 'comer e roubando de outras raças o que precisam.\n'
                 '\n'
                 'Goblins geralmente deterioram as áreas onde vivem, extraindo '
                 'tudo o que puderem consumir: caça, madeira, água e recursos, '
                 'migrando para um novo território quando o atual se exaurir.',
  'dv': '1',
  'dv_bonus': '-1',
  'encounters': '2d4',
  'encounters_lair': '6d10',
  'flavor': 'Usam armas comuns e táticas simples de combate, contando com a '
            'força dos números para sobrepujar os adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 174},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 96},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 15},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/tu1.json',
              'page': 25}],
  'habitats': ['qualquer'],
  'id': 'goblin',
  'jp': '5',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Goblin',
  'picture': 'https://public.olddragon.com.br/p6ez5le3p922fgw10au8ol7x1eg4',
  'pv': '4',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/yppbox6v4d96i975frafrm2bv3xr',
  'treasure': 'q',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/goblin.json',
  'variant': False,
  'xp': '15'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Usam armas comuns e táticas simples de combate, contando com a '
            'força dos números para sobrepujar os adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 92},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/ja1.json',
              'page': 40}],
  'habitats': ['qualquer'],
  'id': 'goblin-arqueiro',
  'name': 'Goblin Arqueiro',
  'parent_monster_url': 'https://olddragon.com.br/monstros/goblin.json',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/goblin-arqueiro.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Arco',
               'text': '1 × Arco +1 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '11',
  'concept': 'humanoide',
  'description': 'Goblins são criaturas tão antigas quanto os anões, nutrindo '
                 'um ódio profundo por esta raça.\n'
                 '\n'
                 'Espalhados por todos os cantos possíveis, muitas vezes são '
                 'contratados (ou escravizados) por outras raças para servirem '
                 'na vanguarda de exércitos e na frente de batalha.\n'
                 '\n'
                 'Em seus clãs, são liderados pelo maior e mais forte Goblin '
                 'da tribo, e temem seus xamãs como figuras de grande '
                 'conhecimento e poder.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Acreditam na força dos números e preferem emboscar seus '
                 'alvos ou atacar primeiramente de longe, enfraquecendo as '
                 'vítimas.\n'
                 '\n'
                 'Costumam debandar quando entendem que a luta não é mais '
                 'favorável a eles, deixando os feridos para trás.\n'
                 '\n'
                 '  * **Classe de armadura**: Goblins possuem CA 11 ou 13 '
                 'quando usam armadura de couro.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em grandes tribos ou grupos errantes, mas sempre '
                 'coletivamente. Preferem uma vida mais selvagem, caçando para '
                 'comer e roubando de outras raças o que precisam.\n'
                 '\n'
                 'Goblins geralmente deterioram as áreas onde vivem, extraindo '
                 'tudo o que puderem consumir: caça, madeira, água e recursos, '
                 'migrando para um novo território quando o atual se exaurir.',
  'dv': '1',
  'dv_bonus': '-1',
  'encounters': '2d4',
  'encounters_lair': '6d10',
  'flavor': 'Usam armas comuns e táticas simples de combate, contando com a '
            'força dos números para sobrepujar os adversários.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 96}],
  'habitats': ['qualquer'],
  'id': 'goblin-batedor',
  'jp': '5',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Goblin Batedor',
  'parent_monster_url': 'https://olddragon.com.br/monstros/goblin.json',
  'picture': 'https://public.olddragon.com.br/p6ez5le3p922fgw10au8ol7x1eg4',
  'pv': '4',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/yppbox6v4d96i975frafrm2bv3xr',
  'treasure': 'q',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/goblin-batedor.json',
  'variant': True,
  'variant_modifications': ['Chance de 1-2 em 1d6 de estar montando lobos.'],
  'xp': '15'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Usam armas comuns e táticas simples de combate, contando com a '
            'força dos números para sobrepujar os adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 72}],
  'habitats': ['qualquer'],
  'id': 'goblin-chefe',
  'name': 'Goblin Chefe',
  'parent_monster_url': 'https://olddragon.com.br/monstros/goblin.json',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/goblin-chefe.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Os Goblins das Profundezas são uma das raças goblinóides mais '
            'comuns nas Infinitas Cavernas e demais subterrâneos de Kadur.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 32}],
  'habitats': ['subterraneos'],
  'id': 'goblin-das-profundezas',
  'name': 'Goblin das Profundezas',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/goblin-das-profundezas.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Usam armas comuns e táticas simples de combate, contando com a '
            'força dos números para sobrepujar os adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 72}],
  'habitats': ['qualquer'],
  'id': 'goblin-de-elite',
  'name': 'Goblin de Elite',
  'parent_monster_url': 'https://olddragon.com.br/monstros/goblin.json',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/goblin-de-elite.json',
  'variant': True},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': '  * **Classe de armadura**: Goblins possuem CA 11 ou 13 '
                 'quando usam armadura de couro.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '6d10',
  'flavor': 'Usam armas comuns e táticas simples de combate, contando com a '
            'força dos números para sobrepujar os adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/tu2.json',
              'page': 45}],
  'habitats': ['qualquer'],
  'id': 'goblin-fungico',
  'jp': '4',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Goblin Fúngico',
  'parent_monster_url': 'https://olddragon.com.br/monstros/goblin.json',
  'pv': '5',
  'size': 'pequeno',
  'treasure': 'q',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/goblin-fungico.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '15'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Usam armas comuns e táticas simples de combate, contando com a '
            'força dos números para sobrepujar os adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 71}],
  'habitats': ['qualquer'],
  'id': 'goblin-guarda',
  'name': 'Goblin Guarda',
  'parent_monster_url': 'https://olddragon.com.br/monstros/goblin.json',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/goblin-guarda.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Usam armas comuns e táticas simples de combate, contando com a '
            'força dos números para sobrepujar os adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 73}],
  'habitats': ['qualquer'],
  'id': 'goblin-guardiao',
  'name': 'Goblin Guardião',
  'parent_monster_url': 'https://olddragon.com.br/monstros/goblin.json',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/goblin-guardiao.json',
  'variant': True},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1 + Veneno',
               'description': 'azagaia',
               'text': '1 × azagaia +4 (1d4+1 + Veneno)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': '  * **Classe de armadura**: Goblins possuem CA 11 ou 13 '
                 'quando usam armadura de couro.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.',
  'dv': '2',
  'dv_bonus': '+4',
  'encounters': '2d4',
  'encounters_lair': '6d10',
  'flavor': 'Usam armas comuns e táticas simples de combate, contando com a '
            'força dos números para sobrepujar os adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 116},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 22}],
  'habitats': ['qualquer'],
  'id': 'goblin-guardiao-veterano',
  'jp': '5',
  'mo': 10,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Goblin Guardião Veterano',
  'parent_monster_url': 'https://olddragon.com.br/monstros/goblin.json',
  'pv': '14',
  'size': 'pequeno',
  'treasure': 'q',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/goblin-guardiao-veterano.json',
  'variant': True,
  'variant_modifications': ['Veneno: JPC para evitar.'],
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Espada curta',
               'text': '1 × Espada curta +3 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': 'Goblins são criaturas tão antigas quanto os anões, nutrindo '
                 'um ódio profundo por esta raça.\n'
                 '\n'
                 'Espalhados por todos os cantos possíveis, muitas vezes são '
                 'contratados (ou escravizados) por outras raças para servirem '
                 'na vanguarda de exércitos e na frente de batalha.\n'
                 '\n'
                 'Em seus clãs, são liderados pelo maior e mais forte Goblin '
                 'da tribo, e temem seus xamãs como figuras de grande '
                 'conhecimento e poder.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Acreditam na força dos números e preferem emboscar seus '
                 'alvos ou atacar primeiramente de longe, enfraquecendo as '
                 'vítimas.\n'
                 '\n'
                 'Costumam debandar quando entendem que a luta não é mais '
                 'favorável a eles, deixando os feridos para trás.\n'
                 '\n'
                 '  * **Classe de armadura**: Goblins possuem CA 11 ou 13 '
                 'quando usam armadura de couro.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em grandes tribos ou grupos errantes, mas sempre '
                 'coletivamente. Preferem uma vida mais selvagem, caçando para '
                 'comer e roubando de outras raças o que precisam.\n'
                 '\n'
                 'Goblins geralmente deterioram as áreas onde vivem, extraindo '
                 'tudo o que puderem consumir: caça, madeira, água e recursos, '
                 'migrando para um novo território quando o atual se exaurir.',
  'dv': '3',
  'dv_bonus': '-1',
  'encounters': '2d4',
  'encounters_lair': '6d10',
  'flavor': 'Usam armas comuns e táticas simples de combate, contando com a '
            'força dos números para sobrepujar os adversários.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 96},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/tu1.json',
              'page': 25}],
  'habitats': ['qualquer'],
  'id': 'goblin-lider',
  'jp': '6',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Goblin Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/goblin.json',
  'picture': 'https://public.olddragon.com.br/p6ez5le3p922fgw10au8ol7x1eg4',
  'pv': '14',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/yppbox6v4d96i975frafrm2bv3xr',
  'treasure': 'q',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/goblin-lider.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '75'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Usam armas comuns e táticas simples de combate, contando com a '
            'força dos números para sobrepujar os adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 71},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/ja1.json',
              'page': 39}],
  'habitats': ['qualquer'],
  'id': 'goblin-nao-combatente',
  'name': 'Goblin Não Combatente',
  'parent_monster_url': 'https://olddragon.com.br/monstros/goblin.json',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/goblin-nao-combatente.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Usam armas comuns e táticas simples de combate, contando com a '
            'força dos números para sobrepujar os adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 91}],
  'habitats': ['qualquer'],
  'id': 'goblin-veterano',
  'name': 'Goblin Veterano',
  'parent_monster_url': 'https://olddragon.com.br/monstros/goblin.json',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/goblin-veterano.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Usam armas comuns e táticas simples de combate, contando com a '
            'força dos números para sobrepujar os adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 71}],
  'habitats': ['qualquer'],
  'id': 'goblin-vigia',
  'name': 'Goblin Vigia',
  'parent_monster_url': 'https://olddragon.com.br/monstros/goblin.json',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/goblin-vigia.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Bordão',
               'text': '1 × Bordão +2 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': 'Goblins são criaturas tão antigas quanto os anões, nutrindo '
                 'um ódio profundo por esta raça.\n'
                 '\n'
                 'Espalhados por todos os cantos possíveis, muitas vezes são '
                 'contratados (ou escravizados) por outras raças para servirem '
                 'na vanguarda de exércitos e na frente de batalha.\n'
                 '\n'
                 'Em seus clãs, são liderados pelo maior e mais forte Goblin '
                 'da tribo, e temem seus xamãs como figuras de grande '
                 'conhecimento e poder.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Acreditam na força dos números e preferem emboscar seus '
                 'alvos ou atacar primeiramente de longe, enfraquecendo as '
                 'vítimas.\n'
                 '\n'
                 'Costumam debandar quando entendem que a luta não é mais '
                 'favorável a eles, deixando os feridos para trás.\n'
                 '\n'
                 '  * **Classe de armadura**: Goblins possuem CA 11 ou 13 '
                 'quando usam armadura de couro.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em grandes tribos ou grupos errantes, mas sempre '
                 'coletivamente. Preferem uma vida mais selvagem, caçando para '
                 'comer e roubando de outras raças o que precisam.\n'
                 '\n'
                 'Goblins geralmente deterioram as áreas onde vivem, extraindo '
                 'tudo o que puderem consumir: caça, madeira, água e recursos, '
                 'migrando para um novo território quando o atual se exaurir.',
  'dv': '2',
  'dv_bonus': '-1',
  'encounters': '2d4',
  'encounters_lair': '6d10',
  'flavor': 'Usam armas comuns e táticas simples de combate, contando com a '
            'força dos números para sobrepujar os adversários.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 96}],
  'habitats': ['qualquer'],
  'id': 'goblin-xama',
  'jp': '5',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Goblin Xamã',
  'parent_monster_url': 'https://olddragon.com.br/monstros/goblin.json',
  'picture': 'https://public.olddragon.com.br/p6ez5le3p922fgw10au8ol7x1eg4',
  'pv': '9',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/yppbox6v4d96i975frafrm2bv3xr',
  'treasure': 'q',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/goblin-xama.json',
  'variant': True,
  'variant_modifications': ['Magia como Clérigo de 2º nível.'],
  'xp': '50'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'constructo',
  'flavor': 'Guardiões eficientes, são criados do barro para executar '
            'implacavelmente as ordens de seu mestre.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/ja1.json',
              'page': 54}],
  'habitats': ['qualquer'],
  'id': 'golem-de-barro',
  'name': 'Golem de Barro',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/golem-de-barro.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 9,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Pancadas',
               'text': '2 × Pancadas +9 (2d8)',
               'times': 2,
               'weapon': False}],
  'ca': '13',
  'concept': 'constructo',
  'description': 'Aparentam um morto-vivo gigantesco, cheio de pedaços muitas '
                 'vezes desconexos e desproporcionais.\n'
                 '\n'
                 'De andar trôpego e claudicante, murmuram com uma voz grave, '
                 'palavras soltas e repetidas enquanto se movem.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Estes golens atacam de qualquer forma, sem se preocupar com '
                 'mais nada que não seja cumprir as ordens recebidas.\n'
                 '\n'
                 'Contudo, alguns Golens de Carne parecem ter desenvolvido uma '
                 'certa consciência, tendo um desejo de se autopreservar, '
                 'maior do que os outros Golens de Carne.\n'
                 '\n'
                 '  * **Imunidades**: um Golem de Carne é imune ao dano de '
                 'qualquer arma não mágica. Além disso, não são atingidos por '
                 'ataques que necessitem de um alvo vivo (como gases, venenos '
                 'ou magias mentais como ilusões ou demais formas mágicas de '
                 'interferir na mente de seres vivos).\n'
                 '\n'
                 '  * **Cura Elétrica**: o Golem de Carne cura 1 ponto de vida '
                 'para cada dado de dano causado por um ataque de fogo.\n'
                 '\n'
                 '  * **Fogo e Frio**: ataques de fogo e frio, mesmo os '
                 'mágicos, deixam os golens lerdos por 2d6 rodadas. Um golem '
                 'lerdo tem seu movimento reduzido à metade, e recebe uma '
                 'penalidade de 2 em todas as jogadas e na CA.\n'
                 '\n'
                 '  * **Fúria**: a cada rodada que estiver em combate, um '
                 'Golem de Carne tem uma chance cumulativa de 1% de se '
                 'libertar do controle do seu mestre e entrar em fúria, '
                 'atacando tudo e a todos que estiverem ao seu alcance.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Alguns golens (1-2 chances em 1d6) são constituídos apenas '
                 'por partes de corpos de seres humanos e por isso, conseguem '
                 'andar na civilização como se fossem “pessoas comuns”.\n'
                 '\n'
                 'No entanto, vivem em constante tormenta, com lampejos '
                 'aleatórios sobre sua origem e das memórias de sua vida '
                 'anterior.',
  'dv': '9',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Espécie de boneco formado com pedaços de vários corpos '
            'diferentes, formando uma única criatura horrenda.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 83},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/ja1.json',
              'page': 39},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 97},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'golem-de-carne',
  'jp': '11',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Golem de Carne',
  'picture': 'https://public.olddragon.com.br/fsmqdsfsu5bcgrnydfr9uotbjhjj',
  'pv': '45',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/azhd1b0kdnolj2l0acw6vxasogrx',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/golem-de-carne.json',
  'variant': False,
  'xp': '1025'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 12,
               'damage': '4d8',
               'damage_bonus': None,
               'damage_description': '4d8',
               'description': 'Pancada',
               'text': '1 × Pancada +12 (4d8)',
               'times': 1,
               'weapon': False},
              {'ba': 15,
               'damage': '4d10',
               'damage_bonus': None,
               'damage_description': '4d10',
               'description': 'Espada curta',
               'text': '1 × Espada curta +15 (4d10)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'constructo',
  'description': 'Estes golens gigantescos aparentam guerreiros antigos e '
                 'destemidos, armados como um soldado ou herói lendário.\n'
                 '\n'
                 'Tendo sido criado por um mestre, normalmente um Mago ou '
                 'Sábio de grande sabedoria, não possuem vontade própria, '
                 'agindo conforme programados ou ordenados pelo seu mestre.\n'
                 '\n'
                 'O Golem de Ferro não fala ou emite ruídos a não ser os dos '
                 'seus passos que, além de ruidosos e pesados, fazem o chão '
                 'trepidar devido seu peso.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'A não ser que tenham sido ordenados para realizarem algo '
                 'diferente, atacam de forma impiedosa e brutal, visando '
                 'primeiramente magos e usuários de magia, e deixando '
                 'guerreiros por último.\n'
                 '\n'
                 '  * **Imunidades**: um Golem de Ferro é imune ao dano de '
                 'qualquer arma não mágica. Além disso, não são atingidos por '
                 'ataques que necessitem de um alvo vivo (como gases, venenos '
                 'ou magias mentais como ilusões ou demais formas mágicas de '
                 'interferir na mente de seres vivos).\n'
                 '\n'
                 '  * **Baforada de gás**: uma vez a cada 7 ataques '
                 'desferidos, o Golem de Ferro é capaz de lançar uma nuvem de '
                 'gás venenoso causando 3d6 de dano a todos a até 6 metros de '
                 'distância dele.  Uma JPD pode reduzir o dano à metade.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Muito usados como guardas, estes golens não são muito '
                 'comuns, pois necessitam de metais raros para compor seu '
                 'interior além de grande custo para seus encantamentos e '
                 'poder para dominar o processo de construção\n'
                 '\n'
                 'Completamente sem emoção, não podem ser influenciados de '
                 'forma alguma, seguindo apenas as ordens recebidas. Como '
                 'constructos, não possuem desejos que não sejam os de seu '
                 'mestre e criador.\n'
                 '\n'
                 'Normalmente são forjados já com suas espadas curtas nos '
                 'punhos. Se de alguma forma perderem este tipo de ataque, '
                 'concentrarão suas ações em desferir pancadas com ambas as '
                 'mãos.',
  'dv': '18',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Humanoides forjados como grandes guerreiros armadurados, feitos '
            'do mais puro ferro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 98},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 14},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday14.json',
              'page': 26},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'golem-de-ferro',
  'jp': '14',
  'mo': 12,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Golem de Ferro',
  'picture': 'https://public.olddragon.com.br/b3j8dtp6rd4rg9avm57u9ib42m73',
  'pv': '90',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/d0t1gctjp69elwkzul53pgnde736',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/golem-de-ferro.json',
  'variant': False,
  'xp': '4200'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'constructo',
  'flavor': 'Humanoides forjados como grandes guerreiros armadurados, feitos '
            'do mais puro ferro.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 109}],
  'habitats': ['qualquer'],
  'id': 'golem-de-ferro-louco',
  'name': 'Golem de Ferro Louco',
  'parent_monster_url': 'https://olddragon.com.br/monstros/golem-de-ferro.json',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/golem-de-ferro-louco.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 9,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Pancadas',
               'text': '2 × Pancadas +9 (2d8)',
               'times': 2,
               'weapon': False}],
  'ca': '17',
  'concept': 'constructo',
  'description': 'Seu formato lembra espetos de gelo, estalactites azuladas ou '
                 'esbranquiçadas. Seu corpo e forma de andar parecem muito '
                 'mais pesados do que realmente o são.\n'
                 '\n'
                 'Tendo sido criado por um mestre, normalmente um xamã de '
                 'povos dos árticos de grande sabedoria, não possuem vontade '
                 'própria, agindo conforme são programados ou ordenados pelo '
                 'seu mestre.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Em combate são programados a fim de se posicionarem próximo '
                 'dos inimigos, sempre que estejam próximos de morrer, para '
                 'ampliar a efetividade do seu mortal ataque de estilhaços.\n'
                 '\n'
                 'São capazes de atacar até mesmo outros Golens de Gelo, no '
                 'raríssimo caso onde mais de um estiver presente, caso seja '
                 'necessário ativar esta habilidade especial.\n'
                 '\n'
                 '  * **Imunidades**: um Golem de Gelo é imune ao dano de '
                 'qualquer arma não mágica. Além disso, não são atingidos por '
                 'ataques que necessitem de um alvo vivo (como gases, venenos '
                 'ou magias mentais como ilusões ou demais formas mágicas de '
                 'interferir na mente de seres vivos). Um Golem de Gelo também '
                 'é inume a qualquer ataque de gelo ou frio.\n'
                 '\n'
                 '  * **Estilhaços de Gelo**: quando reduzido a zero pontos de '
                 'vida, um Golem de Gelo explode em estilhaços de gelo '
                 'afiados. Todas as criaturas a até 3 metros de distância do '
                 'Golem de Gelo recebem 3d6 pontos de dano da explosão. Uma '
                 'JPD pode reduzir o dano à metade.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Frios, estes golens são muito selvagens e perigosos.  Usam '
                 'de tudo que dispõe para garantir a vitória. Algumas vezes, '
                 'terminam suas tarefas e saem errantes nas imensidões '
                 'gélidas, buscando propósito em sua vida.\n'
                 '\n'
                 'Completamente sem emoção, não podem ser influenciados de '
                 'forma alguma, seguindo apenas as ordens recebidas. Como '
                 'constructos, não possuem desejos que não sejam os de seu '
                 'mestre e criador.',
  'dv': '8',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Estátua humanoide feita de gelo coberta de espinhos de gelo '
            'afiados por todo o corpo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 99},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['geleiras'],
  'id': 'golem-de-gelo',
  'jp': '7',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Golem de Gelo',
  'picture': 'https://public.olddragon.com.br/jb4mm545jfjar2jpnnuuzsoqryf3',
  'pv': '40',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/idc3soucjr8ijknfvt6vz547djar',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/golem-de-gelo.json',
  'variant': False,
  'xp': '740'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Pancada',
               'text': '1 × Pancada +2 (1d8)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'constructo',
  'description': 'O Golem de Madeira é um pequeno humanoide muitas vezes com o '
                 'processo de criação ocorrendo sobre marionetes ou outros '
                 'bonecos infantis.\n'
                 '\n'
                 'Quando em repouso, parecem inofensivos e com feições '
                 'alegres. Mas, algumas vezes, podem assumir traços bizarros e '
                 'assustadores, como versões dantescas de seres humanos.\n'
                 '\n'
                 'Apesar de criado por um mestre, normalmente um Mago ou Sábio '
                 'de grande sabedoria, possuem vontade própria, agindo '
                 'conforme suas próprias vontades e motivações.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Não costumam atacar, a menos que seja estritamente '
                 'necessário. Usufruem de sua aparência frágil para provocar '
                 'simpatia e atacar suas vítimas pelas costas.\n'
                 '\n'
                 '  * **Imunidades**: um Golem de Madeira é imune ao dano de '
                 'qualquer arma não mágica. Além disso, não são atingidos por '
                 'ataques que necessitem de um alvo vivo (como gases, venenos '
                 'ou magias mentais como ilusões ou demais formas mágicas de '
                 'interferir na mente de seres vivos).\n'
                 '\n'
                 '  * **Vulnerabilidade**: um Golem de Madeira resiste a '
                 'qualquer ataque de fogo com um penalizador de -2 e recebe um '
                 'dano adicional de 1 em todo dano causado por fogo.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Criados de forma muito mais fácil que os demais golens, '
                 'geralmente são frutos dos primeiros experimentos de magos '
                 'que buscam fazer golens mais importantes.\n'
                 '\n'
                 'São bem humanizados e conscientes, mas, por buscarem estar '
                 'normalmente entre os vivos não como serviçais, e sim como '
                 'iguais, usam de mentiras e tramoias para matar quem se '
                 'opuser aos seus desejos.\n'
                 '\n'
                 'Buscam esconder sua verdadeira forma a todo o custo, '
                 'deixando para demonstrar sua real natureza apenas após seus '
                 'planos começarem a dar certo. Isso envolve criar '
                 'estratagemas intricados, armadilhas traiçoeiras e, se '
                 'possível, tirar de ação seus inimigos mais poderosos.',
  'dv': '2',
  'dv_bonus': '+2',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Pequenos golens construídos com madeira em formas humanoides. Com '
            'vontade própria, agem livremente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 100},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'golem-de-madeira',
  'jp': '5',
  'mo': 12,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Golem de Madeira',
  'picture': 'https://public.olddragon.com.br/g062nvxfnrvj3wh891cpw0gt3bb6',
  'pv': '12',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/s36wn1udimcxdlb2nyd4tebzp67b',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/golem-de-madeira.json',
  'variant': False,
  'xp': '65'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 9,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma +9 (Arma)',
               'times': 1,
               'weapon': True}],
  'ca': '18',
  'concept': 'constructo',
  'description': 'Além dos braços característicos, seu formato pode ser bem '
                 'variado, e até mesmo de proporções não humanoides, como ter '
                 'duas colunas, crânios nos joelhos e outras formas não '
                 'anatômicas.\n'
                 '\n'
                 'Raramente são construídos com armaduras ou armas, sendo '
                 'facilmente confundidos com mortos-vivos, para o grande '
                 'desespero de quem comete esse engano.\n'
                 '\n'
                 'Tendo sido criado por um mestre, normalmente um Necromante '
                 'de grande sabedoria, não possuem vontade própria, agindo '
                 'conforme programados ou ordenados pelo seu mestre.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam diversos oponentes, buscando primeiro os que estão '
                 'mais próximos, não se importando com aqueles que atacam a '
                 'distância.\n'
                 '\n'
                 '  * **Imunidades**: um Golem de Ossos é imune ao dano de '
                 'qualquer arma não mágica. Além disso, não são atingidos por '
                 'ataques que necessitem de um alvo vivo (como gases, venenos '
                 'ou magias mentais como ilusões ou demais formas mágicas de '
                 'interferir na mente de seres vivos).\n'
                 '\n'
                 '  * **Quatro Braços**: um Golem de Ossos possui 4 braços os '
                 'quais podem ser usados para atacar até 2 oponentes '
                 'diferentes. Um Golem de Ossos pode ainda usar duas armas de '
                 'duas mãos e desferir dois ataques em um único oponente.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Estas aberrações caóticas são de difícil controle.  Por '
                 'isso, apenas necromantes muito preparados arriscam '
                 'criá-los.\n'
                 '\n'
                 'Completamente sem emoção, não podem ser influenciados forma '
                 'alguma quando seguem as ordens recebidas.\n'
                 '\n'
                 'Como constructos, não possuem desejos que não sejam os de '
                 'seu criador, mas apenas até a conclusão das suas missões.\n'
                 '\n'
                 'Uma vez cumpridas, podem tornar-se perigosos e atacar seu '
                 'criador, caso não tenham sido meticulosamente criados e '
                 'programados.',
  'dv': '8',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Golem criado com ossos humanos de diferentes criaturas. Possui '
            'quatro braços totalmente funcionais.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 101},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 14},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday14.json',
              'page': 18},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'golem-de-ossos',
  'jp': '7',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Golem de Ossos',
  'picture': 'https://public.olddragon.com.br/po48jgk4ttbeynu7qxpj45pim03h',
  'pv': '40',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/8bkg9kc2mv8xoloo67ytv0cp3rp9',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/golem-de-ossos.json',
  'variant': False,
  'xp': '740'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'constructo',
  'flavor': 'Golem criado com ossos humanos de diferentes criaturas. Possui '
            'quatro braços totalmente funcionais.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 68}],
  'habitats': ['qualquer'],
  'id': 'golem-de-ossos-louco',
  'name': 'Golem de Ossos Louco',
  'parent_monster_url': 'https://olddragon.com.br/monstros/golem-de-ossos.json',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/golem-de-ossos-louco.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 13,
               'damage': '3d8',
               'damage_bonus': None,
               'damage_description': '3d8',
               'description': 'Pancada',
               'text': '1 × Pancada +13 (3d8)',
               'times': 1,
               'weapon': False}],
  'ca': '19',
  'concept': 'constructo',
  'description': 'Sua aparência pode variar entre algo levemente humanoide, de '
                 'rosto bruto de pedra, a até uma escultura lindamente feita '
                 'em pedras nobres.\n'
                 '\n'
                 'Tendo sido criado por um mestre, normalmente um Mago ou '
                 'Sábio de grande sabedoria, não possuem vontade própria, '
                 'agindo conforme programados ou ordenados pelo seu mestre.\n'
                 '\n'
                 'A cabeça pode ser esculpida para se assemelhar a um capacete '
                 'ou outra peça de cabeça. Está sempre sem armas e nunca usa '
                 'roupas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'A não ser que tenham sido ordenados para realizarem algo '
                 'diferente, usam de sua habilidade de Lentidão e poderosos '
                 'socos para abrir caminho entre os oponentes, buscando sempre '
                 'os alvos mais fracos primeiro.\n'
                 '\n'
                 '  * **Imunidades**: um Golem de Pedra é imune ao dano de '
                 'qualquer arma não mágica. Além disso, não são atingidos por '
                 'ataques que necessitem de um alvo vivo (como gases, venenos '
                 'ou magias mentais como ilusões ou demais formas mágicas de '
                 'interferir na mente de seres vivos).\n'
                 '\n'
                 '  * **Lentidão**: Golens de Pedra são capazes de criar uma '
                 'área de lentidão a todos ao seu redor. Todos dentro de uma '
                 'área de 6 x 6 metros que não passarem em uma JPC ficarão '
                 'lentos. Suas movimentações ficam reduzidas pela metade, e '
                 'recebem uma penalidade de 2 em todas as jogadas e na CA.  O '
                 'efeito tem duração de 2d6 turnos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Muitos Golens de Pedra são criados por tribos primitivas, '
                 'buscando, na união com a terra, forças para defenderem seus '
                 'interesses.\n'
                 '\n'
                 'Completamente sem emoção, não podem ser influenciados de '
                 'forma alguma, seguindo apenas as ordens recebidas. Como '
                 'constructos, não possuem desejos que não sejam os de seu '
                 'mestre e criador.',
  'dv': '14',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Grande humanoide esculpido na pedra bruta e animado em rituais '
            'arcanos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 102},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 14},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday14.json',
              'page': 22},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'golem-de-pedra',
  'jp': '13',
  'mo': 12,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Golem de Pedra',
  'picture': 'https://public.olddragon.com.br/s31jm29q1ag3fekdgnbnjps26xfx',
  'pv': '70',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/3zcde75ysjzvb0lhhvgo108wov0f',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/golem-de-pedra.json',
  'variant': False,
  'xp': '2800'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'constructo',
  'flavor': 'Grande humanoide esculpido na pedra bruta e animado em rituais '
            'arcanos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 87}],
  'habitats': ['qualquer'],
  'id': 'golem-de-pedra-louco',
  'name': 'Golem de Pedra Louco',
  'parent_monster_url': 'https://olddragon.com.br/monstros/golem-de-pedra.json',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/golem-de-pedra-louco.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 9,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Chifre',
               'text': '1 × Chifre +9 (2d6)',
               'times': 1,
               'weapon': False}],
  'ca': '18',
  'concept': 'besta',
  'description': 'Um enorme touro de pele grossa e metálica, de cor escura e '
                 'carranca perigosa.  Alguns apresentam veias reluzentes em '
                 'tons azulados ou esverdeados, que brilham e pulsam enquanto '
                 'está furioso.\n'
                 '\n'
                 'De suas narinas, saem dois jatos de gases tóxicos levemente '
                 'esverdeados, resultado da sua sempre ofegante respiração.\n'
                 '\n'
                 'São agressivos e, geralmente, atacam com fúria qualquer '
                 'criatura ou pessoa encontrada, parando apenas quando '
                 'abatidos ou quando precisam fugir para se manter vivos.\n'
                 '\n'
                 'Sua ferocidade é tão grande que relatos de Górgons que '
                 'tenham passado dias perseguindo suas vítimas não são '
                 'incomuns.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Ao avistar o alvo, parte correndo para lhe atropelar. Em '
                 'alguns casos, quando o alvo está sozinho, usa sua baforada '
                 'para petrificá-lo e, logo após, ataca com toda a fúria de '
                 'sua investida para destruí-lo.\n'
                 '\n'
                 '  * **Atropelar**: um Górgon ainda não engajado em combate '
                 'pode usar a manobra de investida para causar o dobro de dano '
                 'com seus chifres.\n'
                 '\n'
                 '  * **Baforada Petrificante**: um Górgon é capaz de lançar '
                 'uma nuvem de gás petrificante a todos a até 10 metros de '
                 'distância do Górgon. Uma JPC evita a petrificação.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Não costumam viver em bandos, abandonando seu parceiro assim '
                 'que o filhote se mostra apto a se defender.\n'
                 '\n'
                 'Podem comer qualquer coisa, inclusive metal, fazendo muitos '
                 'acreditarem que isso tem alguma ligação com a sua pele '
                 'rígida.\n'
                 '\n'
                 'Não possuem inimigos naturais na natureza, além delas mesmas '
                 'e dos humanos (a única criatura conhecida por caçar '
                 'Górgons).\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A couraça do Górgon é muito usada na confecção de itens '
                 'mágicos de proteção, como armaduras ou escudos.',
  'dv': '8',
  'dv_bonus': '',
  'encounters': '1d2',
  'encounters_lair': '1d4',
  'flavor': 'Touro enorme com uma carapaça metálica. Hostil, ataca antes sem '
            'se importar como e porquê.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 109},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 103},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['planicies', 'colinas'],
  'id': 'gorgon',
  'jp': '8',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Górgon',
  'picture': 'https://public.olddragon.com.br/7wc9lctzbpcd2rkg7v11rnyb29ej',
  'pv': '40',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/xka7u88j7bioe2nltuw5emnpsuq7',
  'treasure': None,
  'treasure_lair': 'e',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gorgon.json',
  'variant': False,
  'xp': '740'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Pancadas',
               'text': '2 × Pancadas +4 (1d4)',
               'times': 2,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '2d6',
  'encounters_lair': '5d6',
  'flavor': 'Primatas enormes e ferozes que vivem nas florestas tropicais.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 17},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas'],
  'id': 'gorila',
  'jp': '6',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': 6,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Gorila',
  'picture': None,
  'pv': '20',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gorila.json',
  'variant': False,
  'xp': '125'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': 0,
               'damage_description': '1d4',
               'description': 'Pancada',
               'text': '1 × Pancada +2 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'morto_vivo',
  'description': '  * **Silencioso**: não produz som algum ao movimentar-se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Corpo de Osso**: armas impactantes causam o dobro de '
                 'dano nos Esqueletos, mas, em contrapartida, armas '
                 'perfurantes causam metade do ano.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar Mortos-Vivos.',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '3d4',
  'encounters_lair': '3d10',
  'flavor': 'Mortos-vivos normalmente usados como guardiões de locais antigos '
            'e esquecidos. Sem medo, atacam até caírem aos pedaços.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/tu2.json',
              'page': 43}],
  'habitats': ['qualquer'],
  'id': 'gosma-esqueleto',
  'jp': '4',
  'mo': 12,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Gosma Esqueleto',
  'parent_monster_url': 'https://olddragon.com.br/monstros/esqueleto.json',
  'pv': '10',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gosma-esqueleto.json',
  'variant': True,
  'variant_modifications': ['Indestrutíveis: qualquer ataque que o atinja é '
                            'imediatamente repelido pela gosma, evitando todo '
                            'tipo de dano.',
                            'Imunidades: fogo, ácido, ataques físicos ou '
                            'mágicos, magia Afastar mortos-vivos ou qualquer '
                            'outra fonte de dano.',
                            'Especial: existem apenas 4 Gosmas Esqueletos na '
                            'Masmorra. Após derrotar todos, petrificando-os '
                            'com o Basilisco ou empurrando-os no abismo, '
                            'ignore este tipo de resultado da tabela de '
                            'encontros aleatórios.'],
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 1,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4 + Arrastar',
               'description': 'Agarrão',
               'text': '1 × Agarrão +1 (1d4 + Arrastar)',
               'times': 1,
               'weapon': False}],
  'ca': '10',
  'concept': 'gosma',
  'description': 'Gosma feita de lava incandescente. Vive e se move pela lava, '
                 'buscando presas para agarrar.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Incandescente**: qualquer dano do tipo fogo não causa '
                 'efeito algum na Gosma. Água e líquidos não inflamáveis '
                 'causam 1d8 de dano na Gosma.\n'
                 '\n'
                 '  * **Arrastar**: ao ser acertado, o jogador precisa fazer '
                 'uma JPD para se esquivar de ser agarrado pela Gosma '
                 'Incandescente. Caso agarre alguém, o ataque da Gosma '
                 'Incandescente acerta automaticamente na próxima rodada, e '
                 'ela usa seu movimento para arrastar o personagem em direção '
                 'à lava.\n'
                 '\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 22}],
  'habitats': ['subterraneos'],
  'id': 'gosma-incandescente',
  'jp': '7',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Gosma Incandescente',
  'picture': None,
  'pv': '10',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gosma-incandescente.json',
  'variant': False,
  'xp': '95'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 1,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Pancada',
               'text': '1 × Pancada +1 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '10',
  'concept': 'gosma',
  'description': '  * **Incandescente**: qualquer dano do tipo fogo não causa '
                 'efeito algum na Gosma. Água e líquidos não inflamáveis '
                 'causam 1d8 de dano na Gosma.\n'
                 '\n'
                 '  * **Arrastar**: ao ser acertado, o jogador precisa fazer '
                 'uma JPD para se esquivar de ser agarrado pela Gosma '
                 'Incandescente. Caso agarre alguém, o ataque da Gosma '
                 'Incandescente acerta automaticamente na próxima rodada, e '
                 'ela usa seu movimento para arrastar o personagem em direção '
                 'à lava.',
  'dv': '½',
  'dv_bonus': '',
  'encounters': '',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 19}],
  'habitats': ['subterraneos'],
  'id': 'gosma-incandescente-menor',
  'jp': '4',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Gosma Incandescente Menor',
  'parent_monster_url': 'https://olddragon.com.br/monstros/gosma-incandescente.json',
  'pv': '2',
  'size': 'pequeno',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gosma-incandescente-menor.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 5,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6 + Ácido',
               'description': 'Toque',
               'text': '1 × Toque +5 (1d6 + Ácido)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'gosma',
  'description': 'Amorfa, esta criatura é um tipo de bolha repulsiva, uma '
                 'ameba disforme gigante com partes de seu corpo escorrendo e '
                 'se ergundo em constante movimento.\n'
                 '\n'
                 'Deixam um rastro úmido, porém inodoro e pegajoso por onde '
                 'passam.\n'
                 '\n'
                 'Usam seu corpo maleável para escorrer por frestas e por '
                 'debaixo de portas, infiltrando-se por onde conseguirem em '
                 'busca de carne, celulose ou outros materiais orgânicos para '
                 'devorar.\n'
                 '\n'
                 '**Som**: líquido gotejando e escorrendo.\n'
                 '\n'
                 '**Odor**: ácido e salgado, como maresia.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Avessas à luz, gostam de se esconder no escuro, às vezes se '
                 'aderindo à paredes e teto, caindo em cima dos oponentes.\n'
                 '\n'
                 '  * **Ácido**: a Gosma Ocre causa dano ácido aos inimigos '
                 'tocados em combate. Seu ácido é capaz de destruir papel, '
                 'tecido, couro e madeira, mas não pedra e metal.\n'
                 '\n'
                 '  * **Divisão**: se atacadas por eletricidade ou armas '
                 'cortantes, uma Gosma Ocre pode ser dividida ao meio. As '
                 'Gosmas Ocres resultantes da divisão devem ser tratadas como '
                 'dois inimigos diferentes com a metade dos pontos de vida '
                 'restantes da Gosma Ocre original.\n'
                 '\n'
                 '  * **Imunidades**: imune aos efeitos do frio e da '
                 'eletricidade. Uma Gosma Ocre atacada com eletricidade ainda '
                 'pode se dividir ao meio.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Estas gosmas vivem em grupos apenas quando, por algum '
                 'motivo, sofreram divisão, ou seja, quando mais de uma está '
                 'reunida, é porque elas fazem parte da mesma gosma original.\n'
                 '\n'
                 'É possível algumas gosmas se juntarem para formar uma gosma '
                 'única, gigantesca e monstruosa, a qual poderia comandar '
                 'todas as gosmas com seu poder mental, mas esta possibilidade '
                 'nunca foi confirmada.',
  'dv': '5',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '0',
  'flavor': 'Criatura amorfa similar a uma ameba gigante e de cor parda.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 104},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday24.json',
              'page': 16},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'gosma-ocre',
  'jp': '8',
  'mo': 12,
  'mv': 6,
  'mvc': None,
  'mve': 6,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Gosma Ocre',
  'picture': 'https://public.olddragon.com.br/zd636mvxz41lsygqjrhs6qsqtmxo',
  'pv': '25',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/awrll4u1s548f3r1y4pcszvec6eu',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/gosma-ocre.json',
  'variant': False,
  'xp': '235'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8 + Infecção',
               'description': 'Mordida',
               'text': '1 × Mordida +3 (1d8 + Infecção)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'morto_vivo',
  'description': 'Zumbis são criaturas lentas que servem a entidades malignas, '
                 'após serem reanimados de seus túmulos.\n'
                 '\n'
                 'Diferente dos Esqueletos, matam não apenas por ordem, mas '
                 'porque desejam devorar suas vítimas. Quando criados por meio '
                 'de animais, normalmente se encontram presos a coleiras, pois '
                 'a fome pelos vivos é enorme.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usados como soldados, os Zumbis não costumam trabalhar com '
                 'criaturas vivas, pois são uma ameaça a sua segurança.\n'
                 '\n'
                 'O desejo incontrolável por devorar a carne dos vivos faz com '
                 'que sejam colocados com outros mortos-vivos ou criaturas '
                 'incorpóreas. Quando atacam, usam suas garras para puxar e '
                 'para tentar morder seus alvos, mas só conseguirão caso a '
                 'vítima esteja lutando sem armas ou com armas pequenas como '
                 'adagas.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a magias mentais de manipulação, '
                 'controle ou ilusão, ou demais formas mágicas de interferir '
                 'na mente de seres vivos. Sofre 1d6 de dano ácido por frasco '
                 'de água benta.\n'
                 '\n'
                 '  * **Lento**: sempre perde a Iniciativa num combate. Um '
                 'Zumbi sempre ataca por último.\n'
                 '\n'
                 '  * **Infecção**: personagens mordidos devem passar em uma '
                 'JPC ou se tornarão Zumbis em 1d4 dias, a não ser que uma '
                 'magia de Curar Doenças ou Curar Ferimentos seja usada no '
                 'alvo infectado.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral a '
                 'não ser quando sofrem o efeito de um Afastar Mortos-Vivos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Zumbis não se relacionam com nenhuma outra criatura, assim '
                 'como a maioria dos mortos-vivos que não possuem '
                 'inteligência.\n'
                 '\n'
                 'Quando estão em grupos grandes, devoram as vítimas até não '
                 'sobrar mais nada, por isso novos Zumbis surgem destes '
                 'ataques apenas quando o bando é menor e quando resta alguma '
                 'integridade no corpo para que possa se locomover e atacar.\n'
                 '\n'
                 'Além de Magos e Clérigos, existem casos em que energias '
                 'muito malignas acabam criando estes mortos-vivos de forma '
                 'espontânea pela simples emanação energética de planos '
                 'negativos.\n'
                 '\n'
                 '## Variações\n'
                 '\n'
                 'Os acontecimentos que desencadeiam a criação de um Zumbi '
                 'ainda estão longe de serem dominados pelos maiores '
                 'estudiosos da necromancia. Não sendo uma espécie única, os '
                 'Zumbis possuem as mais diferentes origens, comportamentos e '
                 'características, dando origem a diferentes tipos, com '
                 'propósitos e meios de agir únicos.\n'
                 '\n'
                 '### Zumbi do Sal\n'
                 '\n'
                 'Criado pela horrenda experiência de morrer de sede em '
                 'desertos. Desidratados e desesperados, perseguem os vivos '
                 'pela água em seus corpos.  São capazes de se transformarem '
                 'em criaturas realmente determinadas pelo seu objetivo único '
                 'de se hidratar a todo o custo.\n'
                 '\n'
                 'Mantém todas as estatísticas e habilidades de um Zumbi '
                 'comum, mas troca sua habilidade de Infecção pela habilidade '
                 'a seguir:\n'
                 '\n'
                 '  * **Sugar**: se o ataque de mordida for bem-sucedido, ele '
                 'agarra sua vítima e começa a sugar o seu sangue, causando '
                 '1d6 de dano por rodada até ser morta. A única forma de '
                 'soltá-lo da vítima é destruindo sua cabeça, reduzindo seus '
                 'PV a zero ou menos.\n'
                 '\n'
                 '### Zumbi Afogado\n'
                 '\n'
                 'Criado por pessoas afogadas. Seu corpo é inchado, gotejante '
                 'e deformado, como as vítimas de afogamentos.  Sua carne tem '
                 'aspecto de ter sido comida por peixes e outros seres do '
                 'mar.\n'
                 '\n'
                 'Mantém todas as estatísticas e habilidades de um Zumbi '
                 'comum, mas troca sua habilidade de Infecção pela habilidade '
                 'a seguir:\n'
                 '\n'
                 '  * **Explodir**: ao sofrer dano, há uma chance de 1 em 1d6 '
                 'do seu corpo estourar, espalhando em todos dentro de uma '
                 'área de 3m uma onda de dejetos pútridos e purulentos, '
                 'repletos de doenças e infecção. Um alvo atingido deve ser '
                 'bem-sucedido numa JPC ou sofrerá os efeitos do contágio, '
                 'deixando o doente com Constituição 1 durante 1d6 dias.  Há '
                 'uma chance de 1 em 1d6 do doente morrer.\n'
                 '\n'
                 '### Esporo-Zumbi\n'
                 '\n'
                 'Resultado imprevisível de mortos-vivos atacados por fungos '
                 'desconhecidos dos subterrâneos.\n'
                 '\n'
                 'Os esporos se desenvolvem nos corpos contaminados pelo ar ou '
                 'por alimentos e líquidos contaminados. Passam a controlar o '
                 'cérebros de seus hospedeiros, transformando-os em criaturas '
                 'assassinas e agressivas, que perseguem suas vítimas para '
                 'passar a infecção adiante.\n'
                 '\n'
                 'Possui diferentes habilidades à medida que a infecção cresce '
                 'e toma conta de seu corpo:\n'
                 '\n'
                 '  * **Infectado**: durante os primeiros dias da infecção e '
                 'por toda esta fase, o Esporo-Zumbi troca suas habilidades '
                 'Silencioso e Lento pela habilidade de Correr, tendo o '
                 'movimento de quando era vivo.\n'
                 '\n'
                 '  * **Fendido**: após os primeiros dias de infecção, seu '
                 'crânio fica fendido por vários fungos que brotam de seu '
                 'interior. Nesta fase, ele troca sua habilidade de Correr '
                 'pela habilidade de Perseguir, usando uma espécie de '
                 'ecolocalização para saber precisamente onde todo ser vivo '
                 'está num raio de 30m.\n'
                 '\n'
                 '  * **Rei**: aproximadamente um mês após a infecção, têm seu '
                 'corpo completamente tomado pelo fungo, tornando-se uma '
                 'máquina de propagar seus esporos. Durante um combate, todos '
                 'em até 9m de um Esporo-Zumbi Rei que receberem um ataque '
                 'bem-sucedido, possuem uma chance de 1 em 1d6 de serem '
                 'infectados pelos esporos, tornando-se um Infectado, '
                 'reiniciando todo o processo.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '4d6',
  'flavor': 'Morto-vivo sem inteligência. Avança para cima de suas vítimas com '
            'o único intuito de destroçá-las com garras e dentes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 178}],
  'habitats': ['qualquer'],
  'id': 'grande-felino-zumbi',
  'jp': '15',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Grande Felino Zumbi',
  'parent_monster_url': 'https://olddragon.com.br/monstros/zumbi.json',
  'picture': 'https://public.olddragon.com.br/cz4xa87qz93imyvxgtmjrpst2zrk',
  'pv': '20',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/6yi5o3kte4bwdldij0z092zdsk4x',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/grande-felino-zumbi.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '125'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Bordão',
               'text': '1 × Bordão +1 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': '  * **Infravisão**: 18 metros.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '4d4',
  'encounters_lair': '6d10',
  'flavor': 'Humanoides pequenos e covardes que armam armadilhas para '
            'surpreenderem seus adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 6},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday23.json',
              'page': 16}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'grande-xama-kobold',
  'jp': '6',
  'mo': 10,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Grande Xamã Kobold',
  'parent_monster_url': 'https://olddragon.com.br/monstros/kobold.json',
  'pv': '20',
  'size': 'pequeno',
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/grande-xama-kobold.json',
  'variant': True,
  'variant_modifications': ['Magia como Clérigo de 2º nível.'],
  'xp': '150'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 7,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Garras',
               'text': '2 × Garras +7 (1d4)',
               'times': 2,
               'weapon': False},
              {'ba': 7,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Mordida',
               'text': '1 × Mordida +7 (2d8)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'besta',
  'description': 'Estas majestosas criaturas meio leão e meio águia, são '
                 'ferozes carnívoras que atacam animais de grande porte e '
                 'outras criaturas voadoras gigantes para obter sua '
                 'alimentação.\n'
                 '\n'
                 'A cabeça e toda a parte superior do seu corpo são como as de '
                 'uma Águia Gigante, com penas, patas dianteiras com garras '
                 'afiadas e um bico curvo afiado como uma adaga. Já a parte '
                 'posterior do corpo é a de um imenso leão, com pelos '
                 'brilhosos e amarelos, fortes patas felinas e uma cauda cuja '
                 'ponta possui um pequeno emaranhado de penas.\n'
                 '\n'
                 'Grifos totalmente brancos ou totalmente negros são '
                 'extremamente raros.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Preferem atacar com suas garras dando golpes em alta '
                 'velocidade, descendo dos céus.  Usam também suas poderosas '
                 'asas para levantar poeira e prejudicar o adversário.\n'
                 '\n'
                 '  * **Presa Preferencial**: Grifos na natureza possuem como '
                 'principal fonte de alimentação os cavalos selvagens. Assim, '
                 'sempre que encontrar um cavalo, precisará passar em um teste '
                 'de moral para não atacá-lo instintivamente.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Extremamente protetores de seus filhotes, Grifos escolhem '
                 'moradas em lugares perigosos e de difícil acesso, pois '
                 'muitos são os que buscam seus ovos para domesticar os '
                 'filhotes.\n'
                 '\n'
                 'Entrar próximo do território de um Grifo já pode ser motivo '
                 'mais que suficiente para provocar um ataque.\n'
                 '\n'
                 'Muito inteligentes, quando domesticados são poderosos '
                 'reforços em tempos de guerra.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Ovos não chocados de Grifos são muito valorizados por '
                 'criadores de montarias aladas.',
  'dv': '7',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '2d4',
  'flavor': 'Um enorme leão alado com cabeça, patas dianteiras e asas de águia '
            'gigante.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 105},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['colinas', 'montanhas'],
  'id': 'grifo',
  'jp': '6',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 21,
  'name': 'Grifo',
  'picture': 'https://public.olddragon.com.br/ak3yy4x9s3ixwchhylk33xh1yrzg',
  'pv': '35',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/68uwhdggf1v22p2k6e5oxoqtedgy',
  'treasure': None,
  'treasure_lair': 'e',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/grifo.json',
  'variant': False,
  'xp': '420'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide_monstruoso',
  'flavor': 'Grotescos são versões deformadas e monstruosas de humanoides '
            'contaminados pelo Sangue Sombrio secretado pelo Verme-Que-Anda, o '
            'Marcado conhecido como o Lorde da Podridão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 33}],
  'habitats': ['qualquer'],
  'id': 'grotesco',
  'name': 'Grotesco',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/grotesco.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Espada curta',
               'text': '1 × Espada curta +1 (1d6+1)',
               'times': 1,
               'weapon': False},
              {'ba': 1,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Arco curto',
               'text': '1 × Arco curto +1 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': 'Organizados em caravanas percorrendo as estradas, levam seus '
                 'produtos em grandes carroças, vendendo e comprando '
                 'mercadorias para as mais diferentes e distantes '
                 'localizações.\n'
                 '\n'
                 'Encontrados em caravanas de 4d6 + 10 indivíduos.\n'
                 '\n'
                 'Caravana: há duas carroças repletas de mercadorias para cada '
                 'mercador, descontados os guarda-costas e Chefe da Guarda. '
                 'Cada carroça é puxada por uma parelha de dois cavalos de '
                 'tração.\n'
                 '\n'
                 'Mercadorias: jogue 1d6 para determinar o que a caravana '
                 'transporta. O resultado do dado significa que a caravana '
                 'transporta aquele tipo de item e os de valor menor: 1. '
                 'Alimentos, 2. Utilidades Domésticas, 3. Especiarias, 4. '
                 'Equipamentos Gerais, 5. Armas e Armaduras e 6. Objetos de '
                 'Valor.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 4 Mercadores, um deles será um '
                 'Guarda-Costas. Além disso, há sempre um Chefe da Guarda por '
                 'caravana.\n'
                 '\n'
                 '  * **Montada**: cavalo de montaria.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 184},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'guarda-costas-mercadores',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Guarda-Costas (Mercadores)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/mercador.json',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'a',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/guarda-costas-mercadores.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 2,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Espada bastarda',
               'text': '1 × Espada bastarda +2 (1d8+2)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'humanoide',
  'description': '\n\n  * **Montado**: cavalo de guerra.\n\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday22.json',
              'page': 13}],
  'habitats': ['qualquer'],
  'id': 'guarda-do-grifo-branco',
  'jp': '5',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Guarda do Grifo Branco',
  'picture': None,
  'pv': '10',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/guarda-do-grifo-branco.json',
  'variant': False,
  'xp': '50'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide',
  'flavor': 'Guardas do Palácio da Noite, prontos para defender o local.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 69}],
  'habitats': ['desertos'],
  'id': 'guarda-do-palacio',
  'name': 'Guarda do Palácio',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/guarda-do-palacio.json',
  'variant': False},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 0,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Lança',
               'text': '1 × Lança (1d6)',
               'times': 1,
               'weapon': False},
              {'ba': 1,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Mordidas',
               'text': '2 × Mordidas +1 (1d4)',
               'times': 2,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': '  * **Infravisão**: 18 metros.',
  'dv': '½',
  'dv_bonus': '1',
  'encounters': '4d4',
  'encounters_lair': '6d10',
  'flavor': 'Humanoides pequenos e covardes que armam armadilhas para '
            'surpreenderem seus adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 69},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 6}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'guarda-kobold',
  'jp': '4',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Guarda Kobold',
  'parent_monster_url': 'https://olddragon.com.br/monstros/kobold.json',
  'pv': '3',
  'size': 'pequeno',
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/guarda-kobold.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '5'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Espada curta',
               'text': '1 × Espada curta +1 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': 'Estes homens formam o corpo da guarda ou do exército de um '
                 'nobre local e fazem parte de um destacamento de patrulha '
                 'urbana ou dos ermos.  Vivem para vigiar e resguardar a lei e '
                 'a ordem em nome do nobre local.\n'
                 '\n'
                 '**Pedidos de socorro**: Patrulhas/Milícias possuem uma '
                 'chance básica de 1-2 em 1d6 de ouvir um pedido de socorro em '
                 'agrupamentos urbanos iguais a uma cidade ou metrópole.\n'
                 '\n'
                 '**Encontrados**: as patrulhas são formadas por 2d6 Guardas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: toda patrulha possui um Chefe da Guarda. '
                 'Há ainda uma chance de 1-2 em 1d6 do Capitão da Guarda estar '
                 'presente.\n'
                 '\n'
                 '## Reforços\n'
                 '\n'
                 'Sempre que uma ocorrência ocorre e uma patrulha se encontra '
                 'com um grupo que impõe resistência a prisão, há 1-2 chances '
                 'em 1d6 de um dos guardas deixar o local do encontro para '
                 'buscar reforços.\n'
                 '\n'
                 '**Ermos**: se o encontro for realizado em um ermo, o guarda '
                 'procurará a base da guarda para avisar do encontro e trazer '
                 'reforços para o local. Use a contagem de tempo e viagem até '
                 'o local apropriado ou se em necessidade, um reforço demorará '
                 '1d4+2 turnos para chegar. O reforço usa as mesmas regras '
                 'para sua formação que uma patrulha normal, mas existirá '
                 'apenas um único Capitão da Guarda.\n'
                 '\n'
                 '**Urbanos**: reforços urbanos são mais rápidos de se obter. '
                 'Mesmo que nenhum guarda abandone o local para chamá-los há '
                 '1-3 chances de um reforço surgir no local do encontro após '
                 '2d6 rodadas, simplesmente pela confusão, gritos e barulho de '
                 'batalha. Depois que este primeiro grupo de reforço chegar ao '
                 'local, um novo grupo de reforço chegará ao local em ondas de '
                 'patrulhas a cada 1d6+2 rodadas.\n'
                 '\n'
                 '## Pedindo Socorro\n'
                 '\n'
                 'Se a intenção é gritar por ajuda da guarda, as chances de se '
                 'obter ajuda são pequenas e dependem exclusivamente do local '
                 'onde se está.\n'
                 '\n'
                 '**Ermos**: a não ser que haja um forte, castelo, agrupamento '
                 'urbano no hexágono em questão nenhuma patrulha ouvirá um '
                 'pedido de socorro.  Caso haja, há apenas 1 chance em 1d6 de '
                 'uma patrulha estar passando subhex no momento do pedido de '
                 'socorro e apenas 1 chance em 1d6 deste ser ouvido.\n'
                 '\n'
                 '**Urbanos**: nas cidades, vilas e povoados a chance está '
                 'ligada ao tamanho da cidade e do tipo de distrito onde o '
                 'pedido de socorro é proferido. Em aldeias ou Bairros Pobres, '
                 'a chance é de 1 em 1d6. Em Vilas ou Bairros Ricos e '
                 'Comerciais, a chance é de 1-3 em 1d6.\n'
                 '\n'
                 '## Corrupção\n'
                 '\n'
                 'Se durante o encontro com uma patrulha, houver negociação e '
                 'necessidade de argumentar uma passagem livre, os personagens '
                 'podem sentir necessidade de negociar alguma vantagem para '
                 'serem deixados em paz.\n'
                 '\n'
                 'Se houver uma tentativa de corromper os guardas, com o '
                 'oferecimento de uma vantagem ilícita, há 1-2 chances em 1d6 '
                 'do efeito ser o contrário e isso enfurecer ainda mais a '
                 'patrulha. Neste caso, um teste de reação deve ser realizado '
                 'para saber qual a reação da patrulha à tentativa de '
                 'corrupção.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 190},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'guarda-patrulha-milicia',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Guarda (Patrulha/Milícia)',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/guarda-patrulha-milicia.json',
  'variant': False,
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '2d6',
               'damage_bonus': 4,
               'damage_description': '2d6+4',
               'description': 'Machado',
               'text': '1 × Machado +4 (2d6+4)',
               'times': 1,
               'weapon': False}],
  'ca': '13/20',
  'concept': 'humanoide_monstruoso',
  'description': 'Usam uma armadura completa, enegrecida, com grandes chifres '
                 'em seus elmos.\n'
                 '\n'
                 'Não é possível ver seus rostos, ou até mesmo seus olhos, '
                 'pois a armadura parece fundida em seus corpos.\n'
                 '\n'
                 'Levam signos do caos pintados em seus corpos para reforçar a '
                 'conexão com seus mestres.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam com extrema fúria e inteligência, dispensando ataques '
                 'à longa distância.\n'
                 '\n'
                 'Podem comandar mercenários, usando-os como linha de frente '
                 'para depois entrarem com seus poderosos machados.\n'
                 '\n'
                 '  * **Classe de armadura**: Guerreiros do Caos possuem CA 13 '
                 'ou 20 quando usam armadura completa.\n'
                 '\n'
                 '  * **Lutar além da morte**: mantêm-se ativos em combate por '
                 'até 1d6+2 rodadas após atingirem zero pontos de vida. Ao fim '
                 'deste tempo, caem imediatamente mortos ao chão.\n'
                 '\n'
                 '  * **Marca do caos**: ao desejarem, deixam o caos tomar '
                 'conta de seus corpos. Recebem +2 no BA e +4 no dano, além de '
                 '4 pontos de dano em si mesmos ao fim de cada rodada em que '
                 'esta habilidade estiver acionada.\n'
                 '\n'
                 '  * **Resistência à dano**: ignoram 1 ponto de dano de cada '
                 'ataque físico.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Escolhidos dentre os melhores guerreiros dos reinos, '
                 'Guerreiros do Caos têm a mente distorcida após o contato com '
                 'as energias caóticas de seus senhores.\n'
                 '\n'
                 'São bárbaros, preocupando-se apenas em destruir e conquistar '
                 'territórios para os Arautos, grupo seleto de agentes dos '
                 'deuses malignos.',
  'dv': '7',
  'dv_bonus': '+3',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Guerreiros fanáticos que lutam pelas forças do caos. Possuem '
            'poderes que os levam além dos limites da vida e da morte.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 106},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'guerreiro-do-caos',
  'jp': '11',
  'mo': 11,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Guerreiro do Caos',
  'picture': 'https://public.olddragon.com.br/k8hgqletrrdnsqvqyabnakfqucpa',
  'pv': '38',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/dqnq6ascwzsc8c7uduwl0qefk06y',
  'treasure': 'tx2',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/guerreiro-do-caos.json',
  'variant': False,
  'xp': '540'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Espada Longa',
               'text': '1 × Espada Longa +3 (1d8+2)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': '\n\n\n\n',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': 'Guerreiros vindos do poderoso Império Hecatiano, que se baseia em '
            'três pilares - controle, trabalho e dinheiro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday17.json',
              'page': 21}],
  'habitats': ['qualquer'],
  'id': 'guerreiro-hecatiano',
  'jp': '6',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Guerreiro Hecatiano',
  'picture': None,
  'pv': '15',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/guerreiro-hecatiano.json',
  'variant': False,
  'xp': '125'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Espada Curta',
               'text': '1 × Espada Curta +2 (1d6)',
               'times': 1,
               'weapon': False},
              {'ba': 0,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Agarrar',
               'description': 'Agarrar',
               'text': '1 × Agarrar (Agarrar)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': '\n'
                 '\n'
                 '  * **Agarrar**: imobiliza um alvo médio ou menor, fazendo '
                 'com que não possa se movimentar e faça seus ataques e testes '
                 'como difícil. Em sua ação, o alvo pode fazer um teste '
                 'resistido de FOR contra o guerreiro, conseguindo fugir do '
                 'agarrão caso obtenha sucesso. Enquanto agarrado, o guerreiro '
                 'pode se movimentar, levando consigo o alvo agarrado.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '+1',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': 'Povo alto e forte do leste, são conhecidos por suas práticas '
            'escravocráticas que cobrem todo o continente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 14}],
  'habitats': ['qualquer'],
  'id': 'guerreiro-ibano',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Guerreiro Íbano',
  'picture': None,
  'pv': '6',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/guerreiro-ibano.json',
  'variant': False,
  'xp': '25'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '2d6',
               'damage_bonus': 1,
               'damage_description': '2d6+1',
               'description': 'Chifre',
               'text': '1 × Chifre +2 (2d6+1)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Garras',
               'text': '2 × Garras +2 (1d8+1)',
               'times': 2,
               'weapon': False}],
  'ca': '17',
  'concept': 'besta',
  'description': 'Medindo quase 3 metros de altura, possui corpo delgado e '
                 'corcunda, com chifre e carapaça semelhantes aos de um '
                 'besouro.\n'
                 '\n'
                 'Suas patas traseiras possuem pés com três pequenas garras em '
                 'forma de ganchos. Já as dianteiras, são como um longo e '
                 'recurvado gancho córneo, perfeito para escalar e prender-se '
                 'em superfícies.\n'
                 '\n'
                 'A cabeça lembra a de um abutre ou urubu com olhos '
                 'multifacetados como os dos insetos, adaptados a enxergar no '
                 'escuro.\n'
                 '\n'
                 '**Som**: pancadas leves na pedra.\n'
                 '\n'
                 '**Odor**: poeira e mofo seco.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Quando percebem uma presa, se fixam no teto com seus ganchos '
                 'nas mãos, atacando de surpresa.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '  * **Camuflagem**: sua cor escura garante um bônus de +1 em '
                 'testes de surpresa.\n'
                 '\n'
                 '  * **Desarmar**: caso obtenham um resultado 20 no dado de '
                 'ataque, arrancam das mãos do inimigo seu escudo ou arma '
                 '(nesta ordem, caso os tenham).\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Alimentam-se principalmente de pequenos mamíferos e fungos, '
                 'e vivem em grupos pequenos em tocas no subterrâneo.\n'
                 '\n'
                 'Os machos saem para caçar, mas nunca vão muito longe do lar, '
                 'enquanto as fêmeas defendem as tocas e protegem os filhotes '
                 'de intrusos e outros predadores.\n'
                 '\n'
                 'Estão bem acostumados à vida nas cavernas e possuem '
                 'pouquíssimos predadores naturais.\n'
                 '\n'
                 'Gostam de objetos brilhantes, mas, como não conseguem pegar '
                 'moedas, preferem tesouros maiores ou mais fáceis de serem '
                 'levados, como colares, pulseiras e joias.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'O exoesqueleto do Haken seca, ficando muito frágil para uso '
                 'após um mês. Mas seus ganchos permanecem intactos, '
                 'produzindo ótimos troféus para aventureiros.',
  'dv': '5',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '2d6',
  'flavor': 'Perigosa criatura com mãos de gancho. Vive nos subterrâneos e '
            'atacam os alvos de surpresa.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 107},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'haken',
  'jp': '8',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': 3,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Haken',
  'picture': 'https://public.olddragon.com.br/7bkcxpv41d9mv9xzn0rsqalprgjl',
  'pv': '25',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/spol8mqusrsnwajz61tnwpys45ip',
  'treasure': None,
  'treasure_lair': 'j',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/haken.json',
  'variant': False,
  'xp': '175'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Funda',
               'text': '1 × Funda +2 (1d4)',
               'times': 1,
               'weapon': False},
              {'ba': 1,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Espada curta',
               'text': '1 × Espada curta +1 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': 'Halflings são encontrados em grupos de patrulha ou pequenos '
                 'grupos de fazendeiros.\n'
                 '\n'
                 'Encontrados em grupos pequenos de 2d4 indivíduos ou em '
                 'grupos maiores como um acampamento com 2d12 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 15 halflings, um deles será um '
                 'Halfling Líder, e há 1-2 chances em 1d6 do líder ser um '
                 'Halfling Aventureiro.\n'
                 '\n'
                 '  * **Furtivo**: 1-2 chances em 1d6 de se esconderem.\n'
                 '\n'
                 '  * **Bom de mira**: ataques à distância como ataques '
                 'fáceis.\n'
                 '\n'
                 '  * **Pequenos**: atacantes grandes ou maiores realizam '
                 'ataques difíceis para acertar um halfling.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 186},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'halfling',
  'jp': '6',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Halfling',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/halfling.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '1d4',
               'damage_bonus': 3,
               'damage_description': '1d4+3',
               'description': 'Funda',
               'text': '1 × Funda +3 (1d4+3)',
               'times': 1,
               'weapon': False},
              {'ba': 3,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Espada curta',
               'text': '1 × Espada curta +3 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Halflings são encontrados em grupos de patrulha ou pequenos '
                 'grupos de fazendeiros.\n'
                 '\n'
                 'Encontrados em grupos pequenos de 2d4 indivíduos ou em '
                 'grupos maiores como um acampamento com 2d12 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 15 halflings, um deles será um '
                 'Halfling Líder, e há 1-2 chances em 1d6 do líder ser um '
                 'Halfling Aventureiro.\n'
                 '\n'
                 '  * **Furtivo**: 1-2 chances em 1d6 de se esconderem.\n'
                 '\n'
                 '  * **Bom de mira**: ataques à distância como ataques '
                 'fáceis.\n'
                 '\n'
                 '  * **Pequenos**: atacantes grandes ou maiores realizam '
                 'ataques difíceis para acertar um halfling.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 186},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'halfling-aventureiro',
  'jp': '6',
  'mo': 10,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Halfling Aventureiro',
  'parent_monster_url': 'https://olddragon.com.br/monstros/halfling.json',
  'picture': None,
  'pv': '15',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/halfling-aventureiro.json',
  'variant': True,
  'variant_modifications': ['Furtivo: 1-2 chances em 1d6 de se esconderem.',
                            'Bom de mira: ataques à distância como ataques '
                            'fáceis.',
                            'Pequenos: atacantes grandes ou maiores realizam '
                            'ataques difíceis para acertar um halfling.',
                            'Infravisão: 18 metros.',
                            'Senso de perigo: detecta perigo com 1-2 chances '
                            'em 1d6 para não ser surpreendido.',
                            'Arma racial: funda.',
                            'Valente: imune a qualquer tipo de medo.'],
  'xp': '135'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1',
               'description': 'Funda',
               'text': '1 × Funda +3 (1d4+1)',
               'times': 1,
               'weapon': False},
              {'ba': 3,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Espada curta',
               'text': '1 × Espada curta +3 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Halflings são encontrados em grupos de patrulha ou pequenos '
                 'grupos de fazendeiros.\n'
                 '\n'
                 'Encontrados em grupos pequenos de 2d4 indivíduos ou em '
                 'grupos maiores como um acampamento com 2d12 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 15 halflings, um deles será um '
                 'Halfling Líder, e há 1-2 chances em 1d6 do líder ser um '
                 'Halfling Aventureiro.\n'
                 '\n'
                 '  * **Furtivo**: 1-2 chances em 1d6 de se esconderem.\n'
                 '\n'
                 '  * **Bom de mira**: ataques à distância como ataques '
                 'fáceis.\n'
                 '\n'
                 '  * **Pequenos**: atacantes grandes ou maiores realizam '
                 'ataques difíceis para acertar um halfling.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 186},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'halfling-lider',
  'jp': '7',
  'mo': 10,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Halfling Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/halfling.json',
  'picture': None,
  'pv': '15',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/halfling-lider.json',
  'variant': True,
  'variant_modifications': ['Furtivo: 1-2 chances em 1d6 de se esconderem.',
                            'Bom de mira: ataques à distância como ataques '
                            'fáceis.',
                            'Pequenos: atacantes grandes ou maiores realizam '
                            'ataques difíceis para acertar um halfling.',
                            'Infravisão: 18 metros.',
                            'Moral: enquanto o líder estiver em combate, todos '
                            'os halflings fazem o teste de moral com um bônus '
                            'de +1.'],
  'xp': '115'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 6,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Garras',
               'text': '2 × Garras +6 (1d6)',
               'times': 2,
               'weapon': False},
              {'ba': 6,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma +6 (Arma)',
               'times': 1,
               'weapon': True}],
  'ca': '15',
  'concept': 'humanoide_monstruoso',
  'description': 'Aparentam Bruxas velhas e deformadas, com corpo de águia ou '
                 'outra ave semelhante.\n'
                 '\n'
                 'Suas garras dos pés são poderosas como a de uma ave de '
                 'rapina e suas mãos, embora mais comuns, possuem unhas muito '
                 'compridas.\n'
                 '\n'
                 'Seu cabelos são desgrenhados e, em casos não muito comuns, '
                 'usam roupas e até mesmo armas.\n'
                 '\n'
                 'Têm um apetite voraz, devorando todo tipo de homem e animal. '
                 'Deliciam-se com a tortura e frequentemente matam por '
                 'prazer.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Utilizam seu canto para enfraquecer os alvos, retalhando-os '
                 'com suas garras dos pés. Podem capturar alvos não muito '
                 'pesados e arremessá-los do céu, para depois se alimentarem '
                 'da carcaça.\n'
                 '\n'
                 '  * **Canto**: a Harpia emite um canto lamurioso o qual '
                 'encanta todos que estejam a até 90 metros dela. Uma JPS nega '
                 'os efeitos do canto pelas próximas 24 horas, mas, em caso de '
                 'falha, o alvo caminhará em direção à Harpia pelo melhor '
                 'caminho possível. A única ação possível a uma pessoa sob o '
                 'efeito do canto da Harpia é se defender. O efeito do '
                 'encantamento dura até um turno após a interrupção do canto.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em comunidades pequenas, normalmente com 10 membros, e '
                 'fazem seus ninhos em cavernas ou em tocas nas encostas das '
                 'falésias próximas ao mar.\n'
                 '\n'
                 'Mantêm ninhos muito bem protegidos, afastando qualquer '
                 'animal que ouse se aproximar.  Levam suas vítimas para estes '
                 'ninhos, para devorá-las sem preocupação.\n'
                 '\n'
                 'Harpias não precisam de machos para colocar ovos. De fato, '
                 'não há notícia de Harpias machos, transformando seu processo '
                 'de procriação em um grande mistério para os sábios.\n'
                 '\n'
                 'As Harpias não cuidam de seus filhotes, os quais vivem de '
                 'carcaças e insetos das cavernas até terem idade suficiente '
                 'para cantar e caçar.',
  'dv': '7',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '2d4',
  'flavor': 'Junção de ave de rapina com Bruxa que ataca qualquer criatura em '
            'seu território com seu canto lamurioso.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 108},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['montanhas', 'florestas'],
  'id': 'harpia',
  'jp': '7',
  'mo': 10,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Harpia',
  'picture': 'https://public.olddragon.com.br/rwpc9a7uz9ib2c5yst8qv90ybf98',
  'pv': '35',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/jmwf1l6o7240jvsy93orlf1dby1c',
  'treasure': 'r',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/harpia.json',
  'variant': False,
  'xp': '420'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 8,
               'damage': '1d10',
               'damage_bonus': None,
               'damage_description': '1d10',
               'description': 'Mordida',
               'text': '1 × Mordida +8 (1d10)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'besta',
  'description': 'De corpo reptiliano, as Hidras possuem longos pescoços e '
                 'cabeças que lembram lagartos e, em alguns casos, até mesmo '
                 'dragões.\n'
                 '\n'
                 'A variação do número de cabeças se dá principalmente pela '
                 'idade da Hidra, sendo mais numerosa quando mais velha.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Hidras atacam ferozmente e na maioria das vezes sem muito '
                 'planejamento.\n'
                 '\n'
                 'Quando o adversário está próximo, gostam de atacar de lados '
                 'distintos, tornando o uso de escudos muito difícil.\n'
                 '\n'
                 '  * **Múltiplas cabeças**: Hidras são encontradas com 1d8+4 '
                 'cabeças, cada uma com 1 Dado de Vida e 1 ataque. Uma Hidra '
                 'perde 1 cabeça a cada 8 pontos de dano recebidos. Uma cabeça '
                 'perdida se regenera dando origem a duas outras cabeças em '
                 '1d4 turnos (recuperando 2 DV e 2 ataques). Contudo, a cabeça '
                 'cortada não irá se regenerar caso seja atacada com fogo ou '
                 'ácido. Nesses casos, o pescoço fica inerte, não regenerando '
                 'novas cabeças.  Uma Hidra pode possuir no máximo 12 cabeças '
                 'simultaneamente.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Estas criaturas mágicas não são muito comuns, para a sorte '
                 'dos demais. Elas são muito vorazes, destruindo rebanhos '
                 'inteiros em algumas horas.\n'
                 '\n'
                 'Podem ficar muito tempo sem se alimentar novamente, mas, '
                 'quando precisam, deixam um rastro de carcaças.\n'
                 '\n'
                 'Quando ficam velhas, adquirem mais cabeças.  Cabeças '
                 'adquiridas por meio de combate caem após alguns dias, '
                 'transformando-se em pequenos ossos que caberiam em um saco '
                 'de veludo se reunidos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'O sangue das Hidras é o ingrediente base para a confecção de '
                 'poções de regeneração e cura.',
  'dv': '5 a 12',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Criatura semelhante a um lagarto imenso com várias cabeças.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 109},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['pantanos'],
  'id': 'hidra',
  'jp': '12',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Hidra',
  'picture': 'https://public.olddragon.com.br/t4cvcj8lcxwwt6313u15ipau3dq0',
  'pv': '25 a 60',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/za91l04not2bs5geic72s3z8a9ux',
  'treasure': None,
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/hidra.json',
  'variant': False,
  'xp': 'Especial'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '2',
  'dv_bonus': '+2',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Estes carnívoros ferozes vivem em grupos nas planícies tropicais '
            'e são peritas em caçar em grupo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 17},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['planicies'],
  'id': 'hiena',
  'jp': '5',
  'mo': 7,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Hiena',
  'picture': None,
  'pv': '12',
  'size': 'pequeno',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/hiena.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 3,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Arma',
               'text': '1 × Arma +3 (1d8+1)',
               'times': 1,
               'weapon': False}],
  'ca': '11/16',
  'concept': 'humanoide',
  'description': 'Estes humanoides vivem para a guerra, tomando-a como uma '
                 'arte e o caminho até seus deuses.\n'
                 '\n'
                 'São até mais organizados que os Orcs, mas padecem do mesmo '
                 'defeito: a falta de um líder que os una como uma grande '
                 'horda.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam de estratégia para sobrepujar os inimigos.\n'
                 '\n'
                 'Flanqueiam com cavaleiros, atacam com arqueiros e sua '
                 'infantaria recebe suporte de lanceiros e piqueiros embora o '
                 'seu conhecimento de armas de cerco seja rudimentar.\n'
                 '\n'
                 '  * **Classe de armadura**: Hobglobins possuem CA 11 ou 16 '
                 'quando usam cota de malha e escudo.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Divididos em tribos, vivem competindo entre si por prestígio '
                 'na forma de ouro e glórias.\n'
                 '\n'
                 'Levam a arte da guerra como um estilo de vida, mantendo suas '
                 'armas e armaduras bem cuidados e tatuagens aque demonstram '
                 'suas vitórias.\n'
                 '\n'
                 'Consideram os mais velhos como seus líderes, pois um '
                 'Hobgoblin, nunca deixa de lutar e por isso, se chegou até a '
                 'velhice, é porque deve ter sido em seu tempo, um grande '
                 'guerreiro.',
  'dv': '1',
  'dv_bonus': '+1',
  'encounters': '1d6',
  'encounters_lair': '4d6',
  'flavor': 'Militarizados, usam táticas avançadas de guerrilha, tornando-os '
            'em grandes forças mercenárias.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 75},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 175},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 110},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'hobgoblin',
  'jp': '5',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Hobgoblin',
  'picture': 'https://public.olddragon.com.br/io1vziktqpiudahi4ab9k3pgs1zh',
  'pv': '6',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/y3az06roefvckaoer0p4p48mkiv9',
  'treasure': 's',
  'treasure_lair': 'e',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/hobgoblin.json',
  'variant': False,
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Lança',
               'text': '1 × Lança +2 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'humanoide',
  'description': 'Estes humanoides vivem para a guerra, tomando-a como uma '
                 'arte e o caminho até seus deuses.\n'
                 '\n'
                 'São até mais organizados que os Orcs, mas padecem do mesmo '
                 'defeito: a falta de um líder que os una como uma grande '
                 'horda.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam de estratégia para sobrepujar os inimigos.\n'
                 '\n'
                 'Flanqueiam com cavaleiros, atacam com arqueiros e sua '
                 'infantaria recebe suporte de lanceiros e piqueiros embora o '
                 'seu conhecimento de armas de cerco seja rudimentar.\n'
                 '\n'
                 '  * **Classe de armadura**: Hobglobins possuem CA 11 ou 16 '
                 'quando usam cota de malha e escudo.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Divididos em tribos, vivem competindo entre si por prestígio '
                 'na forma de ouro e glórias.\n'
                 '\n'
                 'Levam a arte da guerra como um estilo de vida, mantendo suas '
                 'armas e armaduras bem cuidados e tatuagens aque demonstram '
                 'suas vitórias.\n'
                 '\n'
                 'Consideram os mais velhos como seus líderes, pois um '
                 'Hobgoblin, nunca deixa de lutar e por isso, se chegou até a '
                 'velhice, é porque deve ter sido em seu tempo, um grande '
                 'guerreiro.',
  'dv': '1',
  'dv_bonus': '+1',
  'encounters': '1d6',
  'encounters_lair': '4d6',
  'flavor': 'Militarizados, usam táticas avançadas de guerrilha, tornando-os '
            'em grandes forças mercenárias.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 110}],
  'habitats': ['qualquer'],
  'id': 'hobgoblin-batedor',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Hobgoblin Batedor',
  'parent_monster_url': 'https://olddragon.com.br/monstros/hobgoblin.json',
  'picture': 'https://public.olddragon.com.br/io1vziktqpiudahi4ab9k3pgs1zh',
  'pv': '6',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/y3az06roefvckaoer0p4p48mkiv9',
  'treasure': 's',
  'treasure_lair': 'e',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/hobgoblin-batedor.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '15'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Militarizados, usam táticas avançadas de guerrilha, tornando-os '
            'em grandes forças mercenárias.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 74}],
  'habitats': ['qualquer'],
  'id': 'hobgoblin-besteiro',
  'name': 'Hobgoblin Besteiro',
  'parent_monster_url': 'https://olddragon.com.br/monstros/hobgoblin.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/hobgoblin-besteiro.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Militarizados, usam táticas avançadas de guerrilha, tornando-os '
            'em grandes forças mercenárias.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 119}],
  'habitats': ['qualquer'],
  'id': 'hobgoblin-besteiro-veterano',
  'name': 'Hobgoblin Besteiro Veterano',
  'parent_monster_url': 'https://olddragon.com.br/monstros/hobgoblin.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/hobgoblin-besteiro-veterano.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 4,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Espada longa',
               'text': '1 × Espada longa +4 (1d8+2)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Estes humanoides vivem para a guerra, tomando-a como uma '
                 'arte e o caminho até seus deuses.\n'
                 '\n'
                 'São até mais organizados que os Orcs, mas padecem do mesmo '
                 'defeito: a falta de um líder que os una como uma grande '
                 'horda.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam de estratégia para sobrepujar os inimigos.\n'
                 '\n'
                 'Flanqueiam com cavaleiros, atacam com arqueiros e sua '
                 'infantaria recebe suporte de lanceiros e piqueiros embora o '
                 'seu conhecimento de armas de cerco seja rudimentar.\n'
                 '\n'
                 '  * **Classe de armadura**: Hobglobins possuem CA 11 ou 16 '
                 'quando usam cota de malha e escudo.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Divididos em tribos, vivem competindo entre si por prestígio '
                 'na forma de ouro e glórias.\n'
                 '\n'
                 'Levam a arte da guerra como um estilo de vida, mantendo suas '
                 'armas e armaduras bem cuidados e tatuagens aque demonstram '
                 'suas vitórias.\n'
                 '\n'
                 'Consideram os mais velhos como seus líderes, pois um '
                 'Hobgoblin, nunca deixa de lutar e por isso, se chegou até a '
                 'velhice, é porque deve ter sido em seu tempo, um grande '
                 'guerreiro.',
  'dv': '3',
  'dv_bonus': '+1',
  'encounters': '1d6',
  'encounters_lair': '4d6',
  'flavor': 'Militarizados, usam táticas avançadas de guerrilha, tornando-os '
            'em grandes forças mercenárias.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 110}],
  'habitats': ['qualquer'],
  'id': 'hobgoblin-campeao',
  'jp': '6',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Hobgoblin Campeão',
  'parent_monster_url': 'https://olddragon.com.br/monstros/hobgoblin.json',
  'picture': 'https://public.olddragon.com.br/io1vziktqpiudahi4ab9k3pgs1zh',
  'pv': '16',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/y3az06roefvckaoer0p4p48mkiv9',
  'treasure': 's',
  'treasure_lair': 'e',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/hobgoblin-campeao.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '75'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Militarizados, usam táticas avançadas de guerrilha, tornando-os '
            'em grandes forças mercenárias.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 75}],
  'habitats': ['qualquer'],
  'id': 'hobgoblin-comandante',
  'name': 'Hobgoblin Comandante',
  'parent_monster_url': 'https://olddragon.com.br/monstros/hobgoblin.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/hobgoblin-comandante.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 4,
               'damage': '2d6',
               'damage_bonus': 3,
               'damage_description': '2d6+3',
               'description': 'Machado de batalha',
               'text': '1 × Machado de batalha +4 (2d6+3)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'humanoide',
  'description': 'Estes humanoides vivem para a guerra, tomando-a como uma '
                 'arte e o caminho até seus deuses.\n'
                 '\n'
                 'São até mais organizados que os Orcs, mas padecem do mesmo '
                 'defeito: a falta de um líder que os una como uma grande '
                 'horda.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam de estratégia para sobrepujar os inimigos.\n'
                 '\n'
                 'Flanqueiam com cavaleiros, atacam com arqueiros e sua '
                 'infantaria recebe suporte de lanceiros e piqueiros embora o '
                 'seu conhecimento de armas de cerco seja rudimentar.\n'
                 '\n'
                 '  * **Classe de armadura**: Hobglobins possuem CA 11 ou 16 '
                 'quando usam cota de malha e escudo.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Divididos em tribos, vivem competindo entre si por prestígio '
                 'na forma de ouro e glórias.\n'
                 '\n'
                 'Levam a arte da guerra como um estilo de vida, mantendo suas '
                 'armas e armaduras bem cuidados e tatuagens aque demonstram '
                 'suas vitórias.\n'
                 '\n'
                 'Consideram os mais velhos como seus líderes, pois um '
                 'Hobgoblin, nunca deixa de lutar e por isso, se chegou até a '
                 'velhice, é porque deve ter sido em seu tempo, um grande '
                 'guerreiro.',
  'dv': '4',
  'dv_bonus': '+1',
  'encounters': '1d6',
  'encounters_lair': '4d6',
  'flavor': 'Militarizados, usam táticas avançadas de guerrilha, tornando-os '
            'em grandes forças mercenárias.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 76},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 110}],
  'habitats': ['qualquer'],
  'id': 'hobgoblin-lider',
  'jp': '6',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Hobgoblin Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/hobgoblin.json',
  'picture': 'https://public.olddragon.com.br/io1vziktqpiudahi4ab9k3pgs1zh',
  'pv': '21',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/y3az06roefvckaoer0p4p48mkiv9',
  'treasure': 's',
  'treasure_lair': 'e',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/hobgoblin-lider.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '125'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 3,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Arco longo',
               'text': '1 × Arco longo +3 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'humanoide',
  'description': 'Estes humanoides vivem para a guerra, tomando-a como uma '
                 'arte e o caminho até seus deuses.\n'
                 '\n'
                 'São até mais organizados que os Orcs, mas padecem do mesmo '
                 'defeito: a falta de um líder que os una como uma grande '
                 'horda.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam de estratégia para sobrepujar os inimigos.\n'
                 '\n'
                 'Flanqueiam com cavaleiros, atacam com arqueiros e sua '
                 'infantaria recebe suporte de lanceiros e piqueiros embora o '
                 'seu conhecimento de armas de cerco seja rudimentar.\n'
                 '\n'
                 '  * **Classe de armadura**: Hobglobins possuem CA 11 ou 16 '
                 'quando usam cota de malha e escudo.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Divididos em tribos, vivem competindo entre si por prestígio '
                 'na forma de ouro e glórias.\n'
                 '\n'
                 'Levam a arte da guerra como um estilo de vida, mantendo suas '
                 'armas e armaduras bem cuidados e tatuagens aque demonstram '
                 'suas vitórias.\n'
                 '\n'
                 'Consideram os mais velhos como seus líderes, pois um '
                 'Hobgoblin, nunca deixa de lutar e por isso, se chegou até a '
                 'velhice, é porque deve ter sido em seu tempo, um grande '
                 'guerreiro.',
  'dv': '2',
  'dv_bonus': '+1',
  'encounters': '1d6',
  'encounters_lair': '4d6',
  'flavor': 'Militarizados, usam táticas avançadas de guerrilha, tornando-os '
            'em grandes forças mercenárias.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 110}],
  'habitats': ['qualquer'],
  'id': 'hobgoblin-montado',
  'jp': '5',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Hobgoblin Montado',
  'parent_monster_url': 'https://olddragon.com.br/monstros/hobgoblin.json',
  'picture': 'https://public.olddragon.com.br/io1vziktqpiudahi4ab9k3pgs1zh',
  'pv': '11',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/y3az06roefvckaoer0p4p48mkiv9',
  'treasure': 's',
  'treasure_lair': 'e',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/hobgoblin-montado.json',
  'variant': True,
  'variant_modifications': ['Montam Worgs.'],
  'xp': '35'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Selvagens e brutais, visam a expansão de seus territórios por '
            'meio de invasões e constantes ataques aos outros povos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 96}],
  'habitats': ['qualquer'],
  'id': 'hobgoblin-veterano',
  'name': 'Hobgoblin Veterano',
  'parent_monster_url': 'https://olddragon.com.br/monstros/orc.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/hobgoblin-veterano.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide_monstruoso',
  'flavor': 'Abutres que podem tomar a forma humanoide, meio humana meio '
            'abutre, ou a forma de humanos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 69}],
  'habitats': ['desertos'],
  'id': 'homem-abutre',
  'name': 'Homem Abutre',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-abutre.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide_monstruoso',
  'flavor': 'Chacais capazes de tomar a forma humanoide, meio humana meio '
            'chacal, ou a forma de humanos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 69}],
  'habitats': ['desertos'],
  'id': 'homem-chacal',
  'name': 'Homem Chacal',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-chacal.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 0,
               'damage': '1d3',
               'damage_bonus': None,
               'damage_description': '1d3',
               'description': 'Soco',
               'text': '1 × Soco (1d3)',
               'times': 1,
               'weapon': False}],
  'ca': '10',
  'concept': 'humanoide',
  'description': 'Homens comuns são as pessoas normais que habitam o mundo, '
                 'não possuindo aspirações aventurescas, poderes ou '
                 'habilidades mínimas de combate. Estes são os pedreiros, '
                 'cavalariços, nobres, ferreiros, artistas, agricultores... '
                 'Enfim, as pessoas comuns do seu cenário de campanha.\n'
                 '\n'
                 'Encontrados em grupos pequenos de 2d4 indivíduos ou em '
                 'grupos maiores, de acordo com o tamanho do assentamento onde '
                 'vivem.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 15 homens, um deles será uma '
                 'Criança.\n'
                 '\n',
  'dv': '½',
  'dv_bonus': '+1',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 187},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday18.json',
              'page': 14},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'homem-comum',
  'jp': '4',
  'mo': 6,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem Comum',
  'picture': None,
  'pv': '3',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-comum.json',
  'variant': False,
  'xp': '5'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [],
  'ca': '9',
  'concept': 'humanoide',
  'description': 'Homens comuns são as pessoas normais que habitam o mundo, '
                 'não possuindo aspirações aventurescas, poderes ou '
                 'habilidades mínimas de combate. Estes são os pedreiros, '
                 'cavalariços, nobres, ferreiros, artistas, agricultores... '
                 'Enfim, as pessoas comuns do seu cenário de campanha.\n'
                 '\n'
                 'Encontrados em grupos pequenos de 2d4 indivíduos ou em '
                 'grupos maiores, de acordo com o tamanho do assentamento onde '
                 'vivem.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 15 homens, um deles será uma '
                 'Criança.\n'
                 '\n',
  'dv': '½',
  'dv_bonus': '-1',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 187},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 18},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'homem-comum-crianca',
  'jp': '4',
  'mo': 4,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem Comum, Criança',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-comum.json',
  'picture': None,
  'pv': '1',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-comum-crianca.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '5'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [],
  'ca': '9',
  'concept': 'humanoide',
  'description': 'Homens comuns são as pessoas normais que habitam o mundo, '
                 'não possuindo aspirações aventurescas, poderes ou '
                 'habilidades mínimas de combate. Estes são os pedreiros, '
                 'cavalariços, nobres, ferreiros, artistas, agricultores... '
                 'Enfim, as pessoas comuns do seu cenário de campanha.\n'
                 '\n'
                 'Encontrados em grupos pequenos de 2d4 indivíduos ou em '
                 'grupos maiores, de acordo com o tamanho do assentamento onde '
                 'vivem.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 15 homens, um deles será uma '
                 'Criança.\n'
                 '\n',
  'dv': '½',
  'dv_bonus': '-1',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 187},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'homem-comum-idoso',
  'jp': '4',
  'mo': 5,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem Comum, Idoso',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-comum.json',
  'picture': None,
  'pv': '1',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-comum-idoso.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '5'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Lança',
               'text': '1 × Lança +1 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '11',
  'concept': 'humanoide',
  'description': 'Homens primitivos, considerados extintos pela maioria dos '
                 'sábios, porém resistem em locais extremamente isolados e '
                 'desabitados.  Culturalmente, vivem a idade da pedra lascada, '
                 'usando ferramentas simplórias de madeira, ossos e pedras. '
                 'Não falam, comunicando-se apenas com grunhidos, e são '
                 'exímios caçadores e guerreiros.\n'
                 '\n'
                 'Encontrados em grupos de caçadores de 2d4 indivíduos ou em '
                 'tribos com 3d10 x 10 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: em grupos de caçadores, os homens das '
                 'cavernas são liderados por um Homem das Cavernas Campeão. Em '
                 'acampamentos, a cada 10 indivíduos, um deles será uma '
                 'Criança; a cada 50 indivíduos, um será um Idoso; e haverá '
                 '1d4 Homens das Cavernas Campeão.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 187},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'homem-das-cavernas',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem das Cavernas',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-das-cavernas.json',
  'variant': False,
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 6,
               'damage': '1d6',
               'damage_bonus': 3,
               'damage_description': '1d6+3',
               'description': 'Clava',
               'text': '1 × Clava +6 (1d6+3)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': 'Homens primitivos, considerados extintos pela maioria dos '
                 'sábios, porém resistem em locais extremamente isolados e '
                 'desabitados.  Culturalmente, vivem a idade da pedra lascada, '
                 'usando ferramentas simplórias de madeira, ossos e pedras. '
                 'Não falam, comunicando-se apenas com grunhidos, e são '
                 'exímios caçadores e guerreiros.\n'
                 '\n'
                 'Encontrados em grupos de caçadores de 2d4 indivíduos ou em '
                 'tribos com 3d10 x 10 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: em grupos de caçadores, os homens das '
                 'cavernas são liderados por um Homem das Cavernas Campeão. Em '
                 'acampamentos, a cada 10 indivíduos, um deles será uma '
                 'Criança; a cada 50 indivíduos, um será um Idoso; e haverá '
                 '1d4 Homens das Cavernas Campeão.\n'
                 '\n',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 187},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'homem-das-cavernas-campeao',
  'jp': '7',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem das Cavernas Campeão',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-das-cavernas.json',
  'picture': None,
  'pv': '20',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-das-cavernas-campeao.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '125'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [],
  'ca': '9',
  'concept': 'humanoide',
  'description': 'Homens primitivos, considerados extintos pela maioria dos '
                 'sábios, porém resistem em locais extremamente isolados e '
                 'desabitados.  Culturalmente, vivem a idade da pedra lascada, '
                 'usando ferramentas simplórias de madeira, ossos e pedras. '
                 'Não falam, comunicando-se apenas com grunhidos, e são '
                 'exímios caçadores e guerreiros.\n'
                 '\n'
                 'Encontrados em grupos de caçadores de 2d4 indivíduos ou em '
                 'tribos com 3d10 x 10 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: em grupos de caçadores, os homens das '
                 'cavernas são liderados por um Homem das Cavernas Campeão. Em '
                 'acampamentos, a cada 10 indivíduos, um deles será uma '
                 'Criança; a cada 50 indivíduos, um será um Idoso; e haverá '
                 '1d4 Homens das Cavernas Campeão.\n'
                 '\n',
  'dv': '½',
  'dv_bonus': '-1',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 187},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'homem-das-cavernas-crianca',
  'jp': '4',
  'mo': 5,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem das Cavernas, Criança',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-das-cavernas.json',
  'picture': None,
  'pv': '1',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-das-cavernas-crianca.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '5'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [],
  'ca': '9',
  'concept': 'humanoide',
  'description': 'Homens primitivos, considerados extintos pela maioria dos '
                 'sábios, porém resistem em locais extremamente isolados e '
                 'desabitados.  Culturalmente, vivem a idade da pedra lascada, '
                 'usando ferramentas simplórias de madeira, ossos e pedras. '
                 'Não falam, comunicando-se apenas com grunhidos, e são '
                 'exímios caçadores e guerreiros.\n'
                 '\n'
                 'Encontrados em grupos de caçadores de 2d4 indivíduos ou em '
                 'tribos com 3d10 x 10 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: em grupos de caçadores, os homens das '
                 'cavernas são liderados por um Homem das Cavernas Campeão. Em '
                 'acampamentos, a cada 10 indivíduos, um deles será uma '
                 'Criança; a cada 50 indivíduos, um será um Idoso; e haverá '
                 '1d4 Homens das Cavernas Campeão.\n'
                 '\n',
  'dv': '½',
  'dv_bonus': '-1',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 187},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'homem-das-cavernas-idoso',
  'jp': '4',
  'mo': 6,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem das Cavernas, Idoso',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-das-cavernas.json',
  'picture': None,
  'pv': '1',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-das-cavernas-idoso.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '5'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 5,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8 + Dreno',
               'description': 'Garra',
               'text': '1 × Garra +5 (1d8 + Dreno)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide_monstruoso',
  'description': 'Um homem muito alto (apesar de existirem relatos de já terem '
                 'o visto como uma mulher), com trajes remetendo a uma versão '
                 'mais sombria e deturpada de roupas nobres e caras.\n'
                 '\n'
                 'Não possui rosto, mas, quando deseja, pode criar uma boca '
                 'repleta de dentes pontiagudos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Gosta de aterrorizar suas vítimas, perseguindo-as em cantos '
                 'de pouca luz.\n'
                 '\n'
                 'Dizem que fareja o medo do alvo, e isso lhe dá mais prazer '
                 'ao devorar sua alma.\n'
                 '\n'
                 '  * **Imunidades**: não recebe dano de armas não mágicas e '
                 'nem é afetado por nenhuma magia, exceto Portal e Desejo.\n'
                 '\n'
                 '  * **Salto Planar**: até 1d4+2 vezes ao dia, um Homem '
                 'Esguio pode percorrer até 30 metros em pequenos saltos '
                 'planares. Uma criatura tocada pelo Homem Esguio o acompanha '
                 'neste salto.\n'
                 '\n'
                 '  * **Drenar Energia**: seu ataque drena 1 nível do '
                 'personagem, caso este não passe em uma JPC. Uma criatura com '
                 'todos seus níveis drenados por um Homem Esguio tem sua alma '
                 'devorada por ele e não pode ser ressuscitada.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Ninguém sabe de onde vem esta criatura, mas está ligada aos '
                 'planos inferiores das sombras.\n'
                 '\n'
                 'Dizem ser um tipo de demônio, mas a verdade é que nem os '
                 'demônios sabem defini-la.\n'
                 '\n'
                 'São raríssimas, e devoram crianças quando se sentem '
                 'enfraquecidas.',
  'dv': '5',
  'dv_bonus': '+5',
  'encounters': '1',
  'encounters_lair': '0',
  'flavor': 'Percorre os planos atrás de alvos para alimentar-se de suas almas '
            'ou sequestrá-los para outros planos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 111},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['extraplanar'],
  'id': 'homem-esguio',
  'jp': '8',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem Esguio',
  'picture': 'https://public.olddragon.com.br/uprvv1wr9y4px20ca8wqxkgxh91d',
  'pv': '30',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/gygx9qpz1oxbyv8ij6yj5wmdw221',
  'treasure': 'u',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-esguio.json',
  'variant': False,
  'xp': '235'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 5,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Garras',
               'text': '2 × Garras +5 (1d6)',
               'times': 2,
               'weapon': False},
              {'ba': 5,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Mordida',
               'text': '1 × Mordida +5 (2d6)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'humanoide',
  'description': 'Em sua forma humanoide, possuem traços delgados e uma '
                 'postura curiosa, como se escutassem algo que os outros não '
                 'escutam.\n'
                 '\n'
                 'Após a transformação, suas garras ficam expostas nas pontas '
                 'dos dedos e seus traços físicos se mesclam com os de um '
                 'gato, variando enormemente em cor e tamanho.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Por meio de armadilhas, emboscam seus alvos e atacam seus '
                 'pontos fracos.\n'
                 '\n'
                 'Gostam de táticas de “bater e correr”, atacando e recuando '
                 'para dar uma falsa sensação de segurança nos inimigos.\n'
                 '\n'
                 '  * **Imunidades**: quando transformados, um Licantropo é '
                 'imune ao dano de qualquer arma não mágica. Armas mágicas, '
                 'magia e prata causam dano normal a um Licantropo.\n'
                 '\n'
                 '  * **Convocar animais**: um Homem-Gato pode convocar 1d3 '
                 'felinos de qualquer tipo. Os animais convocados chegam em '
                 '1d4 rodadas.\n'
                 '  * **Surpresa**: surpreendem seus inimigos com 1-4 chances '
                 'em 1d6.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Urbanos, vivem em becos escuros cheios de ladrões, de '
                 'assassinos e da pior estirpe da encontrada na sociedade.\n'
                 '\n'
                 'Dizem que sua origem se deve ao culto de uma deusa felina, e '
                 'que alguns asseclas teriam sido amaldiçoados após traírem '
                 'seus votos.',
  'dv': '5',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Franzinos e delgados. São curiosos, traiçoeiros e ótimos '
            'rastreadores, escaladores e caçadores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 122},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'homem-gato',
  'jp': '8',
  'mo': 9,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem-Gato',
  'picture': 'https://public.olddragon.com.br/qymeb5kakt0kkni8lpl24wbvoi8z',
  'pv': '25',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/78vr6f90ilicldaucq8m452at23a',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-gato.json',
  'variant': False,
  'xp': '205'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1',
               'description': 'Garras',
               'text': '2 × Garras +3 (1d4+1)',
               'times': 2,
               'weapon': False},
              {'ba': 3,
               'damage': '1d10',
               'damage_bonus': None,
               'damage_description': '1d10',
               'description': 'Mordida',
               'text': '1 × Mordida +3 (1d10)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': 'Em sua forma humanoide, possuem traços delgados e uma '
                 'postura curiosa, como se escutassem algo que os outros não '
                 'escutam.\n'
                 '\n'
                 'Após a transformação, suas garras ficam expostas nas pontas '
                 'dos dedos e seus traços físicos se mesclam com os de um '
                 'gato, variando enormemente em cor e tamanho.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Por meio de armadilhas, emboscam seus alvos e atacam seus '
                 'pontos fracos.\n'
                 '\n'
                 'Gostam de táticas de “bater e correr”, atacando e recuando '
                 'para dar uma falsa sensação de segurança nos inimigos.\n'
                 '\n'
                 '  * **Imunidades**: quando transformados, um Licantropo é '
                 'imune ao dano de qualquer arma não mágica. Armas mágicas, '
                 'magia e prata causam dano normal a um Licantropo.\n'
                 '\n'
                 '  * **Convocar animais**: um Homem-Gato pode convocar 1d3 '
                 'felinos de qualquer tipo. Os animais convocados chegam em '
                 '1d4 rodadas.\n'
                 '  * **Surpresa**: surpreendem seus inimigos com 1-4 chances '
                 'em 1d6.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Urbanos, vivem em becos escuros cheios de ladrões, de '
                 'assassinos e da pior estirpe da encontrada na sociedade.\n'
                 '\n'
                 'Dizem que sua origem se deve ao culto de uma deusa felina, e '
                 'que alguns asseclas teriam sido amaldiçoados após traírem '
                 'seus votos.',
  'dv': '5',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Franzinos e delgados. São curiosos, traiçoeiros e ótimos '
            'rastreadores, escaladores e caçadores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 122}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'homem-gato-forma-animal',
  'jp': '8',
  'mo': 9,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem-Gato, Forma Animal',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-gato.json',
  'picture': 'https://public.olddragon.com.br/qymeb5kakt0kkni8lpl24wbvoi8z',
  'pv': '25',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/78vr6f90ilicldaucq8m452at23a',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-gato-forma-animal.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '205'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Soco',
               'text': '1 × Soco +4 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '10',
  'concept': 'humanoide',
  'description': 'Em sua forma humanoide, possuem traços delgados e uma '
                 'postura curiosa, como se escutassem algo que os outros não '
                 'escutam.\n'
                 '\n'
                 'Após a transformação, suas garras ficam expostas nas pontas '
                 'dos dedos e seus traços físicos se mesclam com os de um '
                 'gato, variando enormemente em cor e tamanho.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Por meio de armadilhas, emboscam seus alvos e atacam seus '
                 'pontos fracos.\n'
                 '\n'
                 'Gostam de táticas de “bater e correr”, atacando e recuando '
                 'para dar uma falsa sensação de segurança nos inimigos.\n'
                 '\n'
                 '  * **Imunidades**: quando transformados, um Licantropo é '
                 'imune ao dano de qualquer arma não mágica. Armas mágicas, '
                 'magia e prata causam dano normal a um Licantropo.\n'
                 '\n'
                 '  * **Convocar animais**: um Homem-Gato pode convocar 1d3 '
                 'felinos de qualquer tipo. Os animais convocados chegam em '
                 '1d4 rodadas.\n'
                 '  * **Surpresa**: surpreendem seus inimigos com 1-4 chances '
                 'em 1d6.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Urbanos, vivem em becos escuros cheios de ladrões, de '
                 'assassinos e da pior estirpe da encontrada na sociedade.\n'
                 '\n'
                 'Dizem que sua origem se deve ao culto de uma deusa felina, e '
                 'que alguns asseclas teriam sido amaldiçoados após traírem '
                 'seus votos.',
  'dv': '5',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Franzinos e delgados. São curiosos, traiçoeiros e ótimos '
            'rastreadores, escaladores e caçadores.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 122}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'homem-gato-forma-humana',
  'jp': '8',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem-Gato, Forma Humana',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-gato.json',
  'picture': 'https://public.olddragon.com.br/qymeb5kakt0kkni8lpl24wbvoi8z',
  'pv': '25',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/78vr6f90ilicldaucq8m452at23a',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-gato-forma-humana.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '205'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 5,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Mordida',
               'text': '1 × Mordida +5 (2d6)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'humanoide_monstruoso',
  'description': 'Mostram-se como pessoas de corpo largo, não necessariamente '
                 'gordas, mas de estrutura grande.\n'
                 '\n'
                 'Possuem rosto grosseiro, assim como seus modos.  Ao se '
                 'transformarem, se mesclam com características físicas do '
                 'javali, como patas traseiras e a cabeça, mas mantêm as mãos '
                 'de um humano.\n'
                 '\n'
                 'Transformados, eles perdem totalmente a noção de civilidade '
                 'e viram uma máquina de matar.\n'
                 '\n'
                 'Devido a mudança corporal da transformação, o Homem -Javali '
                 'prefere roupas simples que são fáceis de remover, consertar '
                 'ou substituir.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam com força bruta, sem muita técnica, mas visando '
                 'primeiro derrubar magos e arqueiros, pois detestam “combates '
                 'injustos”.  Guardam guerreiros e combatentes semelhantes '
                 'para depois.\n'
                 '\n'
                 '  * **Imunidades**: quando transformados, um Licantropo é '
                 'imune ao dano de qualquer arma não mágica. Armas mágicas, '
                 'magia e prata causam dano normal a um Licantropo.\n'
                 '\n'
                 '  * **Convocar animais**: um Homem-Javali pode convocar 1d3 '
                 'javalis. Os animais convocados chegam em 1d4 rodadas.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Acostumados a viver na natureza, valorizam a força acima de '
                 'tudo. Quando encontram adversários fortes, ficam felizes em '
                 'poder matar tal oponente, ou mesmo em ser morto por um '
                 'adversário à sua altura.',
  'dv': '4',
  'dv_bonus': '+1',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Licantropos furiosos e grosseiros, com aparência rústica e '
            'irascível.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 123},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'homem-javali',
  'jp': '6',
  'mo': 9,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem-Javali',
  'picture': 'https://public.olddragon.com.br/p88nflkxnxslw1sahy56us4653hz',
  'pv': '21',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/opphoc0qd50mhcqxbroy1sazsmza',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-javali.json',
  'variant': False,
  'xp': '150'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 3,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4',
               'description': 'Presa',
               'text': '1 × Presa +3 (2d4)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide_monstruoso',
  'description': 'Mostram-se como pessoas de corpo largo, não necessariamente '
                 'gordas, mas de estrutura grande.\n'
                 '\n'
                 'Possuem rosto grosseiro, assim como seus modos.  Ao se '
                 'transformarem, se mesclam com características físicas do '
                 'javali, como patas traseiras e a cabeça, mas mantêm as mãos '
                 'de um humano.\n'
                 '\n'
                 'Transformados, eles perdem totalmente a noção de civilidade '
                 'e viram uma máquina de matar.\n'
                 '\n'
                 'Devido a mudança corporal da transformação, o Homem -Javali '
                 'prefere roupas simples que são fáceis de remover, consertar '
                 'ou substituir.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam com força bruta, sem muita técnica, mas visando '
                 'primeiro derrubar magos e arqueiros, pois detestam “combates '
                 'injustos”.  Guardam guerreiros e combatentes semelhantes '
                 'para depois.\n'
                 '\n'
                 '  * **Imunidades**: quando transformados, um Licantropo é '
                 'imune ao dano de qualquer arma não mágica. Armas mágicas, '
                 'magia e prata causam dano normal a um Licantropo.\n'
                 '\n'
                 '  * **Convocar animais**: um Homem-Javali pode convocar 1d3 '
                 'javalis. Os animais convocados chegam em 1d4 rodadas.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Acostumados a viver na natureza, valorizam a força acima de '
                 'tudo. Quando encontram adversários fortes, ficam felizes em '
                 'poder matar tal oponente, ou mesmo em ser morto por um '
                 'adversário à sua altura.',
  'dv': '4',
  'dv_bonus': '+1',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Licantropos furiosos e grosseiros, com aparência rústica e '
            'irascível.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 123}],
  'habitats': ['qualquer'],
  'id': 'homem-javali-forma-animal',
  'jp': '6',
  'mo': 9,
  'mv': 10,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem-Javali, Forma Animal',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-javali.json',
  'picture': 'https://public.olddragon.com.br/p88nflkxnxslw1sahy56us4653hz',
  'pv': '21',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/opphoc0qd50mhcqxbroy1sazsmza',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-javali-forma-animal.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '150'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 4,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Soco',
               'text': '1 × Soco +4 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '10',
  'concept': 'humanoide_monstruoso',
  'description': 'Mostram-se como pessoas de corpo largo, não necessariamente '
                 'gordas, mas de estrutura grande.\n'
                 '\n'
                 'Possuem rosto grosseiro, assim como seus modos.  Ao se '
                 'transformarem, se mesclam com características físicas do '
                 'javali, como patas traseiras e a cabeça, mas mantêm as mãos '
                 'de um humano.\n'
                 '\n'
                 'Transformados, eles perdem totalmente a noção de civilidade '
                 'e viram uma máquina de matar.\n'
                 '\n'
                 'Devido a mudança corporal da transformação, o Homem -Javali '
                 'prefere roupas simples que são fáceis de remover, consertar '
                 'ou substituir.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam com força bruta, sem muita técnica, mas visando '
                 'primeiro derrubar magos e arqueiros, pois detestam “combates '
                 'injustos”.  Guardam guerreiros e combatentes semelhantes '
                 'para depois.\n'
                 '\n'
                 '  * **Imunidades**: quando transformados, um Licantropo é '
                 'imune ao dano de qualquer arma não mágica. Armas mágicas, '
                 'magia e prata causam dano normal a um Licantropo.\n'
                 '\n'
                 '  * **Convocar animais**: um Homem-Javali pode convocar 1d3 '
                 'javalis. Os animais convocados chegam em 1d4 rodadas.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Acostumados a viver na natureza, valorizam a força acima de '
                 'tudo. Quando encontram adversários fortes, ficam felizes em '
                 'poder matar tal oponente, ou mesmo em ser morto por um '
                 'adversário à sua altura.',
  'dv': '4',
  'dv_bonus': '+1',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Licantropos furiosos e grosseiros, com aparência rústica e '
            'irascível.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 123}],
  'habitats': ['qualquer'],
  'id': 'homem-javali-forma-humana',
  'jp': '6',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem-Javali, Forma Humana',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-javali.json',
  'picture': 'https://public.olddragon.com.br/p88nflkxnxslw1sahy56us4653hz',
  'pv': '21',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/opphoc0qd50mhcqxbroy1sazsmza',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-javali-forma-humana.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '150'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Garra',
               'text': '1 × Garra +2 (1d4)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma +2 (Arma)',
               'times': 1,
               'weapon': True}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'De corpo avantajado, medindo por volta de 2 metros de '
                 'altura, os Homens Lagartos são primitivos e se comunicam por '
                 'uma série de sibilos e palavras mal pronunciadas, adotadas '
                 'de povos vizinhos.\n'
                 '\n'
                 'Usam adornos feitos dos ossos dos inimigos e, às vezes, '
                 'marcam suas peles com cicatrizes para diferenciar seus '
                 'diferentes status na tribo.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Não possuem tática de combate, adotando a simples e selvagem '
                 'força de um ataque frontal.\n'
                 '\n'
                 '  * **Lutar até morrer**: quando encurralados, recebem +1 no '
                 'ataque e dano até o fim do combate.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Alimentam-se de criaturas menores, como peixes, rãs e '
                 'pássaros. Porém, vão atrás de humanos (ou o que mais possam '
                 'capturar após uma boa luta) quando planejam algum banquete '
                 'em oferenda a seus deuses obscuros. São liderados por um '
                 'imenso e gordo chefe, semelhante a um crocodilo.  Um xamã '
                 'serve de conselheiro, fazendo a ligação direta entre a '
                 'vontade divina e a tribo. Às vezes, essa vontade pode ser a '
                 'mesma do xamã, mas ninguém ousa questionar.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A pele dos Homens Lagartos são valorizadas pelos nobres na '
                 'confecção de mobília de couro e peças de vestimenta.',
  'dv': '2',
  'dv_bonus': '+1',
  'encounters': '2d4',
  'encounters_lair': '6d6',
  'flavor': 'Selvagens reptilianos. Atacam de forma desordenada com lanças e '
            'fundas, devastando povoados.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 175},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 112},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['planicies', 'pantanos'],
  'id': 'homem-lagarto',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': 6,
  'mvo': None,
  'mvv': None,
  'name': 'Homem Lagarto',
  'picture': 'https://public.olddragon.com.br/k2ltf37378uzxxpvg92v3etflwyi',
  'pv': '11',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/i4yz3ol3ik6gliplpvacm37piuab',
  'treasure': 'p',
  'treasure_lair': 'j',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-lagarto.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 6,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Lança',
               'text': '1 × Lança +6 (1d6+2)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'De corpo avantajado, medindo por volta de 2 metros de '
                 'altura, os Homens Lagartos são primitivos e se comunicam por '
                 'uma série de sibilos e palavras mal pronunciadas, adotadas '
                 'de povos vizinhos.\n'
                 '\n'
                 'Usam adornos feitos dos ossos dos inimigos e, às vezes, '
                 'marcam suas peles com cicatrizes para diferenciar seus '
                 'diferentes status na tribo.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Não possuem tática de combate, adotando a simples e selvagem '
                 'força de um ataque frontal.\n'
                 '\n'
                 '  * **Lutar até morrer**: quando encurralados, recebem +1 no '
                 'ataque e dano até o fim do combate.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Alimentam-se de criaturas menores, como peixes, rãs e '
                 'pássaros. Porém, vão atrás de humanos (ou o que mais possam '
                 'capturar após uma boa luta) quando planejam algum banquete '
                 'em oferenda a seus deuses obscuros. São liderados por um '
                 'imenso e gordo chefe, semelhante a um crocodilo.  Um xamã '
                 'serve de conselheiro, fazendo a ligação direta entre a '
                 'vontade divina e a tribo. Às vezes, essa vontade pode ser a '
                 'mesma do xamã, mas ninguém ousa questionar.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A pele dos Homens Lagartos são valorizadas pelos nobres na '
                 'confecção de mobília de couro e peças de vestimenta.',
  'dv': '5',
  'dv_bonus': '+1',
  'encounters': '2d4',
  'encounters_lair': '6d6',
  'flavor': 'Selvagens reptilianos. Atacam de forma desordenada com lanças e '
            'fundas, devastando povoados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 112}],
  'habitats': ['planicies', 'pantanos'],
  'id': 'homem-lagarto-campeao',
  'jp': '8',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': 6,
  'mvo': None,
  'mvv': None,
  'name': 'Homem Lagarto Campeão',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-lagarto.json',
  'picture': 'https://public.olddragon.com.br/k2ltf37378uzxxpvg92v3etflwyi',
  'pv': '26',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/i4yz3ol3ik6gliplpvacm37piuab',
  'treasure': 'p',
  'treasure_lair': 'j',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-lagarto-campeao.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '175'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Clava',
               'text': '1 × Clava +3 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'De corpo avantajado, medindo por volta de 2 metros de '
                 'altura, os Homens Lagartos são primitivos e se comunicam por '
                 'uma série de sibilos e palavras mal pronunciadas, adotadas '
                 'de povos vizinhos.\n'
                 '\n'
                 'Usam adornos feitos dos ossos dos inimigos e, às vezes, '
                 'marcam suas peles com cicatrizes para diferenciar seus '
                 'diferentes status na tribo.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Não possuem tática de combate, adotando a simples e selvagem '
                 'força de um ataque frontal.\n'
                 '\n'
                 '  * **Lutar até morrer**: quando encurralados, recebem +1 no '
                 'ataque e dano até o fim do combate.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Alimentam-se de criaturas menores, como peixes, rãs e '
                 'pássaros. Porém, vão atrás de humanos (ou o que mais possam '
                 'capturar após uma boa luta) quando planejam algum banquete '
                 'em oferenda a seus deuses obscuros. São liderados por um '
                 'imenso e gordo chefe, semelhante a um crocodilo.  Um xamã '
                 'serve de conselheiro, fazendo a ligação direta entre a '
                 'vontade divina e a tribo. Às vezes, essa vontade pode ser a '
                 'mesma do xamã, mas ninguém ousa questionar.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A pele dos Homens Lagartos são valorizadas pelos nobres na '
                 'confecção de mobília de couro e peças de vestimenta.',
  'dv': '3',
  'dv_bonus': '+1',
  'encounters': '2d4',
  'encounters_lair': '6d6',
  'flavor': 'Selvagens reptilianos. Atacam de forma desordenada com lanças e '
            'fundas, devastando povoados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 112}],
  'habitats': ['planicies', 'pantanos'],
  'id': 'homem-lagarto-lider',
  'jp': '6',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': 6,
  'mvo': None,
  'mvv': None,
  'name': 'Homem Lagarto Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-lagarto.json',
  'picture': 'https://public.olddragon.com.br/k2ltf37378uzxxpvg92v3etflwyi',
  'pv': '16',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/i4yz3ol3ik6gliplpvacm37piuab',
  'treasure': 'p',
  'treasure_lair': 'j',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-lagarto-lider.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '75'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Lança',
               'text': '1 × Lança +1 (1d6+1)',
               'times': 1,
               'weapon': False},
              {'ba': 1,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1',
               'description': 'Garra',
               'text': '1 × Garra +1 (1d4+1)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'humanoide',
  'description': '  * **Lutar até morrer**: quando encurralados, recebem +1 no '
                 'ataque e dano até o fim do combate.',
  'dv': '2',
  'dv_bonus': '+1',
  'encounters': '2d4',
  'encounters_lair': '6d6',
  'flavor': 'Selvagens reptilianos. Atacam de forma desordenada com lanças e '
            'fundas, devastando povoados.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday24.json',
              'page': 15}],
  'habitats': ['planicies', 'pantanos'],
  'id': 'homem-lagarto-vigia',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': 6,
  'mvo': None,
  'mvv': None,
  'name': 'Homem Lagarto Vigia',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-lagarto.json',
  'pv': '11',
  'size': 'medio',
  'treasure': 'p',
  'treasure_lair': 'j',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-lagarto-vigia.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Clava',
               'text': '1 × Clava +1 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': 'De corpo avantajado, medindo por volta de 2 metros de '
                 'altura, os Homens Lagartos são primitivos e se comunicam por '
                 'uma série de sibilos e palavras mal pronunciadas, adotadas '
                 'de povos vizinhos.\n'
                 '\n'
                 'Usam adornos feitos dos ossos dos inimigos e, às vezes, '
                 'marcam suas peles com cicatrizes para diferenciar seus '
                 'diferentes status na tribo.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Não possuem tática de combate, adotando a simples e selvagem '
                 'força de um ataque frontal.\n'
                 '\n'
                 '  * **Lutar até morrer**: quando encurralados, recebem +1 no '
                 'ataque e dano até o fim do combate.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Alimentam-se de criaturas menores, como peixes, rãs e '
                 'pássaros. Porém, vão atrás de humanos (ou o que mais possam '
                 'capturar após uma boa luta) quando planejam algum banquete '
                 'em oferenda a seus deuses obscuros. São liderados por um '
                 'imenso e gordo chefe, semelhante a um crocodilo.  Um xamã '
                 'serve de conselheiro, fazendo a ligação direta entre a '
                 'vontade divina e a tribo. Às vezes, essa vontade pode ser a '
                 'mesma do xamã, mas ninguém ousa questionar.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A pele dos Homens Lagartos são valorizadas pelos nobres na '
                 'confecção de mobília de couro e peças de vestimenta.',
  'dv': '2',
  'dv_bonus': '+1',
  'encounters': '2d4',
  'encounters_lair': '6d6',
  'flavor': 'Selvagens reptilianos. Atacam de forma desordenada com lanças e '
            'fundas, devastando povoados.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 112}],
  'habitats': ['planicies', 'pantanos'],
  'id': 'homem-lagarto-xama',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': 6,
  'mvo': None,
  'mvv': None,
  'name': 'Homem Lagarto Xamã',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-lagarto.json',
  'picture': 'https://public.olddragon.com.br/k2ltf37378uzxxpvg92v3etflwyi',
  'pv': '11',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/i4yz3ol3ik6gliplpvacm37piuab',
  'treasure': 'p',
  'treasure_lair': 'j',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-lagarto-xama.json',
  'variant': True,
  'variant_modifications': ['Magia como Clérigo de 2º nível.'],
  'xp': '50'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 4,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4',
               'description': 'Mordida',
               'text': '1 × Mordida +4 (2d4)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide_monstruoso',
  'description': 'Por serem os mais antigos de todos, estes Licantropos '
                 'possuem uma variedade incrível no que diz respeito a sua '
                 'aparência, sendo muito difícil distingui-los de pessoas '
                 'comuns até que estejam transformados.\n'
                 '\n'
                 'Quando transformados, ficam encurvados e com bocarras '
                 'repletas de dentes pontiagudos e perigosíssimos como os dos '
                 'selvagens lobos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Preferem atacar em grupos grandes, como se estivessem em uma '
                 'alcatéia e, quando sentem que estão em franca desvantagem, '
                 'recuam sem maiores constrangimentos.\n'
                 '\n'
                 'Os poucos que vivem na cidade atacam em becos escuros, '
                 'evitando chamar a atenção das autoridades e de caçadores de '
                 'licantropos.\n'
                 '\n'
                 '  * **Imunidades**: quando transformados, um Licantropo é '
                 'imune ao dano de qualquer arma não mágica. Armas mágicas, '
                 'magia e prata causam dano normal a um Licantropo.\n'
                 '\n'
                 '  * **Convocar animais**: um Homem-Lobo pode convocar 1d3 '
                 'lobos. Os animais convocados chegam em 1d4 rodadas. Quando '
                 'acompanhados por um lobisomem, o moral destes lobos é 9.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Existem duas grandes divisões entre os Licantropos-lobo: os '
                 'que vivem na cidade (considerados párias pela alcateia) e os '
                 'que vivem nas florestas (em grandes bandos).\n'
                 '\n'
                 'Outro grupo rival são os lobisomenss conhecidos como '
                 'Homobos. Ainda mais selvagens, são lobisomens que fizeram o '
                 'caminho inverso, ou seja, são lobos que se transformam em '
                 'homens.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '2d6',
  'flavor': 'Também conhecidos como Lobisomem, são de longe os Licantropos '
            'mais comuns e ferozes conhecidos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 124},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'homem-lobo',
  'jp': '6',
  'mo': 8,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem-Lobo',
  'picture': 'https://public.olddragon.com.br/rsjs5pbu307hf5nbvo77uzt13e9s',
  'pv': '20',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/phtxnc3hzi2tskn9zhnjg07ku1q6',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-lobo.json',
  'variant': False,
  'xp': '150'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 3,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Mordida',
               'text': '1 × Mordida +3 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide_monstruoso',
  'description': 'Por serem os mais antigos de todos, estes Licantropos '
                 'possuem uma variedade incrível no que diz respeito a sua '
                 'aparência, sendo muito difícil distingui-los de pessoas '
                 'comuns até que estejam transformados.\n'
                 '\n'
                 'Quando transformados, ficam encurvados e com bocarras '
                 'repletas de dentes pontiagudos e perigosíssimos como os dos '
                 'selvagens lobos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Preferem atacar em grupos grandes, como se estivessem em uma '
                 'alcatéia e, quando sentem que estão em franca desvantagem, '
                 'recuam sem maiores constrangimentos.\n'
                 '\n'
                 'Os poucos que vivem na cidade atacam em becos escuros, '
                 'evitando chamar a atenção das autoridades e de caçadores de '
                 'licantropos.\n'
                 '\n'
                 '  * **Imunidades**: quando transformados, um Licantropo é '
                 'imune ao dano de qualquer arma não mágica. Armas mágicas, '
                 'magia e prata causam dano normal a um Licantropo.\n'
                 '\n'
                 '  * **Convocar animais**: um Homem-Lobo pode convocar 1d3 '
                 'lobos. Os animais convocados chegam em 1d4 rodadas. Quando '
                 'acompanhados por um lobisomem, o moral destes lobos é 9.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Existem duas grandes divisões entre os Licantropos-lobo: os '
                 'que vivem na cidade (considerados párias pela alcateia) e os '
                 'que vivem nas florestas (em grandes bandos).\n'
                 '\n'
                 'Outro grupo rival são os lobisomenss conhecidos como '
                 'Homobos. Ainda mais selvagens, são lobisomens que fizeram o '
                 'caminho inverso, ou seja, são lobos que se transformam em '
                 'homens.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '2d6',
  'flavor': 'Também conhecidos como Lobisomem, são de longe os Licantropos '
            'mais comuns e ferozes conhecidos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 124}],
  'habitats': ['qualquer'],
  'id': 'homem-lobo-forma-animal',
  'jp': '6',
  'mo': 9,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem-Lobo, Forma Animal',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-lobo.json',
  'picture': 'https://public.olddragon.com.br/rsjs5pbu307hf5nbvo77uzt13e9s',
  'pv': '20',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/phtxnc3hzi2tskn9zhnjg07ku1q6',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-lobo-forma-animal.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '150'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 3,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Soco',
               'text': '1 × Soco +3 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '10',
  'concept': 'humanoide_monstruoso',
  'description': 'Por serem os mais antigos de todos, estes Licantropos '
                 'possuem uma variedade incrível no que diz respeito a sua '
                 'aparência, sendo muito difícil distingui-los de pessoas '
                 'comuns até que estejam transformados.\n'
                 '\n'
                 'Quando transformados, ficam encurvados e com bocarras '
                 'repletas de dentes pontiagudos e perigosíssimos como os dos '
                 'selvagens lobos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Preferem atacar em grupos grandes, como se estivessem em uma '
                 'alcatéia e, quando sentem que estão em franca desvantagem, '
                 'recuam sem maiores constrangimentos.\n'
                 '\n'
                 'Os poucos que vivem na cidade atacam em becos escuros, '
                 'evitando chamar a atenção das autoridades e de caçadores de '
                 'licantropos.\n'
                 '\n'
                 '  * **Imunidades**: quando transformados, um Licantropo é '
                 'imune ao dano de qualquer arma não mágica. Armas mágicas, '
                 'magia e prata causam dano normal a um Licantropo.\n'
                 '\n'
                 '  * **Convocar animais**: um Homem-Lobo pode convocar 1d3 '
                 'lobos. Os animais convocados chegam em 1d4 rodadas. Quando '
                 'acompanhados por um lobisomem, o moral destes lobos é 9.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Existem duas grandes divisões entre os Licantropos-lobo: os '
                 'que vivem na cidade (considerados párias pela alcateia) e os '
                 'que vivem nas florestas (em grandes bandos).\n'
                 '\n'
                 'Outro grupo rival são os lobisomenss conhecidos como '
                 'Homobos. Ainda mais selvagens, são lobisomens que fizeram o '
                 'caminho inverso, ou seja, são lobos que se transformam em '
                 'homens.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '2d6',
  'flavor': 'Também conhecidos como Lobisomem, são de longe os Licantropos '
            'mais comuns e ferozes conhecidos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 124}],
  'habitats': ['qualquer'],
  'id': 'homem-lobo-forma-humana',
  'jp': '6',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem-Lobo, Forma Humana',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-lobo.json',
  'picture': 'https://public.olddragon.com.br/rsjs5pbu307hf5nbvo77uzt13e9s',
  'pv': '20',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/phtxnc3hzi2tskn9zhnjg07ku1q6',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-lobo-forma-humana.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '150'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 4,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Mordida',
               'text': '1 × Mordida +4 (1d4)',
               'times': 1,
               'weapon': False},
              {'ba': 4,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Espada curta',
               'text': '1 × Espada curta +4 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide_monstruoso',
  'description': 'Sua aparência antes da transformação é de uma pessoa fraca, '
                 'doente, com marcas na pele e cabelos desgrenhados e sujos.\n'
                 '\n'
                 'Os traços de rato são bem visíveis ainda antes de se '
                 'transformarem, mas não o suficiente para atrair para um '
                 'humano a acusação de serem licantropos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Traiçoeiros, atacam pelas costas sempre que podem, às vezes '
                 'criando iscas como prisioneiros, tesouros de menor valor ou '
                 'mesmo um dos integrantes de seu próprio bando.\n'
                 '\n'
                 'Podem usar armas com lâminas sujas para causar doenças '
                 'terríveis nos alvos.\n'
                 '\n'
                 '  * **Imunidades**: quando transformados, um Licantropo é '
                 'imune ao dano de qualquer arma não mágica. Armas mágicas, '
                 'magia e prata causam dano normal a um Licantropo.\n'
                 '\n'
                 '  * **Convocar animais**: um Homem-Rato pode convocar 1d3 '
                 'ratos gigantes. Os animais convocados chegam em 1d4 '
                 'rodadas.\n'
                 '  * **Transformado**: Homens-Rato podem falar mesmo na forma '
                 'monstruosa e podem usar armas de ataque. Um Homem-Rato em '
                 'forma animal se transforma em um Rato Gigante.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Covardes, vivem no lixo das civilizações, seja nos esgotos, '
                 'becos imundos ou casebres abandonados.\n'
                 '\n'
                 'Não possuem honra alguma, podendo trair seu melhor amigo se '
                 'a recompensa valer a pena.\n'
                 '\n'
                 'Constantemente estão envolvidos com o crime nas grandes '
                 'cidades, agindo como agentes de guildas de ladrões ou meros '
                 'informantes do submundo do crime.',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '1d8',
  'encounters_lair': '2d8',
  'flavor': 'Astutos, frequentemente formando guildas de ladrões. São furtivos '
            'e preferem atacar por meio de emboscadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 125},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'homem-rato',
  'jp': '6',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem-Rato',
  'picture': 'https://public.olddragon.com.br/yq8q2l161qynywn5t20j1614k2yz',
  'pv': '15',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/1dyanibbu7px9gtrtosksq0tmi0y',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-rato.json',
  'variant': False,
  'xp': '95'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 3,
               'damage': '1d3',
               'damage_bonus': None,
               'damage_description': '1d3',
               'description': 'Mordida',
               'text': '1 × Mordida +3 (1d3)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide_monstruoso',
  'description': 'Sua aparência antes da transformação é de uma pessoa fraca, '
                 'doente, com marcas na pele e cabelos desgrenhados e sujos.\n'
                 '\n'
                 'Os traços de rato são bem visíveis ainda antes de se '
                 'transformarem, mas não o suficiente para atrair para um '
                 'humano a acusação de serem licantropos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Traiçoeiros, atacam pelas costas sempre que podem, às vezes '
                 'criando iscas como prisioneiros, tesouros de menor valor ou '
                 'mesmo um dos integrantes de seu próprio bando.\n'
                 '\n'
                 'Podem usar armas com lâminas sujas para causar doenças '
                 'terríveis nos alvos.\n'
                 '\n'
                 '  * **Imunidades**: quando transformados, um Licantropo é '
                 'imune ao dano de qualquer arma não mágica. Armas mágicas, '
                 'magia e prata causam dano normal a um Licantropo.\n'
                 '\n'
                 '  * **Convocar animais**: um Homem-Rato pode convocar 1d3 '
                 'ratos gigantes. Os animais convocados chegam em 1d4 '
                 'rodadas.\n'
                 '  * **Transformado**: Homens-Rato podem falar mesmo na forma '
                 'monstruosa e podem usar armas de ataque. Um Homem-Rato em '
                 'forma animal se transforma em um Rato Gigante.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Covardes, vivem no lixo das civilizações, seja nos esgotos, '
                 'becos imundos ou casebres abandonados.\n'
                 '\n'
                 'Não possuem honra alguma, podendo trair seu melhor amigo se '
                 'a recompensa valer a pena.\n'
                 '\n'
                 'Constantemente estão envolvidos com o crime nas grandes '
                 'cidades, agindo como agentes de guildas de ladrões ou meros '
                 'informantes do submundo do crime.',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '1d8',
  'encounters_lair': '2d8',
  'flavor': 'Astutos, frequentemente formando guildas de ladrões. São furtivos '
            'e preferem atacar por meio de emboscadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 125}],
  'habitats': ['qualquer'],
  'id': 'homem-rato-forma-animal',
  'jp': '6',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem-Rato, Forma Animal',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-rato.json',
  'picture': 'https://public.olddragon.com.br/yq8q2l161qynywn5t20j1614k2yz',
  'pv': '15',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/1dyanibbu7px9gtrtosksq0tmi0y',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-rato-forma-animal.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '95'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Soco',
               'text': '1 × Soco +2 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '10',
  'concept': 'humanoide_monstruoso',
  'description': 'Sua aparência antes da transformação é de uma pessoa fraca, '
                 'doente, com marcas na pele e cabelos desgrenhados e sujos.\n'
                 '\n'
                 'Os traços de rato são bem visíveis ainda antes de se '
                 'transformarem, mas não o suficiente para atrair para um '
                 'humano a acusação de serem licantropos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Traiçoeiros, atacam pelas costas sempre que podem, às vezes '
                 'criando iscas como prisioneiros, tesouros de menor valor ou '
                 'mesmo um dos integrantes de seu próprio bando.\n'
                 '\n'
                 'Podem usar armas com lâminas sujas para causar doenças '
                 'terríveis nos alvos.\n'
                 '\n'
                 '  * **Imunidades**: quando transformados, um Licantropo é '
                 'imune ao dano de qualquer arma não mágica. Armas mágicas, '
                 'magia e prata causam dano normal a um Licantropo.\n'
                 '\n'
                 '  * **Convocar animais**: um Homem-Rato pode convocar 1d3 '
                 'ratos gigantes. Os animais convocados chegam em 1d4 '
                 'rodadas.\n'
                 '  * **Transformado**: Homens-Rato podem falar mesmo na forma '
                 'monstruosa e podem usar armas de ataque. Um Homem-Rato em '
                 'forma animal se transforma em um Rato Gigante.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Covardes, vivem no lixo das civilizações, seja nos esgotos, '
                 'becos imundos ou casebres abandonados.\n'
                 '\n'
                 'Não possuem honra alguma, podendo trair seu melhor amigo se '
                 'a recompensa valer a pena.\n'
                 '\n'
                 'Constantemente estão envolvidos com o crime nas grandes '
                 'cidades, agindo como agentes de guildas de ladrões ou meros '
                 'informantes do submundo do crime.',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '1d8',
  'encounters_lair': '2d8',
  'flavor': 'Astutos, frequentemente formando guildas de ladrões. São furtivos '
            'e preferem atacar por meio de emboscadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 125}],
  'habitats': ['qualquer'],
  'id': 'homem-rato-forma-humana',
  'jp': '6',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem-Rato, Forma Humana',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-rato.json',
  'picture': 'https://public.olddragon.com.br/yq8q2l161qynywn5t20j1614k2yz',
  'pv': '15',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/1dyanibbu7px9gtrtosksq0tmi0y',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-rato-forma-humana.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '95'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 6,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4',
               'description': 'Garras',
               'text': '2 × Garras +6 (2d4)',
               'times': 2,
               'weapon': False},
              {'ba': 6,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Mordida',
               'text': '1 × Mordida +6 (2d8)',
               'times': 1,
               'weapon': False}],
  'ca': '18',
  'concept': 'humanoide_monstruoso',
  'description': 'Robustos e altos, quando em sua forma não transformada '
                 'possuem barbas e/ ou cabelos cheios, muitas vezes bem '
                 'cuidados e arrumados. De rosto quadrado, aparentam traços '
                 'bem singulares, como nariz achatado e voz grave, mesmo entre '
                 'as mulheres.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'De forma geral, evitam o combate. Porém, quando necessário, '
                 'investem com suas poderosas garras para alcançar o alvo e '
                 'apertá-lo com seu abraço mortal.\n'
                 '\n'
                 'Mais racionais do que a maioria dos Licantropos, pensam bem '
                 'no terreno, nos inimigos e em suas chances antes de lutar.\n'
                 '\n'
                 '  * **Imunidades**: quando transformados, um Licantropo é '
                 'imune ao dano de qualquer arma não mágica. Armas mágicas, '
                 'magia e prata causam dano normal a um Licantropo.\n'
                 '\n'
                 '  * **Convocar animais**: um Homem-Urso pode convocar 1d3 '
                 'ursos. Os animais convocados chegam em 1d4 rodadas.\n'
                 '\n'
                 '  * **Abraço**: se o Homem-Urso acertar os dois ataques com '
                 'suas garras, conseguirá agarrar o alvo, causando 2d8 de dano '
                 'enquanto estiver agarrando o alvo.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem entre ursos ou isolados no meio da natureza, apesar de '
                 'manterem algum contato com povoados vizinhos (evitando '
                 'apenas grandes centros urbanos).\n'
                 '\n'
                 'Alguns de sua raça escolhem viver como eremitas, cuidando da '
                 'natureza e fazendo aliados entre druidas e patrulheiros.',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Estes Licantropos mantêm sua racionalidade mesmo quando '
            'transformados. Vivem isolados ou entre ursos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 126},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'homem-urso',
  'jp': '8',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem-Urso',
  'picture': 'https://public.olddragon.com.br/nqmtccm5d2etavmqteokqfei5sij',
  'pv': '30',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/df4zknqvx4t7u1ak4scep1papd1v',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-urso.json',
  'variant': False,
  'xp': '305'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 4,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Garras',
               'text': '2 × Garras +4 (1d4)',
               'times': 2,
               'weapon': False},
              {'ba': 3,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Mordida',
               'text': '1 × Mordida +3 (1d8)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide_monstruoso',
  'description': 'Robustos e altos, quando em sua forma não transformada '
                 'possuem barbas e/ ou cabelos cheios, muitas vezes bem '
                 'cuidados e arrumados. De rosto quadrado, aparentam traços '
                 'bem singulares, como nariz achatado e voz grave, mesmo entre '
                 'as mulheres.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'De forma geral, evitam o combate. Porém, quando necessário, '
                 'investem com suas poderosas garras para alcançar o alvo e '
                 'apertá-lo com seu abraço mortal.\n'
                 '\n'
                 'Mais racionais do que a maioria dos Licantropos, pensam bem '
                 'no terreno, nos inimigos e em suas chances antes de lutar.\n'
                 '\n'
                 '  * **Imunidades**: quando transformados, um Licantropo é '
                 'imune ao dano de qualquer arma não mágica. Armas mágicas, '
                 'magia e prata causam dano normal a um Licantropo.\n'
                 '\n'
                 '  * **Convocar animais**: um Homem-Urso pode convocar 1d3 '
                 'ursos. Os animais convocados chegam em 1d4 rodadas.\n'
                 '\n'
                 '  * **Abraço**: se o Homem-Urso acertar os dois ataques com '
                 'suas garras, conseguirá agarrar o alvo, causando 2d8 de dano '
                 'enquanto estiver agarrando o alvo.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem entre ursos ou isolados no meio da natureza, apesar de '
                 'manterem algum contato com povoados vizinhos (evitando '
                 'apenas grandes centros urbanos).\n'
                 '\n'
                 'Alguns de sua raça escolhem viver como eremitas, cuidando da '
                 'natureza e fazendo aliados entre druidas e patrulheiros.',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Estes Licantropos mantêm sua racionalidade mesmo quando '
            'transformados. Vivem isolados ou entre ursos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 126}],
  'habitats': ['qualquer'],
  'id': 'homem-urso-forma-animal',
  'jp': '8',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem-Urso, Forma Animal',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-urso.json',
  'picture': 'https://public.olddragon.com.br/nqmtccm5d2etavmqteokqfei5sij',
  'pv': '30',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/df4zknqvx4t7u1ak4scep1papd1v',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-urso-forma-animal.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '305'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 5,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1',
               'description': 'Soco',
               'text': '1 × Soco +5 (1d4+1)',
               'times': 1,
               'weapon': False}],
  'ca': '11',
  'concept': 'humanoide_monstruoso',
  'description': 'Robustos e altos, quando em sua forma não transformada '
                 'possuem barbas e/ ou cabelos cheios, muitas vezes bem '
                 'cuidados e arrumados. De rosto quadrado, aparentam traços '
                 'bem singulares, como nariz achatado e voz grave, mesmo entre '
                 'as mulheres.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'De forma geral, evitam o combate. Porém, quando necessário, '
                 'investem com suas poderosas garras para alcançar o alvo e '
                 'apertá-lo com seu abraço mortal.\n'
                 '\n'
                 'Mais racionais do que a maioria dos Licantropos, pensam bem '
                 'no terreno, nos inimigos e em suas chances antes de lutar.\n'
                 '\n'
                 '  * **Imunidades**: quando transformados, um Licantropo é '
                 'imune ao dano de qualquer arma não mágica. Armas mágicas, '
                 'magia e prata causam dano normal a um Licantropo.\n'
                 '\n'
                 '  * **Convocar animais**: um Homem-Urso pode convocar 1d3 '
                 'ursos. Os animais convocados chegam em 1d4 rodadas.\n'
                 '\n'
                 '  * **Abraço**: se o Homem-Urso acertar os dois ataques com '
                 'suas garras, conseguirá agarrar o alvo, causando 2d8 de dano '
                 'enquanto estiver agarrando o alvo.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem entre ursos ou isolados no meio da natureza, apesar de '
                 'manterem algum contato com povoados vizinhos (evitando '
                 'apenas grandes centros urbanos).\n'
                 '\n'
                 'Alguns de sua raça escolhem viver como eremitas, cuidando da '
                 'natureza e fazendo aliados entre druidas e patrulheiros.',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Estes Licantropos mantêm sua racionalidade mesmo quando '
            'transformados. Vivem isolados ou entre ursos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 126}],
  'habitats': ['qualquer'],
  'id': 'homem-urso-forma-humana',
  'jp': '8',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Homem-Urso, Forma Humana',
  'parent_monster_url': 'https://olddragon.com.br/monstros/homem-urso.json',
  'picture': 'https://public.olddragon.com.br/nqmtccm5d2etavmqteokqfei5sij',
  'pv': '30',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/df4zknqvx4t7u1ak4scep1papd1v',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homem-urso-forma-humana.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '305'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d3',
               'damage_bonus': None,
               'damage_description': '1d3 + Veneno',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (1d3 + Veneno)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'constructo',
  'description': 'Sua aparência pode variar muito, pois depende mais da '
                 'vontade e criatividade de seu criador do que de outros '
                 'fatores.\n'
                 '\n'
                 'Alguns podem parecer pequenos Diabretes inchados, enquanto '
                 'outros aparentam macaquinhos sem pelo e cobertos de '
                 'bolotas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Protetores ao seu criador, atacam com sua mordida venenosa e '
                 'em conjunto aos desejos de seu mestre, mesmo que seja para '
                 'morrer por sua vontade.\n'
                 '\n'
                 '  * **Veneno**: qualquer criatura mordida pelo Homúnculo '
                 'deve ser bem-sucedida em uma JPC para evitar os efeitos '
                 'soníferos de seu veneno por 1d3 turnos. O veneno começa a '
                 'fazer efeito 1d6+5 rodadas após a mordida.\n'
                 '\n'
                 '  * **Vínculo**: o processo de criação do Homúnculo cria um '
                 'elo telepático permanente com seu criador o qual consegue '
                 'ver, ouvir, sentir e entender tudo o que o Homúnculo está '
                 'vendo, ouvindo, sentindo e entendendo.\n'
                 '\n'
                 '  * **Imunidades**: um Homúnculo não é atingido por ataques '
                 'que necessitem de um alvo vivo (como gases, venenos ou '
                 'magias mentais como ilusões, ou demais formas mágicas de '
                 'interferir na mente de seres vivos).\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Criados para servir, não possuem organização social ou '
                 'qualquer interesse deste tipo.\n'
                 '\n'
                 'São muito fiéis e carentes da atenção do seu mestre, mesmo '
                 'quando essa atenção é expressa com cascudos e xingamentos.\n'
                 '\n'
                 'Constantemente são considerados nada mais do que meras '
                 'ferramentas, fornecendo aos seus criadores uma variedade de '
                 'serviços úteis.\n'
                 '\n'
                 '## Especial\n'
                 '\n'
                 'Lendas dizem que qualquer pessoa pode ser capaz de criar seu '
                 'próprio Homúnculo.  Misturando ingredientes absurdos e pouco '
                 'usuais e aplicando-lhes o ritual correto, qualquer pessoa '
                 'seria capaz de ter o seu próprio Homúnculo a lhe servir.\n'
                 '\n'
                 'No entanto, como não há comprovação, os sábios classificam '
                 'estas histórias como meras lendas propagadas pela ignorância '
                 'popular.',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Constructo humanoide usado por magos para serviços como envio de '
            'mensagens, vigilância ou espionagem.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 113},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'homunculo',
  'jp': '5',
  'mo': 9,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Homúnculo',
  'picture': 'https://public.olddragon.com.br/cq142bd3pkpenfetuddh0u53ucxf',
  'pv': '10',
  'size': 'miudo',
  'thumb_picture': 'https://public.olddragon.com.br/pxcphli7jv0i42w3foc4m160h0og',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/homunculo.json',
  'variant': False,
  'xp': '50'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Morto-vivo sem inteligência. Avança para cima de suas vítimas com '
            'o único intuito de destroçá-las com garras e dentes.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc2.json',
              'page': 33}],
  'habitats': ['qualquer'],
  'id': 'horda-zumbi-grande',
  'name': 'Horda Zumbi (Grande)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/zumbi.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/horda-zumbi-grande.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Morto-vivo sem inteligência. Avança para cima de suas vítimas com '
            'o único intuito de destroçá-las com garras e dentes.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc2.json',
              'page': 30}],
  'habitats': ['qualquer'],
  'id': 'horda-zumbi-media',
  'name': 'Horda Zumbi (Média)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/zumbi.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/horda-zumbi-media.json',
  'variant': True},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Garra',
               'text': '1 × Garra +2 (1d6+2)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1 + Infecção',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (1d4+1 + Infecção)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'morto_vivo',
  'description': '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a magias mentais de manipulação, '
                 'controle ou ilusão, ou demais formas mágicas de interferir '
                 'na mente de seres vivos. Sofre 1d6 de dano ácido por frasco '
                 'de água benta.\n'
                 '\n'
                 '  * **Lento**: sempre perde a Iniciativa num combate. Um '
                 'Zumbi sempre ataca por último.\n'
                 '\n'
                 '  * **Infecção**: personagens mordidos devem passar em uma '
                 'JPC ou se tornarão Zumbis em 1d4 dias, a não ser que uma '
                 'magia de Curar Doenças ou Curar Ferimentos seja usada no '
                 'alvo infectado.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral a '
                 'não ser quando sofrem o efeito de um Afastar Mortos-Vivos.',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '4d6',
  'flavor': 'Morto-vivo sem inteligência. Avança para cima de suas vítimas com '
            'o único intuito de destroçá-las com garras e dentes.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday24.json',
              'page': 17}],
  'habitats': ['qualquer'],
  'id': 'horda-zumbi-menor',
  'jp': '7',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Horda Zumbi (Menor)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/zumbi.json',
  'pv': '30',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/horda-zumbi-menor.json',
  'variant': True,
  'variant_modifications': ['Experiência: 3 pontos de experiência por dano '
                            'causado à horda.'],
  'xp': 'Especial'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Morto-vivo sem inteligência. Avança para cima de suas vítimas com '
            'o único intuito de destroçá-las com garras e dentes.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc2.json',
              'page': 28}],
  'habitats': ['qualquer'],
  'id': 'horda-zumbi-pequena',
  'name': 'Horda Zumbi (Pequena)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/zumbi.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/horda-zumbi-pequena.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Abominações extraplanares, constituídas de pura Magia Abissal, '
            'criadas nos Abismos do Sem-Fim. Materializam-se nas Chagas Negras '
            'de Ryanon, misturando-se com o que encontram no Plano Material de '
            'Kadur.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 38}],
  'habitats': ['extraplanar'],
  'id': 'horror-comum',
  'name': 'Horror Comum',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/horror-comum.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Abominações extraplanares, constituídas de pura Magia Abissal, '
            'criadas nos Abismos do Sem-Fim. Materializam-se nas Chagas Negras '
            'de Ryanon, misturando-se com o que encontram no Plano Material de '
            'Kadur.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 39}],
  'habitats': ['extraplanar'],
  'id': 'horror-de-elite',
  'name': 'Horror de Elite',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/horror-de-elite.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 31}],
  'habitats': [],
  'id': 'horror-decrepito',
  'name': 'Horror Decrépito',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/horror-decrepito.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 33}],
  'habitats': [],
  'id': 'horror-decrepito-ancestral',
  'name': 'Horror Decrépito Ancestral',
  'parent_monster_url': 'https://olddragon.com.br/monstros/horror-decrepito.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/horror-decrepito-ancestral.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 36}],
  'habitats': [],
  'id': 'horror-decrepito-superior',
  'name': 'Horror Decrépito Superior',
  'parent_monster_url': 'https://olddragon.com.br/monstros/horror-decrepito.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/horror-decrepito-superior.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 86}],
  'habitats': ['qualquer'],
  'id': 'iniciado',
  'name': 'Iniciado',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/iniciado.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'ordeiro',
  'concept': 'besta',
  'flavor': 'Humanoides com aparência insetoide, com quatro a seis braços, '
            'duas pernas e de aparência muito variada.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 40}],
  'habitats': ['subterraneos', 'desertos', 'florestas'],
  'id': 'insectaris',
  'name': 'Insectaris',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/insectaris.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1 + Dreno',
               'description': 'Garra',
               'text': '1 × Garra +4 (1d4+1 + Dreno)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'morto_vivo',
  'description': 'Estas criaturas possuem traços físicos semelhantes aos de '
                 'quando eram vivos, mas distorcidos.\n'
                 '\n'
                 'A mandíbula parece quebrada e sua língua apodrecida fica '
                 'pendente e salivante. A pele é dura, como a de cadáveres '
                 'mais antigos, mas pouco danificada, ao contrário de um '
                 'Zumbi.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Inumanos preferem atacar em grupos pequenos, para '
                 'surpreenderem seus inimigos enquanto tentam enfraquecer seus '
                 'alvos com seu poderoso ataque de dreno.\n'
                 '\n'
                 'Podem usar armas improvisadas, mas preferem atacar com suas '
                 'bocarras fétidas e garras pútridas.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantêm silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Imunidades**: além das imunidades comuns aos '
                 'mortos-vivos, Inumanos são feridos apenas por magia e armas '
                 'mágicas ou de prata.\n'
                 '\n'
                 '  * **Dreno**: o ataque de um Inumano, além do dano normal, '
                 'drena 1 nível do alvo caso este não passe em uma JPC. Um '
                 'alvo que tenha todos os seus níveis drenados assim retorna '
                 'como um Inumano sob controle do Inumano que o criou.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar '
                 'Mortos-Vivos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Inumanos rondam lugares nos quais ocorreram muitas mortes, '
                 'como os campos de batalha e cemitérios.\n'
                 '\n'
                 'Apesar de não terem nenhuma inteligência, possuem um grande '
                 'instinto de caça além de sentidos sobrenaturais.\n'
                 '\n'
                 'Dificilmente estão sozinhos, preferindo andar em pequenos '
                 'grupos de não mais do que 5 ou 6.  Contudo, algumas lendas '
                 'relatam uma cidade no deserto habitada apenas por estas '
                 'criaturas.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '1d8',
  'flavor': 'Cadáveres ambulantes possuídos por espíritos malignos. Usam sua '
            'forma física para aterrorizar os mortais.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 88},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 116},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday12.json',
              'page': 26},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday17.json',
              'page': 29},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'inumano',
  'jp': '7',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Inumano',
  'picture': 'https://public.olddragon.com.br/kutrld8mtg2f9w622e1yl4opce3b',
  'pv': '20',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/20eykbsttfu0o13e343kwxjrkwr7',
  'treasure': 'p',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/inumano.json',
  'variant': False,
  'xp': '150'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Pode atravessar para diferentes planos através de ângulos agudos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 70}],
  'habitats': ['desertos'],
  'id': 'inumano-colerico',
  'name': 'Inumano Colérico',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/inumano-colerico.json',
  'variant': False},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2 + Explosão',
               'description': 'Picareta',
               'text': '1 × Picareta +4 (1d8+2 + Explosão)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'morto_vivo',
  'description': '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantêm silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Imunidades**: além das imunidades comuns aos '
                 'mortos-vivos, Inumanos são feridos apenas por magia e armas '
                 'mágicas ou de prata.\n'
                 '\n'
                 '  * **Dreno**: o ataque de um Inumano, além do dano normal, '
                 'drena 1 nível do alvo caso este não passe em uma JPC. Um '
                 'alvo que tenha todos os seus níveis drenados assim retorna '
                 'como um Inumano sob controle do Inumano que o criou.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar Mortos-Vivos.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '1d8',
  'flavor': 'Cadáveres ambulantes possuídos por espíritos malignos. Usam sua '
            'forma física para aterrorizar os mortais.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday12.json',
              'page': 28}],
  'habitats': ['qualquer'],
  'id': 'inumano-explosivo',
  'jp': '7',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Inumano Explosivo',
  'parent_monster_url': 'https://olddragon.com.br/monstros/inumano.json',
  'pv': '20',
  'size': 'medio',
  'treasure': 'p',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/inumano-explosivo.json',
  'variant': True,
  'variant_modifications': ['Explosão: sempre que faz ou recebe um ataque com '
                            'armas de metal, há 3 chances em 1d6 de engatilhar '
                            'uma explosão. Caso ocorra, todos os personagens '
                            'num raio de 3 metros devem fazer uma JPD para '
                            'reduzir 2d6 de dano pela metade, além de evitar '
                            'ficarem cegos. Criaturas cegas fazem rolagens de '
                            'ataque ou que incluam visão como Muito Difícil. '
                            'Ao explodir, o morto-vivo se desintegra, morrendo '
                            'de vez.'],
  'xp': '150'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 8,
               'damage': '1d10',
               'damage_bonus': None,
               'damage_description': '1d10 + Paralisia',
               'description': 'Toque',
               'text': '1 × Toque +8 (1d10 + Paralisia)',
               'times': 1,
               'weapon': False}],
  'ca': '20',
  'concept': 'morto_vivo',
  'description': '\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar-se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Aura Aterrorizante**: qualquer criatura com 4 dados de '
                 'vida ou menos e a até 30 metros do Lich, capaz de ver ou '
                 'percebê-lo, é afetada pela Aura Aterrorizante do Lich que '
                 'afugenta todos por 1d4 turnos. Nenhuma Jogada de Proteção '
                 'pode anular o efeito desta Aura Aterrorizante. Há 1-4 '
                 'chances em 1d6 de uma de uma pessoa em fuga deixar cair o '
                 'que estiver carregando.\n'
                 '\n'
                 '  * **Paralisia**: alvo atingido por um Lich deve ser '
                 'bem-sucedido em uma JPC ou ficará paralisado permanentemente '
                 'ou até uma Curar Doenças ser lançada por um Clérigo.\n'
                 '\n'
                 '  * **Magias**: um Lich pode lançar magias como um '
                 'Necromante de 15º nível.\n'
                 '\n',
  'dv': '20',
  'dv_bonus': '',
  'encounters': '',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/tu2.json',
              'page': 45}],
  'habitats': [],
  'id': 'ix-manter',
  'jp': '16',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Ix Manter',
  'picture': 'https://public.olddragon.com.br/3c1ltehme2bxxzcm1on4gic9lmdx',
  'pv': '100',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/2x2itutpjnonehmjkqpm9yr809ca',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/ix-manter.json',
  'variant': False,
  'xp': '4975'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'besta',
  'flavor': 'Felino de 6 patas com pelagem escura. Tem dois tentáculos saindo '
            'de suas costas e terminando com uma hacha repleta de espinhos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 70}],
  'habitats': ['desertos'],
  'id': 'jaguar-das-dunas',
  'name': 'Jaguar das Dunas',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/jaguar-das-dunas.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4',
               'description': 'Presa',
               'text': '1 × Presa +4 (2d4)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Investida**: se ainda não engajado em combate, pode '
                 'usar a manobra de investida para causar o dobro de dano com '
                 'suas presas.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '1d6',
  'flavor': 'Estes porcos selvagens e ferozes vivem nas florestas e planícies. '
            'Costumam atacar ao menor sinal de perigo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 170},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 17},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 15},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['colinas', 'florestas', 'planicies'],
  'id': 'javali',
  'jp': '6',
  'mo': 9,
  'mv': 10,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Javali',
  'picture': None,
  'pv': '15',
  'size': 'pequeno',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/javali.json',
  'variant': False,
  'xp': '75'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Maiores do que um javali padrão, mas igualmente perigosos se '
            'perturbados. Podem se locomover no subterrâneo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 70}],
  'habitats': ['desertos'],
  'id': 'javali-toupeira',
  'name': 'Javali-Toupeira',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/javali-toupeira.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'besta',
  'flavor': 'Humanoides altos envoltos em nuvens. São seres altamente mágicos, '
            'inteligentes e munidos de livre-arbítrio. Vêm do plano elemental '
            'do ar.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 70}],
  'habitats': ['desertos'],
  'id': 'jinn',
  'name': 'Jinn',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/jinn.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Coice',
               'text': '1 × Coice +1 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Firme**: pode ser levado ao interior de masmorras.\n'
                 '  * **Teimoso**: uma vez ao dia, há 1 chance em 1d6 de '
                 'empacar por 1 turno sem sair do lugar.\n'
                 '  * **Carga**: carrega ou puxa até 2.000 moedas ou 1.000 '
                 'moedas e um montador.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '0',
  'flavor': 'Resultado do cruzamento entre burro e cavalo. É semelhante a um '
            'cavalo leve, mas um pouco mais rústico.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 170},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 17},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'jumento-mula',
  'jp': '5',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Jumento/Mula',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/jumento-mula.json',
  'variant': False,
  'xp': '15'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 6,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Maça',
               'text': '1 × Maça +6 (1d8+2)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'humanoide',
  'description': '  * **Variações**: 1 a cada 4 cultistas são Cultistas '
                 'Adeptos. Além disso, há sempre um Cultista Sacerdote por '
                 'grupo.\n'
                 '\n'
                 '  * **Magias memorizadas**: Escuridão e Santuário. Podem '
                 'trocar estas magias por um Causar Ferimentos.',
  'dv': '8',
  'dv_bonus': '+2',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday12.json',
              'page': 21}],
  'habitats': ['qualquer'],
  'id': 'kadhras',
  'jp': '10',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Kadhras',
  'parent_monster_url': 'https://olddragon.com.br/monstros/cultista.json',
  'pv': '42',
  'size': 'medio',
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/kadhras.json',
  'variant': True,
  'variant_modifications': ['Magia como Clérigo de 7º nível',
                            'Magias memorizadas: Constrição, Escuridão, Luz, '
                            'Santuário, Profanar, Imobilizar Pessoas, '
                            'Silêncio, Convocar Insetos x2, Portal Dimensional',
                            'Itens carregados: Adaga ritualística (550 PO), '
                            'Colar de Ouro (300 PO), Braceletes de Prata (25 '
                            'PO), Maça de Mitral +1 (dano 1d8+1, 100 PO).'],
  'xp': '750'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 9,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8 + Veneno',
               'description': 'Ferrão',
               'text': '1 × Ferrão +9 (2d8 + Veneno)',
               'times': 1,
               'weapon': False},
              {'ba': 9,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Mordidas',
               'text': '2 × Mordidas +9 (1d4)',
               'times': 2,
               'weapon': False}],
  'ca': '15',
  'concept': 'besta',
  'description': '  * **Veneno**: o ferrão serrilhado da naga inocula Veneno '
                 'Sonífero. Uma JPC evita qualquer efeito deste veneno. Uma '
                 'falha no teste causa a perda de 1d6 pontos de Inteligência '
                 'por turno até o alvo perder todos os pontos de Inteligência '
                 'e morrer. Um antídoto ou magia podem neutralizar o veneno e '
                 'encerrar seus efeitos.\n'
                 '\n'
                 '  * **Magia**: uma naga pode conjurar magias como se fosse '
                 'um Mago de 6º nível.\n'
                 '\n'
                 '  * **Imunidades**: uma naga é imune ao dano de qualquer '
                 'ácido e veneno.',
  'dv': '8',
  'dv_bonus': '',
  'encounters': '1d2',
  'encounters_lair': '1d4',
  'flavor': 'Possuem corpo de serpente e cabeça humana. Vivem em suas tocas, '
            'guardando lugares e tesouros.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday24.json',
              'page': 18}],
  'habitats': ['pantanos', 'subterraneos'],
  'id': 'kallak-o-antigo',
  'jp': '7',
  'mo': 11,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': 9,
  'mvo': None,
  'mvv': None,
  'name': 'Kallak, o Antigo',
  'parent_monster_url': 'https://olddragon.com.br/monstros/naga-negra.json',
  'pv': '40',
  'size': 'medio',
  'treasure': 't',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/kallak-o-antigo.json',
  'variant': True,
  'variant_modifications': ['Magias: Aterrorizar x3, Criar Mortos-Vivos x2, '
                            'Drenar Vida x2.'],
  'xp': '740'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '2d4',
               'damage_bonus': 3,
               'damage_description': '2d4+3',
               'description': 'Pancadas',
               'text': '2 × Pancadas +3 (2d4+3)',
               'times': 2,
               'weapon': False},
              {'ba': 6,
               'damage': '1d8',
               'damage_bonus': 4,
               'damage_description': '1d8+4',
               'description': 'Arma',
               'text': '1 × Arma +6 (1d8+4)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': '1d4',
               'damage_bonus': 2,
               'damage_description': '1d4+2',
               'description': 'Chifre',
               'text': '1 × Chifre +2 (1d4+2)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'gigante',
  'description': 'Um pouco menores que um Ogro, possuem um único chifre curvo '
                 'na testa e olhos ameaçadores com pupilas levemente '
                 'amareladas.\n'
                 '\n'
                 'Vestem-se com poucas roupas, pois sua dura pele lhes garante '
                 'uma boa proteção.\n'
                 '\n'
                 'Usam o cabelo em trança ou rabo de cavalo, sendo estes os '
                 'únicos pelos de seus corpos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Apesar de preferirem o combate corpo a corpo, alguns '
                 'integrantes dos clãs, geralmente os mais fracos, usam '
                 'arcos.Contudo, recorrem a ataques à distância apenas em '
                 'última análise quando, por exemplo, enfrentam oponentes com '
                 'habilidades mágicas.\n'
                 '\n'
                 '  * **Empalar**: ao tirar o dano máximo com o chifre, o '
                 'personagem receberá 12 pontos de dano a mais e ficará preso '
                 'ao chifre. Uma JPD anula metade do dano e ficar preso no '
                 'chifre.  O Kawamung recebe uma penalidade de -2 em seu CA '
                 'contra o personagem empalado.\n'
                 '\n'
                 '  * **Golpe Potente**: se causar, com uma pancada, chifre ou '
                 'arma, uma quantidade de dano maior do que a força do alvo, '
                 'este é arremessado 1d4 metros para trás.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Kawamungs são seres escravocratas, atacando povoados '
                 'isolados em busca de mão de obra barata para seus impérios.\n'
                 '\n'
                 'Acreditam na lei do mais forte, sendo que o líder recebe '
                 'anualmente um desafio de outro integrante do bando em busca '
                 'de seu cargo.\n'
                 '\n'
                 'Assim, e talvez devido a isso, poucos chegam a idades '
                 'avançadas, o que seria considerado uma desonra entre os '
                 'clãs.\n'
                 '\n'
                 'Algumas vezes trabalham com gigantes, desde que vejam alguma '
                 'vantagem na aliança.\n'
                 '\n'
                 'Abominam seriamente a magia e não possuem xamãs, apesar de '
                 'conhecerem o segredo das ervas de cura.',
  'dv': '4',
  'dv_bonus': '+4',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Guerreiros conquistadores que expandem seus impérios com o '
            'trabalho de escravos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 117},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 14},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'kawamung',
  'jp': '7',
  'mo': 11,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Kawamung',
  'picture': 'https://public.olddragon.com.br/fv5lhwxoc92r2yqj7xmultguahmc',
  'pv': '20',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/sn0nw9okntmhsvmd41tvb7zj0kzh',
  'treasure': 't',
  'treasure_lair': 'd',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/kawamung.json',
  'variant': False,
  'xp': '150'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 5,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Garra',
               'text': '1 × Garra +5 (1d6)',
               'times': 1,
               'weapon': False},
              {'ba': 3,
               'damage': '1d10',
               'damage_bonus': None,
               'damage_description': '1d10',
               'description': 'Cauda',
               'text': '1 × Cauda +3 (1d10)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'besta',
  'description': '\n'
                 '\n'
                 '  * Magia como Clérigo de 3º nível.\n'
                 '  * **Magias Preparadas**: Escudo Arcano, Sono, Toque '
                 'Sombrio, Mísseis Mágicos 1d4+1 (3x), Névoa Mortal.\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '  * **Imunidade**: Dano de fogo.\n'
                 '\n',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '1',
  'flavor': 'Um kobold meio-demônio, tocado pela marca de Olog Tulhu.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 27}],
  'habitats': ['subterraneos'],
  'id': 'khalathor',
  'jp': '7',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Khalathor',
  'picture': 'https://public.olddragon.com.br/ncfi1broirbswofjwmh8h5jpjo73',
  'pv': '30',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/nn2u5h41i8m9x3zo84div0n5344e',
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/khalathor.json',
  'variant': False,
  'xp': '150'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 0,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma (Arma)',
               'times': 1,
               'weapon': True},
              {'ba': 1,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Mordidas',
               'text': '2 × Mordidas +1 (1d4)',
               'times': 2,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': 'Um pouco menores do que os Goblins, mas geralmente mais '
                 'franzinos, os Kobolds lembram cachorros vira-latas por causa '
                 'do rosto longo, e também por viverem na sujeira e por '
                 'consumirem restos.\n'
                 '\n'
                 'Possuem dois pequenos chifres córneos no topo da cabeça '
                 'levemente pendidos para trás.\n'
                 '\n'
                 'Famosos pela sua covardia, roubam sem serem vistos ou após '
                 'armarem algum tipo de armadilha.\n'
                 '\n'
                 '**Som**: passos e rosnados leves como o de um cachorro '
                 'bravo.\n'
                 '\n'
                 '**Odor**: quarto habitado por um cachorro molhado.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Fisicamente mais fracos do que tantas outras raças, os '
                 'Kobolds confiam na força dos números e em armadilhas bem '
                 'posicionadas.\n'
                 '\n'
                 'De simples buracos escondidos com redes, até dardos com '
                 'sonífero e potes com escorpiões, eles sabem como surpreender '
                 'suas vítimas.\n'
                 '\n'
                 'Adeptos do “bater e fugir”, podem atacar várias vezes o '
                 'mesmo lugar, caso seja seguro e faça parte do plano de minar '
                 'as defesas do adversário.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em grandes grupos alocados em cavernas escuras, nem '
                 'sempre desocupadas.\n'
                 '\n'
                 'Quando ocupam florestas, disputam os territórios com os '
                 'Taslois, seus principais inimigos neste habitat.\n'
                 '\n'
                 'Podem conviver com qualquer criatura em troca de proteção, '
                 'por isso não é incomum, em uma caverna de Kobolds, encontrar '
                 'um Troll, Ogro ou mesmo uma Mantícora.\n'
                 '\n'
                 'Seus xamãs usam suas magias mais para ajudar os demais do '
                 'que para guerrear, mas ainda podem ter alguns poderes úteis '
                 'em combate.',
  'dv': '½',
  'dv_bonus': '',
  'encounters': '4d4',
  'encounters_lair': '6d10',
  'flavor': 'Humanoides pequenos e covardes que armam armadilhas para '
            'surpreenderem seus adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 69},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 176},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 118},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 6},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'kobold',
  'jp': '4',
  'mo': 5,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Kobold',
  'picture': 'https://public.olddragon.com.br/kvdwsp2usmybqrl3rcqg2y7wvj6j',
  'pv': '2',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/g5wr9k2yjnuta9rwpa8idwj1z49z',
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/kobold.json',
  'variant': False,
  'xp': '5'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Humanoides pequenos e covardes que armam armadilhas para '
            'surpreenderem seus adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 69}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'kobold-atirador',
  'name': 'Kobold Atirador',
  'parent_monster_url': 'https://olddragon.com.br/monstros/kobold.json',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/kobold-atirador.json',
  'variant': True},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Mordidas',
               'text': '2 × Mordidas +3 (1d6)',
               'times': 2,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': '  * **Infravisão**: 18 metros.',
  'dv': '3',
  'dv_bonus': '1',
  'encounters': '4d4',
  'encounters_lair': '6d10',
  'flavor': 'Humanoides pequenos e covardes que armam armadilhas para '
            'surpreenderem seus adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 70},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 6}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'kobold-atroz',
  'jp': '5',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Kobold Atroz',
  'parent_monster_url': 'https://olddragon.com.br/monstros/kobold.json',
  'pv': '16',
  'size': 'pequeno',
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/kobold-atroz.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '75'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Humanoides pequenos e covardes que armam armadilhas para '
            'surpreenderem seus adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 69}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'kobold-besteiro',
  'name': 'Kobold Besteiro',
  'parent_monster_url': 'https://olddragon.com.br/monstros/kobold.json',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/kobold-besteiro.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Humanoides pequenos e covardes que armam armadilhas para '
            'surpreenderem seus adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 70}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'kobold-besteiro-de-elite',
  'name': 'Kobold Besteiro de Elite',
  'parent_monster_url': 'https://olddragon.com.br/monstros/kobold.json',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/kobold-besteiro-de-elite.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Humanoides pequenos e covardes que armam armadilhas para '
            'surpreenderem seus adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 70}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'kobold-chefe',
  'name': 'Kobold Chefe',
  'parent_monster_url': 'https://olddragon.com.br/monstros/kobold.json',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/kobold-chefe.json',
  'variant': True},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': 'Especial',
               'description': 'Rede',
               'text': '1 × Rede +1 (Especial)',
               'times': 1,
               'weapon': False},
              {'ba': 1,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Espada curta',
               'text': '1 × Espada curta +1 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': '  * **Infravisão**: 18 metros.',
  'dv': '1',
  'dv_bonus': '3',
  'encounters': '4d4',
  'encounters_lair': '6d10',
  'flavor': 'Humanoides pequenos e covardes que armam armadilhas para '
            'surpreenderem seus adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 70},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 6}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'kobold-de-elite',
  'jp': '5',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Kobold de Elite',
  'parent_monster_url': 'https://olddragon.com.br/monstros/kobold.json',
  'pv': '8',
  'size': 'pequeno',
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/kobold-de-elite.json',
  'variant': True,
  'variant_modifications': ['Especial: Atacar um alvo enredado é um ataque '
                            'fácil. Atacar estando enredado é um ataque '
                            'difícil. Uma rodada de combate deve ser gasta '
                            'para livrar-se de uma rede.'],
  'xp': '15'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 0,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Mordidas',
               'text': '2 × Mordidas (1d4)',
               'times': 2,
               'weapon': False}],
  'ca': '11',
  'concept': 'humanoide',
  'description': '  * **Infravisão**: 18 metros.',
  'dv': '½',
  'dv_bonus': '',
  'encounters': '4d4',
  'encounters_lair': '6d10',
  'flavor': 'Humanoides pequenos e covardes que armam armadilhas para '
            'surpreenderem seus adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 70},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday23.json',
              'page': 17}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'kobold-desarmado',
  'jp': '4',
  'mo': 5,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Kobold Desarmado',
  'parent_monster_url': 'https://olddragon.com.br/monstros/kobold.json',
  'pv': '2',
  'size': 'pequeno',
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/kobold-desarmado.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '5'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 0,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Mordidas',
               'text': '2 × Mordidas (1d4)',
               'times': 2,
               'weapon': False}],
  'ca': '11',
  'concept': 'humanoide',
  'description': '  * **Infravisão**: 18 metros.',
  'dv': '½',
  'dv_bonus': '',
  'encounters': '4d4',
  'encounters_lair': '6d10',
  'flavor': 'Humanoides pequenos e covardes que armam armadilhas para '
            'surpreenderem seus adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday23.json',
              'page': 17}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'kobold-filhote',
  'jp': '4',
  'mo': 5,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Kobold Filhote',
  'parent_monster_url': 'https://olddragon.com.br/monstros/kobold.json',
  'pv': '2',
  'size': 'pequeno',
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/kobold-filhote.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '5'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Humanoides pequenos e covardes que armam armadilhas para '
            'surpreenderem seus adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 70}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'kobold-lanceiro-de-elite',
  'name': 'Kobold Lanceiro de Elite',
  'parent_monster_url': 'https://olddragon.com.br/monstros/kobold.json',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/kobold-lanceiro-de-elite.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 1,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Bordão',
               'text': '1 × Bordão +1 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': 'Um pouco menores do que os Goblins, mas geralmente mais '
                 'franzinos, os Kobolds lembram cachorros vira-latas por causa '
                 'do rosto longo, e também por viverem na sujeira e por '
                 'consumirem restos.\n'
                 '\n'
                 'Possuem dois pequenos chifres córneos no topo da cabeça '
                 'levemente pendidos para trás.\n'
                 '\n'
                 'Famosos pela sua covardia, roubam sem serem vistos ou após '
                 'armarem algum tipo de armadilha.\n'
                 '\n'
                 '**Som**: passos e rosnados leves como o de um cachorro '
                 'bravo.\n'
                 '\n'
                 '**Odor**: quarto habitado por um cachorro molhado.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Fisicamente mais fracos do que tantas outras raças, os '
                 'Kobolds confiam na força dos números e em armadilhas bem '
                 'posicionadas.\n'
                 '\n'
                 'De simples buracos escondidos com redes, até dardos com '
                 'sonífero e potes com escorpiões, eles sabem como surpreender '
                 'suas vítimas.\n'
                 '\n'
                 'Adeptos do “bater e fugir”, podem atacar várias vezes o '
                 'mesmo lugar, caso seja seguro e faça parte do plano de minar '
                 'as defesas do adversário.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em grandes grupos alocados em cavernas escuras, nem '
                 'sempre desocupadas.\n'
                 '\n'
                 'Quando ocupam florestas, disputam os territórios com os '
                 'Taslois, seus principais inimigos neste habitat.\n'
                 '\n'
                 'Podem conviver com qualquer criatura em troca de proteção, '
                 'por isso não é incomum, em uma caverna de Kobolds, encontrar '
                 'um Troll, Ogro ou mesmo uma Mantícora.\n'
                 '\n'
                 'Seus xamãs usam suas magias mais para ajudar os demais do '
                 'que para guerrear, mas ainda podem ter alguns poderes úteis '
                 'em combate.',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '4d4',
  'encounters_lair': '6d10',
  'flavor': 'Humanoides pequenos e covardes que armam armadilhas para '
            'surpreenderem seus adversários.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 118},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 6}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'kobold-xama',
  'jp': '5',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Kobold Xamã',
  'parent_monster_url': 'https://olddragon.com.br/monstros/kobold.json',
  'picture': 'https://public.olddragon.com.br/kvdwsp2usmybqrl3rcqg2y7wvj6j',
  'pv': '5',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/g5wr9k2yjnuta9rwpa8idwj1z49z',
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/kobold-xama.json',
  'variant': True,
  'variant_modifications': ['Magia como Clérigo de 1º nível.'],
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Pancada',
               'text': '1 × Pancada +1 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'morto_vivo',
  'description': 'Quando um vampiro decide criar um Lacaio, ele o faz de forma '
                 'especialmente maldosa. Dando pequenas quantidades de seus '
                 'próprio sangue para o lacaio beber, viciando-o na sensação '
                 'entorpecente que esse ritual causa em suas vítimas, ao mesmo '
                 'tempo drenando a força de vontade do lacaio e tornando-o em '
                 'um ser completamente a mercê dos caprichos do Vampiro que o '
                 'controla totalmente. Um verdadeiro escravo dos caprichos do '
                 'Vampiro mestre.\n'
                 '\n'
                 'Este lacaio recém criado possui uma mínima fração do poder '
                 'de seu criador. Portanto, é incapaz de desafiar a autoridade '
                 'de seu mestre.\n'
                 '\n'
                 'Além disso, Vampiros exercem uma poderosa forma de encanto '
                 'sobre seus lacaios, impedindo-os de agir para destruí-lo.\n'
                 '\n'
                 'Isso não significa que os lacaios do Vampiro não possam agir '
                 'para minar os planos do Vampiro de maneiras menores, apenas '
                 'que eles devem fazer o que for ordenado por seu senhor.\n'
                 '\n'
                 '\n'
                 '\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': None,
  'encounters_lair': None,
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 171}],
  'habitats': ['qualquer'],
  'id': 'lacaio-vampirico',
  'jp': '5',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Lacaio Vampírico',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/lacaio-vampirico.json',
  'variant': False,
  'xp': '21'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 6,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Mordida',
               'text': '1 × Mordida +6 (2d6)',
               'times': 1,
               'weapon': False},
              {'ba': 6,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Garra',
               'text': '1 × Garra +6 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'animal',
  'description': 'Esta criatura gigantesca parece uma iguana ou lagarto do '
                 'deserto de tamanho desproporcional.\n'
                 '\n'
                 'Existem variações dentro do que se categoriza como “Lagarto '
                 'Gigante”, de forma que até exemplares mais próximos dos '
                 'camaleões e lagartixas podem ser encontrados.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'É um animal selvagem, atacando por instinto na caça ou na '
                 'sobrevivência.\n'
                 '\n'
                 'Quando domesticados, são ensinados a atacar os alvos com '
                 'mordidas, enquanto o cavaleiro usa lanças para acertar o '
                 'mesmo alvo.\n'
                 '\n'
                 '  * **Montaria**: pode ser usado como montaria apta para '
                 'combater, sendo capaz de realizar ataques de investida se '
                 'ainda não engajado em combate, de usar armaduras e de atacar '
                 'na mesma rodada que seu condutor.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'A maioria é ovípara, nascendo de um ovo, fazendo com que '
                 'caçadores procurem os ovos para vender ao mercador certo.\n'
                 '\n'
                 'De relativa facilidade para serem treinados, os lagartos são '
                 'usados como montarias de guerra e, às vezes, como animais de '
                 'transporte e de cargas.\n'
                 '\n'
                 'Comportam-se basicamente como seu equivalente de tamanho '
                 '“normal”.',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '1d8',
  'flavor': 'Lagarto quadrúpede similar a uma iguana imensa. Carnívoro e, '
            'quando domesticado, usado como montaria.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 119},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['montanhas', 'pantanos', 'desertos'],
  'id': 'lagarto-gigante',
  'jp': '8',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': 9,
  'mvo': None,
  'mvv': None,
  'name': 'Lagarto Gigante',
  'picture': 'https://public.olddragon.com.br/1mrqhl9oqgh1szy941mwih8rwd04',
  'pv': '30',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/k272ko5pu7at23ue8d0r7poi05u5',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/lagarto-gigante.json',
  'variant': False,
  'xp': '270'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Lagartos noturnos e carnívoros de 1,5m de comprimento.  Possuem '
            'escamas azuladas com manchas laranjas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 71}],
  'habitats': ['desertos'],
  'id': 'lagarto-gigante-do-deserto',
  'name': 'Lagarto Gigante do Deserto',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/lagarto-gigante-do-deserto.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 6,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1',
               'description': 'Garras',
               'text': '2 × Garras +6 (1d4+1)',
               'times': 2,
               'weapon': False},
              {'ba': 6,
               'damage': '1d10',
               'damage_bonus': None,
               'damage_description': '1d10',
               'description': 'Mordida',
               'text': '1 × Mordida +6 (1d10)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '5',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '1d8',
  'flavor': 'O felino mais feroz e poderoso das planícies tropicais, ataca em '
            'grupo, inclusive humanos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 17},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['planicies'],
  'id': 'leao',
  'jp': '8',
  'mo': 9,
  'mv': 10,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Leão',
  'picture': None,
  'pv': '25',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/leao.json',
  'variant': False,
  'xp': '175'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Grandes e majestosos felinos. Devido à pelagem branca, podem se '
            'camuflar em meio às dunas prateadas. Vivem em grupos. Raramente '
            'são encontrados em seu estado selvagem, próximos a piscinas '
            'naturais. Costumam ser adestrados pelos povos Mortik, recebendo '
            'uma coleira especial feita a partir das escamas de um Diabo '
            'Branco.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 71}],
  'habitats': ['desertos'],
  'id': 'leao-branco',
  'name': 'Leão Branco',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/leao-branco.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 5,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Pancadas',
               'text': '4 × Pancadas +5 (1d8+2)',
               'times': 4,
               'weapon': False}],
  'ca': '16',
  'concept': 'besta',
  'description': 'Parecem lesmas normais, mas do topo de sua cabeça saem '
                 'quatro poderosas maças, feitas de material ósseo.\n'
                 '\n'
                 'Essas maças balançam de acordo com o humor da criatura e '
                 'podem ser usados como armas formidáveis em combate.\n'
                 '\n'
                 '**Som**: líquido escorrendo.\n'
                 '\n'
                 '**Odor**: cheiro ocre levemente adocicado.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam sem piedade os inimigos que escorregam, amaciando-os '
                 'com muitas pancadas antes de devorá-los lentamente.\n'
                 '\n'
                 '  * **Muco**: a Lesma Mangual deixa um rastro de muco '
                 'escorregadio por onde passa. Por 1d3 turnos essa trilha '
                 'escorregadia faz com que todos que pisem nela tenham que ser '
                 'bem-sucedidos numa JPD ou escorregarão e cairão no chão. Há '
                 'uma chance de 1-2 em 1d6 de uma pessoa que escorregue solte '
                 'qualquer objeto que esteja segurando. A Lesma Mangual pode '
                 'deslizar, deslocando-se assim com o dobro do seu movimento '
                 'por uma área na qual já possua o muco no chão.\n'
                 '\n'
                 '  * **Refletir Magia**: Lesmas Manguais distorcem todas as '
                 'magias lançadas diretamente sobre elas (com exceção das '
                 'magias de área).  Quando forem alvos de uma magia, lance 1d6 '
                 'e confira na lista:\n'
                 '\n'
                 '**1**. A magia lançada ricocheteia em seu casco e retorna, '
                 'causando efeitos ao conjurador.\n'
                 '\n'
                 '**2**. A magia lançada ricocheteia em seu casco e retorna, '
                 'atingindo o alvo mais próximo que não seja o conjurador ou a '
                 'Lesma Mangual.\n'
                 '\n'
                 '**3-4**. A magia lançada ricocheteia em seu casco e atinge o '
                 'teto, a parede ou o piso, não causando nenhum efeito.\n'
                 '\n'
                 '**5-6**. A magia lançada causa seu efeito normalmente.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Muito antigas, dizem que os primeiros homens usavam os '
                 'manguais dessas criaturas como armas, antes de descobrirem o '
                 'segredo da forja.  Nos lares delas, milhares de caracóis, '
                 'lesmas e caramujos fazem suas próprias casas, protegidos '
                 'pela Lesma Mangual.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A baba das Lesmas Manguais é usada como ingrediente '
                 'espessante de caldos e sopas na culinária de alguns povos do '
                 'subterrâneo.',
  'dv': '5',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1d2',
  'flavor': 'Caracóis gigantes com grandes maças ósseos no topo de sua cabeça. '
            'Percorrem os subterrâneos atrás de qualquer alimento.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 120},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'lesma-mangual',
  'jp': '8',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Lesma Mangual',
  'picture': 'https://public.olddragon.com.br/tfhepnvxtbwsmobqre4vadtyvaxg',
  'pv': '25',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/uvdsfs6eiykty5rf5cp6esongs86',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/lesma-mangual.json',
  'variant': False,
  'xp': '235'},
 {'access': 'limited',
  'alignment': 'ordeiro',
  'concept': 'besta',
  'flavor': 'Vermes tentaculares alados e colossais, oriundos dos Abismos do '
            'Sem-Fim. São conhecidos por se alimentarem de dragões.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 42}],
  'habitats': ['extraplanar'],
  'id': 'leviata-dos-abismos-do-sem-fim',
  'name': 'Leviatã dos Abismos do Sem-Fim',
  'size': 'colossal',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/leviata-dos-abismos-do-sem-fim.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 8,
               'damage': '1d10',
               'damage_bonus': None,
               'damage_description': '1d10 + Paralisia',
               'description': 'Toque',
               'text': '1 × Toque +8 (1d10 + Paralisia)',
               'times': 1,
               'weapon': False}],
  'ca': '20',
  'concept': 'morto_vivo',
  'description': 'Os Lichs possuem um corpo sem vida, decadente, necrosado, '
                 'desnutrido ou mesmo sem carne alguma. Poderiam aparentar até '
                 'mesmo um Zumbi comum, se não fosse as roupas nobres e o '
                 'intenso brilho maligno de seus olhos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam legiões de mortos-vivos contra os incômodos mais '
                 'simples, no entanto se necessário usam seu poder mágico para '
                 'se proteger.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Imunidades**: além das imunidades comuns aos '
                 'mortos-vivos, Lichs são feridos apenas por magia e armas '
                 'mágicas se lançadas ou usadas por criaturas com 5 ou mais '
                 'dados de vida. Além disso, são imunes a efeitos mágicos que '
                 'envolvam eletricidade, necromancia ou insanidade. Lichs '
                 'também são imunes ao poder de Afastar Mortos-Vivos de um '
                 'Clérigo.\n'
                 '\n'
                 '  * **Paralisia**: alvo atingido por um Lich deve ser '
                 'bem-sucedido em uma JPC ou ficará paralisado permanentemente '
                 'ou até uma Curar Doenças ser lançada por um Clérigo.\n'
                 '\n'
                 '  * **Aura Aterrorizante**: qualquer criatura com 4 dados de '
                 'vida ou menos e a até 30 metros do Lich, capaz de ver ou '
                 'percebê-lo, é afetada pela Aura Aterrorizante do Lich que '
                 'afugenta todos por 1d4 turnos. Nenhuma Jogada de Proteção '
                 'pode anular o efeito desta Aura Aterrorizante. Há 1-4 '
                 'chances em 1d6 de uma de uma pessoa em fuga deixar cair o '
                 'que estiver carregando.\n'
                 '\n'
                 '  * **Magias**: um Lich pode lançar magias como um '
                 'Necromante de 15º nível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Apenas os Necromantes que se descontrolam e ficam insanos '
                 'tornam-se um Lich. Solitários, não se interessam por nada '
                 'que não envolva seu aumento com os poderes sombrios. Alguns '
                 'tentam até mesmo alcançar o status divino, custe o que '
                 'custar.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'O pó dos ossos dos Lichs é citado em várias lendas ligadas à '
                 'profanação\n'
                 '\n'
                 'Tesouro\n'
                 '\n'
                 '1d4+1 itens mágicos adicionais.',
  'dv': '20',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'O Lich é o resultado do que a cobiça por poder causa a uma mente '
            'enlouquecida pelo conhecimento obscuro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 127},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'lich',
  'jp': '16',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Lich',
  'picture': 'https://public.olddragon.com.br/nhctypt7hppahgddh802ue1d5e4o',
  'pv': '100',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/36vh50avx3uh6lodzu85yu70v15t',
  'treasure': 'especial',
  'treasure_lair': 'h',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/lich.json',
  'variant': False,
  'xp': '4975'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Toque',
               'text': '1 × Toque +3 (2d8)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'gosma',
  'description': 'Estas criaturas amorfas possuem um corpo acinzentado, mas '
                 'ainda assim um pouco translúcido.\n'
                 '\n'
                 'Elas esticam seus pseudópodos para atacar e alcançar as '
                 'vítimas, em busca de alimento.\n'
                 '\n'
                 '**Som**: líquido gotejando e escorrendo.\n'
                 '\n'
                 '**Odor**: cheiro excessivamente doce.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Seu maior interesse está nos matais. Por isso, atacam '
                 'aventureiros em busca de suas armas, armaduras e '
                 'equipamentos.\n'
                 '\n'
                 'Raramente atacam sem ter fome, preferindo se esconder '
                 'enquanto os grupos passam, caso não desejem se alimentar.\n'
                 '\n'
                 '  * **Camuflagem**: pelo seu aspecto acinzentado e molhado, '
                 'são confundidos com pedras molhadas. Nestas circunstâncias, '
                 'surpreendem seus inimigos com um resultado de 1 a 4 em 1d6.\n'
                 '\n'
                 '  * **Ácido**: após um ataque bem-sucedido, o limo gruda na '
                 'vítima e passa a liberar um potente ácido, mas que corrói '
                 'apenas metais. Este ácido é capaz de atingir armas e '
                 'armaduras, causando uma penalidade no dano (no caso de '
                 'armas) ou na proteção (no caso de armaduras) de 1 a cada '
                 'rodada que o limo passa aderido ao alvo.  Se uma arma recebe '
                 'uma quantidade de dano igual ao seu dado de dano (4 para 1d4 '
                 'ou 6 para 1d6, por exemplo), a arma ficará permanentemente '
                 'destruída. Se uma armadura recebe uma quantidade de dano '
                 'igual ao seu bônus no CA (+4 para uma cota de malha, por '
                 'exemplo), a armadura ficará permanentemente destruída.\n'
                 '\n'
                 '  * **Imunidades**: imune aos efeitos do frio e da '
                 'eletricidade.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem principalmente em masmorras e em outros lugares '
                 'desabitados.\n'
                 '\n'
                 'Felizmente, se alimentam apenas uma vez por semana, pois sua '
                 'digestão é bem lenta.\n'
                 '\n'
                 'Procriam apenas uma vez ao ano, após ingerirem uma enorme '
                 'quantidade de metal, que será usada para nutrir a cria.',
  'dv': '3',
  'dv_bonus': '+3',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Cinzenta e viscosa esta gosma escorre pelos corredores das '
            'masmorras procurando toda forma de metal para corroer.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 128},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'limo-cinzento',
  'jp': '6',
  'mo': 8,
  'mv': 3,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Limo Cinzento',
  'picture': 'https://public.olddragon.com.br/p7enc151qorshd04aevj3v48w2d4',
  'pv': '18',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/1i9kdxtt4oussj0h0792fa69l7d7',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/limo-cinzento.json',
  'variant': False,
  'xp': '95'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Alcateia**: O moral de um Lobo é 8 se estiver em '
                 'grupos de 4 ou mais.\n'
                 '\n',
  'dv': '2',
  'dv_bonus': '+2',
  'encounters': '2d6',
  'encounters_lair': '3d6',
  'flavor': 'Canídeos que vivem em geleiras, montanhas e florestas geladas. '
            'Vivem em grupos e fazem disso sua principal força de combate.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/ja1.json',
              'page': 38},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 170},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 17},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['colinas', 'florestas', 'geleiras', 'montanhas'],
  'id': 'lobo',
  'jp': '5',
  'mo': 6,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Lobo',
  'picture': None,
  'pv': '12',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/lobo.json',
  'variant': False,
  'xp': '175'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'morto_vivo',
  'description': 'Criados por forças dos planos negativos, os Esqueletos lutam '
                 'instintivamente atacando seus alvos de forma incansável.  '
                 'Esqueletos podem ser criados a partir de qualquer criatura '
                 'viva.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Não se sabe ao certo de onde vem a habilidade de luta de um '
                 'Esqueleto, visto que nem todos foram combatentes quando '
                 'vivos.\n'
                 '\n'
                 'De qualquer forma, por sua falta de medo e de emoções, '
                 'Esqueletos lutam friamente com as armas que lhes foram '
                 'dadas, sejam espadas, lanças ou arcos.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar-se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Corpo de Osso**: armas impactantes causam o dobro de '
                 'dano nos Esqueletos, mas, em contrapartida, armas '
                 'perfurantes causam metade do ano.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar '
                 'Mortos-Vivos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'O motivo de sua existência é servir ao seu criador, seja '
                 'este um necromante ou qualquer outra criatura capaz de '
                 'criá-los. Quando seu criador perde o controle sobre os '
                 'Esqueletos, estes se tornam errantes e sem propósito, a não '
                 'ser matar todos os seres encontrados. Esqueletos geralmente '
                 'estão em grupos, pois não são fortes o suficiente para '
                 'atuarem sozinhos como guardas.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os ossos dos Esqueletos triturados são base de várias poções '
                 'e venenos, além de tornarem os campos inférteis se '
                 'espalhados sobre a terra.',
  'dv': '2',
  'dv_bonus': '+1',
  'encounters': '3d4',
  'encounters_lair': '3d10',
  'flavor': 'Mortos-vivos normalmente usados como guardiões de locais antigos '
            'e esquecidos. Sem medo, atacam até caírem aos pedaços.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 76}],
  'habitats': ['qualquer'],
  'id': 'lobo-esqueleto',
  'jp': '5',
  'mo': 10,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Lobo Esqueleto',
  'parent_monster_url': 'https://olddragon.com.br/monstros/esqueleto.json',
  'picture': 'https://public.olddragon.com.br/tkskg2j4sowg5uvnv57v40jcu5h2',
  'pv': '11',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/d01ibazu0zbf8i7de2eyw8d17zxt',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/lobo-esqueleto.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6 + Infecção',
               'description': 'Mordida',
               'text': '1 × Mordida +3 (1d6 + Infecção)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'morto_vivo',
  'description': 'Zumbis são criaturas lentas que servem a entidades malignas, '
                 'após serem reanimados de seus túmulos.\n'
                 '\n'
                 'Diferente dos Esqueletos, matam não apenas por ordem, mas '
                 'porque desejam devorar suas vítimas. Quando criados por meio '
                 'de animais, normalmente se encontram presos a coleiras, pois '
                 'a fome pelos vivos é enorme.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usados como soldados, os Zumbis não costumam trabalhar com '
                 'criaturas vivas, pois são uma ameaça a sua segurança.\n'
                 '\n'
                 'O desejo incontrolável por devorar a carne dos vivos faz com '
                 'que sejam colocados com outros mortos-vivos ou criaturas '
                 'incorpóreas. Quando atacam, usam suas garras para puxar e '
                 'para tentar morder seus alvos, mas só conseguirão caso a '
                 'vítima esteja lutando sem armas ou com armas pequenas como '
                 'adagas.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a magias mentais de manipulação, '
                 'controle ou ilusão, ou demais formas mágicas de interferir '
                 'na mente de seres vivos. Sofre 1d6 de dano ácido por frasco '
                 'de água benta.\n'
                 '\n'
                 '  * **Lento**: sempre perde a Iniciativa num combate. Um '
                 'Zumbi sempre ataca por último.\n'
                 '\n'
                 '  * **Infecção**: personagens mordidos devem passar em uma '
                 'JPC ou se tornarão Zumbis em 1d4 dias, a não ser que uma '
                 'magia de Curar Doenças ou Curar Ferimentos seja usada no '
                 'alvo infectado.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral a '
                 'não ser quando sofrem o efeito de um Afastar Mortos-Vivos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Zumbis não se relacionam com nenhuma outra criatura, assim '
                 'como a maioria dos mortos-vivos que não possuem '
                 'inteligência.\n'
                 '\n'
                 'Quando estão em grupos grandes, devoram as vítimas até não '
                 'sobrar mais nada, por isso novos Zumbis surgem destes '
                 'ataques apenas quando o bando é menor e quando resta alguma '
                 'integridade no corpo para que possa se locomover e atacar.\n'
                 '\n'
                 'Além de Magos e Clérigos, existem casos em que energias '
                 'muito malignas acabam criando estes mortos-vivos de forma '
                 'espontânea pela simples emanação energética de planos '
                 'negativos.\n'
                 '\n'
                 '## Variações\n'
                 '\n'
                 'Os acontecimentos que desencadeiam a criação de um Zumbi '
                 'ainda estão longe de serem dominados pelos maiores '
                 'estudiosos da necromancia. Não sendo uma espécie única, os '
                 'Zumbis possuem as mais diferentes origens, comportamentos e '
                 'características, dando origem a diferentes tipos, com '
                 'propósitos e meios de agir únicos.\n'
                 '\n'
                 '### Zumbi do Sal\n'
                 '\n'
                 'Criado pela horrenda experiência de morrer de sede em '
                 'desertos. Desidratados e desesperados, perseguem os vivos '
                 'pela água em seus corpos.  São capazes de se transformarem '
                 'em criaturas realmente determinadas pelo seu objetivo único '
                 'de se hidratar a todo o custo.\n'
                 '\n'
                 'Mantém todas as estatísticas e habilidades de um Zumbi '
                 'comum, mas troca sua habilidade de Infecção pela habilidade '
                 'a seguir:\n'
                 '\n'
                 '  * **Sugar**: se o ataque de mordida for bem-sucedido, ele '
                 'agarra sua vítima e começa a sugar o seu sangue, causando '
                 '1d6 de dano por rodada até ser morta. A única forma de '
                 'soltá-lo da vítima é destruindo sua cabeça, reduzindo seus '
                 'PV a zero ou menos.\n'
                 '\n'
                 '### Zumbi Afogado\n'
                 '\n'
                 'Criado por pessoas afogadas. Seu corpo é inchado, gotejante '
                 'e deformado, como as vítimas de afogamentos.  Sua carne tem '
                 'aspecto de ter sido comida por peixes e outros seres do '
                 'mar.\n'
                 '\n'
                 'Mantém todas as estatísticas e habilidades de um Zumbi '
                 'comum, mas troca sua habilidade de Infecção pela habilidade '
                 'a seguir:\n'
                 '\n'
                 '  * **Explodir**: ao sofrer dano, há uma chance de 1 em 1d6 '
                 'do seu corpo estourar, espalhando em todos dentro de uma '
                 'área de 3m uma onda de dejetos pútridos e purulentos, '
                 'repletos de doenças e infecção. Um alvo atingido deve ser '
                 'bem-sucedido numa JPC ou sofrerá os efeitos do contágio, '
                 'deixando o doente com Constituição 1 durante 1d6 dias.  Há '
                 'uma chance de 1 em 1d6 do doente morrer.\n'
                 '\n'
                 '### Esporo-Zumbi\n'
                 '\n'
                 'Resultado imprevisível de mortos-vivos atacados por fungos '
                 'desconhecidos dos subterrâneos.\n'
                 '\n'
                 'Os esporos se desenvolvem nos corpos contaminados pelo ar ou '
                 'por alimentos e líquidos contaminados. Passam a controlar o '
                 'cérebros de seus hospedeiros, transformando-os em criaturas '
                 'assassinas e agressivas, que perseguem suas vítimas para '
                 'passar a infecção adiante.\n'
                 '\n'
                 'Possui diferentes habilidades à medida que a infecção cresce '
                 'e toma conta de seu corpo:\n'
                 '\n'
                 '  * **Infectado**: durante os primeiros dias da infecção e '
                 'por toda esta fase, o Esporo-Zumbi troca suas habilidades '
                 'Silencioso e Lento pela habilidade de Correr, tendo o '
                 'movimento de quando era vivo.\n'
                 '\n'
                 '  * **Fendido**: após os primeiros dias de infecção, seu '
                 'crânio fica fendido por vários fungos que brotam de seu '
                 'interior. Nesta fase, ele troca sua habilidade de Correr '
                 'pela habilidade de Perseguir, usando uma espécie de '
                 'ecolocalização para saber precisamente onde todo ser vivo '
                 'está num raio de 30m.\n'
                 '\n'
                 '  * **Rei**: aproximadamente um mês após a infecção, têm seu '
                 'corpo completamente tomado pelo fungo, tornando-se uma '
                 'máquina de propagar seus esporos. Durante um combate, todos '
                 'em até 9m de um Esporo-Zumbi Rei que receberem um ataque '
                 'bem-sucedido, possuem uma chance de 1 em 1d6 de serem '
                 'infectados pelos esporos, tornando-se um Infectado, '
                 'reiniciando todo o processo.',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '4d6',
  'flavor': 'Morto-vivo sem inteligência. Avança para cima de suas vítimas com '
            'o único intuito de destroçá-las com garras e dentes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 178}],
  'habitats': ['qualquer'],
  'id': 'lobo-zumbi',
  'jp': '6',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Lobo Zumbi',
  'parent_monster_url': 'https://olddragon.com.br/monstros/zumbi.json',
  'picture': 'https://public.olddragon.com.br/cz4xa87qz93imyvxgtmjrpst2zrk',
  'pv': '15',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/6yi5o3kte4bwdldij0z092zdsk4x',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/lobo-zumbi.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '75'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'planta',
  'flavor': 'Vegetal viscoso e grudento de odor forte e coloração variada. '
            'Cresce sobre superfícies úmidas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 71}],
  'habitats': ['desertos'],
  'id': 'lodo',
  'name': 'Lodo',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/lodo.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8 + Dreno',
               'description': 'Garra',
               'text': '1 × Garra +4 (1d8 + Dreno)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'morto_vivo',
  'description': '\n'
                 '\n'
                 '  * **Semi-corpórea**: Lorana sofre o dobro de dano de armas '
                 'de prata, mas metade do dano de outros tipos de armas.\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '  * **Dreno**: cada ataque bem-sucedido de Lorana exige que '
                 'o alvo faça uma JPC para evitar ter 1 ponto de FOR drenado. '
                 'Um alvo que tenha todos os seus pontos de FOR drenados, '
                 'ficará permanentemente morto. O personagem recupera 1 ponto '
                 'drenado a cada descanso completo.\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar '
                 'Mortos-Vivos.\n'
                 '\n',
  'dv': '6',
  'dv_bonus': '',
  'encounters': None,
  'encounters_lair': None,
  'flavor': 'A forma incorpórea e fantasmagórica da feiticeira Lorana, uma das '
            'ex-capitãs do navio Donzela Carmesim.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday16.json',
              'page': 17}],
  'habitats': ['qualquer'],
  'id': 'lorana-a-alma-penada-estagio-1',
  'jp': '9',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Lorana, a Alma Penada (Estágio 1)',
  'picture': 'https://public.olddragon.com.br/gbbv41vlxxolhhebujzdoczbncvh',
  'pv': '30',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/8c6xsh45potqz946dsn8p6tjvuyy',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/lorana-a-alma-penada-estagio-1.json',
  'variant': False,
  'xp': '650'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 9,
               'damage': '1d10',
               'damage_bonus': None,
               'damage_description': '1d10 + Dreno',
               'description': 'Garras',
               'text': '2 × Garras +9 (1d10 + Dreno)',
               'times': 2,
               'weapon': False}],
  'ca': '15',
  'concept': 'morto_vivo',
  'description': '  * **Semi-corpórea**: Lorana sofre o dobro de dano de armas '
                 'de prata, mas metade do dano de outros tipos de armas.\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '  * **Dreno**: cada ataque bem-sucedido de Lorana exige que '
                 'o alvo faça uma JPC para evitar ter 1 ponto de FOR drenado. '
                 'Um alvo que tenha todos os seus pontos de FOR drenados, '
                 'ficará permanentemente morto. O personagem recupera 1 ponto '
                 'drenado a cada descanso completo.\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar Mortos-Vivos.',
  'dv': '11',
  'dv_bonus': '+5',
  'encounters': None,
  'encounters_lair': None,
  'flavor': 'A forma incorpórea e fantasmagórica da feiticeira Lorana, uma das '
            'ex-capitãs do navio Donzela Carmesim.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday16.json',
              'page': 21}],
  'habitats': ['qualquer'],
  'id': 'lorana-a-alma-penada-estagio-2',
  'jp': '10',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Lorana, a Alma Penada (Estágio 2)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/lorana-a-alma-penada-estagio-1.json',
  'pv': '60',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/lorana-a-alma-penada-estagio-2.json',
  'variant': True,
  'variant_modifications': ['Dreno: cada ataque bem-sucedido de Lorana drena 1 '
                            'ponto de FOR do personagem sem direito a jogada '
                            'de proteção. Um alvo que tenha todos os seus '
                            'pontos de FOR drenados, ficará permanentemente '
                            'morto. O personagem recupera 1 ponto drenado a '
                            'cada descanso completo.'],
  'xp': '1250'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 11,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8 + Dreno',
               'description': 'Garras',
               'text': '2 × Garras +11 (2d8 + Dreno)',
               'times': 2,
               'weapon': False}],
  'ca': '17',
  'concept': 'morto_vivo',
  'description': '  * **Semi-corpórea**: Lorana sofre o dobro de dano de armas '
                 'de prata, mas metade do dano de outros tipos de armas.\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '  * **Dreno**: cada ataque bem-sucedido de Lorana exige que '
                 'o alvo faça uma JPC para evitar ter 1 ponto de FOR drenado. '
                 'Um alvo que tenha todos os seus pontos de FOR drenados, '
                 'ficará permanentemente morto. O personagem recupera 1 ponto '
                 'drenado a cada descanso completo.\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar Mortos-Vivos.',
  'dv': '16',
  'dv_bonus': '',
  'encounters': None,
  'encounters_lair': None,
  'flavor': 'A forma incorpórea e fantasmagórica da feiticeira Lorana, uma das '
            'ex-capitãs do navio Donzela Carmesim.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday16.json',
              'page': 26}],
  'habitats': ['qualquer'],
  'id': 'lorana-a-alma-penada-estagio-3',
  'jp': '12',
  'mo': 11,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Lorana, a Alma Penada (Estágio 3)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/lorana-a-alma-penada-estagio-1.json',
  'pv': '80',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/lorana-a-alma-penada-estagio-3.json',
  'variant': True,
  'variant_modifications': ['Dreno: cada ataque bem-sucedido de Lorana drena 1 '
                            'ponto de FOR do personagem sem direito a jogada '
                            'de proteção. Um alvo que tenha todos os seus '
                            'pontos de FOR drenados, ficará permanentemente '
                            'morto. O personagem recupera 1 ponto drenado a '
                            'cada descanso completo.'],
  'xp': '1950'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 67}],
  'habitats': ['qualquer'],
  'id': 'lujia',
  'name': 'Lujia',
  'parent_monster_url': 'https://olddragon.com.br/monstros/cultista.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/lujia.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'besta',
  'flavor': 'Criaturas alienígenas. Seu aspecto lembra um retângulo branco e '
            'plumado voador. Às vezes, podem ser confundidas com um tapete '
            'branco voando solitário no alto dos céus (até 200m).',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 71}],
  'habitats': ['desertos'],
  'id': 'mae-plumada',
  'name': 'Mãe-Plumada',
  'size': 'imenso',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/mae-plumada.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'constructo',
  'flavor': 'Constructo arkaidiano, criado por feiticeiros construtomantes. É '
            'movido por magia primordial.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 44}],
  'habitats': ['qualquer'],
  'id': 'magolem',
  'name': 'Magolem',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/magolem.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'constructo',
  'flavor': 'Pequenas pedras retangulares, aparentando um paralelepípido de '
            'pedra escura com cabelos humanos colados ao topo. Quando ativos, '
            'lançam pseudópodes bizarros, capazes de fazê-los andar livremente '
            'e sempre em grupos gigantescos. São um constructo mágico '
            'Castanho.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 71}],
  'habitats': ['desertos'],
  'id': 'maldicao-pedra-cabelo',
  'name': 'Maldição Pedra-Cabelo',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/maldicao-pedra-cabelo.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 12,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Presas',
               'text': '2 × Presas +12 (2d6)',
               'times': 2,
               'weapon': False},
              {'ba': 10,
               'damage': '4d8',
               'damage_bonus': None,
               'damage_description': '4d8',
               'description': 'Atropelar',
               'text': '1 × Atropelar +10 (4d8)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Investida**: se ainda não engajado em combate, pode '
                 'usar a manobra de investida para causar o dobro de dano com '
                 'sua tromba.\n'
                 '\n',
  'dv': '12',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1d8',
  'flavor': 'Esta criatura vive em regiões frias e geleiras onde pastoreiam as '
            'tundras e se protegem com suas enormes presas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 18},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['geleiras'],
  'id': 'mamute',
  'jp': '12',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Mamute',
  'picture': None,
  'pv': '60',
  'size': 'imenso',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/mamute.json',
  'variant': False,
  'xp': '1950'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 6,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Garras',
               'text': '2 × Garras +6 (1d4)',
               'times': 2,
               'weapon': False},
              {'ba': 6,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Espinhos',
               'text': '6 × Espinhos +6 (1d6)',
               'times': 6,
               'weapon': False},
              {'ba': 6,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4',
               'description': 'Mordida',
               'text': '1 × Mordida +6 (2d4)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'besta',
  'description': 'A cabeça acompanha a idade da criatura, sendo a de uma velha '
                 'ou velho quando a Mantícora já está com idade avançada, por '
                 'exemplo.\n'
                 '\n'
                 'As asas são bem grandes, podendo cobrir seu corpo caso '
                 'queira. O corpo é forte e de pelagem semelhante a de um '
                 'leão, apesar de existirem casos raros de Mantícoras '
                 'vermelhas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'De longe, lançam seus espinhos para enfraquecer o adversário '
                 'e, ao se aproximarem, atacam ferozmente com tudo que podem.\n'
                 '\n'
                 'Se estiver ao ar livre, a Mantícora tenta ficar no ar para '
                 'minimizar a chance de ser atacada.\n'
                 '\n'
                 'Seu voo é levemente desajeitado, e ela não pode usar os '
                 'ataques de mordida enquanto voa, mas, ainda assim, sua '
                 'eficiência com os espinhos assusta até os mais competentes '
                 'inimigos.\n'
                 '\n'
                 '  * **Explosão de Espinhos**: uma Mantícora possui 24 '
                 'espinhos em sua cauda os quais podem ser arremessados em um '
                 'ataque a até 6 alvos diferentes. A cada dia, 1d6 espinhos se '
                 'regeneram após lançados.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em duplas e em lugares de difícil acesso, mas próximos '
                 'a povoados.\n'
                 '\n'
                 'São orgulhosas e traiçoeiras, não sabendo lidar muito bem '
                 'com outras raças.\n'
                 '\n'
                 'Seus filhos são perturbadores, com a cabeça de um bebê '
                 'humano no corpo de um filhote de leão.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os espinhos das Mantícoras são usados na confecção de '
                 'flechas mágicas de rara beleza e eficiência.',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '1d2',
  'encounters_lair': '1d4',
  'flavor': 'Esta monstruosidade, com cabeça humana, corpo de leão, asas e uma '
            'cauda com espinhos, caça homens para se alimentar.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 129},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['montanhas'],
  'id': 'manticora',
  'jp': '8',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Mantícora',
  'picture': 'https://public.olddragon.com.br/qyed5dx6ltkcd5dv89epsyzrb7qt',
  'pv': '30',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/ilga7nbvujx7s8xig3z73s152o4w',
  'treasure': None,
  'treasure_lair': 'd',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/manticora.json',
  'variant': False,
  'xp': '305'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide_monstruoso',
  'flavor': 'Usam os poderes do Arquidemônio preso em suas Marcas Místicas '
            'para realizar magias.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 48}],
  'habitats': ['qualquer'],
  'id': 'marcado-demoguerreiro',
  'name': 'Marcado Demoguerreiro',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/marcado-demoguerreiro.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide_monstruoso',
  'flavor': 'Usam os poderes do Arquidemônio preso em suas Marcas Místicas '
            'para realizar magias.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 49}],
  'habitats': ['qualquer'],
  'id': 'marcado-demomago',
  'name': 'Marcado Demomago',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/marcado-demomago.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 1,
               'damage': '1d4',
               'damage_bonus': 2,
               'damage_description': '1d4+2 + Dreno',
               'description': 'Mordida',
               'text': '1 × Mordida +1 (1d4+2 + Dreno)',
               'times': 1,
               'weapon': False},
              {'ba': -6,
               'damage': '1d10',
               'damage_bonus': 1,
               'damage_description': '1d10+1',
               'description': 'Sabre',
               'text': '1 × Sabre -6 (1d10+1)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'morto_vivo',
  'description': '\n'
                 '\n'
                 '  * **Cegueira**: a falta de olhos impõe -6 em seus ataques. '
                 'Porém, após a cada dois ataques errados com o sabre, o '
                 'Marinheiro Cego tenta agarrar e morder um personagem (o '
                 'ataque de mordida).\n'
                 '  * **Dreno**: o alvo deve passar em uma JPC para evitar um '
                 'dreno de 1d4 pontos em seu valor de Constituição. Um alvo '
                 'que tenha todos os seus pontos de Constituição drenados, '
                 'ficará permanentemente morto. O personagem recupera 1 ponto '
                 'drenado a cada descanso completo.\n'
                 '  * **Silencioso**: não produz som algum ao movimentar-se e '
                 'se mantém silencioso até atacar.\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '  * **Corpo de Osso**: armas impactantes causam o dobro de '
                 'dano nos Esqueletos, mas, em contrapartida, armas '
                 'perfurantes causam metade do ano.\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral, '
                 'a não ser quando sofrem o efeito de um Afastar '
                 'Mortos-Vivos.\n'
                 '\n',
  'dv': '4',
  'dv_bonus': '',
  'encounters': None,
  'encounters_lair': None,
  'flavor': 'Um esqueleto putrefato do que um dia foi um marinheiro. Seu rosto '
            'é disforme e alongado, sem olhos – apenas as cavidades oculares. '
            'Sua boca parece ter explodido em bolhas, deixando um aspecto tão '
            'horrível quanto o odor.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday16.json',
              'page': 16}],
  'habitats': ['qualquer'],
  'id': 'marinheiro-cego',
  'jp': '6',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Marinheiro Cego',
  'picture': 'https://public.olddragon.com.br/ky9re4z38uqa71xyoseq9bpx68cy',
  'pv': '20',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/nv32mezj7v658dg04snxtpq7yeqw',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/marinheiro-cego.json',
  'variant': False,
  'xp': '100'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 6,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Arma',
               'text': '1 × Arma +6 (1d8+1)',
               'times': 1,
               'weapon': False},
              {'ba': 6,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4 + Veneno',
               'description': 'Adaga',
               'text': '1 × Adaga +6 (1d4 + Veneno)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': '\n'
                 '\n'
                 '  * **Tocaia**: ao se esconder ou disfarçar a chance do '
                 'matador causar Surpresa ao atacar é de 1-3 em 1d6. Ao atacar '
                 'um alvo surpreso, realiza o ataque como muito fácil, '
                 'causando dano multiplicado por 2.\n'
                 '\n'
                 '  * **Veneno**: uma JPC evita qualquer efeito deste veneno. '
                 'Uma falha no teste causa a perda de 2 PV por rodada até o '
                 'alvo perder todos os pontos de vida e morrer. Um antídoto ou '
                 'magia podem neutralizar o veneno e encerrar seus efeitos. Um '
                 'matador geralmente anda com pelo menos 1 frasco de antídoto, '
                 'para caso seja envenenado por acidente.\n'
                 '\n',
  'dv': '6',
  'dv_bonus': '+4',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': 'Humanoide especializado na arte de assassinar pessoas, geralmente '
            'treinados e empregados por organizações secretas e perigosas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday17.json',
              'page': 23}],
  'habitats': ['qualquer'],
  'id': 'matador',
  'jp': '8',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Matador',
  'picture': None,
  'pv': '34',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/matador.json',
  'variant': False,
  'xp': '700'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Arco',
               'text': '1 × Arco +4 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'besta',
  'description': 'Aparenta ser uma mulher linda, de traços encantadores. Seus '
                 'movimentos são suaves e hipnóticos, e em sua cabeça, no '
                 'lugar dos cabelos, existem dezenas de serpentes sibilam de '
                 'acordo com as emoções da Medusa.\n'
                 '\n'
                 'Quando estão enfurecidas, seus traços se transformam e a '
                 'medusa assume feições de víboras prestes a atacar.\n'
                 '\n'
                 'Algumas Medusas possuem a metade inferior do corpo em forma '
                 'de serpente, sendo essas mais respeitadas que as demais '
                 'medusas e consideradas líderes.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Costumam enganar aventureiros ao se passarem por mulheres '
                 'normais, usando seus poderes de petrificação assim que os '
                 'alvos entram na área de efeito. Quando o confronto já é '
                 'eminente, usam arcos para atacar.\n'
                 '\n'
                 '  * **Olhar Petrificante**: qualquer alvo que olhar '
                 'diretamente nos olhos de uma Medusa ficará permanentemente '
                 'petrificado caso falhe em uma JPC.\n'
                 '\n'
                 '  * **Veneno**: qualquer criatura mordida pelas serpentes do '
                 'cabelo da Medusa deve ser bem-sucedida em uma JPC para '
                 'evitar os efeitos do veneno ou cairá morta um 1d3 turnos.\n'
                 '\n'
                 '  * **Resistência à magia**: qualquer magia lançada contra a '
                 'Medusa possui 1 chance em 1d6 de ser completamente '
                 'ignorada.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Amaldiçoadas pelos deuses, essas mulheres vivem em masmorras '
                 'e cavernas, transtornadas psicologicamente pela sua condição '
                 'física.\n'
                 '\n'
                 'Aparentando normalidade, são psicóticas e muito perigosas. '
                 'Não se tem notícias de uma “versão masculina”, e acredita-se '
                 'que nasçam apenas por meio de rituais realizados por certos '
                 'cultos obscuros de Deuses-Serpentes.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os olhos das Medusas são ingredientes para poções de '
                 'petrificação.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1d3',
  'encounters_lair': '1d4',
  'flavor': 'Uma linda e sedutora mulher. Seus cabelos são feitos inteiramente '
            'de sagazes serpentes, e seu olhar é realmente matador!',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 130},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'medusa',
  'jp': '7',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Medusa',
  'picture': 'https://public.olddragon.com.br/0tucfilz31gbhzqi9oo91khhff7x',
  'pv': '20',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/nnv03kqw0nqjd1ecc1uee885bkj2',
  'treasure': None,
  'treasure_lair': 'f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/medusa.json',
  'variant': False,
  'xp': '175'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Os Lagartos-Búfalos do Deserto dos Crânios. Enormes e robustos, '
            'possuem dois grandes chifres dianteiros e uma crista de chifres.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 50}],
  'habitats': ['desertos'],
  'id': 'menargar',
  'name': 'Menárgar',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/menargar.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 0,
               'damage': '1d3',
               'damage_bonus': None,
               'damage_description': '1d3',
               'description': 'soco',
               'text': '1 × soco (1d3)',
               'times': 1,
               'weapon': False}],
  'ca': '10',
  'concept': 'humanoide',
  'description': 'Organizados em caravanas percorrendo as estradas, levam seus '
                 'produtos em grandes carroças, vendendo e comprando '
                 'mercadorias para as mais diferentes e distantes '
                 'localizações.\n'
                 '\n'
                 'Encontrados em caravanas de 4d6 + 10 indivíduos.\n'
                 '\n'
                 'Caravana: há duas carroças repletas de mercadorias para cada '
                 'mercador, descontados os guarda-costas e Chefe da Guarda. '
                 'Cada carroça é puxada por uma parelha de dois cavalos de '
                 'tração.\n'
                 '\n'
                 'Mercadorias: jogue 1d6 para determinar o que a caravana '
                 'transporta. O resultado do dado significa que a caravana '
                 'transporta aquele tipo de item e os de valor menor: 1. '
                 'Alimentos, 2. Utilidades Domésticas, 3. Especiarias, 4. '
                 'Equipamentos Gerais, 5. Armas e Armaduras e 6. Objetos de '
                 'Valor.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 4 Mercadores, um deles será um '
                 'Guarda-Costas. Além disso, há sempre um Chefe da Guarda por '
                 'caravana.\n'
                 '\n'
                 '  * **Montada**: cavalo de montaria.\n'
                 '\n',
  'dv': '½',
  'dv_bonus': '+1',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 184},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'mercador',
  'jp': '4',
  'mo': 6,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Mercador',
  'picture': None,
  'pv': '3',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'a',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/mercador.json',
  'variant': False,
  'xp': '5'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 5,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6 + Paralisia',
               'description': 'Pancada',
               'text': '1 × Pancada +5 (1d6 + Paralisia)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'morto_vivo',
  'description': 'Com galhos negros e retorcidos que lhe conferem o aspecto de '
                 'uma árvore morta, o Mil-Galhos é o resultado da mente '
                 'doentia de necromantes que enxertam no interior de árvores '
                 'mortas o coração de Ghouls.\n'
                 '\n'
                 'Estão sempre à espreita de pessoas que, por ventura, '
                 'adentrem as regiões que estas criaturas devem vigiar e '
                 'proteger. Caem sobre suas vítimas, envenenando-as, '
                 'paralisando-as e, por fim, alimentando-se de seus corpos '
                 'enquanto se preparam para atacar novas vítimas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'O Mil-Galhos fica imóvel, sem dar nenhum sinal de que '
                 'pretende atacar. Espera a vítima estar bem distraída e '
                 'próxima de seu tronco ou galhos para cair sobre ela.\n'
                 '\n'
                 'Como realiza um único ataque (visto que demora cerca de 24 '
                 'horas para se reerguer), muitas vezes passa despercebida '
                 'como monstro, sendo confundida com uma simples árvore velha '
                 'que, pela ação do tempo, acabou caindo.\n'
                 '\n'
                 '  * **Imóvel e Silencioso**: não se locomove e, por isso, '
                 'não produz som algum até atacar, surpreendendo seus alvos '
                 'com um resultado de 1-4 em 1d6.\n'
                 '\n'
                 '  * **Fogo**: um Mil-Galhos é especialmente suscetível ao '
                 'fogo. Todo dano causado pelo fogo deve ser ampliado em 50%.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Paralisia**: alvo atingido por um Mil-Galhos deve ser '
                 'bem-sucedido em uma JPC ou ficará paralisado por até 1d6 '
                 'turnos. Elfos são imunes a habilidade de Paralisia de um '
                 'Mil-Galhos assim como a dos Ghouls.\n'
                 '\n'
                 '  * **Imunidades**: além das imunidades comuns aos '
                 'mortos-vivos, são imunes ao poder de Afastar Mortos-Vivos de '
                 'um Clérigo.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Mil-Galhos são o resultado do amálgama mágico entre zumbis e '
                 'árvores mortas criadas por necromantes enlouquecidos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Sua lenha é ideal para aquecer uma forja onde pretende-se '
                 'forjar qualquer item de metal amaldiçoado.',
  'dv': '4',
  'dv_bonus': '+4',
  'encounters': '1',
  'encounters_lair': '',
  'flavor': 'Árvore espinhenta e canibal. Usa seus galhos retorcidos e '
            'espinhos para se alimentar.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 131},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc2.json',
              'page': 28},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['pantanos', 'florestas'],
  'id': 'mil-galhos',
  'jp': '10',
  'mo': 10,
  'mv': 0,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Mil-Galhos',
  'picture': 'https://public.olddragon.com.br/ott5ytfaf3dlggh5zm2m5l2tlu2j',
  'pv': '24',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/iykupc1gg66pety6dte9mbp9uq7w',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/mil-galhos.json',
  'variant': False,
  'xp': '200'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 5,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Mordida',
               'text': '1 × Mordida +5 (2d6)',
               'times': 1,
               'weapon': False},
              {'ba': 8,
               'damage': '3d4',
               'damage_bonus': None,
               'damage_description': '3d4 + Cola',
               'description': 'Pancada',
               'text': '1 × Pancada +8 (3d4 + Cola)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'besta',
  'description': 'Mímicos podem apresentar uma diversidade de formas. Baús, '
                 'barris, camas, armários, vasos de plantas, latrinas e etc.\n'
                 '\n'
                 'Qualquer coisa que faça sentido no lugar e na qual possam se '
                 'disfarçar para obter alimentos.\n'
                 '\n'
                 '**Som**: tilintar metálico.\n'
                 '\n'
                 '**Odor**: químico forte e não identificável, semelhante a '
                 'vômito seco.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atraem a vítima com seu disfarce, tentando mordê-la assim '
                 'que esta estiver presa na sua cola.\n'
                 '\n'
                 '  * **Cola**: qualquer coisa que toque o corpo de um Mímico '
                 'ficará presa em uma poderosa cola. Um teste de Força pode '
                 'soltar o objeto do corpo do Mímico. A cola perderá sua '
                 'adesão por volta de 1 minuto após a morte do Mímico.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Mímicos são criaturas misteriosas e de origem completamente '
                 'desconhecida.\n'
                 '\n'
                 'Possuem uma limitada capacidade de ler mentes, captando '
                 'imagens familiares às vítimas e se transformando dentro de '
                 'suas capacidades.\n'
                 '\n'
                 'Dificilmente conseguem atingir uma forma maior do que um '
                 'armário ou menor do que uma caixa de madeira.\n'
                 '\n'
                 'Ninguém conhece a “forma original” de um Mímico, e a forma '
                 'assumida por eles, apesar de idêntica a original, tem sempre '
                 'uma sensação tátil como se fosse feita de pedra.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A cola dos Mímicos, mesmo sem aderência, é usada nas '
                 'argamassas e como ingrediente de itens mágicos.\n'
                 '\n'
                 '## Especial\n'
                 '\n'
                 'Caso seja necessário determinar a forma adotada pelo Mímico, '
                 'jogue 1d6: 1-3, baú de tesouro; 4, armário; 5, barril; 6, '
                 'especial.\n'
                 '\n'
                 'Para determinar a forma especial do Mímico, jogue 1d6: 1, '
                 'vaso de plantas; 2, latrina sanitária; 3, porta; 4, degrau '
                 'de escada; 5, estátua; 6, cadeira.',
  'dv': '7',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '0',
  'flavor': 'Metamorfos de pele rochosa que assumem formas mundanas para '
            'surpreender seus inimigos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 72},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 132},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'mimico',
  'jp': '6',
  'mo': 11,
  'mv': 3,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Mímico',
  'picture': 'https://public.olddragon.com.br/uqsskzhymhjjjvdrkzcfja3qohya',
  'pv': '35',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/wp369ghvwdemkfzk84afrsdzi1kt',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/mimico.json',
  'variant': False,
  'xp': '460'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 7,
               'damage': '2d6',
               'damage_bonus': 2,
               'damage_description': '2d6+2',
               'description': 'Machado de batalha',
               'text': '1 × Machado de batalha +7 (2d6+2)',
               'times': 1,
               'weapon': False},
              {'ba': 7,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Chifre',
               'text': '1 × Chifre +7 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'gigante',
  'description': 'Aparentam uma mistura de homem com touro, de corpo musculoso '
                 'coberto de pelos os quais podem variar em muitas cores e '
                 'padrões.\n'
                 '\n'
                 'Apesar de terem mãos humanas, seus pés são cascos '
                 'duríssimos, assim como seus chifres pontiagudos e ocos.\n'
                 '\n'
                 '**Som**: pancadas ritmadas de passos e o bufar '
                 'característico dos bovinos.\n'
                 '\n'
                 '**Odor**: odor corporal (suor).\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Quando em clãs, atacam com armas de arremesso e depois com '
                 'seus machados.\n'
                 '\n'
                 'Os desgarrados preferem criar armadilhas nos labirintos, '
                 'garantindo seu sucesso nas batalhas.\n'
                 '\n'
                 '  * **Atropelar**: um minotauro ainda não engajado em '
                 'combate pode usar a manobra de investida para causar o dobro '
                 'de dano com seus chifres.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Quando fora de labirintos, uma estranha predileção desta '
                 'criatura, vivem em clãs nômades muito bem estruturados, '
                 'deixando os desgarrados para trás quando necessário.\n'
                 '\n'
                 'Estes desgarrados são os que abandonam os hábitos e cultura '
                 'do clã, preferindo construir complexos labirintos para '
                 'atrair aventureiros com falsas promessas de tesouros.\n'
                 '\n'
                 'Desgarrados são um motivo de vergonha entre a comunidade dos '
                 'Minotauros, considerados simples bestas entregues aos '
                 'instintos primitivos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Um dos troféus mais valorizados pelos nobres é a cabeça '
                 'empalhada de um Minotauro, bem como as garrafas de água '
                 'ardente confeccionada com suas patas e as cornetas com seus '
                 'chifres.',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '1d8',
  'flavor': 'Metade homem e metade touro, vive em labirintos subterrâneos, '
            'guardando seus corredores e tesouros.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 133},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'minotauro',
  'jp': '9',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Minotauro',
  'picture': 'https://public.olddragon.com.br/j00a6wnmie1cpevfvltjesmy15lo',
  'pv': '30',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/4vandcvwx786o71y8n9j2dppn7tt',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/minotauro.json',
  'variant': False,
  'xp': '270'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide',
  'flavor': 'Guerreiros e guerreiras modificados, possuindo partes de '
            'criatruras e monstros em seus corpos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 52}],
  'habitats': ['qualquer'],
  'id': 'modificado',
  'name': 'Modificado',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/modificado.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 5,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Enferrujar',
               'description': 'Tentáculo',
               'text': '1 × Tentáculo +5 (Enferrujar)',
               'times': 1,
               'weapon': False}],
  'ca': '18',
  'concept': 'besta',
  'description': 'Possui uma carapaça dura, mas capaz de se dobrar como uma '
                 'bola, embora raramente o faça.\n'
                 '\n'
                 'Possui dois apêndices nos lados da boca, usados para '
                 'enferrujar o metal, e poderosas garras com alta força de '
                 'preensão.\n'
                 '\n'
                 '**Som**: raspar rápido de pedra.\n'
                 '\n'
                 '**Odor**: ferrugem, corrosão e maresia.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam primeiro os alvos com potencial de alimento, como '
                 'cavaleiros ou clérigos.\n'
                 '\n'
                 'De inteligência animal, fogem ao se sentirem acuados ou ao '
                 'perceberem que a batalha não lhes será favorável.\n'
                 '\n'
                 '  * **Enferrujar**: todo metal que toca um Monstro Ferrugem '
                 'ou que é tocado por ele, enferruja e se desmancha em pó '
                 'imediatamente.  Itens mágicos de metal, como armas e '
                 'armaduras, possuem 10% de chance por bônus (uma adaga +3 '
                 'possui 30% de chance) de não serem afetados ao tocarem ou '
                 'serem tocados por um Monstro Ferrugem. Se um item mágico for '
                 'afetado, perderá um dos seus bônus mágicos (se afetada, a '
                 'adaga +3 se torna uma adaga +2).\n'
                 '\n'
                 '  * **Imunidades**: um Monstro Ferrugem é imune ao dano de '
                 'qualquer arma não mágica.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Inimigos naturais dos Limos Cinzentos, lutam por '
                 'aventureiros que estejam portando equipamentos metálicos.\n'
                 '\n'
                 'O Monstro Ferrugem costuma ficar fechado quando dorme, '
                 'tornando-se uma grande bola de carapaça.\n'
                 '\n'
                 'Utilizam esta técnica ocasionalmente por ela, às vezes, '
                 'confundir os predadores.\n'
                 '\n'
                 'Costumam ter uma ninhada pequena, geralmente em minas ou no '
                 'subsolo de antigos campos de batalha.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os tentáculos do Monstro Ferrugem são usados na mineração do '
                 'ferro para testar a qualidade dos veios metálicos.',
  'dv': '5',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Semelhantes a enormes tatus gigantes, percorrem o subterrâneo '
            'atrás de metal para enferrujar e se alimentar.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 134},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'monstro-ferrugem',
  'jp': '8',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Monstro Ferrugem',
  'picture': 'https://public.olddragon.com.br/5kgo239utqbqnznk2u6cgsbz834k',
  'pv': '25',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/sii2q05kzzlwqmjd51owrv6mrrbh',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/monstro-ferrugem.json',
  'variant': False,
  'xp': '205'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Com muitos ninhos nas Montanhas Centrais, as Monthras, mariposas '
            'gigantes de trinta metros de envergadura, fazem parte da paisagem '
            'da região ao sul do Deserto dos Crânios.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 54}],
  'habitats': ['montanhas', 'subterraneos'],
  'id': 'monthra',
  'name': 'Monthra',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/monthra.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 0,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Confusão',
               'description': 'Enxame',
               'text': '1 × Enxame (Confusão)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Confusão**: quando 10 ou mais morcegos sobrevoam um '
                 'alvo, causam nele um ataque de confusão. O alvo recebe -2 '
                 'para realizar qualquer ação que não seja se debater e tentar '
                 'afastar os morcegos.\n'
                 '\n',
  'dv': '½',
  'dv_bonus': '-1',
  'encounters': '1d100',
  'encounters_lair': '1d100',
  'flavor': 'Pequenos mamíferos comedores de insetos que vivem em qualquer '
            'subterrâneo ou locais sem luz.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 72},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 76},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 18},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas', 'subterraneos'],
  'id': 'morcego',
  'jp': '4',
  'mo': 6,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 9,
  'name': 'Morcego',
  'picture': None,
  'pv': '1',
  'size': 'miudo',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/morcego.json',
  'variant': False,
  'xp': '5'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 0,
               'damage': '1d2',
               'damage_bonus': None,
               'damage_description': '1d2 + Doença',
               'description': 'Mordida',
               'text': '1 × Mordida (1d2 + Doença)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Doença**: Um Morcego Vampiro possui 1-2 chances em 1d6 '
                 'de transmitir uma doença a um alvo mordido. Um alvo mordido '
                 'que falhe em uma JPC, fica doente e com valor de força igual '
                 'a 1 por 1d6 dias.\n'
                 '\n',
  'dv': '½',
  'dv_bonus': '-1',
  'encounters': '1d10',
  'encounters_lair': '1d10',
  'flavor': 'Morcegos que se alimentam de sangue de animais, podendo inclusive '
            'atacar humanos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 98},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 18},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday17.json',
              'page': 22},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas', 'montanhas', 'subterraneos'],
  'id': 'morcego-vampiro',
  'jp': '4',
  'mo': 6,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 9,
  'name': 'Morcego Vampiro',
  'picture': None,
  'pv': '1',
  'size': 'miudo',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/morcego-vampiro.json',
  'variant': False,
  'xp': '5'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Como um zumbi, mas com roupas sofisticadas e nobres.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 72}],
  'habitats': ['desertos'],
  'id': 'mordomo-morto-vivo',
  'name': 'Mordomo Morto-Vivo',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/mordomo-morto-vivo.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Machado',
               'text': '1 × Machado +1 (1d6+2)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1',
               'description': 'Garras',
               'text': '2 × Garras +2 (1d4+1)',
               'times': 2,
               'weapon': False}],
  'ca': '14',
  'concept': 'humanoide',
  'description': 'Morloks são humanoides antropófagos com pele cinza e úmida '
                 'ao toque. Possuem cabelos ensebados e escorridos pela '
                 'cabeça, sempre na cor branca. Contam com grandes garras nos '
                 'pés, que se dobram como se fossem mãos, conferindo-lhes '
                 'extrema facilidade em escalar superfícies e escavar.\n'
                 '\n'
                 '**Som**: som surdo de passos ritmados.\n'
                 '\n'
                 '**Odor**: terra molhada recém revirada.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Totalmente cegos, usam seu olfato aguçado e sua camuflagem '
                 'natural para surpreender e atacar seus inimigos nos '
                 'subterrâneos e nas florestas que habitam.\n'
                 '\n'
                 '  * **Inimigo Natural**: Morloks odeiam a civilização élfica '
                 'e farão de tudo para destruí-los. Contra estas criaturas, '
                 'todo ataque do Morlock é considerado um ataque fácil.\n'
                 '  * **Sentidos Aguçados**: seu olfato e sentido sísmico o '
                 'permite sentir odores e vibrações no solo a até 30 metros de '
                 'onde estiver. Ele consegue identificar movimento, perceber a '
                 'exata localização de uma presa e identificar o tamanho e a '
                 'quantidade de inimigos na área.\n'
                 '  * **Camuflagem**: quando imóvel, surpreende seus inimigos '
                 'com uma chance de 1-4 em 1d6.\n'
                 '  * **Imunidades**: são imunes a ataques visuais, efeitos '
                 'visuais, ilusões, e outras formas de ataque que dependam da '
                 'visão.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Os Morloks vivem dentro da terra fofa das florestas de '
                 'Kadur, onde criam túneis e câmaras complexas. Possuem '
                 'sociedade matriarcal, em queas fêmeas morbidamente obesas '
                 'ficam protegidas enquanto possuem diversos machos de quem '
                 'exigem que tragam suas capturas.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Tanto os altos elfos tarkarianos como os Elfos Cinzentos '
                 'Elmarianos costumam pagar bem por cabeças de Morloks '
                 'abatidas. Isso movimenta um grande contingente de Caçadores '
                 'de Recompensas em busca de dinheiro aparentemente fácil e da '
                 'oportunidade de aproveitar a situação e comercializar alguns '
                 'bens de luxo com as comunidades élficas.',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '1d8',
  'encounters_lair': '4d6',
  'flavor': 'Comedores de carne élfifica dos subterrâneos. Usam seus sentidos '
            'aguçados para surpreender suas vítimas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao.json',
              'page': 315},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao-od2.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'morlok',
  'jp': '5',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': 6,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Morlok',
  'picture': 'https://public.olddragon.com.br/njrhdfiuf9qm4hfpk5063vj5salw',
  'pv': '15',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/ijwvvj8rdoitfj3ygk6nfldpb6am',
  'treasure': 'q',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/morlok.json',
  'variant': False,
  'xp': '95'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'besta',
  'flavor': 'Uma espécie de cisne com bico fino e comprido, com barrigas '
            'volumosas e salientes. Estes malditos pássaros concentram, em '
            'suas barrigas, bolas de cera branca paralisante.  Despejam nos '
            'alvos que, ao ficarem paralisados, não podem correr. Atacam '
            'usando o bico que, com uma força sobrenatural, é comparado ao '
            'estrago de uma picareta. Pode destruir um corpo humano inteiro em '
            'questão de minutos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 72}],
  'habitats': ['desertos'],
  'id': 'morte-alva',
  'name': 'Morte-Alva',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/morte-alva.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Pássaros de caça ágeis. Atacam humanos apenas quando estes '
            'parecerem indefesos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 72}],
  'habitats': ['desertos'],
  'id': 'morte-sombra',
  'name': 'Morte-Sombra',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/morte-sombra.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Mordida',
               'text': '1 × Mordida +3 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'inseto',
  'description': '\n\n\n\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '2d6',
  'flavor': 'Estes insetos gigantes encontrados em praticamente qualquer lugar '
            'vivem de sugar o sangue de suas presas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 115}],
  'habitats': ['florestas', 'pantanos', 'subterraneos'],
  'id': 'mosca-gigante',
  'jp': '5',
  'mo': 8,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Mosca Gigante',
  'picture': None,
  'pv': '10',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/mosca-gigante.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 6,
               'damage': '1d12',
               'damage_bonus': None,
               'damage_description': '1d12 + Doença',
               'description': 'Toque',
               'text': '1 × Toque +6 (1d12 + Doença)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'morto_vivo',
  'description': 'Apenas os mais poderosos e nobres sofriam o processo de '
                 'mumificação, então é comum Múmias ainda portarem cetros e '
                 'joias que indiquem seu status.\n'
                 '\n'
                 'Por trás das faixas há uma carne ressecada e cinzenta, e '
                 'olhos de puro ódio.\n'
                 '\n'
                 '**Som**: arrastar lento sobre o chão.\n'
                 '\n'
                 '**Odor**: decomposição, carne apodrecida, mofo e poeira '
                 'misturados.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Dificílimas de serem acertadas, as Múmias não se preocupam '
                 'com ataques à distância, usando suas habilidades para '
                 'encurtar rapidamente a luta.\n'
                 '\n'
                 'Em algumas ocasiões, são servidas por outras criaturas '
                 'mumificadas, como chacais e pássaros.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Imunidades**: além das imunidades comuns aos '
                 'mortos-vivos, Múmias são feridas apenas por fogo, magia ou '
                 'armas mágicas e, mesmo assim, todo dano recebido é reduzido '
                 'à metade.\n'
                 '\n'
                 '  * **Aura Aterrorizante**: qualquer criatura a até 30 '
                 'metros da Múmia, capaz de ver ou percebê-la, é afetada pela '
                 'sua Aura Aterrorizante. Enquanto a Múmia não atacar ou não '
                 'se afastar, todos afetados pela Aura Aterrorizante ficarão '
                 'paralisados de medo.  Uma JPS nega o efeito da Aura '
                 'Aterrorizante.\n'
                 '\n'
                 '  * **Doença**: qualquer alvo que receber dano de um ataque '
                 'físico de uma Múmia será infectado pela Podridão da Múmia. A '
                 'Podridão impede toda cura mágica e retarda toda forma de '
                 'cura não mágica a uma taxa de apenas 10% da cura normal, '
                 'além de causar o apodrecimento da vítima. Apenas um Curar '
                 'Doenças remove uma Podridão da Múmia.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Senhores de muitas terras, as Múmias são enterradas dentro '
                 'de suas propriedades, ou ao menos em algum lugar fortemente '
                 'ligado as elas.  Aguardam em seus sarcófagos em um estado '
                 'letárgico, mas serão facilmente despertadas ao perceberem '
                 'que seu descanso foi violado.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Pó das ataduras da Múmia é usado como abortivo e como '
                 'redutor da fertilidade masculina.',
  'dv': '6',
  'dv_bonus': '+5',
  'encounters': '1d4',
  'encounters_lair': '1d12',
  'flavor': 'Morto-vivo embalsamado e amaldiçoado. Vive em tumbas e ruínas '
            'ancestrais, destilando seu ódio pelos vivos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 72},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 135},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 12},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['desertos', 'subterraneos'],
  'id': 'mumia',
  'jp': '9',
  'mo': 9,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Múmia',
  'picture': 'https://public.olddragon.com.br/sz1hhdukv694clkn7la0dmb0uflq',
  'pv': '35',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/o55rzn98hey2ufc9fs3aflg2fg42',
  'treasure': None,
  'treasure_lair': 'd',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/mumia.json',
  'variant': False,
  'xp': '340'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 9,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8 + Veneno',
               'description': 'Ferrão',
               'text': '1 × Ferrão +9 (2d8 + Veneno)',
               'times': 1,
               'weapon': False},
              {'ba': 9,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Mordidas',
               'text': '2 × Mordidas +9 (1d4)',
               'times': 2,
               'weapon': False}],
  'ca': '15',
  'concept': 'besta',
  'description': 'O corpo longo e púrpura lembra o de uma grande serpente. '
                 'Apesar do rosto humano, a cabeça possui traços singulares, '
                 'como chifres, olhos de cobra, língua bifurcada e até mesmo '
                 'presas.\n'
                 '\n'
                 'Sábias e pacientes, conseguem ficar paradas por horas, mas '
                 'se movem rapidamente quando alarmadas. Elas preferem '
                 'descansar em um estado semiconsciente que conserva sua '
                 'energia e as torna muito difíceis de surpreender.\n'
                 '\n'
                 '**Som**: arrastar áspero e contínuo sobre o chão.\n'
                 '\n'
                 '**Odor**: fezes.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Seu veneno e suas magias a transformam em um oponente '
                 'terrível de ser enfrentado.\n'
                 '\n'
                 'Muito inteligente, usará de artimanhas e do conhecimento do '
                 'terreno para ter vantagem sobre os inimigos.\n'
                 '\n'
                 '  * **Veneno**: o ferrão serrilhado da naga inocula Veneno '
                 'Sonífero. Uma JPC evita qualquer efeito deste veneno. Uma '
                 'falha no teste causa a perda de 1d6 pontos de Inteligência '
                 'por turno até o alvo perder todos os pontos de Inteligência '
                 'e morrer. Um antídoto ou magia podem neutralizar o veneno e '
                 'encerrar seus efeitos.\n'
                 '\n'
                 '  * **Magia**: uma naga pode conjurar magias como se fosse '
                 'um Mago de 6º nível.\n'
                 '\n'
                 '  * **Imunidades**: uma naga é imune ao dano de qualquer '
                 'ácido e veneno.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Nagas são egocêntricas e egoístas, dominando seres menos '
                 'poderosos e transformando-os em seus servos.\n'
                 '\n'
                 'Alguns destes servos as tomam como criaturas divinas, '
                 'cultuando-as como se fossem um “deus serpente” e elas, '
                 'claro, se aproveitam disso.\n'
                 '\n'
                 'Amam magia arcana e se encantam quando podem ver os efeitos '
                 'fantásticos causados pela manipulação mágica.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'O cérebro da Naga Negra é usado como ingrediente de itens '
                 'mágicos ligados aos poderes de controle mental.',
  'dv': '8',
  'dv_bonus': '',
  'encounters': '1d2',
  'encounters_lair': '1d4',
  'flavor': 'Possuem corpo de serpente e cabeça humana. Vivem em suas tocas, '
            'guardando lugares e tesouros.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 136},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['pantanos', 'subterraneos'],
  'id': 'naga-negra',
  'jp': '7',
  'mo': 11,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': 9,
  'mvo': None,
  'mvv': None,
  'name': 'Naga Negra',
  'picture': 'https://public.olddragon.com.br/ugu2fezd6483rlqltap4mr9dba0v',
  'pv': '40',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/t2pzznl1avlpq3jkjb2in8jzvjn3',
  'treasure': 't',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/naga-negra.json',
  'variant': False,
  'xp': '740'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide',
  'flavor': 'Especializados no uso de coquetéis de Drogas de Combate feitas de '
            'cogumelos mágicos, no uso de Venenos de Combate que passam em '
            'suas armas e corpos e, também, no uso dos Sacos de Esporos de '
            'Combate.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 56}],
  'habitats': ['qualquer'],
  'id': 'narcoguerreiro',
  'name': 'Narcoguerreiro',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/narcoguerreiro.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'gigante',
  'flavor': 'Espécie degenerada de gigantes imortais com magia abissal inata. '
            'Vivem nas profundezas mais sombrias das Infinitas Cavernas desde '
            'tempos imemoriais, quando eram os principais inimigos dos '
            'Insectaris.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 58}],
  'habitats': ['subterraneos'],
  'id': 'nargug',
  'name': 'Nargug',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/nargug.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Das Covas Castanhas, é um cavaleiro ARKHImancista e Necromante '
            'que viaja em um Yeldra da Noite. Capaz de Criar e Comandar '
            'Mortosvivos; e de criar tempestades de fogo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 73}],
  'habitats': ['desertos'],
  'id': 'necromante-mistico',
  'name': 'Necromante Místico',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/necromante-mistico.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'ordeiro',
  'concept': 'humanoide',
  'flavor': 'Senianos da Necrotirania Seniana das Terras Mortas, cuja capital '
            'é Malseun. Totalmente adeptos a cultura da morte.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 60}],
  'habitats': ['qualquer'],
  'id': 'necromante-seniano',
  'name': 'Necromante Seniano',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/necromante-seniano.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide_monstruoso',
  'flavor': 'Com apenas 90cm de altura, apresentam-se como mulheres '
            'misteriosas de pele azulada, esverdeada e acinzentada.  '
            'Entocam-se nas partes mais fundas de lagos de oásis.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 74}],
  'habitats': ['desertos'],
  'id': 'ninfa-do-oasis',
  'name': 'Ninfa do Oásis',
  'size': 'miudo',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/ninfa-do-oasis.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 5,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6+1 + Doença',
               'description': 'Mordidas',
               'text': '3 × Mordidas +5 (1d6+1 + Doença)',
               'times': 3,
               'weapon': False},
              {'ba': 5,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Efeito',
               'description': 'Praga Voraz',
               'text': '1 × Praga Voraz +5 (Efeito)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Dedetização**: a cada 5 pontos de dano a Ninhada de '
                 'Ratos faz um teste de Moral. Em caso de falha, o dano '
                 'sofrido naquele ataque é dobrado, ou triplicado no caso de '
                 'ataques com fogo.\n'
                 '  * **Doença**: uma Ninhada de Ratos possui 1 chance em 1d6 '
                 'de transmitir Febre do Esgoto a um alvo mordido. Um alvo '
                 'mordido que falhar em uma JPC, ficará doente e com valor de '
                 'Constituição igual a 1 por 1d6 dias.\n'
                 '  * **Medo de Fogo**: sempre que estiver na presença de '
                 'fogo, a Ninhada de Ratos deve realizar um teste de MO para '
                 'determinar se se dispersa e foge do combate.\n'
                 '  * **Praga Voraz**: a Ninhada de Ratos age como uma única '
                 'entidade, englobando um alvo e impedindo-o de se mover. '
                 'Enquanto estiver engolfado, o alvo recebe dano em dobro, '
                 'além de ter todo o dano causado à Ninhada de Ratos reduzido '
                 'pela metade. Enquanto envolve um alvo, a Ninhada de Ratos '
                 'não pode se mover. Para escapar, o alvo deve gastar sua ação '
                 'para tentar ser bem-sucedido em uma JPC feita como Difícil.\n'
                 '\n',
  'dv': '10',
  'dv_bonus': '',
  'encounters': None,
  'encounters_lair': None,
  'flavor': 'Uma enorme ninhada de ratos , que investe contra todos como se '
            'fosse uma única criatura com dezenas de olhos que emitem um tênue '
            'brilho vermelho.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday16.json',
              'page': 20}],
  'habitats': ['subterraneos'],
  'id': 'ninhada-de-ratos',
  'jp': '5',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Ninhada de Ratos',
  'picture': None,
  'pv': '50',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/ninhada-de-ratos.json',
  'variant': False,
  'xp': '1250'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma +1 (Arma)',
               'times': 1,
               'weapon': True}],
  'ca': '13',
  'concept': 'humanoide_monstruoso',
  'description': 'Medindo aproximadamente um palmo de altura, Nixies parecem '
                 'humanos esguios, de cor semelhante à agua em que vivem.\n'
                 '\n'
                 'Têm dedos das mãos e pés com membranas, orelhas pontudas e '
                 'grandes olhos prateados.\n'
                 '\n'
                 'As fêmeas são vaidosas, muitas vezes entrelaçando conchas e '
                 'fios de pérolas em seus cabelos grossos, e vestem-se '
                 'modestamente em xales justos tecidos com algas coloridas.\n'
                 '\n'
                 'Podem caminhar normalmente na água como se estivessem no '
                 'chão, de forma a parecer que estão fundidas na água.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Nixies não são combativas, mas são muito curiosas, fazendo '
                 'com que, muitas vezes, se metam em problemas. Por isso, '
                 'quando é preciso, atraem seus alvos para dentro d’água por '
                 'meio de seu poder de encantar.\n'
                 '\n'
                 'Se julgarem necessário, quebram o encanto e deixam o alvo '
                 'morrer afogado. Caso contrário, o mantém preso por um ano em '
                 'um estado de sono.\n'
                 '\n'
                 '  * **Encantar**: podem, uma vez ao dia, usar a magia '
                 'Enfeitiçar Pessoas como um Mago de 12º nível. Apenas um '
                 'Dissipar Magia ou um sucesso em uma JPS nega o efeito.\n'
                 '\n'
                 '  * **Comandar Peixes**: podem comandar até 1d10x10 peixes '
                 'para fazerem suas vontades, até mesmo para atacar. Os peixes '
                 'só deixarão de combater caso sejam ameaçados com fogo ou '
                 'algum tipo de explosão.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em corpos de água doce e limpos, sempre brincando com '
                 'os peixes.\n'
                 '\n'
                 'São criaturas cheias de vida, mas também de grande '
                 'curiosidade, e sem travas sociais.\n'
                 '\n'
                 'Podem furtar coisas bonitas, como joias ou taças, e guardar '
                 'para si mesmas em pequenas pilhas escondidas embaixo d’água.',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '2d20',
  'flavor': 'Fadas elementais da água. Atraem aventureiros para dentro de '
            'lagos e rios.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 137},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['oceanos'],
  'id': 'nixie',
  'jp': '6',
  'mo': 6,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': 12,
  'mvo': None,
  'mvv': None,
  'name': 'Nixie',
  'picture': 'https://public.olddragon.com.br/zh2awipf3h6uceoxtyddbmxlrjfe',
  'pv': '5',
  'size': 'miudo',
  'thumb_picture': 'https://public.olddragon.com.br/19n5i4iwiks6vj2yhepcfnoe6qq2',
  'treasure': 'l+t',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/nixie.json',
  'variant': False,
  'xp': '65'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Lança longa',
               'text': '1 × Lança longa +2 (1d8+1)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'humanoide',
  'description': 'Homens poderosos (como Barões e Duques) ou mesmo membros da '
                 'Corte (como Conselheiros, Magistrados, Diplomatas e outros '
                 'funcionários do Lorde local). São encontrados também '
                 'residindo em seus castelos e fortalezas, ou em viagem '
                 'durante alguma missão especial.\n'
                 '\n'
                 'Encontrados: quando fora de seus castelos, 1d3 nobres são '
                 'encontrados, escoltados por 2d4 Soldados Leves e 1d4 '
                 'Cavaleiros Leves. Toda a escolta é liderada por um Cavaleiro '
                 'de Guerra que faz o papel de Comandante de Guerra.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Montado**: cavalo de guerra.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 189},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'nobre',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Nobre',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'vx3',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/nobre.json',
  'variant': False,
  'xp': '25'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 0,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Arma improvisada',
               'text': '1 × Arma improvisada (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '10',
  'concept': 'humanoide',
  'description': 'São habitantes dos ermos, muitas vezes chamados de Bárbaros. '
                 'Vivem em grupos nômades cuidando de pequenas criações de '
                 'animais, cultivando a terra nas estações mais quentes e '
                 'migrando para outras regiões durante os meses mais frios. '
                 'Podem se transformar em inimigos formidáveis em combate caso '
                 'se sintam ameaçados.\n'
                 '\n'
                 'Encontrados em grupos de 2d4 Nômades Caçadores ou em tribos '
                 'nômades com 3d10 x 10 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: nos acampamentos, para cada 50 nômades, '
                 'um deles será um Nômade Xamã; e em todo acampamento haverá '
                 'um Nômade Líder.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '-1',
  'encounters': '-',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 189},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'nomade',
  'jp': '4',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Nômade',
  'picture': None,
  'pv': '4',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'p',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/nomade.json',
  'variant': False,
  'xp': '5'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Arco curto',
               'text': '1 × Arco curto +1 (1d6)',
               'times': 1,
               'weapon': False},
              {'ba': 1,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Espada curta',
               'text': '1 × Espada curta +1 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': 'São habitantes dos ermos, muitas vezes chamados de Bárbaros. '
                 'Vivem em grupos nômades cuidando de pequenas criações de '
                 'animais, cultivando a terra nas estações mais quentes e '
                 'migrando para outras regiões durante os meses mais frios. '
                 'Podem se transformar em inimigos formidáveis em combate caso '
                 'se sintam ameaçados.\n'
                 '\n'
                 'Encontrados em grupos de 2d4 Nômades Caçadores ou em tribos '
                 'nômades com 3d10 x 10 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: nos acampamentos, para cada 50 nômades, '
                 'um deles será um Nômade Xamã; e em todo acampamento haverá '
                 'um Nômade Líder.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 189},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'nomade-cacador',
  'jp': '4',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Nômade Caçador',
  'parent_monster_url': 'https://olddragon.com.br/monstros/nomade.json',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'p',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/nomade-cacador.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Espada longa',
               'text': '1 × Espada longa +3 (1d8+1)',
               'times': 1,
               'weapon': False},
              {'ba': 3,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Arco curto',
               'text': '1 × Arco curto +3 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'São habitantes dos ermos, muitas vezes chamados de Bárbaros. '
                 'Vivem em grupos nômades cuidando de pequenas criações de '
                 'animais, cultivando a terra nas estações mais quentes e '
                 'migrando para outras regiões durante os meses mais frios. '
                 'Podem se transformar em inimigos formidáveis em combate caso '
                 'se sintam ameaçados.\n'
                 '\n'
                 'Encontrados em grupos de 2d4 Nômades Caçadores ou em tribos '
                 'nômades com 3d10 x 10 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: nos acampamentos, para cada 50 nômades, '
                 'um deles será um Nômade Xamã; e em todo acampamento haverá '
                 'um Nômade Líder.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 189},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'nomade-lider',
  'jp': '6',
  'mo': 8,
  'mv': 18,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Nômade Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/nomade.json',
  'picture': None,
  'pv': '15',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'p',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/nomade-lider.json',
  'variant': True,
  'variant_modifications': ['Montado: Cavalo de Guerra.',
                            'Moral: enquanto o líder estiver em combate, todos '
                            'os Nômades fazem o teste de moral com um bônus de '
                            '+1.'],
  'xp': '95'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1',
               'description': 'Bordão',
               'text': '1 × Bordão +1 (1d4+1)',
               'times': 1,
               'weapon': False}],
  'ca': '11',
  'concept': 'humanoide',
  'description': 'São habitantes dos ermos, muitas vezes chamados de Bárbaros. '
                 'Vivem em grupos nômades cuidando de pequenas criações de '
                 'animais, cultivando a terra nas estações mais quentes e '
                 'migrando para outras regiões durante os meses mais frios. '
                 'Podem se transformar em inimigos formidáveis em combate caso '
                 'se sintam ameaçados.\n'
                 '\n'
                 'Encontrados em grupos de 2d4 Nômades Caçadores ou em tribos '
                 'nômades com 3d10 x 10 indivíduos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: nos acampamentos, para cada 50 nômades, '
                 'um deles será um Nômade Xamã; e em todo acampamento haverá '
                 'um Nômade Líder.\n'
                 '\n',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 189},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'nomade-xama',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Nômade Xamã',
  'parent_monster_url': 'https://olddragon.com.br/monstros/nomade.json',
  'picture': None,
  'pv': '10',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'p',
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/nomade-xama.json',
  'variant': True,
  'variant_modifications': ['Magias memorizadas: Arma Abençoada e Curar '
                            'Ferimentos.',
                            'Transe: enquanto o xamã estiver em combate, todos '
                            'os Nômades realizam seus ataques como ataques '
                            'fáceis.'],
  'xp': '65'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Uma centopeia composta por 100 humanos. Fruto de uma experiência '
            'bizarra dos ARKHImancistas, esta criatura é uma verdadeia máquina '
            'mortífera.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 74}],
  'habitats': ['desertos'],
  'id': 'normosia',
  'name': 'Normósia',
  'size': 'imenso',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/normosia.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 4,
               'damage': '1d6',
               'damage_bonus': 3,
               'damage_description': '1d6+3',
               'description': 'Mordida',
               'text': '1 × Mordida +4 (1d6+3)',
               'times': 1,
               'weapon': False}],
  'ca': '18',
  'concept': 'besta',
  'description': 'Observadores possuem o corpo esférico, com um grande olho '
                 'central e uma bocarra com dentes pontiagudos.\n'
                 '\n'
                 'Outros dez olhos menores saem do alto de sua cabeça, presos '
                 'em apêndices mais finos.\n'
                 '\n'
                 '**Som**: leves ruídos como giz apitando sobre quadro negro '
                 'misturado com estalos de estática.\n'
                 '\n'
                 '**Odor**: amônia.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Caso seja possível, buscará conhecer bem seus adversários '
                 'para se preparar da melhor forma para o combate.\n'
                 '\n'
                 'Usa a variedade de poderes de seus olhos para garantir '
                 'vantagem em combate, preferindo resolver tudo à distância.\n'
                 '\n'
                 '  * **Atento**: só pode ser surpreendido com um resultado 1 '
                 'em 1d6.\n'
                 '\n'
                 '  * **Resistência à magia**: qualquer magia lançada contra o '
                 'Observador possui 1-2 chances em 1d6 de ser completamente '
                 'ignorada.\n'
                 '\n'
                 '  * **Olho central**: capaz de anular qualquer efeito mágico '
                 '(seja de itens, poderes ou habilidades mágicas). Basta o '
                 'alvo estar dentro de um arco de 90º da visão do olho central '
                 'para sofrer o efeito.\n'
                 '\n'
                 '  * **Olhos secundários**: cada um possui uma função, e '
                 'apenas 3 podem usar suas habilidades ao mesmo tempo (apesar '
                 'de enxergarem o tempo todo). As habilidades funcionam como '
                 'se fossem usadas por um personagem de 10º nível. São elas:\n'
                 '\n'
                 '**1**. Sono;\n'
                 '\n'
                 '**2**. Enfeitiçar Pessoas;\n'
                 '\n'
                 '**3**. Aterrorizar;\n'
                 '\n'
                 '**4**. Detectar Invisibilidade;\n'
                 '\n'
                 '**5**. Lentidão;\n'
                 '\n'
                 '**6**. Magia da Morte;\n'
                 '\n'
                 '**7**. Telecinesia;\n'
                 '\n'
                 '**8**. Imobilizar Pessoas;\n'
                 '\n'
                 '**9**. Ilusão;\n'
                 '\n'
                 '**10**. Confusão.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Acredita-se que estas criaturas sejam de outro plano, ou '
                 'mesmo de outro planeta.\n'
                 '\n'
                 'São gênios que organizam planos capazes de abalar reinos '
                 'inteiros, apenas na esfera político-econômica.\n'
                 '\n'
                 'Gananciosos, traiçoeiros e confiantes, montam uma rede de '
                 'servidores que se estende muito além de seu lar nos '
                 'subterrâneos.',
  'dv': '11',
  'dv_bonus': '+10',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Grande esfera ardilosa. Possui vários olhos, cada um com um poder '
            'diferente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 138},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'observador',
  'jp': '14',
  'mo': 10,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Observador',
  'picture': 'https://public.olddragon.com.br/x8hwa5f6uayjrtgeirgpu0mu9rni',
  'pv': '65',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/cvk3k6qgh8v6ecxj9cr7hvsx1eaf',
  'treasure': None,
  'treasure_lair': 'a',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/observador.json',
  'variant': False,
  'xp': '1900'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 5,
               'damage': None,
               'damage_bonus': 6,
               'damage_description': 'Arma +6',
               'description': 'Arma',
               'text': '1 × Arma +5 (Arma +6)',
               'times': 1,
               'weapon': True},
              {'ba': 4,
               'damage': '1d6',
               'damage_bonus': 4,
               'damage_description': '1d6+4',
               'description': 'Pancada',
               'text': '1 × Pancada +4 (1d6+4)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'gigante',
  'description': 'Medindo cerca de duas vezes a altura de um homem comum, os '
                 'Ogros são corpulentos e grosseiros.\n'
                 '\n'
                 'Não costumam fazer prisioneiros, pois devoram todos aqueles '
                 'que derrotamem combate.\n'
                 '\n'
                 'Trabalham como mercenários, pois sua grande força e baixa '
                 'inteligência fazem dos Ogros ótimos contratados.\n'
                 '\n'
                 'Adoram ouro e costumam ignorar objetos artísticos de valor, '
                 'mesmo que valham muito.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Perigosíssimos com armas de impacto, os Ogros atacam de '
                 'forma desorganizada, confiando em seu tamanho e força.\n'
                 '\n'
                 'Aprendendo com os gigantes, às vezes começam um ataque '
                 'arremessando alguma pedra grande e pesada, quebrando '
                 'formações de batalha, para depois atacarem onde sentirem que '
                 'há mais medo e desordem.\n'
                 '\n'
                 '  * **Golpe Potente**: se conseguir causar, com uma pancada '
                 'ou arma, uma quantidade de dano superior a força do alvo, '
                 'este é arremessado 1d4 metros para trás.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Ogros se envolvem em atividades com diversos tipos de '
                 'humanoides malignos.\n'
                 '\n'
                 'São tolerados pelos gigantes que, por sua vez, consideram os '
                 'Orcs úteis para ocasiões nas quais precisam alcançar algo '
                 'que seu tamanho avantajado impeça.\n'
                 '\n'
                 'Devoram qualquer tipo de carne, mas preferem halflings, '
                 'considerando-os uma iguaria.\n'
                 '\n'
                 'Cada tribo tem seu líder, mas os líderes são regionalmente '
                 'comandados por um chefe das tribos, muito maior e voraz.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A couraça do Ogro é usada na confecção de itens mágicos '
                 'ligados à força bruta.',
  'dv': '4',
  'dv_bonus': '+4',
  'encounters': '1d6',
  'encounters_lair': '2d6',
  'flavor': 'Tolos, agressivos e gananciosos, servem a quem puder pagar seu '
            'preço.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 118},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/ja1.json',
              'page': 38},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 176},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 139},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday12.json',
              'page': 21},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday14.json',
              'page': 17},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday17.json',
              'page': 22},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'ogro',
  'jp': '7',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Ogro',
  'picture': 'https://public.olddragon.com.br/qq91311kos7ncfzwyqzlkhku1079',
  'pv': '24',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/l5nfxh0fs8965kf7ifk0nzv3v4ww',
  'treasure': 'tx2',
  'treasure_lair': 'd',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/ogro.json',
  'variant': False,
  'xp': '125'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'gigante',
  'flavor': 'Tolos, agressivos e gananciosos, servem a quem puder pagar seu '
            'preço.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 68}],
  'habitats': ['qualquer'],
  'id': 'ogro-bandido',
  'name': 'Ogro Bandido',
  'parent_monster_url': 'https://olddragon.com.br/monstros/ogro.json',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/ogro-bandido.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 7,
               'damage': '1d6',
               'damage_bonus': 5,
               'damage_description': '1d6+5',
               'description': 'Clava',
               'text': '1 × Clava +7 (1d6+5)',
               'times': 1,
               'weapon': False}],
  'ca': '18',
  'concept': 'gigante',
  'description': 'Medindo cerca de duas vezes a altura de um homem comum, os '
                 'Ogros são corpulentos e grosseiros.\n'
                 '\n'
                 'Não costumam fazer prisioneiros, pois devoram todos aqueles '
                 'que derrotamem combate.\n'
                 '\n'
                 'Trabalham como mercenários, pois sua grande força e baixa '
                 'inteligência fazem dos Ogros ótimos contratados.\n'
                 '\n'
                 'Adoram ouro e costumam ignorar objetos artísticos de valor, '
                 'mesmo que valham muito.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Perigosíssimos com armas de impacto, os Ogros atacam de '
                 'forma desorganizada, confiando em seu tamanho e força.\n'
                 '\n'
                 'Aprendendo com os gigantes, às vezes começam um ataque '
                 'arremessando alguma pedra grande e pesada, quebrando '
                 'formações de batalha, para depois atacarem onde sentirem que '
                 'há mais medo e desordem.\n'
                 '\n'
                 '  * **Golpe Potente**: se conseguir causar, com uma pancada '
                 'ou arma, uma quantidade de dano superior a força do alvo, '
                 'este é arremessado 1d4 metros para trás.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Ogros se envolvem em atividades com diversos tipos de '
                 'humanoides malignos.\n'
                 '\n'
                 'São tolerados pelos gigantes que, por sua vez, consideram os '
                 'Orcs úteis para ocasiões nas quais precisam alcançar algo '
                 'que seu tamanho avantajado impeça.\n'
                 '\n'
                 'Devoram qualquer tipo de carne, mas preferem halflings, '
                 'considerando-os uma iguaria.\n'
                 '\n'
                 'Cada tribo tem seu líder, mas os líderes são regionalmente '
                 'comandados por um chefe das tribos, muito maior e voraz.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A couraça do Ogro é usada na confecção de itens mágicos '
                 'ligados à força bruta.',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '2d6',
  'flavor': 'Tolos, agressivos e gananciosos, servem a quem puder pagar seu '
            'preço.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 139}],
  'habitats': ['qualquer'],
  'id': 'ogro-lider',
  'jp': '9',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Ogro Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/ogro.json',
  'picture': 'https://public.olddragon.com.br/qq91311kos7ncfzwyqzlkhku1079',
  'pv': '30',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/l5nfxh0fs8965kf7ifk0nzv3v4ww',
  'treasure': 'tx2',
  'treasure_lair': 'd',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/ogro-lider.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '175'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'gigante',
  'flavor': 'Tolos, agressivos e gananciosos, servem a quem puder pagar seu '
            'preço.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 75}],
  'habitats': ['qualquer'],
  'id': 'ogro-prisioneiro',
  'name': 'Ogro Prisioneiro',
  'parent_monster_url': 'https://olddragon.com.br/monstros/ogro.json',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/ogro-prisioneiro.json',
  'variant': True},
 {'access': 'partial',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': 3,
               'damage_description': '1d4+3 + Dreno',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (1d4+3 + Dreno)',
               'times': 1,
               'weapon': False},
              {'ba': 4,
               'damage': '1d6',
               'damage_bonus': 4,
               'damage_description': '1d6+4 + Golpe Potente',
               'description': 'Pancada',
               'text': '1 × Pancada +4 (1d6+4 + Golpe Potente)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'gigante',
  'description': '  * **Golpe Potente**: se conseguir causar, com uma pancada '
                 'ou arma, uma quantidade de dano superior a força do alvo, '
                 'este é arremessado 1d4 metros para trás.',
  'dv': '4',
  'dv_bonus': '+4',
  'encounters': '1d6',
  'encounters_lair': '2d6',
  'flavor': 'Tolos, agressivos e gananciosos, servem a quem puder pagar seu '
            'preço.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday12.json',
              'page': 20}],
  'habitats': ['qualquer'],
  'id': 'ogro-zumbi',
  'jp': '7',
  'mo': 12,
  'mv': 3,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Ogro Zumbi',
  'parent_monster_url': 'https://olddragon.com.br/monstros/ogro.json',
  'pv': '24',
  'size': 'grande',
  'treasure': 'tx2',
  'treasure_lair': 'd',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/ogro-zumbi.json',
  'variant': True,
  'variant_modifications': ['Morto-vivo: imune a frio, magias mentais de '
                            'manipulação, controle ou ilusão, ou demais formas '
                            'mágicas de interferir na mente de seres vivos. '
                            'Sofre 1d6 de dano ácido por frasco de água benta.',
                            'Inabalável: mortos-vivos não fazem testes de '
                            'moral, a não ser quando sofrem o efeito de um '
                            'Afastar Mortos-vivos.',
                            'Lento: sempre perde a Iniciativa num combate. Um '
                            'Zumbi sempre ataca por último.',
                            'Dreno: o alvo faz uma JPC para evitar um dreno em '
                            '1d4 de seus pontos de CON. Um alvo que tenha '
                            'todos os seus pontos de Constituição drenados, '
                            'ficará permanentemente morto. Pontos drenados '
                            'recuperam em 1d3+1 a cada noite de descanso, ou '
                            'com através da magia Curar Doenças.'],
  'xp': '320'},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 5,
               'damage': None,
               'damage_bonus': 4,
               'damage_description': 'Arma +4',
               'description': 'Arma',
               'text': '1 × Arma +5 (Arma +4)',
               'times': 1,
               'weapon': True}],
  'ca': '13/16',
  'concept': 'gigante',
  'description': 'Grandes estudiosos de artes milenares, os Oni Magos chefiam '
                 'terras em todos os continentes conhecidos.\n'
                 '\n'
                 'Treinados desde crianças na arte da guerra, prosperam pela '
                 'espada, magia e sabedoria, empregando criaturas diversas aos '
                 'seus serviços, como Orcs, Trolls ou mesmo Gigantes.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Preferem estudar o inimigo antes, o que os torna muito '
                 'perigosos. É provável que conheçam seu adversário antes de '
                 'encontrá-lo e, por isso, estarão preparados com magias de '
                 'Invisibilidade, Escuridão, Sono, etc., para depois entrar em '
                 'combate (geralmente mandando seus guarda-costas na frente '
                 'para minar as forças dos oponentes).\n'
                 '\n'
                 '  * **Classe de armadura**: Oni Magos possuem CA 13 ou 16 '
                 'quando usam armadura de couro batido.\n'
                 '\n'
                 '  * **Magias**: como um Mago de 5º nível.\n'
                 '\n'
                 '  * **Salto**: o Oni Mago pode saltar até 10 metros, os '
                 'quais podem ser divididos entre altura e distância. Assim, é '
                 'possível a ele saltar 10 metros para cima ou 5 metros para '
                 'frente e, ao mesmo tempo, 5 metros para cima.\n'
                 '\n'
                 '  * **Transformar**: pode se transformar em um ser humanoide '
                 '1 vez ao dia, por no máximo 12 horas.\n'
                 '\n'
                 '  * **Pavor de sua imagem**: caso seja refletido em um '
                 'espelho, seus poderes deixarão de funcionar e ele tentará '
                 'fugir a todo custo.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Costumam morar em fortificações, geralmente ocupando o posto '
                 'de senhor de guerra.\n'
                 '\n'
                 'Possuem um apreço muito grande por seus filhos, pois os '
                 'treinam para os substituírem e herdarem suas posses.\n'
                 '\n'
                 'Há rumores de que eles sejam nativos de uma ilha habitada '
                 'inteiramente por Onis no extremo leste do mundo, onde o '
                 'oceano se encontra com o céu. Nenhum explorador humano '
                 'jamais visitou a ilha – pelo menos, nenhum voltou de tal '
                 'expedição, impedindo a confirmação dos rumores.',
  'dv': '5',
  'dv_bonus': '+4',
  'encounters': '1d6',
  'encounters_lair': '0',
  'flavor': 'Conhecidos como Ogro Mago, são inteligentes e cruéis. Usam vestes '
            'e armas exóticas, e adoram enigmas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 140},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['planicies', 'colinas', 'montanhas'],
  'id': 'oni-mago',
  'jp': '9',
  'mo': 9,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Oni Mago',
  'picture': 'https://public.olddragon.com.br/bddw7cxdr10xykz1pz69sfs5yyam',
  'pv': '29',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/ikw4f6bbxx6pno1hnx137cmn6b17',
  'treasure': 'u',
  'treasure_lair': 'a+f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/oni-mago.json',
  'variant': False,
  'xp': '205'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma +3 (Arma)',
               'times': 1,
               'weapon': True}],
  'ca': '11/14',
  'concept': 'humanoide',
  'description': 'Criados na guerra, os Orcs não conseguem dominar os demais '
                 'povos porque não possuem um líder que os una.\n'
                 '\n'
                 'Extremamente numerosos, escravizam Goblins e tribos mais '
                 'fracas para lhes servirem em suas arremetidas bélicas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam com fúria e insensatez, muitas vezes sem perceber '
                 'alguma chance de fuga quando necessário.\n'
                 '\n'
                 'Orcs não honram seus mortos, pois consideram que não foram '
                 'fortes o suficiente para a próxima batalha.\n'
                 '\n'
                 '  * **Classe de armadura**: possuem CA 11 ou 14 quando usam '
                 'armadura de couro e escudo.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Orcs vivem em tribos, cultuando seus deuses violentos e '
                 'intolerantes. Quando um clã é destruído, se tornam '
                 'desgarrados e procuram habitar lugares abandonados ou mesmo '
                 'servir a algum senhor da guerra ou lorde, como mercenários.  '
                 'Sua condição física lhes permite marchar por muitas horas, o '
                 'que auxilia seus ataques e incursões. Os campeões de cada '
                 'clã se tornam o chefe, até outro lhe matar e tomar seu '
                 'lugar.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Frequentemente, a apresentação de uma cabeça Orc '
                 'recém-caçada é prova de coragem para iniciados em algumas '
                 'tribos bárbaras ou guilda de assassinos.',
  'dv': '1',
  'dv_bonus': '+1',
  'encounters': '2d4',
  'encounters_lair': '1d6x10',
  'flavor': 'Selvagens e brutais, visam a expansão de seus territórios por '
            'meio de invasões e constantes ataques aos outros povos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 74},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 177},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 141},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc2.json',
              'page': 27},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'orc',
  'jp': '5',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Orc',
  'picture': 'https://public.olddragon.com.br/tjgtu4plg7btvg14mwc7pwd3lr1s',
  'pv': '6',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/gesk2333xjtirkrw8ovk1b0yyq95',
  'treasure': 's',
  'treasure_lair': 'b+c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/orc.json',
  'variant': False,
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Arco',
               'text': '1 × Arco +3 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': 'Criados na guerra, os Orcs não conseguem dominar os demais '
                 'povos porque não possuem um líder que os una.\n'
                 '\n'
                 'Extremamente numerosos, escravizam Goblins e tribos mais '
                 'fracas para lhes servirem em suas arremetidas bélicas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam com fúria e insensatez, muitas vezes sem perceber '
                 'alguma chance de fuga quando necessário.\n'
                 '\n'
                 'Orcs não honram seus mortos, pois consideram que não foram '
                 'fortes o suficiente para a próxima batalha.\n'
                 '\n'
                 '  * **Classe de armadura**: possuem CA 11 ou 14 quando usam '
                 'armadura de couro e escudo.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Orcs vivem em tribos, cultuando seus deuses violentos e '
                 'intolerantes. Quando um clã é destruído, se tornam '
                 'desgarrados e procuram habitar lugares abandonados ou mesmo '
                 'servir a algum senhor da guerra ou lorde, como mercenários.  '
                 'Sua condição física lhes permite marchar por muitas horas, o '
                 'que auxilia seus ataques e incursões. Os campeões de cada '
                 'clã se tornam o chefe, até outro lhe matar e tomar seu '
                 'lugar.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Frequentemente, a apresentação de uma cabeça Orc '
                 'recém-caçada é prova de coragem para iniciados em algumas '
                 'tribos bárbaras ou guilda de assassinos.',
  'dv': '1',
  'dv_bonus': '+1',
  'encounters': '2d4',
  'encounters_lair': '1d6x10',
  'flavor': 'Selvagens e brutais, visam a expansão de seus territórios por '
            'meio de invasões e constantes ataques aos outros povos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 141}],
  'habitats': ['qualquer'],
  'id': 'orc-batedor',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Orc Batedor',
  'parent_monster_url': 'https://olddragon.com.br/monstros/orc.json',
  'picture': 'https://public.olddragon.com.br/tjgtu4plg7btvg14mwc7pwd3lr1s',
  'pv': '6',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/gesk2333xjtirkrw8ovk1b0yyq95',
  'treasure': 's',
  'treasure_lair': 'b+c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/orc-batedor.json',
  'variant': True,
  'variant_modifications': ['Chance de 1 em 1d6 de estar montando Worgs.'],
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d8',
               'damage_bonus': 3,
               'damage_description': '1d8+3',
               'description': 'Machado',
               'text': '1 × Machado +3 (1d8+3)',
               'times': 1,
               'weapon': False},
              {'ba': 3,
               'damage': '1d4',
               'damage_bonus': 2,
               'damage_description': '1d4+2',
               'description': 'Soco',
               'text': '1 × Soco +3 (1d4+2)',
               'times': 1,
               'weapon': False}],
  'ca': '13/15',
  'concept': 'humanoide',
  'description': 'Vindos do norte gelado e entre os mais selvagens guerreiros, '
                 'Orcs Brancos traçam suas origens desde os grandes caçadores '
                 'de dragões brancos. São especialistas em viver em clima '
                 'ártico, em montanhas geladas e geleiras no norte.\n'
                 '\n'
                 'Possuem a pele em tons que vão do branco ao cinza pálido. '
                 'Seus pelos são grossos, densos e claros, levemente '
                 'amarelados.\n'
                 '\n'
                 'Seus olhos possuem uma terceira pálpebra que filtra os raios '
                 'solares nos dias claros o que erroneamente faz com que sejam '
                 'descritos como orcs com olhos brancos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam com fúria e selvageria, muitas vezes sem se '
                 'preocuparem sequer com fuga ou rendição.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Classe de armadura**: possuem CA 13 ou 15 quando usam '
                 'armadura de couro.\n'
                 '  * **Resistência ao Frio**: orcs brancos recebem metade do '
                 'dano proveniente de uma fonte ligada ao frio ou gelo e fazem '
                 'seus testes de resistência contra estes elementos como um '
                 'teste muito fácil.\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Orcs Brancos são extremamente bélicos, selvagens e se '
                 'reproduzem rapidamente.\n'
                 '\n'
                 'Antes dos invernos costumam migrar para terras mais ao sul '
                 'para se protegerem do frio intenso e esse movimento '
                 'migratório costuma causar constantes conflitos. Com os '
                 'homens buscando proteger suas terras destas invasões.\n'
                 '\n'
                 'Essa dinâmica anual é fonte de conflitos sem fim na região '
                 'norte.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Norklunds costumam pagar bem por filhotes de Orcs Brancos '
                 'para serem exibidos como animais em feiras e mercados pelo '
                 'Reino.',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '1d6x10',
  'flavor': 'Ainda mais selvagens e bélicos que seus parentes, estes orcs '
            'aterrorizam as planícies geladas onde vivem.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao.json',
              'page': 316},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao-od2.json',
              'page': None},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday17.json',
              'page': 21}],
  'habitats': ['geleiras'],
  'id': 'orc-branco',
  'jp': '6',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': 12,
  'mvo': None,
  'mvv': None,
  'name': 'Orc Branco',
  'picture': 'https://public.olddragon.com.br/mz76j96mz4nq1lh40j1l4tiobko3',
  'pv': '10',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/6u97zuj3ycda5o2imws12n5xtz20',
  'treasure': 's',
  'treasure_lair': 'b+c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/orc-branco.json',
  'variant': False,
  'xp': '35'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Selvagens e brutais, visam a expansão de seus territórios por '
            'meio de invasões e constantes ataques aos outros povos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 74}],
  'habitats': ['qualquer'],
  'id': 'orc-guarda-costas',
  'name': 'Orc Guarda-Costas',
  'parent_monster_url': 'https://olddragon.com.br/monstros/orc.json',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/orc-guarda-costas.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Espada longa',
               'text': '1 × Espada longa +4 (1d8+2)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Criados na guerra, os Orcs não conseguem dominar os demais '
                 'povos porque não possuem um líder que os una.\n'
                 '\n'
                 'Extremamente numerosos, escravizam Goblins e tribos mais '
                 'fracas para lhes servirem em suas arremetidas bélicas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam com fúria e insensatez, muitas vezes sem perceber '
                 'alguma chance de fuga quando necessário.\n'
                 '\n'
                 'Orcs não honram seus mortos, pois consideram que não foram '
                 'fortes o suficiente para a próxima batalha.\n'
                 '\n'
                 '  * **Classe de armadura**: possuem CA 11 ou 14 quando usam '
                 'armadura de couro e escudo.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Orcs vivem em tribos, cultuando seus deuses violentos e '
                 'intolerantes. Quando um clã é destruído, se tornam '
                 'desgarrados e procuram habitar lugares abandonados ou mesmo '
                 'servir a algum senhor da guerra ou lorde, como mercenários.  '
                 'Sua condição física lhes permite marchar por muitas horas, o '
                 'que auxilia seus ataques e incursões. Os campeões de cada '
                 'clã se tornam o chefe, até outro lhe matar e tomar seu '
                 'lugar.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Frequentemente, a apresentação de uma cabeça Orc '
                 'recém-caçada é prova de coragem para iniciados em algumas '
                 'tribos bárbaras ou guilda de assassinos.',
  'dv': '3',
  'dv_bonus': '+1',
  'encounters': '2d4',
  'encounters_lair': '1d6x10',
  'flavor': 'Selvagens e brutais, visam a expansão de seus territórios por '
            'meio de invasões e constantes ataques aos outros povos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 141},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc2.json',
              'page': 27}],
  'habitats': ['qualquer'],
  'id': 'orc-lider',
  'jp': '6',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Orc Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/orc.json',
  'picture': 'https://public.olddragon.com.br/tjgtu4plg7btvg14mwc7pwd3lr1s',
  'pv': '16',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/gesk2333xjtirkrw8ovk1b0yyq95',
  'treasure': 's',
  'treasure_lair': 'b+c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/orc-lider.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '75'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Selvagens e brutais, visam a expansão de seus territórios por '
            'meio de invasões e constantes ataques aos outros povos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 95}],
  'habitats': ['qualquer'],
  'id': 'orc-veterano',
  'name': 'Orc Veterano',
  'parent_monster_url': 'https://olddragon.com.br/monstros/orc.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/orc-veterano.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Maça',
               'text': '1 × Maça +2 (1d8)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': 'Criados na guerra, os Orcs não conseguem dominar os demais '
                 'povos porque não possuem um líder que os una.\n'
                 '\n'
                 'Extremamente numerosos, escravizam Goblins e tribos mais '
                 'fracas para lhes servirem em suas arremetidas bélicas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam com fúria e insensatez, muitas vezes sem perceber '
                 'alguma chance de fuga quando necessário.\n'
                 '\n'
                 'Orcs não honram seus mortos, pois consideram que não foram '
                 'fortes o suficiente para a próxima batalha.\n'
                 '\n'
                 '  * **Classe de armadura**: possuem CA 11 ou 14 quando usam '
                 'armadura de couro e escudo.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Orcs vivem em tribos, cultuando seus deuses violentos e '
                 'intolerantes. Quando um clã é destruído, se tornam '
                 'desgarrados e procuram habitar lugares abandonados ou mesmo '
                 'servir a algum senhor da guerra ou lorde, como mercenários.  '
                 'Sua condição física lhes permite marchar por muitas horas, o '
                 'que auxilia seus ataques e incursões. Os campeões de cada '
                 'clã se tornam o chefe, até outro lhe matar e tomar seu '
                 'lugar.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Frequentemente, a apresentação de uma cabeça Orc '
                 'recém-caçada é prova de coragem para iniciados em algumas '
                 'tribos bárbaras ou guilda de assassinos.',
  'dv': '2',
  'dv_bonus': '+1',
  'encounters': '2d4',
  'encounters_lair': '1d6x10',
  'flavor': 'Selvagens e brutais, visam a expansão de seus territórios por '
            'meio de invasões e constantes ataques aos outros povos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 119},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 141},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc2.json',
              'page': 33}],
  'habitats': ['qualquer'],
  'id': 'orc-xama',
  'jp': '5',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Orc Xamã',
  'parent_monster_url': 'https://olddragon.com.br/monstros/orc.json',
  'picture': 'https://public.olddragon.com.br/tjgtu4plg7btvg14mwc7pwd3lr1s',
  'pv': '11',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/gesk2333xjtirkrw8ovk1b0yyq95',
  'treasure': 's',
  'treasure_lair': 'b+c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/orc-xama.json',
  'variant': True,
  'variant_modifications': ['Magia como Clérigo de 2º nível.'],
  'xp': '50'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 7,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1',
               'description': 'Mordida',
               'text': '1 × Mordida +7 (1d4+1)',
               'times': 1,
               'weapon': False},
              {'ba': 7,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'tentáculos',
               'text': '3 × tentáculos +7 (1d8)',
               'times': 3,
               'weapon': False}],
  'ca': '18',
  'concept': 'besta',
  'description': 'Parecidos com grandes pedras pontudas, ou mesmo com uma '
                 'pilha gigantesca e fossilizada de excremento, estas '
                 'criaturas fétidas têm a pele rochosa e quebradiça, ao menos '
                 'quando não estão ensopados de restos de excrementos, lixo e '
                 'chorume.\n'
                 '\n'
                 '**Som**: passos pesados e desconjuntados.\n'
                 '\n'
                 '**Odor**: chorume, lixo e podridão.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Camuflados em enormes pilhas de lixo, Otyughs aguardam '
                 'pacientemente seu alvo estar em uma posição vulnerável para '
                 'atacar.\n'
                 '\n'
                 'Não são inteligentes, então, quando em grupo, tentam se '
                 'esconder nos lixos, deixando os parceiros não escondidos '
                 'como isca.\n'
                 '\n'
                 '  * **Vigilância**: está sempre vigilante com seus '
                 'tentáculos e não pode ser surpreendido.\n'
                 '\n'
                 '  * **Doença**: qualquer alvo que receber dano de uma '
                 'mordida de um Otyugh, terá uma chance de 1 em 1d6, '
                 'cumulativa por mordida (duas mordidas, 2 chances; três '
                 'mordidas, 3 chances; etc.) de ser infectado pela Cólera do '
                 'Lixo. A doença causa diarreia e a perda de 2d4 pontos de '
                 'Constituição por até 1d4+2 dias.  Uma JPC bem-sucedida evita '
                 'os efeitos de uma Cólera do Lixo.\n'
                 '\n'
                 '  * **Agarrar**: se acertar os dois ataques com seus '
                 'tentáculos, conseguirá agarrar a vítima.  A cada rodada, o '
                 'Otyugh baterá com a vítima no chão, causando 2d8 de dano.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'A ecologia desta raça é incerta e inconstante.  Acredita-se '
                 'que dão cria por brotamento, criando versões menores de si '
                 'mesmos.\n'
                 '\n'
                 'Vivem sem objetivos, a não ser comer e viver um novo dia. '
                 'Apesar de estarem imersos em diferentes culturas, não '
                 'parecem possuir uma própria sendo totalmente ignorantes.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Otyughs são tão repugnantes que nenhum Sábio ou comerciante '
                 'gostaria de tocar em seus restos, então seus corpos ou '
                 'partes não têm uso ou valor conhecido.',
  'dv': '7',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1d2',
  'flavor': 'Estes seres glutões vivem entre lixo e excrementos, alimentando- '
            'se de tudo o que se decompõem nos subterrâneos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 142},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'otyugh',
  'jp': '6',
  'mo': 10,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Otyugh',
  'picture': 'https://public.olddragon.com.br/m7rb3ugojj1vi1lkd4o9zip8ugmn',
  'pv': '35',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/ik6gmrpp64uvfq6cly3wqc1vujzf',
  'treasure': 'p',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/otyugh.json',
  'variant': False,
  'xp': '420'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Garras',
               'text': '2 × Garras +4 (1d4)',
               'times': 2,
               'weapon': False},
              {'ba': 4,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Mordida',
               'text': '1 × Mordida +4 (1d8)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1d2',
  'encounters_lair': '1d6',
  'flavor': 'Um pouco menor que um Leão, a Pantera vive em florestas e '
            'planícies tropicais. Não vive em grupo.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 83},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 18},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['colinas', 'florestas', 'planicies'],
  'id': 'pantera',
  'jp': '6',
  'mo': 8,
  'mv': 15,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Pantera',
  'picture': None,
  'pv': '20',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/pantera.json',
  'variant': False,
  'xp': '125'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Um pouco menor que um Leão, a Pantera vive em florestas e '
            'planícies tropicais. Não vive em grupo.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 131}],
  'habitats': ['colinas', 'florestas', 'planicies'],
  'id': 'pantera-atroz',
  'name': 'Pantera Atroz',
  'parent_monster_url': 'https://olddragon.com.br/monstros/pantera.json',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/pantera-atroz.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 3,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Coices',
               'text': '2 × Coices +3 (1d6)',
               'times': 2,
               'weapon': False}],
  'ca': '14',
  'concept': 'besta',
  'description': 'Essas criaturas inteligentes são muito tímidas e selvagens, '
                 'difíceis de serem domesticadas. Eles servem apenas a pessoas '
                 'de bom coração e, quando o fizerem, servirão a ele com '
                 'absoluta fidelidade pelo resto de sua vida.\n'
                 '\n'
                 'Sua pelagem padrão é inteiramente branca, com crinas e rabos '
                 'perolados e reluzentes, embora existam Pégasos de coloração '
                 'castanha e até mesmo os raríssimos Pégasos negros.\n'
                 '\n'
                 'As penas das suas duas grandes asas são estranhamente '
                 'pesadas, o que não parecem afetar o desempenho de voo da '
                 'criatura.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Comos símbolos e campeões da Ordem, Págasos se oferecem à '
                 'cruzadas da justiça, caso estejam engajados em uma causa '
                 'contra o Caos.\n'
                 '\n'
                 'Quando precisam lutar, dão voos rasantes e patadas nos '
                 'adversários, aproveitando sua exímia habilidade de voo.\n'
                 '\n'
                 '\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'As escrituras sagradas relatam que o deus da Ordem descerá '
                 'dos céus de onde vive montado em um Pégaso, conferindo a '
                 'esta criatura uma aura de pureza e divinização sobrecomum.\n'
                 '\n'
                 'A dificuldade de encontrá-los – vivem reclusos em florestas '
                 'sagradas ou locais semelhantes – em nada contribui para que '
                 'esta aura de pureza legendária se esmoereça.\n'
                 '\n'
                 'Sua beleza e presença são tão grandes, que cavalos comuns, '
                 'mesmo os treinados para a batalha, os temem, da mesma forma '
                 'que um humano temeria um anjo.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Ovos de Pégasos são raros e valorizados por criadores de '
                 'montarias aladas, possuindo um valor descomunal que '
                 'pouquíssimas pessoas em um reino seriam capazes de pagar.\n'
                 '\n'
                 'Já as suas penas são ideais para dar equilíbrio perfeito à '
                 'flechas mágicas.',
  'dv': '2',
  'dv_bonus': '+4',
  'encounters': '0',
  'encounters_lair': '1d12',
  'flavor': 'Garanhões esplêndidos dotados de duas enormes asas revestidas de '
            'penas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 143},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas'],
  'id': 'pegaso',
  'jp': '5',
  'mo': 8,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 18,
  'name': 'Pégaso',
  'picture': 'https://public.olddragon.com.br/6ky2dr6ejydbk8w4l4q12u0ix62m',
  'pv': '14',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/51c3claifgakj9hyr9cfbst6zyoe',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/pegaso.json',
  'variant': False,
  'xp': '35'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'constructo',
  'flavor': 'Antigo filósofo transmutado em um constructo de pedra humanoide.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 74}],
  'habitats': ['desertos'],
  'id': 'pensador',
  'name': 'Pensador',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/pensador.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d10',
               'damage_bonus': None,
               'damage_description': '1d10',
               'description': 'Pique',
               'text': '1 × Pique +1 (1d10)',
               'times': 1,
               'weapon': False},
              {'ba': 1,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Espada curta',
               'text': '1 × Espada curta +1 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': 'Estes soldados estão a serviço de algum senhor local ou '
                 'procurando algum trabalho remunerado para suas armas. '
                 'Fortemente armados e protegidos, são um grupo coeso em '
                 'combate e desafiador para enfrentar.\n'
                 '\n'
                 'Encontrados em grupos formados por: 2d6 soldados, onde 1 a '
                 'cada 5 é um Soldado Pesado atuando como um Sargento; 2d6 '
                 'Arqueiros; 1d6 Besteiros; 1d6 Piqueiros e 1d6 Cavaleiros '
                 'Leves.  A cada 20 homens, haverá adicionalmente um Cavaleiro '
                 'de Guerra onde um destes é o Líder do Grupo.\n'
                 '\n'
                 'Contratando: existe uma chance de 1-2 em 1d6 dos Mercenários '
                 'estarem disponíveis para contratação.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Custo**: 2PO por mês.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 76},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 188},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'piqueiro-mercenario',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Piqueiro (Mercenário)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/soldado-leve-mercenario.json',
  'picture': 'https://public.olddragon.com.br/hysrm9x4j6l66mzz6ny46rxqjei4',
  'pv': '5',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/jgipoxwh8albycdbb1hrb032e8v1',
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/piqueiro-mercenario.json',
  'variant': True,
  'variant_modifications': ['Custo: 3 PO por mês.'],
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Espada curta',
               'text': '1 × Espada curta +1 (1d6)',
               'times': 1,
               'weapon': False},
              {'ba': 1,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1',
               'description': 'Adaga',
               'text': '1 × Adaga +1 (1d4+1)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': 'Piratas são bandidos dos mares que vivem de saques a cidades '
                 'costeiras e a outras embarcações.  Podem viver de crimes e '
                 'do submundo, realizando contrabando, tráfico ou '
                 'escravizações. São famosos pela crueldade e pela forma '
                 'intensa com a qual vivem e gastam o butim de seu trabalho.\n'
                 '\n'
                 'Encontrados: piratas são encontrados em uma quantidade de '
                 'acordo com o tipo de embarcação utilizado. Jogue 1d6 para '
                 'determinar qual a embarcação encontrada: 1-3. Galeão com 40 '
                 'Piratas; 4-5. Trirreme com 20 Piratas; 6. Navio à Vela com '
                 '20 Piratas.\n'
                 '\n'
                 'Escravos Remadores: uma embarcação do tipo Trirreme possui '
                 '150 Escravos Remadores os quais lutarão contra os piratas se '
                 'forem resgatados\n'
                 '\n'
                 'Mapa do Tesouro: há uma chance de 1-3 em 1d6 do tesouro da '
                 'embarcação (A) não estar a bordo, e sim enterrado em um '
                 'esconderijo.  Neste caso, será encontrado na embarcação, um '
                 'mapa com a localização do tesouro.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 10 Piratas, um deles será um '
                 'Pirata Campeão. Além disso, toda embarcação pirata é '
                 'comandada por um Capitão.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 191},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'pirata',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Pirata',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': 'a',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/pirata.json',
  'variant': False,
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Espada longa',
               'text': '1 × Espada longa +3 (1d8+1)',
               'times': 1,
               'weapon': False},
              {'ba': 3,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1',
               'description': 'Adaga',
               'text': '1 × Adaga +3 (1d4+1)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Piratas são bandidos dos mares que vivem de saques a cidades '
                 'costeiras e a outras embarcações.  Podem viver de crimes e '
                 'do submundo, realizando contrabando, tráfico ou '
                 'escravizações. São famosos pela crueldade e pela forma '
                 'intensa com a qual vivem e gastam o butim de seu trabalho.\n'
                 '\n'
                 'Encontrados: piratas são encontrados em uma quantidade de '
                 'acordo com o tipo de embarcação utilizado. Jogue 1d6 para '
                 'determinar qual a embarcação encontrada: 1-3. Galeão com 40 '
                 'Piratas; 4-5. Trirreme com 20 Piratas; 6. Navio à Vela com '
                 '20 Piratas.\n'
                 '\n'
                 'Escravos Remadores: uma embarcação do tipo Trirreme possui '
                 '150 Escravos Remadores os quais lutarão contra os piratas se '
                 'forem resgatados\n'
                 '\n'
                 'Mapa do Tesouro: há uma chance de 1-3 em 1d6 do tesouro da '
                 'embarcação (A) não estar a bordo, e sim enterrado em um '
                 'esconderijo.  Neste caso, será encontrado na embarcação, um '
                 'mapa com a localização do tesouro.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Variações**: a cada 10 Piratas, um deles será um '
                 'Pirata Campeão. Além disso, toda embarcação pirata é '
                 'comandada por um Capitão.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 191},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'pirata-campeao',
  'jp': '6',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Pirata Campeão',
  'parent_monster_url': 'https://olddragon.com.br/monstros/pirata.json',
  'picture': None,
  'pv': '15',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'q',
  'treasure_lair': 'a',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/pirata-campeao.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '75'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma +2 (Arma)',
               'times': 1,
               'weapon': True}],
  'ca': '16',
  'concept': 'humanoide_monstruoso',
  'description': 'De tamanho semelhante às Nixies, estas fadas quando '
                 'visíveis, assemelham-se a pequenos elfos, mas com orelhas '
                 'mais longas. Pixies têm duas asas prateadas, como as das '
                 'mariposas ou das libélulas.\n'
                 '\n'
                 'Usam roupas naturais, totalmente feitas de folhas, fibras '
                 'naturais ou cascas.\n'
                 '\n'
                 'Seus utensílios seguem a mesma lógica, usando apenas madeira '
                 'e rochas magicamente trabalhadas por elas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Tentam permanecer invisíveis, atacando de vários lados '
                 'enquanto voam, buscando provocar acidentes (como fazer o '
                 'inimigo acidentalmente atingir um aliado).\n'
                 '\n'
                 'Se perceberem que seus planos de ataque estão ameaçados ou '
                 'que seus inimigos são mais poderosos que suas forças, podem '
                 'fugir rapidamente de um combate.\n'
                 '\n'
                 '  * **Pó Mágico**: produzem um pó de seus cílios capaz de '
                 'fazer o alvo dormir (como a magia Sono lançada por um Mago '
                 'de 10º nível), ou de fazer com que o alvo levite '
                 'vagarosamente até 60 metros de altura. Ambos os efeitos '
                 'podem ser evitados com uma JPC.\n'
                 '\n'
                 '  * **Invisibilidade**: são naturalmente invisíveis, mas '
                 'qualquer ser invisível pode vê-las normalmente. Sua CA é 11 '
                 'quando não estiver invisível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em bosques e florestas isolados, preferencialmente com '
                 'a menor intervenção possível da civilização.\n'
                 '\n'
                 'São naturalmente invisíveis, e quando desejam podem se '
                 'mostrar aos outros, mas apenas quando possuem certeza de '
                 'suas intenções.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'O pó de asas de Pixies triturados e peneirados sob à lua '
                 'cheia é ingrediente para inúmeros itens mágicos relacionados '
                 'ao desaparecimento.\n'
                 '\n'
                 'No entanto, o pó só mantém o seu poder se o Pixie não morrer '
                 'na extração das suas asas.  Infelizmente, há apenas 1-2 '
                 'chances em 1d6 de um Pixie não morrer neste processo.',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '1d4 x 10',
  'flavor': 'Fadas elementais do ar. Gostam de pregar peças e roubar coisas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 144},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday24.json',
              'page': 17},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas'],
  'id': 'pixie',
  'jp': '6',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Pixie',
  'picture': 'https://public.olddragon.com.br/n8eageb08k9paygaa40cxtwkf0nf',
  'pv': '5',
  'size': 'miudo',
  'thumb_picture': 'https://public.olddragon.com.br/c89san4a8qfw04s2qp14j5wwueda',
  'treasure': 'l+t',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/pixie.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 6,
               'damage': '2d4',
               'damage_bonus': 2,
               'damage_description': '2d4+2',
               'description': 'Tentáculos',
               'text': '2 × Tentáculos +6 (2d4+2)',
               'times': 2,
               'weapon': False}],
  'ca': '17',
  'concept': 'besta',
  'description': 'Seu formato é estranho, mudando de tempos em tempos. Podem '
                 'se apresentar de forma mais arredondada, ou sem forma '
                 'definida alguma, de acordo com seu instinto inconstante.\n'
                 '\n'
                 'Dos olhos vazam fluidos, deixando seu corpo sempre úmido e '
                 'com um aspecto nojento.\n'
                 '\n'
                 '**Som**: vento assobiando.\n'
                 '\n'
                 '**Odor**: ureia ou amônia.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam primeiro com seus raios elétricos, esperando assim, '
                 'aniquilar o maior número possível de adversários.\n'
                 '\n'
                 'Podem usar um pólipo como isca a fim de tentar alinhar as '
                 'vítimas e maximizar o efeito do raio.\n'
                 '\n'
                 '  * **Imunidades**: um Pólipo Voador é imune ao dano de '
                 'qualquer arma não mágica e ao dano proveniente de '
                 'eletricidade.\n'
                 '\n'
                 '  * **Ataque Elétrico**: ao invés de atacar, um Pólipo '
                 'Voador pode desferir ataques elétricos numa linha de até 12 '
                 'metros. O dano de um ataque elétrico é de 3d8 em todos que '
                 'estiverem na linha reta atravessada pelo raio. Um teste de '
                 'JPD pode reduzir o dano pela metade.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Criaturas terríveis, surgem do acúmulo de resquícios mágicos '
                 'criados por arcanos ou clérigos que tenham lidado com '
                 'energias negativas pesadas.\n'
                 '\n'
                 'Passa seus dias varrendo os corredores das masmorras com '
                 'seus ataques elétricos, não possuindo nenhum outro '
                 'propósito, a não ser destruir o que se opuser a elas, o que '
                 'na maioria das vezes, significa todas as criaturas com quem '
                 'ela se encontrar.\n'
                 '\n'
                 'Acredita-se que venham de outro plano de existência, mas, '
                 'mesmo assim, sentem-se confortáveis em espalhar o caos no '
                 'plano material.',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '0',
  'flavor': 'Criatura amorfa como um emaranhado de energia negativa, repleta '
            'de tentáculos, bocas e olhos disformes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 145},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos', 'extraplanar'],
  'id': 'polipo-voador',
  'jp': '8',
  'mo': 10,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 18,
  'name': 'Pólipo Voador',
  'picture': 'https://public.olddragon.com.br/iawaybl8p3ach7invg2kbce17ajy',
  'pv': '30',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/yyj750dvwwi852pzyqzzvsn11mxo',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/polipo-voador.json',
  'variant': False,
  'xp': '305'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 12,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4 + Constrição',
               'description': 'Tentáculos',
               'text': '8 × Tentáculos +12 (2d4 + Constrição)',
               'times': 8,
               'weapon': False},
              {'ba': 12,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Mordida',
               'text': '1 × Mordida +12 (2d6)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'animal',
  'description': 'Polvos Gigantes são criaturas maliciosas e inteligentes, '
                 'conhecidos por serem o terror de marinheiros de mar aberto. '
                 'Mudam de cor para se misturar ao ambiente, camuflando sua '
                 'cor mesmo dentro da água, e pegam as embarcações que '
                 'desejam, sempre de surpresa.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Polvos Gigantes destroem embarcações em busca de alimento. '
                 'Quando abraçam um barco, conseguem atacar por vários pontos '
                 'diferentes com seus tentáculos.\n'
                 '\n'
                 '  * **Constrição**: quando um ataque com tentáculos é '
                 'bem-sucedido, o Polvo Gigante agarra a vítima causando 2d4 '
                 'de dano por rodada.  Um teste de Força bem-sucedido faz com '
                 'que o alvo se livre do tentáculo e da constrição.\n'
                 '\n'
                 '  * **Tentáculos**: se o Polvo Gigante receber 10 ou mais de '
                 'dano, seus tentáculos são amputados.  Para os efeitos de '
                 'testes de MO, trate os tentáculos como um membro de um '
                 'bando, ou seja, teste quando metade dos tentáculos for '
                 'amputada.\n'
                 '\n'
                 '  * **Nuvem de Tinta**: um Polvo Gigante pode lançar na água '
                 'uma nuvem de tinta preta com 20 metros de diâmetro para '
                 'confundir seus perseguidores em uma fuga.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Territorialistas, estes polvos habitam profundezas '
                 'grandiosas, acessíveis apenas por magia ou criaturas '
                 'abissais.\n'
                 '\n'
                 'São atraídos por objetos brilhantes, fato que criou a lenda '
                 'de que eles dormem em cima de pilhas absurdas de tesouros '
                 'nas profundezas.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A principal utilidade da carcaça dos Polvos Gigantes está na '
                 'sua pele, que é forte, maleável e totalmente impermeável.\n'
                 '\n'
                 'Isso faz com que ela seja procurada por marinheiros e '
                 'pescadores para a confecção de roupas de navegação ideais '
                 'para serem usadas durante tempestades ou na chuva.\n'
                 '\n'
                 'Outro subproduto que pode ser extraído de um Polvo Gigante é '
                 'a sua tinta, escura e altamente valiosa, pois são perfeitas '
                 'para a escrita de documentos e pergaminhos.\n'
                 '\n'
                 'Devido a resistência que esta tinta tem frente a água, ela é '
                 'praticamente impossível de ser removida ou apagada.',
  'dv': '12',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1d2',
  'flavor': 'Polvo gigantesco muito territorialista. Ataca embarcações em '
            'busca de alimentos e para proteger seus domínios.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 146},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['oceanos'],
  'id': 'polvo-gigante',
  'jp': '12',
  'mo': 10,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': 9,
  'mvo': None,
  'mvv': None,
  'name': 'Polvo Gigante',
  'picture': 'https://public.olddragon.com.br/v33p0rc8abym11gus7ot8nzhg9k8',
  'pv': '60',
  'size': 'colossal',
  'thumb_picture': 'https://public.olddragon.com.br/vwebintb9obw4ly9mg7nrbyofqnv',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/polvo-gigante.json',
  'variant': False,
  'xp': '1950'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d2',
               'damage_bonus': None,
               'damage_description': '1d2',
               'description': 'Coice',
               'text': '1 × Coice +1 (1d2)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Medroso**: precisa ser bem-sucedido em um teste de '
                 'Moral toda vez que é atacado.\n'
                 '  * **Correr**: pode correr com movimento 12 durante 1 '
                 'turno.\n'
                 '  * **Carga**: carrega até 1.500 moedas ou 750 moedas e um '
                 'montador.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '0',
  'flavor': 'Aparenta ser um cavalo de baixa estatura, mas muito forte, '
            'robusto e resistente para o trabalho.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 18},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'ponei',
  'jp': '5',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Pônei',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/ponei.json',
  'variant': False,
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d3',
               'damage_bonus': None,
               'damage_description': '1d3',
               'description': 'Coice',
               'text': '1 × Coice +2 (1d3)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Correr**: pode correr com movimento 12 durante 1 '
                 'turno.\n'
                 '  * **Preparado**: pode ser usado em combate e são treinados '
                 'no uso de armaduras\n'
                 '  * **Investida**: se ainda não engajado em combate, pode '
                 'usar a manobra de investida para aumentar o dano do ataque '
                 'do cavaleiro.\n'
                 '  * **Combatente**: é capaz de atacar no mesmo turno que seu '
                 'combatente.\n'
                 '  * **Carga**: carrega até 1.500 moedas ou 750 moedas e um '
                 'montador.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '0',
  'flavor': 'A robustez dos Pôneis com treinamento em combate para levar '
            'cavaleiros no caos do combate.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 18},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'ponei-de-guerra',
  'jp': '5',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Pônei de Guerra',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/ponei-de-guerra.json',
  'variant': False,
  'xp': '15'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'besta',
  'flavor': 'Possuídos são Demônios dos Seis Infernos do Limiar encarnados em '
            'mortais de qualquer raça de Kadur.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 64}],
  'habitats': ['qualquer'],
  'id': 'possuido-comum',
  'name': 'Possuído Comum',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/possuido-comum.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'besta',
  'flavor': 'Possuídos são Demônios dos Seis Infernos do Limiar encarnados em '
            'mortais de qualquer raça de Kadur.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 64}],
  'habitats': ['qualquer'],
  'id': 'possuido-de-elite',
  'name': 'Possuído de Elite',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/possuido-de-elite.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma +2 (Arma)',
               'times': 1,
               'weapon': True}],
  'ca': '14',
  'concept': 'besta',
  'description': 'Estes habitantes dos mares possuem a parte de cima do corpo '
                 'humanoide, variando entre azul e verde.\n'
                 '\n'
                 'Ao invés de pernas, possuem uma cauda e algumas outras '
                 'características próprias para se adequarem a uma vida '
                 'marítima.\n'
                 '\n'
                 'Eles habitam principalmente águas mais quentes, mas são '
                 'igualmente capazes de viver em profundidades rasas ou '
                 'grandes.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Normalmente, o Povo do Mar não é violento, atacando apenas '
                 'para revidar ataques anteriores ou apenas com a finalidade '
                 'de captura.\n'
                 '\n'
                 'Usam sua melodia para encantar os navegantes, chegando até '
                 'mesmo a destruir embarcações mais leves que se aproximam.\n'
                 '\n'
                 'Podem atrair o alvo, enquanto outros do mesmo bando atacam '
                 'por trás, com resultados mortais.\n'
                 '\n'
                 'Caso a batalha corra mal, se retiram para seu covil para '
                 'reunir reforços ou para montar uma nova estratégia de '
                 'resistência.\n'
                 '\n'
                 '  * **Voz Melodiosa**: podem utilizar até 3 vezes ao dia sua '
                 'voz para encantar um alvo humanoide, exatamente como na '
                 'magia Enfeitiçar Pessoas.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'O Povo do Mar vive em comunidades submarinas gigantescas, '
                 'com castas bem divididas entre guerreiros e não guerreiros.\n'
                 '\n'
                 'Os mais jovens podem sofrer de uma doença chamada "Fascínio '
                 'da Terra Morta", que é a vontade de viver entre os '
                 'habitantes da superfície.\n'
                 '\n'
                 'Alguns chegam a se apaixonar pelos terrestres, mas, quando '
                 'descobertos, são execrados e expulsos da comunidade.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A cauda destes seres é apreciada pela culinária dos povos '
                 'das ilhas do sul.\n'
                 '\n'
                 'Ela deve ser limpa e manter-se salgada por quase um ano até '
                 'atingir a maturação ideal para ser consumida.',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1d20',
  'flavor': 'Vivem em cidades submersas próximas às costas. Atacam todos que '
            'considerem inimigos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 147},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['oceanos'],
  'id': 'povo-do-mar',
  'jp': '5',
  'mo': 8,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': 9,
  'mvo': None,
  'mvv': None,
  'name': 'Povo do Mar',
  'picture': 'https://public.olddragon.com.br/y2xjvy6br4ion5zavmj163hsw719',
  'pv': '5',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/7bmyijznmbez7g3tztrx8n2belwz',
  'treasure': None,
  'treasure_lair': 'a',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/povo-do-mar.json',
  'variant': False,
  'xp': '15'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide',
  'flavor': 'Exímios caçadores, lutadores e rastreadores de jazídas de jade. '
            'Geralmente, utilizam armaduras, itens e armas de jade, e são '
            'conhecidos por sua calma e precisão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 76}],
  'habitats': ['desertos'],
  'id': 'povo-do-verde-guerreiro',
  'name': 'Povo do Verde (Guerreiro)',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/povo-do-verde-guerreiro.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide',
  'flavor': 'Pode estar recoberto com armaduras de placas de jade, lanças e '
            'espadas poderosas. Comandam esquadrões de ataque, grupos de '
            'comerciantes e agem como juízes e reis em seu domínio.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 76}],
  'habitats': ['desertos'],
  'id': 'povo-do-verde-lider',
  'name': 'Povo do Verde (Líder)',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/povo-do-verde-lider.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 74}],
  'habitats': [],
  'id': 'prisioneiro',
  'name': 'Prisioneiro',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/prisioneiro.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Répteis alados e carnívoros que voam aproveitando as correntes de '
            'ar de climas quentes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 77}],
  'habitats': ['desertos'],
  'id': 'pterodactilo',
  'name': 'Pterodáctilo',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/pterodactilo.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Mordida',
               'text': '1 × Mordida +4 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1d4',
  'flavor': 'Répteis alados e carnívoros que voam aproveitando as correntes de '
            'ar de climas quentes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 42},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': [],
  'id': 'pterossauro',
  'jp': '6',
  'mo': 8,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Pterossauro',
  'picture': 'https://public.olddragon.com.br/i9asn28ivygpvd3p8o1hbpupnkuy',
  'pv': '20',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/42gmiabfuuporusz31ppeizouo9h',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/pterossauro.json',
  'variant': False,
  'xp': '125'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 11,
               'damage': '3d8',
               'damage_bonus': None,
               'damage_description': '3d8',
               'description': 'Mordida',
               'text': '1 × Mordida +11 (3d8)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'gosma',
  'description': 'Estas criaturas amorfas são viscosas e silenciosas.  De cor '
                 'escura como piche, elas se misturam com a noite, de forma '
                 'mortal.\n'
                 '\n'
                 '**Som**: leve borbulhar e gotejamento.\n'
                 '\n'
                 '**Odor**: adocicado e frutado.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Tentam atacar de surpresa, permanecendo inertes até o '
                 'momento de agir. Contudo, seu corpo está em constante '
                 'movimento, então não há garantias de permanecer oculto.\n'
                 '\n'
                 '  * **Imunidades**: imune aos efeitos do frio e da '
                 'eletricidade.\n'
                 '\n'
                 '  * **Ácido**: após um ataque bem-sucedido, a saliva do '
                 'Pudim Negro começa a corroer qualquer material orgânico que '
                 'tiver contato. Este ácido é capaz de atingir armas e '
                 'armaduras causando uma penalidade no dano (no caso de armas) '
                 'ou na proteção (no caso de armaduras) de 1 a cada ataque '
                 'bem-sucedido. Se um equipamento receber uma quantidade de '
                 'dano igual ao seu dano de dano (4 para 1d4 de dano) ou igual '
                 'ao bônus na CA (4 para uma cota de malha) o equipamento '
                 'estará permanentemente destruído.\n'
                 '\n'
                 '  * **Divisão**: todo ataque de arma de corte que cause 8 ou '
                 'mais pontos de dano ao Pudim Negro pode causar sua divisão '
                 'em duas criaturas diferentes, ambas com metade dos pontos de '
                 'vida da criatura atual. Estas duas novas criaturas são '
                 'tratadas como criaturas diferentes, com ações, ataques e '
                 'pontos de vida diferentes, porém, caso sejam derrotadas, '
                 'concedem os pontos de experiência apenas uma única vez. '
                 'Todas as estatísticas do Pudim Negro se mantêm inalteradas.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Pudins Negros podem ter proporções gigantescas, ocupando '
                 'grandes áreas como se fossem uma piscina natural.\n'
                 '\n'
                 'Algumas vezes, os menores se juntam a Limos Cinzentos na '
                 'caça, aproveitando tudo o que um aventureiro e suas posses '
                 'podem proporcionar em termos de alimento.\n'
                 '\n'
                 'Estas criaturas não possuem nenhuma inteligência, agindo '
                 'apenas por instinto, desejando apenas sobreviver e se '
                 'alimentar.',
  'dv': '10',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '0',
  'flavor': 'Esta criatura semelhante a uma enorme ameba negra ataca tudo o '
            'que encontra pela frente com seus golpes ácidos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 148},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/tu2.json',
              'page': 43}],
  'habitats': ['subterraneos'],
  'id': 'pudim-negro',
  'jp': '11',
  'mo': 12,
  'mv': 6,
  'mvc': None,
  'mve': 6,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Pudim Negro',
  'picture': 'https://public.olddragon.com.br/q0azj4ld04g3rp0hiudn6kj3z7ar',
  'pv': '50',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/9zdku48gd09pf7s4rs4gjnltl3su',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/pudim-negro.json',
  'variant': False,
  'xp': '1325'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Mordida',
               'text': '1 × Mordida +4 (1d6)',
               'times': 1,
               'weapon': False},
              {'ba': 4,
               'damage': '1d3',
               'damage_bonus': None,
               'damage_description': '1d3',
               'description': 'Garras',
               'text': '2 × Garras +4 (1d3)',
               'times': 2,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '3',
  'dv_bonus': '+2',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Um pouco menor que a Pantera, vive nas montanhas temperadas e '
            'desertos rochosos. Não vive em grupo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 18},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['colinas', 'desertos', 'montanhas'],
  'id': 'puma',
  'jp': '6',
  'mo': 8,
  'mv': 10,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Puma',
  'picture': None,
  'pv': '17',
  'size': 'miudo',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/puma.json',
  'variant': False,
  'xp': '75'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 7,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Chifre',
               'text': '1 × Chifre +7 (1d4)',
               'times': 1,
               'weapon': False},
              {'ba': 7,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Garras',
               'text': '2 × Garras +7 (1d6)',
               'times': 2,
               'weapon': False},
              {'ba': 9,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4',
               'description': 'Mordidas',
               'text': '3 × Mordidas +9 (2d4)',
               'times': 3,
               'weapon': False}],
  'ca': '16',
  'concept': 'besta',
  'description': 'As Quimeras possuem um corpo poderoso como o de um leão, com '
                 'músculos potentes trazendo grande resistência e força '
                 'física.\n'
                 '\n'
                 'Suas três cabeças podem se mover de forma independente, mas '
                 'procuram sempre se focar em apenas um alvo.\n'
                 '\n'
                 'Gostam de se impor fisicamente, abrindo as asas para '
                 'parecerem muito maiores do que realmente são. e assustar '
                 'seus oponentes\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Caçam como felinos, espreitando pacientemente suas vítimas. '
                 'e encolhendo suas asas, como se fossem um morcego, ficando '
                 'menos visíveis na hora de atacar.\n'
                 '\n'
                 'Suas táticas de combate variam muito, pois apesar de seu '
                 'instinto animal ser predominante, preferem não incinerar '
                 'seus alvos caso o objetivo do combate seja a caça.\n'
                 '\n'
                 'Derrubar com cabeçadas e neutralizar com garras e mordidas é '
                 'sempre a melhor estratégia para manter o sabor e a '
                 'suculência da carne das suas vítimas.\n'
                 '\n'
                 '  * **Baforada de Dragão**: há 1-3 chances em 1d6 de uma '
                 'cabeça de dragão trocar os ataques de mordida por uma '
                 'baforada de dragão de 3d6 de dano.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Quimeras costumam ser solitárias, mas podem viver em '
                 'pequenos grupos dependendo das necessidades de sobrevivência '
                 'da região.\n'
                 '\n'
                 'A personalidade de suas cabeças pode divergir, como a '
                 'teimosia de uma conflitar com a curiosidade ou valentia de '
                 'outra.\n'
                 '\n'
                 'Os filhotes são cuidados por aproximadamente um ano, e '
                 'depois são deixados para trás.\n'
                 '\n'
                 'Ainda assim, um filhote de Quimera pode ser um grande '
                 'problema pois atacam fazendas e locais onde presas fáceis '
                 'podem ser abatidas, devorando gado, cavalos e até mesmo '
                 'crianças.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A cabeça empalhada da Quimera é um dos troféus mais '
                 'valorizados por nobres.',
  'dv': '9',
  'dv_bonus': '',
  'encounters': '1d2',
  'encounters_lair': '1d4',
  'flavor': 'Corpo meio leonino e meio caprino, asas dracônicas e três '
            'cabeças: uma de bode, uma de leão e uma de dragão.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 149},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['planicies', 'montanhas'],
  'id': 'quimera',
  'jp': '11',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Quimera',
  'picture': 'https://public.olddragon.com.br/icjz2tv8xlaaxndcavncntpswxsq',
  'pv': '45',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/oskjfzq7poc92jglfppiqmr3yweq',
  'treasure': None,
  'treasure_lair': 'f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/quimera.json',
  'variant': False,
  'xp': '975'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 8,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Sabre',
               'text': '1 × Sabre +8 (1d8+2)',
               'times': 1,
               'weapon': False},
              {'ba': 8,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Braço Monstruoso',
               'text': '1 × Braço Monstruoso +8 (2d8)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'humanoide',
  'description': '\n'
                 '\n'
                 '  * **Braço Monstruoso**: caso Rakhan obtenha um acerto '
                 'crítico, ou quando o mestre desejar, em um momento '
                 'dramático, seu único braço incha e brota músculos '
                 'monstruosos roxos, e sua metamorfose está completa. Ela '
                 'deixa então de lutar com o sabre e passa a tentar '
                 'estrangular e dar pancadas.\n'
                 '  * **Chamado da Capitã**: caso um personagem morra por '
                 'Rakhan, se torna um zumbi imediatamente, a serviço de '
                 'Rakhan.\n'
                 '\n',
  'dv': '6',
  'dv_bonus': '+5',
  'encounters': None,
  'encounters_lair': None,
  'flavor': 'Rakhan, a espadachim ex-capitã do navio Donzela Carmesim, agora '
            'está em meio a uma metamorfose avançada. Consumida por uma '
            'maldição, se transforma lentamente em uma criatura horrenda.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday16.json',
              'page': 18}],
  'habitats': ['qualquer'],
  'id': 'rakhan-a-amaldicoada-estagio-1',
  'jp': '10',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Rakhan, a Amaldiçoada (Estágio 1)',
  'picture': 'https://public.olddragon.com.br/wd2ddi923w2yy9upgvqz69ovchjt',
  'pv': '35',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/hk55i3mq81qg738xoazuw1vmj4gv',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/rakhan-a-amaldicoada-estagio-1.json',
  'variant': False,
  'xp': '740'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 12,
               'damage': '3d8',
               'damage_bonus': None,
               'damage_description': '3d8',
               'description': 'Braço Monstruoso',
               'text': '1 × Braço Monstruoso +12 (3d8)',
               'times': 1,
               'weapon': False},
              {'ba': 12,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Sabre',
               'text': '1 × Sabre +12 (2d6)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'humanoide',
  'description': '  * **Braço Monstruoso**: caso Rakhan obtenha um acerto '
                 'crítico, ou quando o mestre desejar, em um momento '
                 'dramático, seu único braço incha e brota músculos '
                 'monstruosos roxos, e sua metamorfose está completa. Ela '
                 'deixa então de lutar com o sabre e passa a tentar '
                 'estrangular e dar pancadas.\n'
                 '  * **Chamado da Capitã**: caso um personagem morra por '
                 'Rakhan, se torna um zumbi imediatamente, a serviço de '
                 'Rakhan.',
  'dv': '15',
  'dv_bonus': '',
  'encounters': None,
  'encounters_lair': None,
  'flavor': 'Rakhan, a espadachim ex-capitã do navio Donzela Carmesim, agora '
            'está em meio a uma metamorfose avançada. Consumida por uma '
            'maldição, se transforma lentamente em uma criatura horrenda.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday16.json',
              'page': 22}],
  'habitats': ['qualquer'],
  'id': 'rakhan-a-amaldicoada-estagio-2',
  'jp': '14',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Rakhan, a Amaldiçoada (Estágio 2)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/rakhan-a-amaldicoada-estagio-1.json',
  'pv': '75',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/rakhan-a-amaldicoada-estagio-2.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '3150'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 13,
               'damage': '4d8',
               'damage_bonus': None,
               'damage_description': '4d8',
               'description': 'Braço Monstruoso',
               'text': '1 × Braço Monstruoso +13 (4d8)',
               'times': 1,
               'weapon': False},
              {'ba': 16,
               'damage': '2d10',
               'damage_bonus': None,
               'damage_description': '2d10',
               'description': 'Sabre',
               'text': '1 × Sabre +16 (2d10)',
               'times': 1,
               'weapon': False}],
  'ca': '19',
  'concept': 'humanoide',
  'description': '  * **Braço Monstruoso**: caso Rakhan obtenha um acerto '
                 'crítico, ou quando o mestre desejar, em um momento '
                 'dramático, seu único braço incha e brota músculos '
                 'monstruosos roxos, e sua metamorfose está completa. Ela '
                 'deixa então de lutar com o sabre e passa a tentar '
                 'estrangular e dar pancadas.\n'
                 '  * **Chamado da Capitã**: caso um personagem morra por '
                 'Rakhan, se torna um zumbi imediatamente, a serviço de '
                 'Rakhan.',
  'dv': '18',
  'dv_bonus': '',
  'encounters': None,
  'encounters_lair': None,
  'flavor': 'Rakhan, a espadachim ex-capitã do navio Donzela Carmesim, agora '
            'está em meio a uma metamorfose avançada. Consumida por uma '
            'maldição, se transforma lentamente em uma criatura horrenda.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday16.json',
              'page': 27}],
  'habitats': ['qualquer'],
  'id': 'rakhan-a-amaldicoada-estagio-3',
  'jp': '14',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Rakhan, a Amaldiçoada (Estágio 3)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/rakhan-a-amaldicoada-estagio-1.json',
  'pv': '90',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/rakhan-a-amaldicoada-estagio-3.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '4200'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Mordida',
               'text': '1 × Mordida +1 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Pequeno mamífero carnívoro que vive nas colinas e florestas '
            'temperadas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 19},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['colinas', 'florestas', 'planicies'],
  'id': 'raposa',
  'jp': '5',
  'mo': 7,
  'mv': 15,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Raposa',
  'picture': None,
  'pv': '5',
  'size': 'miudo',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/raposa.json',
  'variant': False,
  'xp': '5'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 0,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4 + Doença',
               'description': 'Mordida',
               'text': '1 × Mordida (1d4 + Doença)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Doença**: um rato possui 1 chance em 1d6 de transmitir '
                 'Febre do Esgoto a um alvo mordido. Um alvo mordido que '
                 'falhar em uma JPC, ficará doente e com valor de Constituição '
                 'igual a 1 por 1d6 dias.\n'
                 '\n',
  'dv': '½',
  'dv_bonus': '-1',
  'encounters': '5d10',
  'encounters_lair': '2d10',
  'flavor': 'Ratos cinza dos esgotos. Sujos, esfomeados e ferozes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 19},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday12.json',
              'page': 19},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday16.json',
              'page': 16},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'rato',
  'jp': '3',
  'mo': 5,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': 3,
  'mvo': None,
  'mvv': None,
  'name': 'Rato',
  'picture': None,
  'pv': '1',
  'size': 'miudo',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/rato.json',
  'variant': False,
  'xp': '10'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Ninhadas repletas de indivíduos de 20 a 60cm de comprimento, com '
            'pelagem marrom ou cinza.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 77}],
  'habitats': ['desertos'],
  'id': 'rato-comum',
  'name': 'Rato Comum',
  'size': 'miudo',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/rato-comum.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d3',
               'damage_bonus': None,
               'damage_description': '1d3 + Doença',
               'description': 'Mordida',
               'text': '1 × Mordida +1 (1d3 + Doença)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'animal',
  'description': 'Estes ratos deformados podem chegar ao tamanho de um '
                 'cachorro médio, com pelos desgrenhados e bocarras com dentes '
                 'afiados.\n'
                 '\n'
                 'Possuem pelagem escura, marrom/preta ou cinza grafite, com a '
                 'barriga branca ou cinza claro, e um rabo grosso e forte sem '
                 'pelo algum.\n'
                 '\n'
                 '**Som**: guinchados baixos e dispersos.\n'
                 '\n'
                 '**Odor**: fezes e esgoto.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Não são muito corajosos e evitam o ataque, a menos se '
                 'estiverem com fome ou acuados.\n'
                 '\n'
                 'Evitam atacar grupos fortes, a menos que sejam movidos pela '
                 'fome ou comandados por alguma criatura, como um Homem-Rato.\n'
                 '\n'
                 'Atacam em grandes grupos, tentando derrubar o alvo e rasgar '
                 'seu corpo com dentadas.\n'
                 '\n'
                 '  * **Doença**: um rato possui 1 chance em 1d6 de transmitir '
                 'Febre do Esgoto a um alvo mordido. Um alvo mordido que '
                 'falhar em uma JPC, ficará doente e com valor de Constituição '
                 'igual a 1 por 1d6 dias.\n'
                 '\n'
                 '  * **Medo de Fogo**: na presença de fogo, um teste de MO '
                 'deve ser feito para determinar se Ratos Gigantes fogem ou '
                 'não do combate.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em lugares imundos, preferencialmente próximos da vida '
                 'urbana como nos esgotos ou nas docas das grandes cidades '
                 'portuárias.\n'
                 '\n'
                 'Alimentam-se de qualquer coisa que consigam capturar ou, em '
                 'situações de maior necessidade, de ratos menores.\n'
                 '\n'
                 'Quando encontram um Homem-Rato, o servem como se este fosse '
                 'um ser divino.\n'
                 '\n'
                 'Ratos Gigantes têm medo de fogo e fogem dele, exceto se '
                 'movidos pela fome ou magia. Eles são excelentes nadadores, e '
                 'podem atacar tanto na água quanto na terra.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'As administrações das grandes cidades, sobretudo as '
                 'portuárias, mais suscetíveis às pragas, costumam pagar um '
                 'prêmio de 5PP por Rato Gigante capturado.\n'
                 '\n'
                 'Esta é uma tentativa desesperada de conter o crescimento '
                 'populacional desta praga urbana.',
  'dv': '½',
  'dv_bonus': '',
  'encounters': '3d6',
  'encounters_lair': '3d10',
  'flavor': 'Enormes com quase 1 metro de comprimento, feições monstruosas e '
            'muito mais ferozes do que um rato comum.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 177},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 150},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday12.json',
              'page': 27},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'rato-gigante',
  'jp': '4',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': 6,
  'mvo': None,
  'mvv': None,
  'name': 'Rato Gigante',
  'picture': 'https://public.olddragon.com.br/1b3aounaaf4f821wxzy7kkqeaip1',
  'pv': '2',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/elce09njjx6mwmvwprvdolinvr3c',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/rato-gigante.json',
  'variant': False,
  'xp': '10'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 12,
               'damage': '5d6',
               'damage_bonus': None,
               'damage_description': '5d6',
               'description': 'Mordida',
               'text': '1 × Mordida +12 (5d6)',
               'times': 1,
               'weapon': False}],
  'ca': '19',
  'concept': 'besta',
  'description': 'Criatura gigantesca, lembrando de certa forma uma centopeia '
                 'gigante, com várias patas e um rosto hediondo.\n'
                 '\n'
                 'Varia de cor em tons mais frios, geralmente branco ou azul '
                 'claro, mas pode ser de uma intensidade de azul bem forte '
                 'quando mais nova.\n'
                 '\n'
                 'Uma característica marcante de um Remorhaz são as asas '
                 'localizadas ao lado da cabeça. Elas vibram quando ele deseja '
                 'demonstrar fúria, fazendo um ruído característico e '
                 'assustador.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usa sua habilidade de secretar um óleo quente para se '
                 'proteger e, dependendo de onde estiver, causando uma nuvem '
                 'de vapor devido ao calor próximo ao gelo.\n'
                 '\n'
                 'Ataca ferozmente tudo o que estiver se movendo, buscando se '
                 'alimentar sempre que possível.\n'
                 '\n'
                 '  * **Derrete Metais**: ao entrar em combate, o Remorhaz '
                 'secreta um óleo incrivelmente quente no seu dorso, capaz até '
                 'mesmo de derreter metais ou causar dano por cauterização.  '
                 'Qualquer um que tocar suas costas sofrerá 10d10 pontos de '
                 'dano. Armas que toquem suas costas durante um ataque são '
                 'imediatamente derretidas. Este efeito não atinge armas '
                 'mágicas.\n'
                 '\n'
                 '  * **Engolir**: se um Remorhaz obtiver um 20 natural em seu '
                 'teste de ataque, engolirá seu oponente matando-o '
                 'imediatamente, sem direito a nenhuma jogada de proteção.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Estes colossos vivem em terrenos gélidos, enterrados.  São '
                 'responsáveis por criar túneis complexos no subterrâneo, mas '
                 'quando se alimentam causam tanto alvoroço que acabam '
                 'destruindo boa parte de suas habitações.\n'
                 '\n'
                 'Também chamados de vermes polares, eles são predadores muito '
                 'agressivos, devorando qualquer matéria animal, incluindo '
                 'humanos, semi-humanos e humanoides de todo o tipo. sua '
                 'ferocidade é tamanha que eles são conhecidos até por atacar '
                 'Gigantes do Gelo.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A couraça de um Remorhaz é ingrediente para itens mágicos '
                 'que possuem proteção contra o frio. Já o óleo quente do seu '
                 'dorso é valioso como um componente para fabricação de itens '
                 'mágicos relacionados ao calor.',
  'dv': '12',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1d3',
  'flavor': 'Este agressivo verme polar devora qualquer tipo de vida que '
            'cruzar a sua frente.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 151},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['geleiras'],
  'id': 'remorhaz',
  'jp': '12',
  'mo': 10,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Remorhaz',
  'picture': 'https://public.olddragon.com.br/m9fywgxvi3qjg2sdb6xcipvv3w1x',
  'pv': '60',
  'size': 'colossal',
  'thumb_picture': 'https://public.olddragon.com.br/1lauqdn6fqfikhf22b2q6w938k9a',
  'treasure': None,
  'treasure_lair': 'd',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/remorhaz.json',
  'variant': False,
  'xp': '2025'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 8,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Garras',
               'text': '2 × Garras +8 (1d8)',
               'times': 2,
               'weapon': False}],
  'ca': '17',
  'concept': 'morto_vivo',
  'description': 'Revenants são cadáveres recém-mortos impossibilitados de '
                 'descansarem eternamente. Saem de suas tumbas para vingar '
                 'suas mortes fúteis e injustas, perseguindo seus assassinos '
                 'de forma implacável.\n'
                 '\n'
                 'Como seu corpo está no início do estágio de decomposição, '
                 'sua aparência é pouco decrépita.  Com pouca luz, podem se '
                 'passar por uma pessoa viva. Suas roupas ainda estão sujas, '
                 'mas inteiras.  Sua pele é amarelada e, em alguns pontos, '
                 'inchada e necrosada. Cheiram a terra molhada com um leve '
                 'odor desagradável de carne em início de apodrecimento.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Um Revenant vai procurar seu algoz e atacá-lo com '
                 'exclusividade, sem se preocupar com os demais alvos. Ele '
                 'atacará um inocente apenas em autodefesa.\n'
                 '\n'
                 'Ele usará suas garras e tentará acertar seus ataques para '
                 'conseguir esganar sua vítima até a morte; e só descansará '
                 'quando estiver vingado, tendo derrotado todos os seus '
                 'assassinos.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar-se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-Vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Imunidades**: além das imunidades comuns aos '
                 'mortos-vivos, Revenants são feridos apenas por magia e armas '
                 'mágicas ou de prata.  Armas de prata causam apenas metade do '
                 'dano. Revenants também são imunes ao poder de Afastar '
                 'Mortos-Vivos de um Clérigo.\n'
                 '\n'
                 '  * **Esganar**: se o Revenant acertar os dois ataques com '
                 'suas garras, conseguirá agarrar o pescoço de sua vítima, '
                 'causando 2d8 por sufocamento enquanto estiver esganando o '
                 'alvo.\n'
                 '\n'
                 '  * **Reconstituição**: um Revenant retornará a vida, e '
                 'continuará sua busca por justiça, 1d4 horas após ser morto. '
                 'As únicas formas de evitar o retorno de um Revenant são: '
                 'destruir seu cadáver com ácido ou fogo, ou a morte de seu '
                 'assassino.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Revenant é criado pelo ódio causado por uma morte violenta e '
                 'sem propósito. Incapaz de perdoar seus assassinos, o morto '
                 'retorna para fazer sua justiça e, assim, poder descansar '
                 'eternamente. Não usam aliados, não se relacionam com outras '
                 'pessoas, não se comunicam e não se envolvem com nada que não '
                 'seja seu único objetivo.',
  'dv': '8',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '0',
  'flavor': 'Mortos-vivos com desejo de vingar a morte injusta que sofreram. '
            'Só descansará quando fizer justiça com as próprias mãos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 152},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 24},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'revenant',
  'jp': '9',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Revenant',
  'picture': 'https://public.olddragon.com.br/pufhp89gsfgudbz1iigipyjluatd',
  'pv': '40',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/gd8qv8uufkvzwfmq27rs395rj85y',
  'treasure': 'v',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/revenant.json',
  'variant': False,
  'xp': '740'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 5,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Efeito',
               'description': 'Envolver',
               'text': '1 × Envolver +5 (Efeito)',
               'times': 1,
               'weapon': False},
              {'ba': 5,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1 + Doença',
               'description': 'Mordidas',
               'text': '3 × Mordidas +5 (1d6+1 + Doença)',
               'times': 3,
               'weapon': False}],
  'ca': '13',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Dispersar**: ao ter seus pontos de vida reduzidos pela '
                 'metade, em todo dano recebido após isso, a revoada faz um '
                 'teste de Moral, podendo se dispersar.\n'
                 '\n'
                 '  * **Doença**: uma Revoada de Morcegos possui 1 chance em '
                 '1d6 de transmitir a Doença do Morcego a um alvo mordido. Um '
                 'alvo mordido que falhar em uma JPC, ficará doente e com '
                 'valor de Constituição igual a 1 por 1d6 dias.\n'
                 '\n'
                 '  * **Medo de Fogo**: na presença de fogo, um teste de Moral '
                 'deve ser feito para determinar se a revoada se dispersa e '
                 'foge do combate.\n'
                 '\n'
                 '  * **Envolver**: a revoada envolve um único alvo, '
                 'englobando-o e impedindo-o de se mover. Enquanto estiver '
                 'envolvido pela revoada, o alvo recebe dano dobrado dela, '
                 'além de metade de quaisquer danos causados a ela. Enquanto '
                 'envolve um alvo, a revoada não pode se mover. Para sair da '
                 'revoada, o alvo deve gastar sua ação para tentar ser '
                 'bem-sucedido em uma JPC feita como Difícil.\n'
                 '\n',
  'dv': '10',
  'dv_bonus': '',
  'encounters': '',
  'encounters_lair': '',
  'flavor': 'Uma enorme revoada de morcegos, que investe contra todos como se '
            'fosse uma única criatura, sobrevoando e atacando no processo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday17.json',
              'page': 25}],
  'habitats': ['florestas', 'subterraneos'],
  'id': 'revoada-de-morcegos',
  'jp': '5',
  'mo': 8,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Revoada de Morcegos',
  'picture': None,
  'pv': '50',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/revoada-de-morcegos.json',
  'variant': False,
  'xp': '1250'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': -1,
               'damage_description': '1d4-1',
               'description': 'Cajado',
               'text': '1 × Cajado +2 (1d4-1)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'humanoide',
  'description': '\n\n  * **Magia**: como Mago de 8º nível.\n\n',
  'dv': '8',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday23.json',
              'page': 15}],
  'habitats': ['qualquer'],
  'id': 'rezingar',
  'jp': '11',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Rezingar',
  'picture': None,
  'pv': '40',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/rezingar.json',
  'variant': False,
  'xp': '695'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 8,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Chifre',
               'text': '1 × Chifre +8 (2d6)',
               'times': 1,
               'weapon': False}],
  'ca': '18',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Investida**: se ainda não engajado em combate, pode '
                 'usar a manobra de investida para causar o dobro de dano com '
                 'seu chifre.\n'
                 '\n',
  'dv': '8',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1d12',
  'flavor': 'Famoso pelo mau humor, vive nas planícies tropicais.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 19},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['planicies'],
  'id': 'rinoceronte',
  'jp': '10',
  'mo': 7,
  'mv': 15,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Rinoceronte',
  'picture': None,
  'pv': '40',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/rinoceronte.json',
  'variant': False,
  'xp': '650'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 11,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4 + Veneno',
               'description': 'Tentáculo',
               'text': '1 × Tentáculo +11 (1d4 + Veneno)',
               'times': 1,
               'weapon': False},
              {'ba': 11,
               'damage': '5d4',
               'damage_bonus': None,
               'damage_description': '5d4',
               'description': 'Mordida',
               'text': '1 × Mordida +11 (5d4)',
               'times': 1,
               'weapon': False}],
  'ca': '21',
  'concept': 'besta',
  'description': 'Sua aparência sempre se mescla com as rochas em volta, '
                 'ajudando a se camuflar.  Os tentáculos ficam presos ao '
                 'corpo, e podem ser detectados com uma investigação mais '
                 'atenciosa.\n'
                 '\n'
                 '**Som**: pedras sendo moídas e tijolos sendo encaixados.\n'
                 '\n'
                 '**Odor**: poeira e umidade.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam primeiramente quem estiver portando uma tocha ou '
                 'fonte de luz semelhante, pois temem o fogo. Imóveis, deixam '
                 'os grupos se aproximarem para atacar com seus tentáculos '
                 'venenosos.\n'
                 '\n'
                 '  * **Veneno**: um alvo atingido por um dos tentáculos do '
                 'Roper deve ser bem-sucedido em uma JPC ou perderá metade de '
                 'sua Força nos próximos 1d3 turnos. O efeito do veneno se '
                 'mantém por até 2d4+1 turnos.\n'
                 '\n'
                 '  * **Agarrar**: um alvo que for atingido por um dos '
                 'tentáculos e que não falhe numa JPC, será agarrado pelo '
                 'Roper e arrastado por 3 metros até sua monstruosa boca.\n'
                 '\n'
                 '  * **Imunidades**: Ropers são imunes a ataques baseados em '
                 'luz e eletricidade, sofrem apenas metade do dano proveniente '
                 'do frio, mas possuem uma penalidade de 4 para resistir a '
                 'efeitos do fogo.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em cavernas onde procriam lentamente, tendo cerca de '
                 'um filhote por ano.\n'
                 '\n'
                 'Não comem nenhum tipo de carne, alimentando- se de fungos e '
                 'líquens do subterrâneo, motivo pelo qual muitas vezes seus '
                 'corpos estão cobertos de musgo ou semelhantes.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os tentáculos do Roper são usados na criação de itens que '
                 'envolvam constrição, já o seu ácido estomacal é ingrediente '
                 'para criação de ácidos.\n'
                 '\n'
                 'Além disso, as remelas de seu olho, são consideradas '
                 'iguarias para alguns povos do subterrâneo.',
  'dv': '10',
  'dv_bonus': '',
  'encounters': '1d3',
  'encounters_lair': '0',
  'flavor': 'Estalactite de pele rochosa sempre à espreita para agarrar seus '
            'inimigos com seus longos tentáculos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 153},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'roper',
  'jp': '11',
  'mo': 11,
  'mv': 3,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Roper',
  'picture': 'https://public.olddragon.com.br/4z26xism4rpcay7utokn8qs0d4jd',
  'pv': '50',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/7d9xazkwbhj39himyoql88f7q9ah',
  'treasure': None,
  'treasure_lair': 'l',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/roper.json',
  'variant': False,
  'xp': '1325'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-mestre.json',
              'page': 29}],
  'habitats': [],
  'id': 'sabio-especialista',
  'name': 'Sábio Especialista',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sabio-especialista.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/kit-do-mestre.json',
              'page': 29}],
  'habitats': [],
  'id': 'sabio-generalista',
  'name': 'Sábio Generalista',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sabio-generalista.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 84}],
  'habitats': ['qualquer'],
  'id': 'sacerdote-maligno',
  'name': 'Sacerdote Maligno',
  'parent_monster_url': 'https://olddragon.com.br/monstros/cultista.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sacerdote-maligno.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d3',
               'damage_bonus': None,
               'damage_description': '1d3',
               'description': 'Garra',
               'text': '1 × Garra +2 (1d3)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Lança',
               'text': '1 × Lança +2 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'São uma raça cruel e predatória que vivem em águas costeiras '
                 'quentes. São altamente organizados e gostam muito de invadir '
                 'comunidades humanas costeiras em busca de comida.\n'
                 '\n'
                 'Suas cores típicas são verde-escuro nas costas, sombreados '
                 'de verde em tons mais claros na barriga, com barbatanas '
                 'pretas.\n'
                 '\n'
                 'Seus grandes olhos fixos são negros, profundos e brilhantes. '
                 'Eles têm pele escamosa, com dedos das mãos e pés separados '
                 'por membranas, e suas bocas são cheias de presas '
                 'serrilhadas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam redes e lanças para atacar a longa distância, e às '
                 'vezes se associam a tubarões ou criaturas semelhantes.\n'
                 '\n'
                 'Escolhem armas que sejam úteis tanto em combate subaquático '
                 'quanto em terra, e por isso preferem lanças ou azagaias.\n'
                 '\n'
                 'São muito táticos em seus ataques. Quando invadem '
                 'embarcações, por exemplo, procuram empurrar os marinheiros '
                 'para a água onde um grupo de Sahuagins estará de prontidão '
                 'para dar cabo destes oponentes, aproveitando-se de estar '
                 'dentro da água, seu ambiente natural.\n'
                 '\n'
                 '\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Alguns marinheiros os chamam de "orcs do mar" por conta dos '
                 'saques e pilhagens.\n'
                 '\n'
                 'Seus covis são vilas ou aldeias, construídos de pedra ou '
                 'corais. Lembram as cidades humanas, mas convertidas para a '
                 'vida marinha.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Guelras de Sahuagin empanadas são iguarias disputadas em '
                 'algumas vilas do sul.',
  'dv': '2',
  'dv_bonus': '+2',
  'encounters': '2d4',
  'encounters_lair': '2d4 x 10',
  'flavor': 'Peixes humanoides e violentos que vivem em tribos próximas a '
            'comunidades costeiras.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 154},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['oceanos'],
  'id': 'sahuagin',
  'jp': '5',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': 15,
  'mvo': None,
  'mvv': None,
  'name': 'Sahuagin',
  'picture': 'https://public.olddragon.com.br/ppvngmah3ylexl905imkz6kyfedg',
  'pv': '12',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/tamq9jvwel7xmu2an2ubz2ftkcql',
  'treasure': 'q',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sahuagin.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 6,
               'damage': '1d6',
               'damage_bonus': 3,
               'damage_description': '1d6+3',
               'description': 'Lança',
               'text': '1 × Lança +6 (1d6+3)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'humanoide',
  'description': 'São uma raça cruel e predatória que vivem em águas costeiras '
                 'quentes. São altamente organizados e gostam muito de invadir '
                 'comunidades humanas costeiras em busca de comida.\n'
                 '\n'
                 'Suas cores típicas são verde-escuro nas costas, sombreados '
                 'de verde em tons mais claros na barriga, com barbatanas '
                 'pretas.\n'
                 '\n'
                 'Seus grandes olhos fixos são negros, profundos e brilhantes. '
                 'Eles têm pele escamosa, com dedos das mãos e pés separados '
                 'por membranas, e suas bocas são cheias de presas '
                 'serrilhadas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam redes e lanças para atacar a longa distância, e às '
                 'vezes se associam a tubarões ou criaturas semelhantes.\n'
                 '\n'
                 'Escolhem armas que sejam úteis tanto em combate subaquático '
                 'quanto em terra, e por isso preferem lanças ou azagaias.\n'
                 '\n'
                 'São muito táticos em seus ataques. Quando invadem '
                 'embarcações, por exemplo, procuram empurrar os marinheiros '
                 'para a água onde um grupo de Sahuagins estará de prontidão '
                 'para dar cabo destes oponentes, aproveitando-se de estar '
                 'dentro da água, seu ambiente natural.\n'
                 '\n'
                 '\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Alguns marinheiros os chamam de "orcs do mar" por conta dos '
                 'saques e pilhagens.\n'
                 '\n'
                 'Seus covis são vilas ou aldeias, construídos de pedra ou '
                 'corais. Lembram as cidades humanas, mas convertidas para a '
                 'vida marinha.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Guelras de Sahuagin empanadas são iguarias disputadas em '
                 'algumas vilas do sul.',
  'dv': '5',
  'dv_bonus': '+1',
  'encounters': '2d4',
  'encounters_lair': '2d4 x 10',
  'flavor': 'Peixes humanoides e violentos que vivem em tribos próximas a '
            'comunidades costeiras.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 154}],
  'habitats': ['oceanos'],
  'id': 'sahuagin-campeao',
  'jp': '8',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': 15,
  'mvo': None,
  'mvv': None,
  'name': 'Sahuagin Campeão',
  'parent_monster_url': 'https://olddragon.com.br/monstros/sahuagin.json',
  'picture': 'https://public.olddragon.com.br/ppvngmah3ylexl905imkz6kyfedg',
  'pv': '26',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/tamq9jvwel7xmu2an2ubz2ftkcql',
  'treasure': 'q',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sahuagin-campeao.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '175'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Lança',
               'text': '1 × Lança +4 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'humanoide',
  'description': 'São uma raça cruel e predatória que vivem em águas costeiras '
                 'quentes. São altamente organizados e gostam muito de invadir '
                 'comunidades humanas costeiras em busca de comida.\n'
                 '\n'
                 'Suas cores típicas são verde-escuro nas costas, sombreados '
                 'de verde em tons mais claros na barriga, com barbatanas '
                 'pretas.\n'
                 '\n'
                 'Seus grandes olhos fixos são negros, profundos e brilhantes. '
                 'Eles têm pele escamosa, com dedos das mãos e pés separados '
                 'por membranas, e suas bocas são cheias de presas '
                 'serrilhadas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam redes e lanças para atacar a longa distância, e às '
                 'vezes se associam a tubarões ou criaturas semelhantes.\n'
                 '\n'
                 'Escolhem armas que sejam úteis tanto em combate subaquático '
                 'quanto em terra, e por isso preferem lanças ou azagaias.\n'
                 '\n'
                 'São muito táticos em seus ataques. Quando invadem '
                 'embarcações, por exemplo, procuram empurrar os marinheiros '
                 'para a água onde um grupo de Sahuagins estará de prontidão '
                 'para dar cabo destes oponentes, aproveitando-se de estar '
                 'dentro da água, seu ambiente natural.\n'
                 '\n'
                 '\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Alguns marinheiros os chamam de "orcs do mar" por conta dos '
                 'saques e pilhagens.\n'
                 '\n'
                 'Seus covis são vilas ou aldeias, construídos de pedra ou '
                 'corais. Lembram as cidades humanas, mas convertidas para a '
                 'vida marinha.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Guelras de Sahuagin empanadas são iguarias disputadas em '
                 'algumas vilas do sul.',
  'dv': '3',
  'dv_bonus': '+1',
  'encounters': '2d4',
  'encounters_lair': '2d4 x 10',
  'flavor': 'Peixes humanoides e violentos que vivem em tribos próximas a '
            'comunidades costeiras.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 154}],
  'habitats': ['oceanos'],
  'id': 'sahuagin-lider',
  'jp': '6',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': 15,
  'mvo': None,
  'mvv': None,
  'name': 'Sahuagin Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/sahuagin.json',
  'picture': 'https://public.olddragon.com.br/ppvngmah3ylexl905imkz6kyfedg',
  'pv': '16',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/tamq9jvwel7xmu2an2ubz2ftkcql',
  'treasure': 'q',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sahuagin-lider.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '75'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Mordida',
               'text': '1 × Mordida +3 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'humanoide',
  'description': 'Com a aparência similar a de uma imensa salamandra vermelha, '
                 'com torso levemente humanoide, de onde pendem dois braços e '
                 'sua cabeça grotesca.\n'
                 '\n'
                 'A parte inferior do corpo possui uma imensa e forte cauda, '
                 'exatamente como a de uma Víbora Gigante, mas coberta com '
                 'grandes e imponentes espinhos afiados.\n'
                 '\n'
                 'Ao lado da cabeça estão três pares de brânquias externas. '
                 'Aparentemente não utilizadas para a respiração, mas que '
                 'secretam uma substância quente e cáustica ao menor toque.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'As Salamandras possuem predileção especial por empunharem '
                 'lanças, usando-as no início do combate para atingir seus '
                 'inimigos antes mesmo de atacarem com fogo.\n'
                 '\n'
                 'Quando o combate corpo a corpo é iniciado, procurarão morder '
                 'seus inimigos com suas presas aterrorizantes e queimar seus '
                 'opositores com suas habilidades.\n'
                 '\n'
                 '  * **Queimar**: podem projetar uma labareda de fogo de suas '
                 'brânquias externas causando 1d6+1 de dano, com alcance de 9 '
                 'metros.\n'
                 '\n'
                 '  * **Queimar Energia**: sua fome por energia necrótica faz '
                 'com que procurem maldições para se alimentarem delas. Ficar '
                 'exposto a uma Salamandra por 1 hora remove encantamentos e '
                 'maldições com uma chance de 1-2 em 1d6.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em regiões quentes, embaixo de pedras e túneis '
                 'úmidos.\n'
                 '\n'
                 'Não é difícil localizá-las, pois as pedras que usam de '
                 'abrigo ficam insuportavelmente aquecidas. Alimentam-se de '
                 'energias necróticas do ambiente, mas raramente chegam a ver '
                 'um morto-vivo.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A carcaça de uma Salamandra é um verdadeiro tesouro para o '
                 'vendedor certo.\n'
                 '\n'
                 'Praticamente tudo do seu corpo pode ser aproveitado para a '
                 'confecção de itens mágicos ligados ao fogo.\n'
                 '\n'
                 'De seu sangue ao seu couro, praticamente todas as partes do '
                 'seu corpo podem ser reaproveitadas e vendidas por um bom '
                 'preço.',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '1d4+1',
  'encounters_lair': '2d4',
  'flavor': 'Cruéis e malignas, estas criaturas anfíbias são originárias do '
            'plano elemental do fogo.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 155},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'salamandra',
  'jp': '5',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Salamandra',
  'picture': 'https://public.olddragon.com.br/47n27zl72lbs8z9r5wg98s6d0sbu',
  'pv': '5',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/hnkdn768zrzro88spgds1pb0ag3z',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/salamandra.json',
  'variant': False,
  'xp': '65'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Morto-vivo embalsamado e amaldiçoado. Vive em tumbas e ruínas '
            'ancestrais, destilando seu ódio pelos vivos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/ja1.json',
              'page': 42}],
  'habitats': ['desertos', 'subterraneos'],
  'id': 'samoth-hibrido-mumia-lobisomem',
  'name': 'Samoth Híbrido Múmia-Lobisomem',
  'parent_monster_url': 'https://olddragon.com.br/monstros/mumia.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/samoth-hibrido-mumia-lobisomem.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Morto-vivo embalsamado e amaldiçoado. Vive em tumbas e ruínas '
            'ancestrais, destilando seu ódio pelos vivos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/ja1.json',
              'page': 41}],
  'habitats': ['desertos', 'subterraneos'],
  'id': 'samoth-mumia',
  'name': 'Samoth Múmia',
  'parent_monster_url': 'https://olddragon.com.br/monstros/mumia.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/samoth-mumia.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1',
               'description': 'Mordida',
               'text': '1 × Mordida +3 (1d4+1)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'animal',
  'description': 'São como sapos comuns, mas em escala muito maior! As cores '
                 'variam muito, e os machos costumam ser menores e um pouco '
                 'mais coloridos.\n'
                 '\n'
                 'São tão pacíficos quanto seus parentes de tamanho normal. O '
                 'problema é que seu apetite é proporcional ao seu tamanho, e '
                 'eles não costumam recusar nenhuma refeição.\n'
                 '\n'
                 '**Som**: coaxar leve e distante.\n'
                 '\n'
                 '**Odor**: fezes.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usam sua língua elástica para puxar os inimigos para si, '
                 'tentando engoli-los.\n'
                 '\n'
                 'Isto torna mais difícil para os aliados atacarem o sapo, '
                 'pois sempre há o risco de ferir o próprio aliado engolido.\n'
                 '\n'
                 '  * **Engolir**: se um Sapo Gigante obtiver um 20 natural em '
                 'seu teste de ataque, engolirá seu oponente. Um oponente '
                 'engolido sofre 1d6 de dano por rodada até conseguir sair. '
                 'Atacar dentro do sistema digestivo é possível com penalidade '
                 'de 4 no ataque.\n'
                 '\n'
                 '  * **Surpresa**: surpreende seus inimigos com um resultado '
                 'de 1 a 3 em 1d6.\n'
                 '\n'
                 '  * **Língua Elástica**: um Sapo Gigante pode agarrar seus '
                 'imigos com sua língua a até 3 metros de distância, '
                 'trazendo-os para sua boca para desferir uma mordida.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Preferem regiões pantanosas ou úmidas de maneira geral, mas '
                 'podem viver em praticamente qualquer lugar que tenha água, '
                 'alimento, e umidade para não ressecar sua pele.\n'
                 '\n'
                 'Desta forma, alguns Sapos gigantes são criados como vigias '
                 'de masmorras, geralmente em níveis mais inferiores.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A saliva dos Sapos Gigantes pode ser usada como cola para '
                 'facilitar escaladas de superfícies muito lisas.',
  'dv': '2',
  'dv_bonus': '+4',
  'encounters': '1d4',
  'encounters_lair': '1d6',
  'flavor': 'Gigantes e pacíficas, estas criaturas assustam principalmente '
            'pela voracidade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 156},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc2.json',
              'page': 27},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday14.json',
              'page': 16},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['pantanos', 'florestas', 'subterraneos'],
  'id': 'sapo-gigante',
  'jp': '5',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Sapo Gigante',
  'picture': 'https://public.olddragon.com.br/w720omjnjsnj5kl08oqdvl7wrp4x',
  'pv': '14',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/3oxkidsuuxc8gnhvwse6jsbe5li9',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sapo-gigante.json',
  'variant': False,
  'xp': '35'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Gigantes e pacíficas, estas criaturas assustam principalmente '
            'pela voracidade.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc2.json',
              'page': 29}],
  'habitats': ['pantanos', 'florestas', 'subterraneos'],
  'id': 'sapo-gigante-guloso',
  'name': 'Sapo Gigante Guloso',
  'parent_monster_url': 'https://olddragon.com.br/monstros/sapo-gigante.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sapo-gigante-guloso.json',
  'variant': True},
 {'access': 'partial',
  'alignment': 'neutro',
  'attacks': [{'ba': 8,
               'damage': '2d4',
               'damage_bonus': 5,
               'damage_description': '2d4+5',
               'description': 'Mordida',
               'text': '1 × Mordida +8 (2d4+5)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'animal',
  'description': '  * **Engolir**: se um Sapo Gigante obtiver um 20 natural em '
                 'seu teste de ataque, engolirá seu oponente. Um oponente '
                 'engolido sofre 1d6 de dano por rodada até conseguir sair. '
                 'Atacar dentro do sistema digestivo é possível com penalidade '
                 'de 4 no ataque.\n'
                 '\n'
                 '  * **Surpresa**: surpreende seus inimigos com um resultado '
                 'de 1 a 3 em 1d6.\n'
                 '\n'
                 '  * **Língua Elástica**: um Sapo Gigante pode agarrar seus '
                 'imigos com sua língua a até 3 metros de distância, '
                 'trazendo-os para sua boca para desferir uma mordida.',
  'dv': '5',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '1d6',
  'flavor': 'Gigantes e pacíficas, estas criaturas assustam principalmente '
            'pela voracidade.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc2.json',
              'page': 32},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday14.json',
              'page': 23}],
  'habitats': ['pantanos', 'florestas', 'subterraneos'],
  'id': 'sapo-gigante-voraz',
  'jp': '7',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Sapo Gigante Voraz',
  'parent_monster_url': 'https://olddragon.com.br/monstros/sapo-gigante.json',
  'pv': '25',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sapo-gigante-voraz.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4',
               'description': 'chifre',
               'text': '1 × chifre +3 (2d4)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide_monstruoso',
  'description': 'Da cintura para baixo, possui o corpo de um bode. Da cintura '
                 'para cima, o de um humano extremamente peludo.\n'
                 '\n'
                 'Seu nariz pode ser mais achatado, próximo de um bode, ou '
                 'como o de um humano comum, de acordo com a pureza de seu '
                 'sangue.\n'
                 '\n'
                 'A maioria possui pequenos chifres no alto da cabeça e '
                 'orelhas horizontais, como os caprinos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Não gostam muito do combate, a não ser que seja para '
                 'defender alguma região ou para auxiliar um druida muito '
                 'poderoso.\n'
                 '\n'
                 'Como meio de defesa, usam sempre sua flauta para adormecer '
                 'as vítimas e jogá-las para fora de seu território.\n'
                 '\n'
                 '  * **Flauta**: tocando sua flauta, um Sátiro consegue '
                 'conjurar as magias Sono, Medo e Enfeitiçar Pessoas como um '
                 'conjurador de 3º nível.\n'
                 '\n'
                 '  * **Silvestre**: sabem como se esconder e como se portar '
                 'dentro de ambientes silvestres.  Sátiros conseguem se '
                 'esconder nestas situações em 90% das vezes, e jamais são '
                 'surpreendidos nestes ambientes.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em grupos médios, escondidos nas florestas, e gostam '
                 'de confraternizar com outras criaturas silvestres.\n'
                 '\n'
                 'Dizem que há uma variação desta raça de pelagem clara, que '
                 'seria extremamente maligna, compactuando com entidades '
                 'perversas da floresta e dos subterrâneos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'O pó do chifre de um sátiro é tido como um dos mais potentes '
                 'e certeiros tônicos sexuais jamais conhecidos.\n'
                 '\n'
                 'Devido a dificuldade de obtê-los, em sua versão mais pura, '
                 'costuma custar mais que seu própriopeso em ouro.',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Humanoides, meio homens e meio bodes, são famosos pelo gosto por '
            'música, dança, jogos e trapaça.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 157},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday14.json',
              'page': 16},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas'],
  'id': 'satiro',
  'jp': '5',
  'mo': 7,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Sátiro',
  'picture': 'https://public.olddragon.com.br/zyitomffpxzvrwr0vikxyzhrvmaf',
  'pv': '10',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/6qvh4bcprkthc62is174ifq6tv65',
  'treasure': 's',
  'treasure_lair': 'i',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/satiro.json',
  'variant': False,
  'xp': '35'},
 {'access': 'limited',
  'alignment': 'ordeiro',
  'concept': 'humanoide',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/tu1.json',
              'page': 25}],
  'habitats': ['qualquer'],
  'id': 'senescal-da-caravana',
  'name': 'Senescal da Caravana',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/senescal-da-caravana.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide_monstruoso',
  'flavor': 'Criaturas que nadam pelas areias.  São escravizadas pelos '
            'ARKHImancistas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 78}],
  'habitats': ['desertos'],
  'id': 'sereia-de-areia',
  'name': 'Sereia de Areia',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sereia-de-areia.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d3',
               'damage_bonus': None,
               'damage_description': '1d3 ou 1d3 + Veneno',
               'description': 'Mordida',
               'text': '1 × Mordida +1 (1d3 ou 1d3 + Veneno)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Veneno**: causa morte em 1d10 turnos caso falhe num '
                 'teste de JPC\n'
                 '\n'
                 '  * Possui 1 chance em 1d6 de ser uma serpente venenosa.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': None,
  'encounters_lair': None,
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 107},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb2.json',
              'page': 121},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'serpente',
  'jp': '5',
  'mo': 12,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Serpente',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/serpente.json',
  'variant': False,
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 7,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4 + Dreno',
               'description': 'Mordida',
               'text': '1 × Mordida +7 (2d4 + Dreno)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'morto_vivo',
  'description': '\n'
                 '\n'
                 '  * **Corpo Ósseo**: imune a magias de enfeitiçar, sono, '
                 'frio, medo, veneno e outros efeitos que necessitem de alvos '
                 'vivos. Se atingida por armas de corte ou perfuração, sofre '
                 'metade do dano causado. Armas impactantes causam o dobro de '
                 'dano.\n'
                 '\n'
                 '  * **Dreno**: uma JPC evita a perda temporária de 2 pontos '
                 'de Força. Um personagem que zere seus pontos de Força está '
                 'morto. O personagem pode recuperar seus pontos de Força '
                 'drenados através de magia, ou descansando. Cada noite de '
                 'descanso completa recupera 1 ponto de Força perdido dessa '
                 'forma.\n'
                 '\n',
  'dv': '8',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': 'Uma enorme serpente formada a partir da junção dos esqueletos de '
            'várias criaturas. Animada e sustentada através de magia.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday17.json',
              'page': 23}],
  'habitats': ['qualquer'],
  'id': 'serpente-de-ossos-estagio-1',
  'jp': '10',
  'mo': 12,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Serpente de Ossos (Estágio 1)',
  'picture': None,
  'pv': '40',
  'size': 'imenso',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/serpente-de-ossos-estagio-1.json',
  'variant': False,
  'xp': '650'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 10,
               'damage': '2d6',
               'damage_bonus': 5,
               'damage_description': '2d6+5 + Dreno',
               'description': 'Mordida',
               'text': '1 × Mordida +10 (2d6+5 + Dreno)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'morto_vivo',
  'description': '  * **Corpo Ósseo**: imune a magias de enfeitiçar, sono, '
                 'frio, medo, veneno e outros efeitos que necessitem de alvos '
                 'vivos. Se atingida por armas de corte ou perfuração, sofre '
                 'metade do dano causado. Armas impactantes causam o dobro de '
                 'dano.\n'
                 '\n'
                 '  * **Dreno**: uma JPC evita a perda temporária de 2 pontos '
                 'de Força. Um personagem que zere seus pontos de Força está '
                 'morto. O personagem pode recuperar seus pontos de Força '
                 'drenados através de magia, ou descansando. Cada noite de '
                 'descanso completa recupera 1 ponto de Força perdido dessa '
                 'forma.',
  'dv': '15',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': 'Uma enorme serpente formada a partir da junção dos esqueletos de '
            'várias criaturas. Animada e sustentada através de magia.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday17.json',
              'page': 27}],
  'habitats': ['qualquer'],
  'id': 'serpente-de-ossos-estagio-2',
  'jp': '12',
  'mo': 12,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Serpente de Ossos (Estágio 2)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/serpente-de-ossos-estagio-1.json',
  'pv': '75',
  'size': 'imenso',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/serpente-de-ossos-estagio-2.json',
  'variant': True,
  'variant_modifications': ['Dreno: uma JPC evita a perda temporária de 1d4+1 '
                            'pontos de Força. Um personagem que zere seus '
                            'pontos de Força está morto. O personagem pode '
                            'recuperar seus pontos de Força drenados através '
                            'de magia, ou descansando. Cada noite de descanso '
                            'completa recupera 1 ponto de Força perdido dessa '
                            'forma.'],
  'xp': '1950'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 15,
               'damage': '2d6',
               'damage_bonus': 5,
               'damage_description': '2d6+5 + Dreno',
               'description': 'Mordidas',
               'text': '3 × Mordidas +15 (2d6+5 + Dreno)',
               'times': 3,
               'weapon': False}],
  'ca': '19',
  'concept': 'morto_vivo',
  'description': '  * **Corpo Ósseo**: imune a magias de enfeitiçar, sono, '
                 'frio, medo, veneno e outros efeitos que necessitem de alvos '
                 'vivos. Se atingida por armas de corte ou perfuração, sofre '
                 'metade do dano causado. Armas impactantes causam o dobro de '
                 'dano.\n'
                 '\n'
                 '  * **Dreno**: uma JPC evita a perda temporária de 2 pontos '
                 'de Força. Um personagem que zere seus pontos de Força está '
                 'morto. O personagem pode recuperar seus pontos de Força '
                 'drenados através de magia, ou descansando. Cada noite de '
                 'descanso completa recupera 1 ponto de Força perdido dessa '
                 'forma.',
  'dv': '20',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': 'Uma enorme serpente formada a partir da junção dos esqueletos de '
            'várias criaturas. Animada e sustentada através de magia.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday17.json',
              'page': 32}],
  'habitats': ['qualquer'],
  'id': 'serpente-de-ossos-estagio-3',
  'jp': '14',
  'mo': 12,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Serpente de Ossos (Estágio 3)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/serpente-de-ossos-estagio-1.json',
  'pv': '100',
  'size': 'imenso',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/serpente-de-ossos-estagio-3.json',
  'variant': True,
  'variant_modifications': ['Dreno: uma JPC evita a perda temporária de 1d6+1 '
                            'pontos de Força. Um personagem que zere seus '
                            'pontos de Força está morto. O personagem pode '
                            'recuperar seus pontos de Força drenados através '
                            'de magia, ou descansando. Cada noite de descanso '
                            'completa recupera 1 ponto de Força perdido dessa '
                            'forma.'],
  'xp': '2400'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 30}],
  'habitats': [],
  'id': 'serpente-farpada',
  'name': 'Serpente Farpada',
  'size': 'miudo',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/serpente-farpada.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'animal',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 32}],
  'habitats': [],
  'id': 'serpente-insana',
  'name': 'Serpente Insana',
  'size': 'imenso',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/serpente-insana.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'animal',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 34}],
  'habitats': [],
  'id': 'serpente-insana-ancestral',
  'name': 'Serpente Insana Ancestral',
  'parent_monster_url': 'https://olddragon.com.br/monstros/serpente-insana.json',
  'size': 'imenso',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/serpente-insana-ancestral.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'animal',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 38}],
  'habitats': [],
  'id': 'serpente-insana-superior',
  'name': 'Serpente Insana Superior',
  'parent_monster_url': 'https://olddragon.com.br/monstros/serpente-insana.json',
  'size': 'imenso',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/serpente-insana-superior.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': 'Víbora escura que se esconde durante o dia e ataca no Assombro ou '
            'em locais escuros durante o Lumien.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 78}],
  'habitats': ['desertos'],
  'id': 'serpente-negra',
  'name': 'Serpente Negra',
  'size': 'miudo',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/serpente-negra.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 13,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Tentáculos',
               'text': '2 × Tentáculos +13 (2d6)',
               'times': 2,
               'weapon': False},
              {'ba': 13,
               'damage': '3d10',
               'damage_bonus': None,
               'damage_description': '3d10',
               'description': 'Mordida',
               'text': '1 × Mordida +13 (3d10)',
               'times': 1,
               'weapon': False}],
  'ca': '19',
  'concept': 'besta',
  'description': 'Amorfas, essas bolhas gelatinosas lembram um piche azulado, '
                 'ou às vezes acinzentado, com bocas e olhos diversos e '
                 'aleatórios em seu corpos.\n'
                 '\n'
                 'Quando na forma ameboide, se deslocam por vontade própria, '
                 'lançando braços de matéria gelatinosa para frente e usando '
                 'as forças de suas bocas para se arrastar.\n'
                 '\n'
                 '**Som**: gorgolejantes e sussurros balbuciados de mil '
                 'bocas.\n'
                 '\n'
                 '**Odor**: pungente como queijo forte.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Gostam de enganar a vítima com sua metamorfose, atacando de '
                 'surpresa com seus dentes pontiagudos.\n'
                 '\n'
                 'Se atacarem na forma amorfa e uma vítima for morta por um '
                 'ataque bem-sucedido de um dos seus tentáculos, esta será '
                 'engolfada, acrescentando ao Shoggoth uma nova boca e um novo '
                 'par de olhos.\n'
                 '\n'
                 'Somente a carcaça da vítima é absorvida assim.  Seus '
                 'equipamentos, roupas e itens carregados serão expelidos e '
                 'abandonados no chão.\n'
                 '\n'
                 '  * **Deflexão**: toda magia lançada diretamente sobre o '
                 'Shoggoth (excetuando-se as magias em área) possui 1-2 '
                 'chances em 1d6 de não surtir efeitos.\n'
                 '\n'
                 '  * **Imunidades**: imune aos efeitos do frio, da '
                 'eletricidade, venenos, paralisação e encantamentos.\n'
                 '\n'
                 '  * **Alterar Forma**: pode assumir a forma de qualquer '
                 'criatura humanoide (M ou G). Um Shoggoth voltará a sua forma '
                 'normal caso seja morto.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Criados para serem escravos de outras raças, mutaram e se '
                 'transformaram em formas mais inteligentes e independentes.\n'
                 '\n'
                 'Vivem em lugares obscuros, próximos de civilizações '
                 'esquecidas.\n'
                 '\n'
                 'Em alguns casos, podem ser aquele velho louco da vila, ou '
                 'aquela mulher esquisita que mora no lixão da cidade.',
  'dv': '15',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Protoplasma amorfo, repleto de olhos terríveis, bocas ferozes e '
            'tentáculos pegajosos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 103},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 158},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 15},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday18.json',
              'page': 19},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos', 'extraplanar'],
  'id': 'shoggoth',
  'jp': '14',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Shoggoth',
  'picture': 'https://public.olddragon.com.br/9giz4w9rg0i7hpsf4788x6sosx8a',
  'pv': '75',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/2u3amabewoi38pen5u3yfslgtf0t',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/shoggoth.json',
  'variant': False,
  'xp': '3150'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 8,
               'damage': '1d12',
               'damage_bonus': None,
               'damage_description': '1d12',
               'description': 'Mordida',
               'text': '1 × Mordida +8 (1d12)',
               'times': 1,
               'weapon': False},
              {'ba': 8,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Tentáculos',
               'text': '2 × Tentáculos +8 (2d6)',
               'times': 2,
               'weapon': False}],
  'ca': '17',
  'concept': 'besta',
  'description': '  * **Deflexão**: toda magia lançada diretamente sobre o '
                 'Shoggoth (excetuando-se as magias em área) possui 1-2 '
                 'chances em 1d6 de não surtir efeitos.\n'
                 '\n'
                 '  * **Imunidades**: imune aos efeitos do frio, da '
                 'eletricidade, venenos, paralisação e encantamentos.\n'
                 '\n'
                 '  * **Alterar Forma**: pode assumir a forma de qualquer '
                 'criatura humanoide (M ou G). Um Shoggoth voltará a sua forma '
                 'normal caso seja morto.',
  'dv': '5',
  'dv_bonus': '+5',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Protoplasma amorfo, repleto de olhos terríveis, bocas ferozes e '
            'tentáculos pegajosos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 81},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 15},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday18.json',
              'page': 16}],
  'habitats': ['subterraneos', 'extraplanar'],
  'id': 'shoggoth-menor',
  'jp': '10',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Shoggoth Menor',
  'parent_monster_url': 'https://olddragon.com.br/monstros/shoggoth.json',
  'pv': '30',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/shoggoth-menor.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '235'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4 + Veneno',
               'description': 'Mordida',
               'text': '1 × Mordida +3 (1d4 + Veneno)',
               'times': 1,
               'weapon': False},
              {'ba': 3,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Espada curta',
               'text': '1 × Espada curta +3 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '13/16',
  'concept': 'humanoide',
  'description': 'Altos e delgados, têm uma postura nobre e prepotente apesar '
                 'da horrenda cabeça e corpo serpente. Usam poucas roupas '
                 '(quando usam), normalmente adaptadas ao clima de onde vivem '
                 'e alguns adereços tribais.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Lutam em grupos com suas espadas afiadas e ao sentirem uma '
                 'abertura na guarda do oponente, tentam morder com o intuito '
                 'de envenená-las.\n'
                 '\n'
                 '  * **Classe de armadura**: possuem CA 13 ou 16 quando usam '
                 'armadura de couro batido.\n'
                 '\n'
                 '  * **Veneno**: qualquer criatura mordida por um Sibilante '
                 'deve ser bem-sucedida em uma JPC para evitar os efeitos '
                 'paralisantes de seu veneno por 1d3 turnos. O veneno começa a '
                 'fazer efeito 1d6+2 rodadas após a mordida.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em clãs bem formados e com castas definidas. Adoram '
                 'deuses antigos e esquecidos, sacrificando suas vidas em um '
                 'instante, se isso for do agrado de suas divindades.\n'
                 '\n'
                 'São fanáticos e brutais, destruindo tudo o que se opuser aos '
                 'seus desejos.',
  'dv': '2',
  'dv_bonus': '+2',
  'encounters': '1d4',
  'encounters_lair': '2d10',
  'flavor': 'Cultistas que buscam trazer de volta os tempos ancestrais, na '
            'tentativa de despertar sua antiga divindade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 159},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 32},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['pantanos', 'desertos', 'florestas'],
  'id': 'sibilante',
  'jp': '5',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Sibilante',
  'picture': 'https://public.olddragon.com.br/lnbe8tknbe4bipdhvr1n6923ckwb',
  'pv': '12',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/h698h5f6ljgn1cti8e7eybco6zmt',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sibilante.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 7,
               'damage': '1d10',
               'damage_bonus': 4,
               'damage_description': '1d10+4 + Veneno',
               'description': 'Mordida',
               'text': '1 × Mordida +7 (1d10+4 + Veneno)',
               'times': 1,
               'weapon': False},
              {'ba': 7,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Especial',
               'description': 'Cuspida',
               'text': '1 × Cuspida +7 (Especial)',
               'times': 1,
               'weapon': False}],
  'ca': '18',
  'concept': 'humanoide',
  'description': 'Altos e delgados, têm uma postura nobre e prepotente apesar '
                 'da horrenda cabeça e corpo serpente. Usam poucas roupas '
                 '(quando usam), normalmente adaptadas ao clima de onde vivem '
                 'e alguns adereços tribais.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Lutam em grupos com suas espadas afiadas e ao sentirem uma '
                 'abertura na guarda do oponente, tentam morder com o intuito '
                 'de envenená-las.\n'
                 '\n'
                 '  * **Classe de armadura**: possuem CA 13 ou 16 quando usam '
                 'armadura de couro batido.\n'
                 '\n'
                 '  * **Veneno**: qualquer criatura mordida por um Sibilante '
                 'deve ser bem-sucedida em uma JPC para evitar os efeitos '
                 'paralisantes de seu veneno por 1d3 turnos. O veneno começa a '
                 'fazer efeito 1d6+2 rodadas após a mordida.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em clãs bem formados e com castas definidas. Adoram '
                 'deuses antigos e esquecidos, sacrificando suas vidas em um '
                 'instante, se isso for do agrado de suas divindades.\n'
                 '\n'
                 'São fanáticos e brutais, destruindo tudo o que se opuser aos '
                 'seus desejos.',
  'dv': '8',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '2d10',
  'flavor': 'Cultistas que buscam trazer de volta os tempos ancestrais, na '
            'tentativa de despertar sua antiga divindade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 159}],
  'habitats': ['pantanos', 'desertos', 'florestas'],
  'id': 'sibilante-abominacao',
  'jp': '10',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Sibilante Abominação',
  'parent_monster_url': 'https://olddragon.com.br/monstros/sibilante.json',
  'picture': 'https://public.olddragon.com.br/lnbe8tknbe4bipdhvr1n6923ckwb',
  'pv': '40',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/h698h5f6ljgn1cti8e7eybco6zmt',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sibilante-abominacao.json',
  'variant': True,
  'variant_modifications': ['Veneno: causa morte em 1d10 turnos em caso de '
                            'falha em um teste de JPC.',
                            'Agarrar: quando um ataque de mordida é '
                            'bem-sucedido, a cobra constritora agarra a '
                            'vítima, causando 2d4 de dano por rodada. Um teste '
                            'de força bem-sucedido livra o alvo da constrição.',
                            'Cegueira: causa cegueira por 1d6 rodadas nos '
                            'alvos atingidos que falharem em um teste de JPD.'],
  'xp': '695'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide',
  'flavor': 'Cultistas que buscam trazer de volta os tempos ancestrais, na '
            'tentativa de despertar sua antiga divindade.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 38}],
  'habitats': ['pantanos', 'desertos', 'florestas'],
  'id': 'sibilante-campeao',
  'name': 'Sibilante Campeão',
  'parent_monster_url': 'https://olddragon.com.br/monstros/sibilante.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sibilante-campeao.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Adaga',
               'text': '1 × Adaga +2 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': 'Altos e delgados, têm uma postura nobre e prepotente apesar '
                 'da horrenda cabeça e corpo serpente. Usam poucas roupas '
                 '(quando usam), normalmente adaptadas ao clima de onde vivem '
                 'e alguns adereços tribais.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Lutam em grupos com suas espadas afiadas e ao sentirem uma '
                 'abertura na guarda do oponente, tentam morder com o intuito '
                 'de envenená-las.\n'
                 '\n'
                 '  * **Classe de armadura**: possuem CA 13 ou 16 quando usam '
                 'armadura de couro batido.\n'
                 '\n'
                 '  * **Veneno**: qualquer criatura mordida por um Sibilante '
                 'deve ser bem-sucedida em uma JPC para evitar os efeitos '
                 'paralisantes de seu veneno por 1d3 turnos. O veneno começa a '
                 'fazer efeito 1d6+2 rodadas após a mordida.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em clãs bem formados e com castas definidas. Adoram '
                 'deuses antigos e esquecidos, sacrificando suas vidas em um '
                 'instante, se isso for do agrado de suas divindades.\n'
                 '\n'
                 'São fanáticos e brutais, destruindo tudo o que se opuser aos '
                 'seus desejos.',
  'dv': '3',
  'dv_bonus': '+2',
  'encounters': '1d4',
  'encounters_lair': '2d10',
  'flavor': 'Cultistas que buscam trazer de volta os tempos ancestrais, na '
            'tentativa de despertar sua antiga divindade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 159}],
  'habitats': ['pantanos', 'desertos', 'florestas'],
  'id': 'sibilante-cultista',
  'jp': '6',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Sibilante Cultista',
  'parent_monster_url': 'https://olddragon.com.br/monstros/sibilante.json',
  'picture': 'https://public.olddragon.com.br/lnbe8tknbe4bipdhvr1n6923ckwb',
  'pv': '17',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/h698h5f6ljgn1cti8e7eybco6zmt',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sibilante-cultista.json',
  'variant': True,
  'variant_modifications': ['Magia como Clérigo de 3º nível.'],
  'xp': '115'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '1d6',
               'damage_bonus': 4,
               'damage_description': '1d6+4',
               'description': 'Pancada',
               'text': '1 × Pancada +4 (1d6+4)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'humanoide',
  'description': '\n'
                 '\n'
                 '  * **Tática de Combate**: a cada rodada, um Sibilante '
                 'Guardião Pétreo pode executar um dos três ataques '
                 'especiais:\n'
                 '  * **Puxar Escudo**: o Guardião atrai magicamente um escudo '
                 'preso na parede diretamente para sua mão, melhorando sua CA '
                 'em 1. O voo do escudo causa 1d6 de dano se atingir algum '
                 'oponente que esteja no caminho.\n'
                 '  * **Saltar e Atacar**: o Guardião salta no ar e ataca um '
                 'alvo a até 6 metros de distância. Ele não cairá sobre os '
                 'alvos, mas qualquer criatura adjacente ao local onde ele '
                 'cair recebe 1d4 de dano adicional e cai no chão. Este dano '
                 'adicional e a queda podem ser evitados completamente por uma '
                 'JPD bem-sucedida.\n'
                 '  * **Corte Gêmeo**: o Guardião golpeia dois alvos com sua '
                 'espada em um mesmo ataque. Os alvos devem estar engajados em '
                 'combate e próximos entre si. O Guardião realiza uma única '
                 'jogada de ataque contra os dois CA, causando, se '
                 'bem-sucedido, 1d8+4 pontos em cada alvo atingido.\n'
                 '\n',
  'dv': '6',
  'dv_bonus': '',
  'encounters': None,
  'encounters_lair': None,
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/tu2.json',
              'page': 43}],
  'habitats': [],
  'id': 'sibilante-guardiao-petreo',
  'jp': '6',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Sibilante Guardião Pétreo',
  'picture': None,
  'pv': '30',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sibilante-guardiao-petreo.json',
  'variant': False,
  'xp': '125'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Espada curta',
               'text': '1 × Espada curta +4 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Altos e delgados, têm uma postura nobre e prepotente apesar '
                 'da horrenda cabeça e corpo serpente. Usam poucas roupas '
                 '(quando usam), normalmente adaptadas ao clima de onde vivem '
                 'e alguns adereços tribais.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Lutam em grupos com suas espadas afiadas e ao sentirem uma '
                 'abertura na guarda do oponente, tentam morder com o intuito '
                 'de envenená-las.\n'
                 '\n'
                 '  * **Classe de armadura**: possuem CA 13 ou 16 quando usam '
                 'armadura de couro batido.\n'
                 '\n'
                 '  * **Veneno**: qualquer criatura mordida por um Sibilante '
                 'deve ser bem-sucedida em uma JPC para evitar os efeitos '
                 'paralisantes de seu veneno por 1d3 turnos. O veneno começa a '
                 'fazer efeito 1d6+2 rodadas após a mordida.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em clãs bem formados e com castas definidas. Adoram '
                 'deuses antigos e esquecidos, sacrificando suas vidas em um '
                 'instante, se isso for do agrado de suas divindades.\n'
                 '\n'
                 'São fanáticos e brutais, destruindo tudo o que se opuser aos '
                 'seus desejos.',
  'dv': '3',
  'dv_bonus': '+2',
  'encounters': '1d4',
  'encounters_lair': '2d10',
  'flavor': 'Cultistas que buscam trazer de volta os tempos ancestrais, na '
            'tentativa de despertar sua antiga divindade.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 159}],
  'habitats': ['pantanos', 'desertos', 'florestas'],
  'id': 'sibilante-lider',
  'jp': '6',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Sibilante Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/sibilante.json',
  'picture': 'https://public.olddragon.com.br/lnbe8tknbe4bipdhvr1n6923ckwb',
  'pv': '17',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/h698h5f6ljgn1cti8e7eybco6zmt',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sibilante-lider.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '75'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Espada curta',
               'text': '1 × Espada curta +1 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': 'Estes soldados estão a serviço de algum senhor local ou '
                 'procurando algum trabalho remunerado para suas armas. '
                 'Fortemente armados e protegidos, são um grupo coeso em '
                 'combate e desafiador para enfrentar.\n'
                 '\n'
                 'Encontrados em grupos formados por: 2d6 soldados, onde 1 a '
                 'cada 5 é um Soldado Pesado atuando como um Sargento; 2d6 '
                 'Arqueiros; 1d6 Besteiros; 1d6 Piqueiros e 1d6 Cavaleiros '
                 'Leves.  A cada 20 homens, haverá adicionalmente um Cavaleiro '
                 'de Guerra onde um destes é o Líder do Grupo.\n'
                 '\n'
                 'Contratando: existe uma chance de 1-2 em 1d6 dos Mercenários '
                 'estarem disponíveis para contratação.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Custo**: 2PO por mês.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 76},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 188},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 5},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'soldado-leve-mercenario',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Soldado Leve (Mercenário)',
  'picture': 'https://public.olddragon.com.br/hysrm9x4j6l66mzz6ny46rxqjei4',
  'pv': '5',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/jgipoxwh8albycdbb1hrb032e8v1',
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/soldado-leve-mercenario.json',
  'variant': False,
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Espada curta',
               'text': '1 × Espada curta +1 (1d6+1)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': 'Homens poderosos (como Barões e Duques) ou mesmo membros da '
                 'Corte (como Conselheiros, Magistrados, Diplomatas e outros '
                 'funcionários do Lorde local). São encontrados também '
                 'residindo em seus castelos e fortalezas, ou em viagem '
                 'durante alguma missão especial.\n'
                 '\n'
                 'Encontrados: quando fora de seus castelos, 1d3 nobres são '
                 'encontrados, escoltados por 2d4 Soldados Leves e 1d4 '
                 'Cavaleiros Leves. Toda a escolta é liderada por um Cavaleiro '
                 'de Guerra que faz o papel de Comandante de Guerra.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Montado**: cavalo de guerra.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 189},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'soldado-leve-nobre',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Soldado Leve (Nobre)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/nobre.json',
  'picture': None,
  'pv': '5',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': 'vx3',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/soldado-leve-nobre.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 1,
               'damage': '1d8',
               'damage_bonus': 1,
               'damage_description': '1d8+1',
               'description': 'Espada longa',
               'text': '1 × Espada longa +1 (1d8+1)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'humanoide',
  'description': 'Estes soldados estão a serviço de algum senhor local ou '
                 'procurando algum trabalho remunerado para suas armas. '
                 'Fortemente armados e protegidos, são um grupo coeso em '
                 'combate e desafiador para enfrentar.\n'
                 '\n'
                 'Encontrados em grupos formados por: 2d6 soldados, onde 1 a '
                 'cada 5 é um Soldado Pesado atuando como um Sargento; 2d6 '
                 'Arqueiros; 1d6 Besteiros; 1d6 Piqueiros e 1d6 Cavaleiros '
                 'Leves.  A cada 20 homens, haverá adicionalmente um Cavaleiro '
                 'de Guerra onde um destes é o Líder do Grupo.\n'
                 '\n'
                 'Contratando: existe uma chance de 1-2 em 1d6 dos Mercenários '
                 'estarem disponíveis para contratação.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 '  * **Custo**: 2PO por mês.\n'
                 '\n',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '-',
  'encounters_lair': '-',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 76},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 188},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 5},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'soldado-pesado-sargento-mercenario',
  'jp': '5',
  'mo': 8,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Soldado Pesado, Sargento (Mercenário)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/soldado-leve-mercenario.json',
  'picture': 'https://public.olddragon.com.br/hysrm9x4j6l66mzz6ny46rxqjei4',
  'pv': '5',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/jgipoxwh8albycdbb1hrb032e8v1',
  'treasure': 'q',
  'treasure_lair': 'g',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/soldado-pesado-sargento-mercenario.json',
  'variant': True,
  'variant_modifications': ['Custo: 3 PO por mês.'],
  'xp': '15'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4 + Dreno',
               'description': 'Toque',
               'text': '1 × Toque +3 (1d4 + Dreno)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'besta',
  'description': 'Lembrando sombras comuns, não costumam ficar ligadas ao '
                 'chão, estando sempre flutuando.\n'
                 '\n'
                 'As mais antigas podem ter asas, que apesar de não serem '
                 'funcionais, são vistas como uma forma de alto status entre '
                 'sua raça.\n'
                 '\n'
                 'Ao contrário do que a sabedoria popular aponta, Sombras não '
                 'são mortos-vivos. São criaturas torturadas no Plano '
                 'Energético Negativo que assumiram esta forma deturpada após '
                 'milênios de dor e sofrimento.\n'
                 '\n'
                 'Não se sabe o que elas vieram fazer e nem como chegaram ao '
                 'Plano Material, mas é certo que não planejam ir embora.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Escondem-se em lugares estremamente escuros, atacando suas '
                 'vítimas de surpresa.\n'
                 '\n'
                 'Não possuem muita estratégia em combate, buscando drenar a '
                 'força dos inimigos para enfraquecê-las e atacando sem muitos '
                 'planos, podendo ainda fugir se julgarem necessário.\n'
                 '\n'
                 '  * **Surpresa**: surpreende o grupo em 1-5 em 1d6, caso não '
                 'esteja num ambiente totalmente iluminado e sem nenhuma '
                 'sombra.\n'
                 '\n'
                 '  * **Dreno**: seu ataque drena 1 ponto de Força '
                 'temporariamente. Um personagem reduzido a zero ou menos '
                 'pontos de Força morre imediatamente. Um ponto de Força '
                 'drenado é recuperado após 8 turnos.\n'
                 '\n'
                 '  * **Imunidades**: são imunes aos efeitos de encantamentos '
                 'ou de uma magia Sono, e a todo dano causado por armas não '
                 'mágicas.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Viajam em grupos parcamente organizados que andam livremente '
                 'por ruínas antigas, cemitérios e masmorras.\n'
                 '\n'
                 'As Sombras não têm líderes e, portanto, passam muito tempo '
                 'vagando sem rumo pelos arredores escolhidos atrás das suas '
                 'vítimas.\n'
                 '\n'
                 'Elas não precisam se alimentar, mas, mesmo assim, consumir a '
                 'força dos seres vivos lhes dá muito prazer e estímulo para '
                 'continuarem caçando.\n'
                 '\n'
                 'Os corpos originais das vítimas são destruídos quando mortos '
                 'por uma Sombra, virando instantaneamente pó. Já sua alma é '
                 'tocada pelo Plano Energético Negativo e transforma-se numa '
                 'nova Sombra.',
  'dv': '2',
  'dv_bonus': '+2',
  'encounters': '1d8',
  'encounters_lair': '1d12',
  'flavor': 'Monstros incorpóreos semelhantes a sombras que modificam suas '
            'formas para atacar seus inimigos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 69},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 178},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 160},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'sombra',
  'jp': '6',
  'mo': 12,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Sombra',
  'picture': 'https://public.olddragon.com.br/a16h3o4khzgyzabhci8dc0htdc0z',
  'pv': '12',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/mt2uwefbajj7r441990p2la38ujj',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sombra.json',
  'variant': False,
  'xp': '50'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Monstro inteligente e incorpóreo, com a capacidade de inflamar-se '
            'e semelhante a uma sombra.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 78}],
  'habitats': ['desertos'],
  'id': 'sombra-agmista',
  'name': 'Sombra Agmista',
  'size': 'pequeno',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sombra-agmista.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'besta',
  'flavor': 'Monstros incorpóreos semelhantes a sombras que modificam suas '
            'formas para atacar seus inimigos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 128}],
  'habitats': ['qualquer'],
  'id': 'sombra-ancestral',
  'name': 'Sombra Ancestral',
  'parent_monster_url': 'https://olddragon.com.br/monstros/sombra.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sombra-ancestral.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'humanoide_monstruoso',
  'flavor': 'Humanoides alados com menos de meio metro de altura.  Tímidos, '
            'mas extremamente curiosos, parecem ser movidos por seu senso de '
            'humor peculiar.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 78}],
  'habitats': ['desertos'],
  'id': 'sprites',
  'name': 'Sprites',
  'size': 'miudo',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sprites.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 2,
               'damage': '1d3',
               'damage_bonus': None,
               'damage_description': '1d3 + Dreno',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (1d3 + Dreno)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'besta',
  'description': 'Estas criaturas possuem uma cor avermelhada ou verde/marrom, '
                 'dependendo da região da qual vêm.\n'
                 '\n'
                 'São criaturas semelhantes a um amálgama de insetos e '
                 'pássaros que bebem o sangue de suas vítimas para se '
                 'alimentar.\n'
                 '\n'
                 'Possuem quatro pernas pequenas em forma de pinça que usam '
                 'para prender no pescoço de suas vítimas e injetar o bico '
                 'fico e perfurante.\n'
                 '\n'
                 'Os olhos e pés são amarelados. O bico é rosado na ponta e '
                 'cinza quando próximo da cabeça.\n'
                 '\n'
                 'Ficam gordas e mais lentas quando alimentadas, por isso voam '
                 'em bando e tentam se alimentar primeiro (deixando os outros '
                 'para trás).\n'
                 '\n'
                 '**Som**: zumbido de baixa frequência, ritmado, indo e '
                 'voltando.\n'
                 '\n'
                 '**Odor**: cânfora com leite há muito azedo.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam em grandes grupos, atingindo o alvo em vários pontos, '
                 'de forma que ele não consiga se livrar de todas ao mesmo '
                 'tempo.\n'
                 '\n'
                 '  * **Dreno de Sangue**: ao acertar o ataque, um Stirge '
                 'consegue drenar sangue de sua vítima causando '
                 'automaticamente 1d3 por rodada.  O Stirge apenas soltará a '
                 'vítima se esta tentar arrancá-lo ou se a vítima morrer.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Stirges vivem em grandes bandos, muitas vezes dentro de '
                 'árvores ou cavernas.\n'
                 '\n'
                 'O território de uma colônia Stirge se estende em um raio de '
                 'aproximadamente 2 quilômetros, que é abandonado assim que '
                 'conseguem afugentar todas as fontes de alimento da região.\n'
                 '\n'
                 'Colocam ovos em criaturas mortas, fazendo ninhos dentro da '
                 'carcaça.\n'
                 '\n'
                 'O eclodir dos ovos e o nascimento dos pequenos novos Stirges '
                 'é um "espetáculo" bem perturbador até para os de estômago '
                 'mais fortes e resistentes.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A saliva de um Stirge pode ser usada como remédio por alguns '
                 'povos para afinar o sangue.',
  'dv': '1',
  'dv_bonus': '',
  'encounters': '1d10',
  'encounters_lair': '3d12',
  'flavor': 'Imenso inseto do tamanho de um pássaro, com asas de morcego e um '
            'vertiginoso bico sugador de sangue.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/ja1.json',
              'page': 38},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 161},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday24.json',
              'page': 17},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['pantanos', 'florestas', 'subterraneos'],
  'id': 'stirge',
  'jp': '5',
  'mo': 9,
  'mv': 3,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Stirge',
  'picture': 'https://public.olddragon.com.br/bvhg760oxgyql7pcoac61080ash4',
  'pv': '5',
  'size': 'miudo',
  'thumb_picture': 'https://public.olddragon.com.br/mf2sk208o1skudtxgtlnx1bssqo4',
  'treasure': None,
  'treasure_lair': 'l',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/stirge.json',
  'variant': False,
  'xp': '25'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 6,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1',
               'description': 'Garras',
               'text': '2 × Garras +6 (1d4+1)',
               'times': 2,
               'weapon': False}],
  'ca': '18',
  'concept': 'humanoide_monstruoso',
  'description': 'De aparência luxuriosa, Súcubos podem se apresentar como '
                 'pessoas incrivelmente belas, ou em sua forma verdadeira com '
                 'asas de morcegos e olhos temíveis. Focam em indivíduos de '
                 'mente fraca e suscetíveis aos seus caprichos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'São espiãs, agentes infiltradas e coletoras de informaçõ '
                 'es. Suas táticas de açã o são sutis. Preferem manipular '
                 'um alvo para matá-lo em segurança, sem testemunhas, com '
                 'sua habilidade de Drenar Energia.\n'
                 '\n'
                 '* **Alterar Forma**: pode alterar sua própria forma '
                 'assumindo a de qualquer humanoide vivo de tamanho '
                 'semelhante, escondendo magicamente suas asas gigantes, '
                 'chifres, e demais características demoníacas.\n'
                 '\n'
                 '* **Drenar Energia**: ao beijar o alvo, pode drenar 1 nível '
                 'deste caso falhe numa JPC. Em caso de sucesso, o alvo '
                 'afastará a Súcubo e identificará seu propósito maligno. '
                 'Se falhar, o alvo terá 1 nível sugado por rodada até o '
                 'beijo ser interrompido. Uma criatura com ao menos 1 nível '
                 'drenado por uma Súcubo, envelhece 10 anos. Ao ter todos os '
                 'seus níveis drenados assim, morre imediatamente.\n'
                 '\n'
                 '* **Magias**: Enfeitiçar Pessoas, Clarividência, '
                 'Escuridão Contínua, Porta Dimensional e Percepçã o '
                 'Extrassensorial, como um Mago de 5ºnível.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'As Súcubos, geralmente femininas, e suas variações '
                 'comumente mais masculinas, os Íncubos, são os lordes do '
                 'Domínio da Luxúria, um dos 7 domínios do inferno '
                 'governado por Orcus, o Demônio Rei. São mais independentes '
                 'do que os outros seres infernais, mas jamais desobedecem a '
                 'uma ordem superior.\n'
                 '\n'
                 'São criaturas cautelosas em suas missões no Plano Material, '
                 'evitando ao máximo qualquer risco. Se em perigo, drenam a '
                 'energia de um alvo e retornam a segurança.\n'
                 '\n'
                 'Súcubos e Íncubos são criados por meios mágicos e '
                 'ritualísticos. Não se reproduzem entre si de forma a criar '
                 'mais demônios de sua mesma classe, porém, são capazes de '
                 'gerar prole com seres humanoides, que não são exatamente da '
                 'mesma espécie de nenhum de seus progenitores.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Não se conhece a utilidade de nenhuma parte da sua '
                 'carcaça, mas isso não impede que sábios e magos queiram '
                 'pesquisá-las e testá-las.',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1',
  'flavor': 'Demônio oriundo do Plano do Caos, um dos lacaios do plano '
            'infernal de Orcus. Vivem no domínio da Luxúria.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/tu2.json',
              'page': 46}],
  'habitats': ['extraplanar'],
  'id': 'sucubo',
  'jp': '9',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 15,
  'name': 'Súcubo',
  'picture': 'https://public.olddragon.com.br/1yn4mv1r9bvm8ehzlnk2qcwj14nd',
  'pv': '30',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/okp6ac5z84ggchq4qmqb6lxohy7j',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/sucubo.json',
  'variant': False,
  'xp': '480'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 12,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Chifres',
               'text': '2 × Chifres +12 (2d8)',
               'times': 2,
               'weapon': False},
              {'ba': 18,
               'damage': '2d12',
               'damage_bonus': None,
               'damage_description': '2d12',
               'description': 'Garras',
               'text': '2 × Garras +18 (2d12)',
               'times': 2,
               'weapon': False},
              {'ba': 12,
               'damage': '5d10',
               'damage_bonus': None,
               'damage_description': '5d10 + Engolir',
               'description': 'Mordida',
               'text': '1 × Mordida +12 (5d10 + Engolir)',
               'times': 1,
               'weapon': False},
              {'ba': 12,
               'damage': '3d10',
               'damage_bonus': None,
               'damage_description': '3d10',
               'description': 'Cauda',
               'text': '1 × Cauda +12 (3d10)',
               'times': 1,
               'weapon': False}],
  'ca': '26',
  'concept': 'besta',
  'description': 'O Tarrasque lembra um imenso dinossauro bípede, com chifres '
                 'e dentes perigosíssimos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Quando esta fera desperta, nada a impede de destruir tudo o '
                 'que vê pela frente. Sua inteligência é animal, e seu poder '
                 'dispensa qualquer necessidade de estratégia.\n'
                 '\n'
                 '  * **Engolir**: se um Tarrasque obtiver 30 ou mais no dano '
                 'de uma mordida, engolirá seu oponente matando-o '
                 'imediatamente, sem direito a nenhuma jogada de proteção.\n'
                 '\n'
                 '  * **Aura Aterrorizante**: afeta qualquer criatura com 3DV '
                 'ou menos, deixando-as paralisadas de pânico, sem qualquer '
                 'reação, até que o Terrasque saia da sua área de visão.  '
                 'Criaturas com 4DV até 6DV, fogem desesperadamente.  Nesta '
                 'fuga, há 1-5 chances em 1d6 de as criaturas soltarem '
                 'qualquer objeto que estiverem segurando. Criaturas com 7DV '
                 'ou mais possuem direito a uma JPS para negar o pavor e não '
                 'fugirem.\n'
                 '\n'
                 '  * **Imunidades**: o Tarrasque é imune aos efeitos do calor '
                 'e do fogo, e a qualquer forma de encantamento. Apenas armas '
                 'mágicas +1 ou superiores causam dano a um Tarrasque.\n'
                 '\n'
                 '  * **Refletir Magia**: a carapaça de um Tarrasque é capaz '
                 'de refletir todas as magias lançadas que tenham o Tarrasque '
                 'como alvo (magias que afetem uma área e não o Tarrasque como '
                 'alvo não são refletidas).Há ainda 1 chance em 1d6 da magia '
                 'retornar ao conjurador causando, nele mesmo os efeitos da '
                 'magia.\n'
                 '\n'
                 '  * **Regeneração**: o Tarrasque é capaz de regenerar 3 '
                 'pontos de vida a cada rodada (mesmo os de fogo/ácido). Esta '
                 'regeneração é capaz de reconstituir membros amputados em até '
                 '1d6 turnos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'O Tarrasque vive em um estado de sono que dura décadas, e '
                 'quando desperta, sua fome é tal que come tudo o que vê pela '
                 'frente. Sábios se dividem entre os que acreditam que ele '
                 'seja uma força da natureza para girar o ciclo da vida, ou '
                 'que ele seja uma cria de deuses destrutivos.  Há ainda os '
                 'que creem que ele seja a própria divindade presa no plano '
                 'material.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'O sangue do Tarrasque pode ser usado como ingrediente de '
                 'poções de regeneração.\n'
                 '\n'
                 'Tesouro\n'
                 '\n'
                 '10d6 Gemas de 1.000 PO',
  'dv': '75',
  'dv_bonus': '+200',
  'encounters': '1',
  'encounters_lair': '0',
  'flavor': 'A lenda faminta que despertará do seu sono para trilhar a morte e '
            'espalhar a destruição por onde passar.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 162},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'tarrasque',
  'jp': '19',
  'mo': 12,
  'mv': 15,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Tarrasque',
  'picture': 'https://public.olddragon.com.br/1wryyutdg494y5uhlruxgoxdsnmd',
  'pv': '575',
  'size': 'colossal',
  'thumb_picture': 'https://public.olddragon.com.br/18xwpahqrdz87u1pjivs7ylvfrpn',
  'treasure': 'q',
  'treasure_lair': 'especial',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/tarrasque.json',
  'variant': False,
  'xp': '24450'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 0,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma (Arma)',
               'times': 1,
               'weapon': True},
              {'ba': 1,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Garras',
               'text': '2 × Garras +1 (1d4)',
               'times': 2,
               'weapon': False}],
  'ca': '12',
  'concept': 'humanoide',
  'description': 'Taslois são pequenos humanoides com pele esverdeada e mãos e '
                 'pés com garras retráteis como as dos gatos.\n'
                 '\n'
                 'Vivem nas copas das árvores das florestas e disputam '
                 'ferrenhamente territórios com seus principais inimigos, os '
                 'Kobolds, de quem nutrem um ódio sem igual.\n'
                 '\n'
                 'Fisicamente, são esguios e delicados, com movimentos bem '
                 'demarcados e elegantes, assim como um pequeno felino.\n'
                 '\n'
                 'Possuem olhos com pupilas verticais, orelhas pontudas no '
                 'topo da cabeça e pelos espalhados por quase todo o corpo.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Taslois não se destacam pela sua ferocidade e habilidade em '
                 'combate, e sim pelas estratégias que costumam usar.\n'
                 '\n'
                 'Como são exímios escaladores, atacam sempre de terreno '
                 'elevado, de cima das árvores, arremessando armas como '
                 'azagaias e outros projéteis para dispersar seus inimigos e '
                 'roubar seus pertences.\n'
                 '\n'
                 '  * **Infravisão**: 18 metros.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Disputam territórios com os Kobolds na maioria das vezes e '
                 'usam seu vasto território para criar aranhas gigantes com '
                 'quem possuem uma relação quase simbiótica.\n'
                 '\n'
                 'Usam das suas teias para proteger seus covis e cidades nas '
                 'copas da árvores, e procuram jogar corpos de inimigos '
                 'derrotados nas teias para agradar às suas parceiras de '
                 'proteção.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Os olhos de um Tasloi costumam ser procurados como uma '
                 'iguaria dos povos das selvas, pois podem ser petrificados '
                 'como um adorno de rara beleza devido suas íris '
                 'multicoloridas e belíssimas sob incidência da luz.',
  'dv': '½',
  'dv_bonus': '',
  'encounters': '4d4',
  'encounters_lair': '6d10',
  'flavor': 'Humanoides pequenos com leve aspecto de gatos. Inimigos mortais '
            'dos Kobolds, com quem disputam territórios.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 163},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas'],
  'id': 'tasloi',
  'jp': '4',
  'mo': 5,
  'mv': 6,
  'mvc': None,
  'mve': 9,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Tasloi',
  'picture': 'https://public.olddragon.com.br/o2eqyq7uau6uhpf9kvg3e03z5g64',
  'pv': '2',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/hk3jnnanspfz3s652267itjy8ow1',
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/tasloi.json',
  'variant': False,
  'xp': '5'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 0,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Mordidas',
               'text': '2 × Mordidas (1d4)',
               'times': 2,
               'weapon': False}],
  'ca': '11',
  'concept': 'humanoide',
  'description': '  * **Infravisão**: 18 metros.',
  'dv': '½',
  'dv_bonus': '',
  'encounters': '4d4',
  'encounters_lair': '6d10',
  'flavor': 'Humanoides pequenos e covardes que armam armadilhas para '
            'surpreenderem seus adversários.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday11.json',
              'page': 17}],
  'habitats': ['colinas', 'montanhas', 'subterraneos'],
  'id': 'teebo-o-kobold-civil',
  'jp': '4',
  'mo': 5,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Teebo, o Kobold Civil',
  'parent_monster_url': 'https://olddragon.com.br/monstros/kobold.json',
  'pv': '2',
  'size': 'pequeno',
  'treasure': 'p',
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/teebo-o-kobold-civil.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '5'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': '',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 31}],
  'habitats': [],
  'id': 'tentaculo-acido',
  'name': 'Tentáculo Ácido',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/tentaculo-acido.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 34}],
  'habitats': [],
  'id': 'tentaculo-acido-ancestral',
  'name': 'Tentáculo Ácido Ancestral',
  'parent_monster_url': 'https://olddragon.com.br/monstros/tentaculo-acido.json',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/tentaculo-acido-ancestral.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'animal',
  'flavor': '',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 37}],
  'habitats': [],
  'id': 'tentaculo-acido-superior',
  'name': 'Tentáculo Ácido Superior',
  'parent_monster_url': 'https://olddragon.com.br/monstros/tentaculo-acido.json',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/tentaculo-acido-superior.json',
  'variant': True},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'humanoide_monstruoso',
  'flavor': 'Maligno e temido, alimenta-se do cérebro de qualquer ser. '
            'Escraviza inimigos que atrapalhem os seus planos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday18.json',
              'page': 12}],
  'habitats': ['subterraneos'],
  'id': 'tfarcevol',
  'name': 'Tfarcevol',
  'parent_monster_url': 'https://olddragon.com.br/monstros/devorador-de-cerebro.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/tfarcevol.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d3',
               'damage_bonus': None,
               'damage_description': '1d3 + Paralisia',
               'description': 'Garras',
               'text': '2 × Garras +3 (1d3 + Paralisia)',
               'times': 2,
               'weapon': False},
              {'ba': 3,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma +3 (Arma)',
               'times': 1,
               'weapon': True}],
  'ca': '13/15',
  'concept': 'humanoide',
  'description': 'Apresentando características marcantes destas três raças, o '
                 'Thoul se destaca principalmente pelo rosto insano e feroz.  '
                 'Veste-se com trapos (quando se veste), sendo assexuados por '
                 'conta de sua criação mágica.\n'
                 '\n'
                 'Os Thouls possuem uma fisionomia muito próxima a dos '
                 'Hobgolins, mas com traços das outras raças. Seus cabelos e '
                 'dentes são mais próximos dos Ghouls, mas sua compleição '
                 'física lembra o porte mais forte dos Hobgoblins.\n'
                 '\n'
                 'Suas peles são relativamente sem pelos com um tom esverdeado '
                 'em vez da pele vermelhoescura ou laranja-avermelhada dos '
                 'Hobgoblins.  Seu cabelo tem textura pegajosa; seu nariz é '
                 'pequeno e muito diferente do focinho, sendo característico '
                 'dos Trolls.\n'
                 '\n'
                 '**Som**: arrastar pesado e descompassado sobre o chão.\n'
                 '\n'
                 '**Odor**: fezes, sangue seco e decomposição como o conteúdo '
                 'de um intestino recém-aberto.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam com suas garras para paralisar, enquanto os '
                 'companheiros usam lanças, espadas e martelos para destruir '
                 'os inimigos.\n'
                 '\n'
                 '  * **Classe de armadura**: Thouls possuem CA 13 ou 15 '
                 'quando usam armadura de couro.\n'
                 '\n'
                 '  * **Paralisia**: um alvo atingido por um Thoul deve ser '
                 'bem-sucedido em uma JPC ou ficará paralisado por até 2d4 '
                 'turnos. Elfos são imunes a habilidade de Paralisia de um '
                 'Thoul.\n'
                 '\n'
                 '  * **Regeneração**: um Thoul é capaz de regenerar 1 ponto '
                 'de vida a cada rodada.  Esta regeneração não é capaz de '
                 'reconstituir membros amputados. Um Thoul não é capaz de '
                 'regenerar nenhum dano causado por fogo ou ácido.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Criados por magos insanos, essas criaturas vivem em estado '
                 'paranoico de loucura, atacando tudo o que lhes for '
                 'ordenado.\n'
                 '\n'
                 'Frutos de magia, não aparentam velhice ou mesmo gênero. Não '
                 'vivem muito, seja pela duração da magia ou periculosidade de '
                 'seu estilo de vida.',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '1d6',
  'encounters_lair': '1d10',
  'flavor': 'Aberração digna da mente dos mais alucinados arcanos, misturando '
            'Trolls, Ghouls e Hobgoblins.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 164},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['montanhas', 'florestas', 'subterraneos'],
  'id': 'thoul',
  'jp': '6',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Thoul',
  'picture': 'https://public.olddragon.com.br/us28tjq9cwnpb15y8ktk3odrkwgo',
  'pv': '15',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/qanaf33d1m50b9pcdr9ik2167gbs',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/thoul.json',
  'variant': False,
  'xp': '75'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 9,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Mordida',
               'text': '1 × Mordida +9 (2d6)',
               'times': 1,
               'weapon': False},
              {'ba': 6,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Garras',
               'text': '2 × Garras +6 (1d6)',
               'times': 2,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1d3',
  'flavor': 'Vive em florestas de clima temperado e em montanhas isoladas. Não '
            'vive em grupos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 19},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas', 'montanhas'],
  'id': 'tigre',
  'jp': '8',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Tigre',
  'picture': None,
  'pv': '30',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/tigre.json',
  'variant': False,
  'xp': '270'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 9,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Mordida',
               'text': '1 × Mordida +9 (2d8)',
               'times': 1,
               'weapon': False},
              {'ba': 9,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Garras',
               'text': '2 × Garras +9 (1d8)',
               'times': 2,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Críticos Vorpais**: se obtiver um acerto crítico em '
                 'seu ataque, amputa um membro do alvo atacado. Uma JPD anula '
                 'a amputação\n'
                 '\n',
  'dv': '8',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1d3',
  'flavor': 'Esta versão monstruosa do Tigre é feroz e violenta. Vive em '
            'florestas e montanhas de regiões isoladas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 19},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas', 'montanhas'],
  'id': 'tigre-dente-de-sabre',
  'jp': '10',
  'mo': 7,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Tigre Dente-de-Sabre',
  'picture': None,
  'pv': '40',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/tigre-dente-de-sabre.json',
  'variant': False,
  'xp': '695'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 16,
               'damage': '6d6',
               'damage_bonus': None,
               'damage_description': '6d6',
               'description': 'Mordida',
               'text': '1 × Mordida +16 (6d6)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Engolir**: se um Tiranossauro obtiver um 20 natural em '
                 'seu teste de ataque, engolirá seu oponente. Um alvo engolido '
                 'pelo Tiranossauro morre imediatamente. Uma JPD impede que o '
                 'Tiranossauro engula o alvo atacado.\n'
                 '\n',
  'dv': '20',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1',
  'flavor': 'Este carnívoro bípede é a máquina de matar perfeita.  É conhecido '
            'como rei dos dinossauros.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 42},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': [],
  'id': 'tiranossauro',
  'jp': '15',
  'mo': 11,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Tiranossauro',
  'picture': 'https://public.olddragon.com.br/rcc651g1sbm6nmm1faymhycty9tl',
  'pv': '100',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/t1hjhz42dodoya9rnhodd6e31e1d',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/tiranossauro.json',
  'variant': False,
  'xp': '4825'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '2d4',
               'damage_bonus': 2,
               'damage_description': '2d4+2',
               'description': 'Pancada',
               'text': '1 × Pancada +4 (2d4+2)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide_monstruoso',
  'description': 'Um Traag é um humanoide grande, por volta de 2,5 metros, com '
                 'a pele azul e olhos vermelhos e redondos, vívidos e sempre '
                 'abertos por não possuírem pálpebras.  No lugar das orelhas, '
                 'possuem uma espécie de guelra. Seu corpo possui grafismos em '
                 'diferentes tons de azul. Um Traag nunca usa roupas e não '
                 'usam ferramentas ou armas e armaduras, ao menos no plano '
                 'material.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Como o objetivo dos Traags é obter conhecimento e levar para '
                 'seu covil onde compartilharão com todos os outros membros de '
                 'sua raça, eles não lutam até a morte. Se falharem num teste '
                 'de MO, abrirão uma fenda planar para seu plano original, '
                 'levando todo conhecimento adquirido em segurança.\n'
                 '\n'
                 '  * **Mente Coletiva**: os Traags compartilham a mesma mente '
                 'coletiva, compartilhando por todos os mesmos conhecimentos. '
                 'Desta forma, um Traag vai acumulando os saberes de todos os '
                 'membros da raça quase imediatamente.  Isso faz com que o '
                 'Traag receba, a cada rodada, um bônus de +1 nos seus ataques '
                 'e um bônus de +1 na sua classe de armadura, ambos '
                 'cumulativos.  Isso representa o compartilhamento de '
                 'conhecimento entre os Traags envolvidos no combate.\n'
                 '\n'
                 '  * **Imunidades**: a mente alienígena dos Traags não pode '
                 'ser compreendida por um mortal, fazendo com que eles sejam '
                 'totalmente imunes a qualquer efeito mental de encantamento '
                 'ou semelhante como ilusões, telepatia, etc.\n'
                 '\n'
                 '  * **Salto Planar**: dois Traags podem abrir uma fenda '
                 'planar e saltar de um plano para outro. Um Traag sozinho não '
                 'consegue realizar o Salto Planar.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Traags são uma espécie avançada mentalmente que dá extremo '
                 'valor ao conhecimento.\n'
                 '\n'
                 'Eles vivem provavelmente no plano astral onde sua grande '
                 'consciência coletiva os interliga e faz o compartilhamento '
                 'de conhecimento entre todos os Traags que estão interligados '
                 'durante longos períodos de meditação.\n'
                 '\n'
                 'Pouco se sabe se seu objetivo final já que Traags não usam '
                 'nenhum idioma conhecido para se comunicar e conversam entre '
                 'eles apenas de forma mental.',
  'dv': '3',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '0',
  'flavor': 'Possuem uma consciência coletiva, conectando todos os membros '
            'desta criatura viajante interplanar.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 165},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['extraplanar'],
  'id': 'traag',
  'jp': '7',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Traag',
  'picture': 'https://public.olddragon.com.br/721cqgrxvlokk2l0dqbx980dgh8r',
  'pv': '15',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/1pm5wzn9f5ftvev91c7sz574xidc',
  'treasure': None,
  'treasure_lair': 'u',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/traag.json',
  'variant': False,
  'xp': '95'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 8,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Pancadas',
               'text': '2 × Pancadas +8 (2d6)',
               'times': 2,
               'weapon': False}],
  'ca': '18',
  'concept': 'planta',
  'description': 'São árvores grandiosas e muito antigas, tão antigas quanto o '
                 'próprio tempo e a criação do plano material.\n'
                 '\n'
                 'Quase indistinguíveis de uma árvore comum em uma primeira '
                 'olhada mais desatenta.\n'
                 '\n'
                 'Possuem feições e membros primitivos, levemente humanoides, '
                 'como barbas semelhantes a folhagens, braços como troncos '
                 'secos e olhos feitos de seiva.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'A não ser para autodefesa, Treants normalmente não entram em '
                 'combate.\n'
                 '\n'
                 'Se o fazem, animam árvores para combaterem ao seu lado e, se '
                 'tiverem oportunidade, cercarão, arremessarão e pisotearão '
                 'seus inimigos.\n'
                 '\n'
                 '  * **Animar Plantas**: um Treant pode animar até duas '
                 'árvores a até 20 metros de distância.  Estas árvores lutam '
                 'como se fossem um Treant, com as mesmas estatísticas de '
                 'combate e com movimento 3.\n'
                 '\n'
                 '  * **Surpresa**: em florestas, surpreendem seus inimigos '
                 'com um resultado de 1 a 3 em 1d6.\n'
                 '\n'
                 '  * **Dano Estrutural**: um Treant é capaz de causar dano '
                 'estrutural a uma construção como se fosse um aríete.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Normalmente vivem em pequenas comunidades nas orlas das '
                 'florestas e bosques atuando como vigias e protetores das '
                 'partes mais profundas das florestas, agindo como uma espécie '
                 'de segurança, controlando tudo o que acontece.\n'
                 '\n'
                 'Uma floresta cuidada por Treants é estranhamente segura, '
                 'desde que eles não achem que o perigo é você.\n'
                 '\n'
                 'São intolerantes a Orcs, Goblins e procuram não se '
                 'relacionar abertamente com criaturas com vidas mais curtas, '
                 'notadamente os que vivam 500 anos ou menos por considerá-los '
                 'acelerados, frívolos e enfadonhos.\n'
                 '\n'
                 'Isentos, não interferem em nenhum assunto que não seja '
                 'apenas o da proteção de seu lar ou de seus companheiros.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'A lenha de um Treant é um ingrediente importante para a '
                 'forja de espadas inteligentes.',
  'dv': '8',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1d8',
  'flavor': 'Plantas antropomórficas que vivem nos ambientes silvestres '
            'protegendo suas florestas de invasores.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 85},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 166},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['planicies', 'colinas', 'florestas'],
  'id': 'treant',
  'jp': '8',
  'mo': 9,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Treant',
  'picture': 'https://public.olddragon.com.br/a42d5a3xfhjsmd1jwglegcy51v38',
  'pv': '40',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/vijfxm49t4ml4129xbq0u6yk486n',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/treant.json',
  'variant': False,
  'xp': '695'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 14,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'chifres',
               'text': '3 × chifres +14 (2d8)',
               'times': 3,
               'weapon': False}],
  'ca': '17',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Carga**: um Tricerátops pode atacar em carga.  Um '
                 'ataque de carga possui +2 no ataque, +2 no dano, mas causa '
                 'uma redução de 2 na CA.\n'
                 '\n',
  'dv': '16',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1d4',
  'flavor': 'Este encouraçado quadrúpede é dócil até precisar se defender, que '
            'é quando usa seus chifres em ataques mortais.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 78},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 42},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': [],
  'id': 'triceratops',
  'jp': '14',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Tricerátops',
  'picture': None,
  'pv': '80',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/triceratops.json',
  'variant': False,
  'xp': '3350'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (1d4)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Garra',
               'text': '1 × Garra +2 (1d4)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Arma',
               'description': 'Arma',
               'text': '1 × Arma +2 (Arma)',
               'times': 1,
               'weapon': True}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Lembram um pouco um Homem Lagarto, mas mais brutos, toscos, '
                 'parrudos, fortes e pouco desenvolvidos.\n'
                 '\n'
                 'Usam armas primitivas de materiais naturais próprios do '
                 'habitat onde vivem.\n'
                 '\n'
                 '**Som**: passos e arrastar sobre o solo.\n'
                 '\n'
                 '**Odor**: pungente, forte e não identificado.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Formam grupos de combate, tentando chegar perto de seus '
                 'inimigos para usar suas habilidades especiais.\n'
                 '\n'
                 'Caso consigam cercar o inimigo, ativam seu odor fétido, '
                 'abrangendo uma grande área.\n'
                 '\n'
                 '  * **Odor Fétido**: o Troglodita expele um óleo fétido em '
                 'sua própria pele. Qualquer um que se engajar em combate com '
                 'um Troglodita deverá ser bem-sucedido em uma JPC ou sofrerá '
                 'um modificador de -2 em todos os seus ataques.\n'
                 '\n'
                 '  * **Surpresa**: os Trogloditas conseguem alterar levemente '
                 'o tom da sua pele, permitindo que consigam surpreender seus '
                 'inimigos com um resultado de 1 a 4 em 1d6.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'São violentos e acreditam apenas na força para resolver as '
                 'coisas.\n'
                 '\n'
                 'Não plantam ou criam animais, vivendo da caça para o momento '
                 'e do saque em povoados.\n'
                 '\n'
                 'São detestados por muitas raças, mas, em especial, pelos '
                 'Homens Lagartos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'As glândulas de odor de um Troglodita podem ser retiradas '
                 'para a criação de repelentes de insetos.',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '1d8',
  'encounters_lair': '5d8',
  'flavor': 'Humanoides reptilianos conhecidos pela sua ferocidade em combate '
            'e pelo ódio que possuem dos humanos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 68},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 167},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['montanhas', 'subterraneos'],
  'id': 'troglodita',
  'jp': '5',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Troglodita',
  'picture': 'https://public.olddragon.com.br/hxly6nqqscrd8b7mib841otmdozs',
  'pv': '10',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/j9nul7if0b5dwddnqxcwhh7rkfa1',
  'treasure': None,
  'treasure_lair': 'a',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/troglodita.json',
  'variant': False,
  'xp': '35'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1',
               'description': 'Lança',
               'text': '1 × Lança +4 (1d6+1)',
               'times': 1,
               'weapon': False},
              {'ba': 4,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1',
               'description': 'Garras',
               'text': '2 × Garras +4 (1d4+1)',
               'times': 2,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': 'Lembram um pouco um Homem Lagarto, mas mais brutos, toscos, '
                 'parrudos, fortes e pouco desenvolvidos.\n'
                 '\n'
                 'Usam armas primitivas de materiais naturais próprios do '
                 'habitat onde vivem.\n'
                 '\n'
                 '**Som**: passos e arrastar sobre o solo.\n'
                 '\n'
                 '**Odor**: pungente, forte e não identificado.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Formam grupos de combate, tentando chegar perto de seus '
                 'inimigos para usar suas habilidades especiais.\n'
                 '\n'
                 'Caso consigam cercar o inimigo, ativam seu odor fétido, '
                 'abrangendo uma grande área.\n'
                 '\n'
                 '  * **Odor Fétido**: o Troglodita expele um óleo fétido em '
                 'sua própria pele. Qualquer um que se engajar em combate com '
                 'um Troglodita deverá ser bem-sucedido em uma JPC ou sofrerá '
                 'um modificador de -2 em todos os seus ataques.\n'
                 '\n'
                 '  * **Surpresa**: os Trogloditas conseguem alterar levemente '
                 'o tom da sua pele, permitindo que consigam surpreender seus '
                 'inimigos com um resultado de 1 a 4 em 1d6.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'São violentos e acreditam apenas na força para resolver as '
                 'coisas.\n'
                 '\n'
                 'Não plantam ou criam animais, vivendo da caça para o momento '
                 'e do saque em povoados.\n'
                 '\n'
                 'São detestados por muitas raças, mas, em especial, pelos '
                 'Homens Lagartos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'As glândulas de odor de um Troglodita podem ser retiradas '
                 'para a criação de repelentes de insetos.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1d8',
  'encounters_lair': '5d8',
  'flavor': 'Humanoides reptilianos conhecidos pela sua ferocidade em combate '
            'e pelo ódio que possuem dos humanos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 167}],
  'habitats': ['montanhas', 'subterraneos'],
  'id': 'troglodita-lider',
  'jp': '6',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Troglodita Líder',
  'parent_monster_url': 'https://olddragon.com.br/monstros/troglodita.json',
  'picture': 'https://public.olddragon.com.br/hxly6nqqscrd8b7mib841otmdozs',
  'pv': '20',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/j9nul7if0b5dwddnqxcwhh7rkfa1',
  'treasure': None,
  'treasure_lair': 'a',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/troglodita-lider.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '125'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Clava',
               'text': '2 × Clava +2 (1d6)',
               'times': 2,
               'weapon': False}],
  'ca': '13',
  'concept': 'humanoide',
  'description': 'Lembram um pouco um Homem Lagarto, mas mais brutos, toscos, '
                 'parrudos, fortes e pouco desenvolvidos.\n'
                 '\n'
                 'Usam armas primitivas de materiais naturais próprios do '
                 'habitat onde vivem.\n'
                 '\n'
                 '**Som**: passos e arrastar sobre o solo.\n'
                 '\n'
                 '**Odor**: pungente, forte e não identificado.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Formam grupos de combate, tentando chegar perto de seus '
                 'inimigos para usar suas habilidades especiais.\n'
                 '\n'
                 'Caso consigam cercar o inimigo, ativam seu odor fétido, '
                 'abrangendo uma grande área.\n'
                 '\n'
                 '  * **Odor Fétido**: o Troglodita expele um óleo fétido em '
                 'sua própria pele. Qualquer um que se engajar em combate com '
                 'um Troglodita deverá ser bem-sucedido em uma JPC ou sofrerá '
                 'um modificador de -2 em todos os seus ataques.\n'
                 '\n'
                 '  * **Surpresa**: os Trogloditas conseguem alterar levemente '
                 'o tom da sua pele, permitindo que consigam surpreender seus '
                 'inimigos com um resultado de 1 a 4 em 1d6.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'São violentos e acreditam apenas na força para resolver as '
                 'coisas.\n'
                 '\n'
                 'Não plantam ou criam animais, vivendo da caça para o momento '
                 'e do saque em povoados.\n'
                 '\n'
                 'São detestados por muitas raças, mas, em especial, pelos '
                 'Homens Lagartos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'As glândulas de odor de um Troglodita podem ser retiradas '
                 'para a criação de repelentes de insetos.',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '1d8',
  'encounters_lair': '5d8',
  'flavor': 'Humanoides reptilianos conhecidos pela sua ferocidade em combate '
            'e pelo ódio que possuem dos humanos.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 86},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 167}],
  'habitats': ['montanhas', 'subterraneos'],
  'id': 'troglodita-xama',
  'jp': '5',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Troglodita Xamã',
  'parent_monster_url': 'https://olddragon.com.br/monstros/troglodita.json',
  'picture': 'https://public.olddragon.com.br/hxly6nqqscrd8b7mib841otmdozs',
  'pv': '10',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/j9nul7if0b5dwddnqxcwhh7rkfa1',
  'treasure': None,
  'treasure_lair': 'a',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/troglodita-xama.json',
  'variant': True,
  'variant_modifications': ['Magia como Clérigo de 2º nível.'],
  'xp': '50'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 6,
               'damage': '2d6',
               'damage_bonus': 4,
               'damage_description': '2d6+4',
               'description': 'Mordida',
               'text': '1 × Mordida +6 (2d6+4)',
               'times': 1,
               'weapon': False},
              {'ba': 6,
               'damage': '1d4',
               'damage_bonus': 4,
               'damage_description': '1d4+4',
               'description': 'Garras',
               'text': '2 × Garras +6 (1d4+4)',
               'times': 2,
               'weapon': False}],
  'ca': '16',
  'concept': 'gigante',
  'description': 'Sua pele é escamosa e viscosa, mas de longe pode se parecer '
                 'com a casca de uma árvore.\n'
                 '\n'
                 'Seu nariz longo e olhos profundos são muito marcantes na '
                 'raça, assim como as mãos em formas de garras '
                 'desproporcionalmente grandes e ameaçadoras.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Pouco inteligentes, atacam quem estiver na frente e ao seu '
                 'alcance.\n'
                 '\n'
                 'Se perceberem algum, tentarão destruir primeiro os inimigos '
                 'que tiverem poder de ataque à distância.\n'
                 '\n'
                 '  * **Regeneração**: um Troll é capaz de regenerar 1 ponto '
                 'de vida a cada rodada.  Esta regeneração é capaz de '
                 'reconstituir até mesmo membros amputados em até 1d6 dias. Um '
                 'Troll não é capaz de regenerar dano causado por fogo ou '
                 'ácido.\n'
                 '\n'
                 '  * **Falsa Morte**: Trolls reduzidos a 0 pontos de vida '
                 'retornam a vida em 2d6 rodadas, a não ser que seus restos '
                 'sejam queimados por fogo ou destruídos com ácido.\n'
                 '\n'
                 '  * **Medo de fogo e ácido**: na presença de fogo ou ácido, '
                 'o valor do Moral de um Troll é 8.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Trolls vivem solitários, pois até mesmo seus pares os acham '
                 'insuportáveis.\n'
                 '\n'
                 'São estúpidos e ferozes, de forma que é comum que um mate o '
                 'outro após procriarem.\n'
                 '\n'
                 'Os que não vivem em cavernas, e se aproximam de meio '
                 'urbanos, gostam de roubar coisas das pessoas que estão '
                 'passando, mesmo que não façam nada com os pertences '
                 'roubados.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'O sangue dos Trolls são ingredientes para poções de cura e '
                 'de regeneração.',
  'dv': '6',
  'dv_bonus': '+5',
  'encounters': '1d8',
  'encounters_lair': '1d8',
  'flavor': 'Horrendos e extremamente fortes com membros longos e uma '
            'desesperadora capacidade de regeneração.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 76},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 178},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 168},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'troll',
  'jp': '9',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Troll',
  'picture': 'https://public.olddragon.com.br/h98tt15ywyqi31slduery0cfe08h',
  'pv': '35',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/f0yhkvi040g4tbmxjwn2wwy5tlft',
  'treasure': None,
  'treasure_lair': 'd',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/troll.json',
  'variant': False,
  'xp': '305'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 9,
               'damage': '2d10',
               'damage_bonus': None,
               'damage_description': '2d10',
               'description': 'Mordida',
               'text': '1 × Mordida +9 (2d10)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '8',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1d4',
  'flavor': 'Grande tubarão branco, feroz, assassino e exímio caçador dos '
            'oceanos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 19},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['oceanos'],
  'id': 'tubarao',
  'jp': '10',
  'mo': 7,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': 12,
  'mvo': None,
  'mvv': None,
  'name': 'Tubarão',
  'picture': None,
  'pv': '40',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/tubarao.json',
  'variant': False,
  'xp': '650'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'besta',
  'flavor': 'Imensos lagartos-dragões do Deserto dos Crânios. Considerados '
            'sagrados pelos seguidores da Igreja Valedora e por parte da '
            'Caçada Sagrada.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 66}],
  'habitats': ['desertos'],
  'id': 'tunargar',
  'name': 'Tunárgar',
  'size': 'colossal',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/tunargar.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 6,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Mordida',
               'text': '1 × Mordida +6 (1d8)',
               'times': 1,
               'weapon': False},
              {'ba': 6,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Garras',
               'text': '2 × Garras +6 (1d8)',
               'times': 2,
               'weapon': False}],
  'ca': '15',
  'concept': 'besta',
  'description': 'Criatura poderosa com cabeça de coruja e corpo de urso, pode '
                 'apresentar grande variedade em tons de suas penas e pelos.  '
                 'Membros mais velhos tendem a ficar com a coloração mais '
                 'homogênea.\n'
                 '\n'
                 'São provavelmente uma criação arcana de uma mente louca, '
                 'misturando a crueldade sanguinário dos ataques das corujas '
                 'com a força física brutal dos ursos.\n'
                 '\n'
                 'O resultado é uma criatura sedenta por matar e terrivelmente '
                 'capaz em combate.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam por entre as árvores, às vezes até mesmo '
                 'derrubando-as.\n'
                 '\n'
                 'Usam de sua grande força para inutilizar rapidamente as '
                 'ameaças em um combate individual.\n'
                 '\n'
                 'Dão preferência por atacar as presas mais próximas e, '
                 'infelizmente para seus opositores, sempre lutando até a '
                 'morte.\n'
                 '\n'
                 '  * **Abraço**: o Urso-Coruja conseguirá agarrar seu alvo se '
                 'acertar os dois ataques com suas garras, causando 2d8 de '
                 'dano enquanto estiver agarrando o alvo.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'As fêmeas são muito protetoras com seus filhotes e ainda '
                 'mais violentas.\n'
                 '\n'
                 'Filhotes já foram roubados de seus pais para o uso em circos '
                 'e atrações, mas a retaliação por parte dos Urso-Coruja faz '
                 'com que este seja um negócio arriscado.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Ovos de Urso-Coruja valem um bom dinheiro no mercado.\n'
                 '\n'
                 'Nunca se soube de treinadores que tenham conseguido domar a '
                 'natureza feroz destas criaturas e, portanto, os magos '
                 'estudiosos são o público ideal para estes ovos.',
  'dv': '5',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Com o corpo forte de um urso e a cabeça de uma coruja, este '
            'predador vive nas florestas e ataca tudo o que encontrar.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 69},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 179},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 169},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 24},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas'],
  'id': 'urso-coruja',
  'jp': '8',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Urso-Coruja',
  'picture': 'https://public.olddragon.com.br/23q8dveq1mbtxwy4f0nu71gdjlm2',
  'pv': '25',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/mfmuayxjxojocxgx06uwdpt66mw2',
  'treasure': 'q',
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/urso-coruja.json',
  'variant': False,
  'xp': '175'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'besta',
  'flavor': 'Com o corpo forte de um urso e a cabeça de uma coruja, este '
            'predador vive nas florestas e ataca tudo o que encontrar.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 135}],
  'habitats': ['florestas'],
  'id': 'urso-coruja-ferido',
  'name': 'Urso-Coruja Ferido',
  'parent_monster_url': 'https://olddragon.com.br/monstros/urso-coruja.json',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/urso-coruja-ferido.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 5,
               'damage': '1d3',
               'damage_bonus': None,
               'damage_description': '1d3',
               'description': 'Garras',
               'text': '2 × Garras +5 (1d3)',
               'times': 2,
               'weapon': False},
              {'ba': 5,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Mordida',
               'text': '1 × Mordida +5 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Abraço**: o Urso conseguirá agarrar seu alvo se '
                 'acertar os dois ataques com suas garras, causando 2d8 de '
                 'dano enquanto estiver agarrando o alvo.\n'
                 '\n',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '1d4',
  'flavor': 'Vivem nas florestas temperadas se alimentando principalmente de '
            'peixes, frutas e raízes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 19},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas', 'montanhas'],
  'id': 'urso-negro',
  'jp': '6',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Urso Negro',
  'picture': None,
  'pv': '20',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/urso-negro.json',
  'variant': False,
  'xp': '125'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 6,
               'damage': '1d8',
               'damage_bonus': None,
               'damage_description': '1d8',
               'description': 'Mordida',
               'text': '1 × Mordida +6 (1d8)',
               'times': 1,
               'weapon': False},
              {'ba': 6,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Garras',
               'text': '2 × Garras +6 (1d4)',
               'times': 2,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Abraço**: se o Urso acertar os dois ataques com suas '
                 'garras, conseguirá agarrar seu alvo, causando 2d8 de dano '
                 'enquanto estiver agarrando o alvo.\n'
                 '\n',
  'dv': '5',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1d4',
  'flavor': 'Vivem em florestas e montanhas e se alimentam principalmente de '
            'carne.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 170},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 19},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['colinas', 'florestas', 'montanhas'],
  'id': 'urso-pardo',
  'jp': '8',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Urso Pardo',
  'picture': None,
  'pv': '25',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/urso-pardo.json',
  'variant': False,
  'xp': '175'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 6,
               'damage': '1d10',
               'damage_bonus': None,
               'damage_description': '1d10',
               'description': 'Mordida',
               'text': '1 × Mordida +6 (1d10)',
               'times': 1,
               'weapon': False},
              {'ba': 6,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Garras',
               'text': '2 × Garras +6 (1d6)',
               'times': 2,
               'weapon': False}],
  'ca': '14',
  'concept': 'animal',
  'description': '\n'
                 '\n'
                 '  * **Abraço**: se o Urso acertar os dois ataques com suas '
                 'garras, conseguirá agarrar seu alvo, causando 2d8 de dano '
                 'enquanto estiver agarrando o alvo.\n'
                 '\n',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1d2',
  'flavor': 'O maior dentre os Ursos, vivem em geleiras e climas polares. '
            'Agressivos contra invasores dos seus territórios. Alimentam-se de '
            'carne.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 19},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['geleiras'],
  'id': 'urso-polar',
  'jp': '8',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': 6,
  'mvo': None,
  'mvv': None,
  'name': 'Urso Polar',
  'picture': None,
  'pv': '30',
  'size': 'grande',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/urso-polar.json',
  'variant': False,
  'xp': '270'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 10,
               'damage': '1d10',
               'damage_bonus': None,
               'damage_description': '1d10 + Dreno',
               'description': 'Toque',
               'text': '1 × Toque +10 (1d10 + Dreno)',
               'times': 1,
               'weapon': False}],
  'ca': '18',
  'concept': 'morto_vivo',
  'description': 'Possuem aparência nobre e aristocrática, além uma beleza '
                 'encantadora. Sua pele é bem clara e, quando estão prontos '
                 'para se alimentar, possuem olhos vermelhos e presas '
                 'pontiagudas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Vampiros usam seus lacaios para amolecer os caçadores mais '
                 'audaciosos, deixando seus poderes para os que sobreviverem.\n'
                 '\n'
                 'Mantêm Ghouls e lobos em seus castelos, usando passagens '
                 'escondidas para atacar de surpresa e individualmente cada '
                 'oponente.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-Vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Imunidades**: além das imunidades comuns aos '
                 'mortos-vivos, Vampiros são feridos apenas por magia e armas '
                 'mágicas.  Vampiros também são imunes ao poder de Afastar '
                 'Mortos-Vivos de um Clérigo.\n'
                 '\n'
                 '  * **Regeneração**: um Vampiro é capaz de regenerar 2 '
                 'pontos de vida a cada rodada.  Esta regeneração é capaz de '
                 'reconstituir até mesmo membros amputados em 1d6 dias. Um '
                 'Vampiro não é capaz de regenerar dano causado por fogo ou '
                 'ácido. Além disso, ao atingir 0 pontos de vida, adquire '
                 'forma gasosa e voa até seu caixão, onde desperta ao '
                 'recuperar todos seus pontos de vida.\n'
                 '\n'
                 '  * **Olhar Encantador**: um Vampiro que olhar sua vítima '
                 'nos olhos por uma rodada é capaz de encantá-la, como se ela '
                 'estivesse sob o efeito de uma magia Encantar Pessoas.  Uma '
                 'JPS pode ser realizada para negar o encantamento com um '
                 'penalizador de 2.\n'
                 '\n'
                 '  * **Alterar forma**: um Vampiro pode, quantas vezes '
                 'desejar, gastar uma rodada completa para alterar sua forma '
                 'atual para uma das quatro formas possíveis: forma humanoide '
                 'padrão, lobo, morcego gigante ou forma gasosa.\n'
                 '\n'
                 '  * **Invocar Bestas**: enquanto estiver na sua forma '
                 'humanoide, e até 2 vezes ao dia, o Vampiro pode invocar '
                 'animais para lutarem ao seu lado: podem ser invocados: 1d10 '
                 '× 10 ratos; ou 5d4 ratos gigantes; ou 1d10 × 10 morcegos; ou '
                 '3d6 lobos.\n'
                 '\n'
                 '  * **Vulnerabilidades**: os Vampiros possuem uma série de '
                 'vulnerabilidades:\n'
                 '\n'
                 '**Água corrente**: um Vampiro não pode cruzar água corrente '
                 'como rios, lagos ou oceanos, a não ser adormecidos em seus '
                 'caixões ou usando pontes.\n'
                 '\n'
                 '**Alhos e símbolos sagrados**: mantêm o Vampiro afastado '
                 'pelo menos até 3 metros do portador de tais objetos.\n'
                 '\n'
                 '**Luz contínua**: causa cegueira nos Vampiros que passam a '
                 'atacar com penalidade de 4 nos seus ataques.\n'
                 '\n'
                 '**Luz solar e estacas cravadas no coração** do Vampiro '
                 'causam sua morte e destruição total, sem regeneração. O '
                 'Vampiro nestas condições deve realizar uma JPC por rodada. '
                 'Caso falhe, estará permanentemente morto.\n'
                 '\n'
                 '  * **Dreno**: seu ataque além do dano normal, drena 2 '
                 'níveis do alvo caso este não passe em uma JPC. Um alvo que '
                 'tenha todos os seus níveis drenados por um Vampiro retorna '
                 'como um Vampiro em 1d3 dias.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vampiros não se reproduzem, mas podem criar outros Vampiros '
                 'ao darem de seu próprio sangue para a vítima beber.\n'
                 '\n'
                 'Fazem isso muito raramente, pois criar um ser tão poderoso '
                 'pode ser arriscado.\n'
                 '\n'
                 'Às vezes, criam apenas versões incompletas de um vampiro, '
                 'chamado de Lacaio, usando-os como asseclas que ainda podem '
                 'entrar em contato com os fatores de sua fraqueza, como a luz '
                 'do sol e símbolos sagrados.',
  'dv': '9',
  'dv_bonus': '+10',
  'encounters': '1d4',
  'encounters_lair': '1d6',
  'flavor': 'Mortos-vivos poderosos. Percorrem a noite caçando suas presas '
            'para se alimentar de sangue.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 170},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'vampiro',
  'jp': '13',
  'mo': 12,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Vampiro',
  'picture': 'https://public.olddragon.com.br/41iqpvzoonp7a5ean52fvoqd837r',
  'pv': '55',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/eqrmzejqdioro5dfa9z4pre0pnm3',
  'treasure': 'v',
  'treasure_lair': 'f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/vampiro.json',
  'variant': False,
  'xp': '1025'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [],
  'ca': '-',
  'concept': 'morto_vivo',
  'description': 'Possuem aparência nobre e aristocrática, além uma beleza '
                 'encantadora. Sua pele é bem clara e, quando estão prontos '
                 'para se alimentar, possuem olhos vermelhos e presas '
                 'pontiagudas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Vampiros usam seus lacaios para amolecer os caçadores mais '
                 'audaciosos, deixando seus poderes para os que sobreviverem.\n'
                 '\n'
                 'Mantêm Ghouls e lobos em seus castelos, usando passagens '
                 'escondidas para atacar de surpresa e individualmente cada '
                 'oponente.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-Vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Imunidades**: além das imunidades comuns aos '
                 'mortos-vivos, Vampiros são feridos apenas por magia e armas '
                 'mágicas.  Vampiros também são imunes ao poder de Afastar '
                 'Mortos-Vivos de um Clérigo.\n'
                 '\n'
                 '  * **Regeneração**: um Vampiro é capaz de regenerar 2 '
                 'pontos de vida a cada rodada.  Esta regeneração é capaz de '
                 'reconstituir até mesmo membros amputados em 1d6 dias. Um '
                 'Vampiro não é capaz de regenerar dano causado por fogo ou '
                 'ácido. Além disso, ao atingir 0 pontos de vida, adquire '
                 'forma gasosa e voa até seu caixão, onde desperta ao '
                 'recuperar todos seus pontos de vida.\n'
                 '\n'
                 '  * **Olhar Encantador**: um Vampiro que olhar sua vítima '
                 'nos olhos por uma rodada é capaz de encantá-la, como se ela '
                 'estivesse sob o efeito de uma magia Encantar Pessoas.  Uma '
                 'JPS pode ser realizada para negar o encantamento com um '
                 'penalizador de 2.\n'
                 '\n'
                 '  * **Alterar forma**: um Vampiro pode, quantas vezes '
                 'desejar, gastar uma rodada completa para alterar sua forma '
                 'atual para uma das quatro formas possíveis: forma humanoide '
                 'padrão, lobo, morcego gigante ou forma gasosa.\n'
                 '\n'
                 '  * **Invocar Bestas**: enquanto estiver na sua forma '
                 'humanoide, e até 2 vezes ao dia, o Vampiro pode invocar '
                 'animais para lutarem ao seu lado: podem ser invocados: 1d10 '
                 '× 10 ratos; ou 5d4 ratos gigantes; ou 1d10 × 10 morcegos; ou '
                 '3d6 lobos.\n'
                 '\n'
                 '  * **Vulnerabilidades**: os Vampiros possuem uma série de '
                 'vulnerabilidades:\n'
                 '\n'
                 '**Água corrente**: um Vampiro não pode cruzar água corrente '
                 'como rios, lagos ou oceanos, a não ser adormecidos em seus '
                 'caixões ou usando pontes.\n'
                 '\n'
                 '**Alhos e símbolos sagrados**: mantêm o Vampiro afastado '
                 'pelo menos até 3 metros do portador de tais objetos.\n'
                 '\n'
                 '**Luz contínua**: causa cegueira nos Vampiros que passam a '
                 'atacar com penalidade de 4 nos seus ataques.\n'
                 '\n'
                 '**Luz solar e estacas cravadas no coração** do Vampiro '
                 'causam sua morte e destruição total, sem regeneração. O '
                 'Vampiro nestas condições deve realizar uma JPC por rodada. '
                 'Caso falhe, estará permanentemente morto.\n'
                 '\n'
                 '  * **Dreno**: seu ataque além do dano normal, drena 2 '
                 'níveis do alvo caso este não passe em uma JPC. Um alvo que '
                 'tenha todos os seus níveis drenados por um Vampiro retorna '
                 'como um Vampiro em 1d3 dias.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vampiros não se reproduzem, mas podem criar outros Vampiros '
                 'ao darem de seu próprio sangue para a vítima beber.\n'
                 '\n'
                 'Fazem isso muito raramente, pois criar um ser tão poderoso '
                 'pode ser arriscado.\n'
                 '\n'
                 'Às vezes, criam apenas versões incompletas de um vampiro, '
                 'chamado de Lacaio, usando-os como asseclas que ainda podem '
                 'entrar em contato com os fatores de sua fraqueza, como a luz '
                 'do sol e símbolos sagrados.',
  'dv': '9',
  'dv_bonus': '+10',
  'encounters': '1d4',
  'encounters_lair': '1d6',
  'flavor': 'Mortos-vivos poderosos. Percorrem a noite caçando suas presas '
            'para se alimentar de sangue.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 170}],
  'habitats': ['qualquer'],
  'id': 'vampiro-em-forma-gasosa',
  'jp': '11',
  'mo': 8,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 12,
  'name': 'Vampiro em Forma Gasosa',
  'parent_monster_url': 'https://olddragon.com.br/monstros/vampiro.json',
  'picture': 'https://public.olddragon.com.br/41iqpvzoonp7a5ean52fvoqd837r',
  'pv': '55',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/eqrmzejqdioro5dfa9z4pre0pnm3',
  'treasure': 'v',
  'treasure_lair': 'f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/vampiro-em-forma-gasosa.json',
  'variant': True,
  'variant_modifications': ['Não ataca na forma gasosa.',
                            'Imune à todas as armas.'],
  'xp': '1025'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 10,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4',
               'description': 'Mordida',
               'text': '1 × Mordida +10 (2d4)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'morto_vivo',
  'description': 'Possuem aparência nobre e aristocrática, além uma beleza '
                 'encantadora. Sua pele é bem clara e, quando estão prontos '
                 'para se alimentar, possuem olhos vermelhos e presas '
                 'pontiagudas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Vampiros usam seus lacaios para amolecer os caçadores mais '
                 'audaciosos, deixando seus poderes para os que sobreviverem.\n'
                 '\n'
                 'Mantêm Ghouls e lobos em seus castelos, usando passagens '
                 'escondidas para atacar de surpresa e individualmente cada '
                 'oponente.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-Vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Imunidades**: além das imunidades comuns aos '
                 'mortos-vivos, Vampiros são feridos apenas por magia e armas '
                 'mágicas.  Vampiros também são imunes ao poder de Afastar '
                 'Mortos-Vivos de um Clérigo.\n'
                 '\n'
                 '  * **Regeneração**: um Vampiro é capaz de regenerar 2 '
                 'pontos de vida a cada rodada.  Esta regeneração é capaz de '
                 'reconstituir até mesmo membros amputados em 1d6 dias. Um '
                 'Vampiro não é capaz de regenerar dano causado por fogo ou '
                 'ácido. Além disso, ao atingir 0 pontos de vida, adquire '
                 'forma gasosa e voa até seu caixão, onde desperta ao '
                 'recuperar todos seus pontos de vida.\n'
                 '\n'
                 '  * **Olhar Encantador**: um Vampiro que olhar sua vítima '
                 'nos olhos por uma rodada é capaz de encantá-la, como se ela '
                 'estivesse sob o efeito de uma magia Encantar Pessoas.  Uma '
                 'JPS pode ser realizada para negar o encantamento com um '
                 'penalizador de 2.\n'
                 '\n'
                 '  * **Alterar forma**: um Vampiro pode, quantas vezes '
                 'desejar, gastar uma rodada completa para alterar sua forma '
                 'atual para uma das quatro formas possíveis: forma humanoide '
                 'padrão, lobo, morcego gigante ou forma gasosa.\n'
                 '\n'
                 '  * **Invocar Bestas**: enquanto estiver na sua forma '
                 'humanoide, e até 2 vezes ao dia, o Vampiro pode invocar '
                 'animais para lutarem ao seu lado: podem ser invocados: 1d10 '
                 '× 10 ratos; ou 5d4 ratos gigantes; ou 1d10 × 10 morcegos; ou '
                 '3d6 lobos.\n'
                 '\n'
                 '  * **Vulnerabilidades**: os Vampiros possuem uma série de '
                 'vulnerabilidades:\n'
                 '\n'
                 '**Água corrente**: um Vampiro não pode cruzar água corrente '
                 'como rios, lagos ou oceanos, a não ser adormecidos em seus '
                 'caixões ou usando pontes.\n'
                 '\n'
                 '**Alhos e símbolos sagrados**: mantêm o Vampiro afastado '
                 'pelo menos até 3 metros do portador de tais objetos.\n'
                 '\n'
                 '**Luz contínua**: causa cegueira nos Vampiros que passam a '
                 'atacar com penalidade de 4 nos seus ataques.\n'
                 '\n'
                 '**Luz solar e estacas cravadas no coração** do Vampiro '
                 'causam sua morte e destruição total, sem regeneração. O '
                 'Vampiro nestas condições deve realizar uma JPC por rodada. '
                 'Caso falhe, estará permanentemente morto.\n'
                 '\n'
                 '  * **Dreno**: seu ataque além do dano normal, drena 2 '
                 'níveis do alvo caso este não passe em uma JPC. Um alvo que '
                 'tenha todos os seus níveis drenados por um Vampiro retorna '
                 'como um Vampiro em 1d3 dias.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vampiros não se reproduzem, mas podem criar outros Vampiros '
                 'ao darem de seu próprio sangue para a vítima beber.\n'
                 '\n'
                 'Fazem isso muito raramente, pois criar um ser tão poderoso '
                 'pode ser arriscado.\n'
                 '\n'
                 'Às vezes, criam apenas versões incompletas de um vampiro, '
                 'chamado de Lacaio, usando-os como asseclas que ainda podem '
                 'entrar em contato com os fatores de sua fraqueza, como a luz '
                 'do sol e símbolos sagrados.',
  'dv': '9',
  'dv_bonus': '+10',
  'encounters': '1d4',
  'encounters_lair': '1d6',
  'flavor': 'Mortos-vivos poderosos. Percorrem a noite caçando suas presas '
            'para se alimentar de sangue.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 170}],
  'habitats': ['qualquer'],
  'id': 'vampiro-lobo',
  'jp': '11',
  'mo': 11,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Vampiro Lobo',
  'parent_monster_url': 'https://olddragon.com.br/monstros/vampiro.json',
  'picture': 'https://public.olddragon.com.br/41iqpvzoonp7a5ean52fvoqd837r',
  'pv': '55',
  'size': 'pequeno',
  'thumb_picture': 'https://public.olddragon.com.br/eqrmzejqdioro5dfa9z4pre0pnm3',
  'treasure': 'v',
  'treasure_lair': 'f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/vampiro-lobo.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '1025'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 8,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Mordida',
               'text': '1 × Mordida +8 (1d4)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'morto_vivo',
  'description': 'Possuem aparência nobre e aristocrática, além uma beleza '
                 'encantadora. Sua pele é bem clara e, quando estão prontos '
                 'para se alimentar, possuem olhos vermelhos e presas '
                 'pontiagudas.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Vampiros usam seus lacaios para amolecer os caçadores mais '
                 'audaciosos, deixando seus poderes para os que sobreviverem.\n'
                 '\n'
                 'Mantêm Ghouls e lobos em seus castelos, usando passagens '
                 'escondidas para atacar de surpresa e individualmente cada '
                 'oponente.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-Vivo**: imune a frio, magias mentais de '
                 'manipulação, controle ou ilusão, ou demais formas mágicas de '
                 'interferir na mente de seres vivos. Sofre 1d6 de dano ácido '
                 'por frasco de água benta.\n'
                 '\n'
                 '  * **Imunidades**: além das imunidades comuns aos '
                 'mortos-vivos, Vampiros são feridos apenas por magia e armas '
                 'mágicas.  Vampiros também são imunes ao poder de Afastar '
                 'Mortos-Vivos de um Clérigo.\n'
                 '\n'
                 '  * **Regeneração**: um Vampiro é capaz de regenerar 2 '
                 'pontos de vida a cada rodada.  Esta regeneração é capaz de '
                 'reconstituir até mesmo membros amputados em 1d6 dias. Um '
                 'Vampiro não é capaz de regenerar dano causado por fogo ou '
                 'ácido. Além disso, ao atingir 0 pontos de vida, adquire '
                 'forma gasosa e voa até seu caixão, onde desperta ao '
                 'recuperar todos seus pontos de vida.\n'
                 '\n'
                 '  * **Olhar Encantador**: um Vampiro que olhar sua vítima '
                 'nos olhos por uma rodada é capaz de encantá-la, como se ela '
                 'estivesse sob o efeito de uma magia Encantar Pessoas.  Uma '
                 'JPS pode ser realizada para negar o encantamento com um '
                 'penalizador de 2.\n'
                 '\n'
                 '  * **Alterar forma**: um Vampiro pode, quantas vezes '
                 'desejar, gastar uma rodada completa para alterar sua forma '
                 'atual para uma das quatro formas possíveis: forma humanoide '
                 'padrão, lobo, morcego gigante ou forma gasosa.\n'
                 '\n'
                 '  * **Invocar Bestas**: enquanto estiver na sua forma '
                 'humanoide, e até 2 vezes ao dia, o Vampiro pode invocar '
                 'animais para lutarem ao seu lado: podem ser invocados: 1d10 '
                 '× 10 ratos; ou 5d4 ratos gigantes; ou 1d10 × 10 morcegos; ou '
                 '3d6 lobos.\n'
                 '\n'
                 '  * **Vulnerabilidades**: os Vampiros possuem uma série de '
                 'vulnerabilidades:\n'
                 '\n'
                 '**Água corrente**: um Vampiro não pode cruzar água corrente '
                 'como rios, lagos ou oceanos, a não ser adormecidos em seus '
                 'caixões ou usando pontes.\n'
                 '\n'
                 '**Alhos e símbolos sagrados**: mantêm o Vampiro afastado '
                 'pelo menos até 3 metros do portador de tais objetos.\n'
                 '\n'
                 '**Luz contínua**: causa cegueira nos Vampiros que passam a '
                 'atacar com penalidade de 4 nos seus ataques.\n'
                 '\n'
                 '**Luz solar e estacas cravadas no coração** do Vampiro '
                 'causam sua morte e destruição total, sem regeneração. O '
                 'Vampiro nestas condições deve realizar uma JPC por rodada. '
                 'Caso falhe, estará permanentemente morto.\n'
                 '\n'
                 '  * **Dreno**: seu ataque além do dano normal, drena 2 '
                 'níveis do alvo caso este não passe em uma JPC. Um alvo que '
                 'tenha todos os seus níveis drenados por um Vampiro retorna '
                 'como um Vampiro em 1d3 dias.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vampiros não se reproduzem, mas podem criar outros Vampiros '
                 'ao darem de seu próprio sangue para a vítima beber.\n'
                 '\n'
                 'Fazem isso muito raramente, pois criar um ser tão poderoso '
                 'pode ser arriscado.\n'
                 '\n'
                 'Às vezes, criam apenas versões incompletas de um vampiro, '
                 'chamado de Lacaio, usando-os como asseclas que ainda podem '
                 'entrar em contato com os fatores de sua fraqueza, como a luz '
                 'do sol e símbolos sagrados.',
  'dv': '9',
  'dv_bonus': '+10',
  'encounters': '1d4',
  'encounters_lair': '1d6',
  'flavor': 'Mortos-vivos poderosos. Percorrem a noite caçando suas presas '
            'para se alimentar de sangue.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 170}],
  'habitats': ['qualquer'],
  'id': 'vampiro-morcego',
  'jp': '11',
  'mo': 11,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Vampiro Morcego',
  'parent_monster_url': 'https://olddragon.com.br/monstros/vampiro.json',
  'picture': 'https://public.olddragon.com.br/41iqpvzoonp7a5ean52fvoqd837r',
  'pv': '55',
  'size': 'miudo',
  'thumb_picture': 'https://public.olddragon.com.br/eqrmzejqdioro5dfa9z4pre0pnm3',
  'treasure': 'v',
  'treasure_lair': 'f',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/vampiro-morcego.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '1025'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'constructo',
  'flavor': 'Constructo branco com articulações de esferas metálicas e espadas '
            'curtas no lugar dos braços.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 79}],
  'habitats': ['desertos'],
  'id': 'varredor',
  'name': 'Varredor',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/varredor.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Maça',
               'text': '1 × Maça +4 (1d6+2)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'humanoide',
  'description': '\n'
                 '\n'
                 '  * **Magias memorizadas**: Constrição, Imobilizar Pessoas, '
                 'Santuário, Silêncio, Convocar Insetos x2, Porta Dimensional, '
                 'Profanar, Escuridão.\n'
                 '\n',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '',
  'encounters_lair': '',
  'flavor': 'Um elfo mago, praticante de magia negra e seguidor de Arak-Takna. '
            'É o líder religioso da Seita do Abismo, em veneração ao buraco '
            'negro.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 14}],
  'habitats': ['qualquer'],
  'id': 'veldren-estagio-1',
  'jp': '9',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Veldren (Estágio 1)',
  'picture': None,
  'pv': '30',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/veldren-estagio-1.json',
  'variant': False,
  'xp': '740'},
 {'access': 'partial',
  'alignment': 'neutro',
  'attacks': [{'ba': 5,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Maça',
               'text': '1 × Maça +5 (1d8+2)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'humanoide',
  'description': '  * **Magias memorizadas**: Constrição, Imobilizar Pessoas, '
                 'Santuário, Silêncio, Convocar Insetos x2, Porta Dimensional, '
                 'Profanar, Escuridão.',
  'dv': '7',
  'dv_bonus': '',
  'encounters': '',
  'encounters_lair': '',
  'flavor': 'Um elfo mago, praticante de magia negra e seguidor de Arak-Takna. '
            'É o líder religioso da Seita do Abismo, em veneração ao buraco '
            'negro.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 14}],
  'habitats': ['qualquer'],
  'id': 'veldren-estagio-2',
  'jp': '9',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Veldren (Estágio 2)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/veldren-estagio-1.json',
  'pv': '35',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/veldren-estagio-2.json',
  'variant': True,
  'variant_modifications': ['Magias memorizadas: Constrição, Imobilizar '
                            'Pessoas, Santuário, Silêncio, Convocar Insetos '
                            'x2, Porta Dimensional, Profanar, Escuridão, '
                            'Proteção contra Alinhamento (Ordem).'],
  'xp': '1325'},
 {'access': 'partial',
  'alignment': 'neutro',
  'attacks': [{'ba': 6,
               'damage': '1d8',
               'damage_bonus': 2,
               'damage_description': '1d8+2',
               'description': 'Maça',
               'text': '1 × Maça +6 (1d8+2)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'humanoide',
  'description': '  * **Magias memorizadas**: Constrição, Imobilizar Pessoas, '
                 'Santuário, Silêncio, Convocar Insetos x2, Porta Dimensional, '
                 'Profanar, Escuridão.',
  'dv': '8',
  'dv_bonus': '+5',
  'encounters': '',
  'encounters_lair': '',
  'flavor': 'Um elfo mago, praticante de magia negra e seguidor de Arak-Takna. '
            'É o líder religioso da Seita do Abismo, em veneração ao buraco '
            'negro.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday13.json',
              'page': 14}],
  'habitats': ['qualquer'],
  'id': 'veldren-estagio-3',
  'jp': '10',
  'mo': 10,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Veldren (Estágio 3)',
  'parent_monster_url': 'https://olddragon.com.br/monstros/veldren-estagio-1.json',
  'pv': '45',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/veldren-estagio-3.json',
  'variant': True,
  'variant_modifications': ['Magias memorizadas: Constrição, Imobilizar '
                            'Pessoas, Santuário, Silêncio, Convocar Insetos '
                            'x2, Porta Dimensional, Profanar, Escuridão, Curar '
                            'Doenças, Consagrar.'],
  'xp': '2000'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4',
               'description': 'Garras',
               'text': '2 × Garras +4 (1d4)',
               'times': 2,
               'weapon': False},
              {'ba': 4,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Mordida',
               'text': '1 × Mordida +4 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '15',
  'concept': 'animal',
  'description': '\n\n\n\n',
  'dv': '3',
  'dv_bonus': '+3',
  'encounters': '0',
  'encounters_lair': '2d4',
  'flavor': 'Veloz e mortal, implacável na caça.  Vive em grupos nas colinas e '
            'planícies.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 42},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': [],
  'id': 'velociraptor',
  'jp': '6',
  'mo': 11,
  'mv': 15,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Velociraptor',
  'picture': None,
  'pv': '18',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/velociraptor.json',
  'variant': False,
  'xp': '75'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'gigante',
  'flavor': 'Criatura anelídea, gigantesca e prateada.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 79}],
  'habitats': ['desertos'],
  'id': 'verme-argenteo',
  'name': 'Verme Argênteo',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/verme-argenteo.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Paralisia',
               'description': 'Tentáculos',
               'text': '8 × Tentáculos +4 (Paralisia)',
               'times': 8,
               'weapon': False},
              {'ba': 4,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Mordida',
               'text': '1 × Mordida +4 (2d6)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'besta',
  'description': 'O Verme possui o corpo segmentado como a lagarta da '
                 'borboleta, e dois olhos compostos muito grandes e negros nas '
                 'laterais da cabeça.\n'
                 '\n'
                 'Sua carapaça parece revestida de um tipo de couro rígido e '
                 'levemente frio ao toque.\n'
                 '\n'
                 'Os tentáculos, que estão sempre em movimento como se fossem '
                 'antenas ou línguas, são escuros e úmidos, parecendo cobertos '
                 'com uma espécie de mucosa fina e delicada.\n'
                 '\n'
                 '**Som**: arrastar liso sobre o chão e como rangido de '
                 'madeira apodrecida.\n'
                 '\n'
                 '**Odor**: decomposição.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'O Verme da Carcaça é muito ligeiro devido as suas pernas, e '
                 'usa a habilidade de subir em paredes e nos tetos como forma '
                 'de obter vantagem em combate.\n'
                 '\n'
                 'Como sua alimentação é baseada em carcaças, o Verme usará '
                 'seus tentáculos para paralisar suas vítimas e só aí '
                 'atacá-las com mordidas para matá-las.\n'
                 '\n'
                 'Uma vez mortas, estas vítimas serão devoradas ao longo de '
                 'alguns dias.\n'
                 '\n'
                 '  * **Paralisia**: o alvo tocado por um dos 8 tentáculos do '
                 'Verme da Carcaça deve ser bem-sucedido em uma JPC ou ficará '
                 'paralisado por 2d4 turnos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Os Vermes da Carcaça são responsáveis por manterem os túneis '
                 'dos subterrâneos limpos de cadáveres e de corpos em '
                 'decomposição, e todo o seu ciclo de vida depende da '
                 'abundância ou não de alimento no seu habitat.\n'
                 '\n'
                 'Se há muito alimento, irão se reproduzir aceleradamente, '
                 'espalhando-se pelos corredores. Se há falta de alimentos, '
                 'praticarão o canibalismo nos indivíduos mais fracos ou '
                 'doentes.',
  'dv': '3',
  'dv_bonus': '+1',
  'encounters': '1d3',
  'encounters_lair': '1d3',
  'flavor': 'Verme necrófago que percorre todo o subterrâneo atrás de carcaças '
            'de animais e de monstros para se alimentar.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 172},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['subterraneos'],
  'id': 'verme-da-carcaca',
  'jp': '6',
  'mo': 9,
  'mv': 9,
  'mvc': None,
  'mve': 6,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Verme da Carcaça',
  'picture': 'https://public.olddragon.com.br/cy6p852aukoms1wme5xpaqhbn6of',
  'pv': '16',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/gxfags1jny0axd54wium5o37oav4',
  'treasure': None,
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/verme-da-carcaca.json',
  'variant': False,
  'xp': '95'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 8,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Mordidas',
               'text': '2 × Mordidas +8 (2d6)',
               'times': 2,
               'weapon': False}],
  'ca': '17',
  'concept': 'besta',
  'description': 'Parecendo um verme comum, difere por ser gigantesco, muito '
                 'mais feroz e por sua coloração característica.\n'
                 '\n'
                 'Seus dentes parecem pedras afiadas, e talvez sejam tão '
                 'fortes quanto.\n'
                 '\n'
                 '**Som**: pancadas surdas e indecifráveis.\n'
                 '\n'
                 '**Odor**: terra revolvida.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Ataca de surpresa, saindo do chão, ganhando vantagem sobre '
                 'as vítimas.\n'
                 '\n'
                 'Tenta engolir a vítima assim que possível, pois não gosta de '
                 'ter muito trabalho.\n'
                 '\n'
                 '  * **Senso Sísmico**: um Verme Escarlate pode sentir '
                 'vibrações no solo a até 30 metros de onde estiver. Ele '
                 'consegue identificar movimento, perceber a exata localização '
                 'de uma presa e identificar o tamanho e a quantidade de '
                 'inimigos na área.\n'
                 '\n'
                 '  * **Engolir**: se um Verme Escarlate obtiver um 20 natural '
                 'em seu teste de ataque, engolirá seu oponente. Um oponente '
                 'engolido sofre 2d4 de dano por rodada até conseguir sair do '
                 'estômago do Verme. Atacar dentro do sistema digestivo é '
                 'possível com penalidade de 4 no ataque.\n'
                 '\n'
                 '  * **Surpresa**: o Verme Escarlate pode atacar vindo '
                 'diretamente do chão, surpreendendo seus inimigos com um '
                 'resultado de 1 a 3 em 1d6.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Criaturas solitárias, se encontram com outros indivíduos da '
                 'espécie apenas para acasalar.\n'
                 '\n'
                 'Seus ovos demoram meses para eclodir, o que faz com que '
                 'muitos caçadores de recompensas cogitem pegar um ou dois '
                 'ovos de seu ninho.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'O estômago dos Vermes Escarlates são usados para triturar '
                 'cereais em algumas culturas.',
  'dv': '8',
  'dv_bonus': '',
  'encounters': '1d2',
  'encounters_lair': '1d4',
  'flavor': 'Verme com uma boca circular repleta de presas pontiagudas usadas '
            'para cavar buracos e mastigar rochas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 173},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['desertos', 'subterraneos'],
  'id': 'verme-escarlate',
  'jp': '6',
  'mo': 9,
  'mv': 6,
  'mvc': None,
  'mve': 3,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Verme Escarlate',
  'picture': 'https://public.olddragon.com.br/l5bjpl48gj4qq2urh4ia2xrtpazr',
  'pv': '40',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/0ab3tpk6aww0zzwmjcd034afrm7d',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/verme-escarlate.json',
  'variant': False,
  'xp': '740'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'besta',
  'flavor': 'Também chamado de Verme das Dunas, é uma criatura verminoide '
            'absurdamente poderosa e destruidora.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 68}],
  'habitats': ['desertos'],
  'id': 'verme-gorlok',
  'name': 'Verme Gorlok',
  'size': 'imenso',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/verme-gorlok.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'ordeiro',
  'concept': 'besta',
  'flavor': 'Assombroso e intimidador, com seu corpo feito inteiramente de '
            'vermes cinza-escuros contorcidos em constante movimento.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 70}],
  'habitats': ['qualquer'],
  'id': 'verme-que-anda-lorde-da-podridao',
  'name': 'Verme-Que-Anda, Lorde da Podridão',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/verme-que-anda-lorde-da-podridao.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4 + Veneno',
               'description': 'Ferrão',
               'text': '1 × Ferrão +4 (2d4 + Veneno)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'inseto',
  'description': '\n'
                 '\n'
                 '  * **Veneno**: causa a perda de 1d4+2 pontos de '
                 'Constituição em caso de falha em uma JPC.\n'
                 '\n',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Insetos ainda mais agressivos que as abelhas, criam tocas em '
            'florestas densas e nos subterrâneos',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 115},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas'],
  'id': 'vespa-gigante',
  'jp': '6',
  'mo': 8,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 18,
  'name': 'Vespa Gigante',
  'picture': None,
  'pv': '20',
  'size': 'medio',
  'thumb_picture': None,
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/vespa-gigante.json',
  'variant': False,
  'xp': '175'},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 6,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6',
               'description': 'Agarrar',
               'text': '1 × Agarrar +6 (2d6)',
               'times': 1,
               'weapon': False},
              {'ba': 6,
               'damage': '3d4',
               'damage_bonus': None,
               'damage_description': '3d4 + Veneno',
               'description': 'Mordidas',
               'text': '2 × Mordidas +6 (3d4 + Veneno)',
               'times': 2,
               'weapon': False}],
  'ca': '15',
  'concept': 'animal',
  'description': 'Iguais à versão de tamanho normal, essas criaturas têm o '
                 'mesmo padrão de cores e de desenho que suas “primas”.\n'
                 '\n'
                 'Mais inteligentes que as suas parentes de tamanho normal, '
                 'estas cobras chegam a viver mais de um século e, na maior '
                 'parte da vida, de modo solitário.\n'
                 '\n'
                 '**Som**: escorregar e arrastar áspero sobre o chão.\n'
                 '\n'
                 '**Odor**: pungente levemente apodrecido.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Apertam e comprimem o alvo até este ficar fraco e sem ar, '
                 'quebrando até algumas costelas se for preciso para mordê-lo '
                 'e engoli-lo em resistência.\n'
                 '\n'
                 'Se possível, gostam de se esconder na água para\n'
                 'atacar suas vítimas de surpresa.\n'
                 '\n'
                 '  * **Veneno**: a Víbora inocula um veneno fatal em sua '
                 'mordida. Uma JPC evita qualquer efeito deste veneno. Já uma '
                 'falha no teste, causa a morte em 1d4 turnos.\n'
                 '\n'
                 '  * **Agarrar**: um alvo atingido por um ataque de agarrar '
                 'que não passe em uma JPD será agarrado pela Víbora e sofrerá '
                 'a cada rodada 2d6 de dano por constrição. Um alvo agarrado '
                 'pode ser mordido automaticamente.\n'
                 '\n'
                 '  * **Montaria**: pode ser usada como montaria apta para '
                 'combater, sendo capaz de realizar ataques de investida se '
                 'ainda não engajada em combate, usar armaduras e atacar na '
                 'mesma rodada que seu condutor.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem em pântanos e regiões úmidas, aguardando a hora de '
                 'colocar seus ovos.\n'
                 '\n'
                 'Povos primitivos parecem conseguir dominar estas criaturas, '
                 'usando-as como montaria.\n'
                 '\n'
                 'Estas Víboras Gigantes são ocasionalmente mantidas por '
                 'cultos e grupos de assassinos. São usadas como meio de '
                 'convencimento e punição para opositores e traidores.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'O veneno das Víboras Gigantes é muito valorizado entre '
                 'guildas de assassinos.',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '1',
  'encounters_lair': '1d4',
  'flavor': 'Vivem espreitando junto a água o melhor momento de atacar sua '
            'próxima refeição.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 174},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/nc1.json',
              'page': 30},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['pantanos', 'subterraneos'],
  'id': 'vibora-gigante',
  'jp': '8',
  'mo': 11,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': 9,
  'mvo': None,
  'mvv': None,
  'name': 'Víbora Gigante',
  'picture': 'https://public.olddragon.com.br/gakmlxy5ycezgp6m5zuvki6umv0b',
  'pv': '30',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/zovtqmmfv83jbtmm4hodj1tbkfk0',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/vibora-gigante.json',
  'variant': False,
  'xp': '305'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 6,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4 + Esporo',
               'description': 'Tentáculos',
               'text': '2 × Tentáculos +6 (2d4 + Esporo)',
               'times': 2,
               'weapon': False}],
  'ca': '15',
  'concept': 'planta',
  'description': 'Parecem plantas normais, mas muito bonitas. Em uma primeira '
                 'análise, não há como diferenciá-las de um conjunto de flores '
                 'silvestres perfumadas e bonitas.\n'
                 '\n'
                 '**Som**: farfalhar de plantas e leves assobios desconexos.\n'
                 '\n'
                 '**Odor**: floral úmido.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atraem as vítimas para perto, esperando a chance de '
                 'infectá-las com seu esporo, usando para isso sua incrível '
                 'capacidade de imitar sons.\n'
                 '\n'
                 'Mesmo que percam a vida neste momento, sabem que cumpriram '
                 'seu objetivo de procriar.\n'
                 '\n'
                 '  * **Esporo**: qualquer alvo que receber dano de uma Vinha '
                 'Mortal tem uma chance de 1 em 1d6, cumulativa por ataque '
                 'recebido (dois ataques, 1-2 chances; três ataques, 1-3 '
                 'chances; etc.) de ser infectado por um esporo. Cada vítima '
                 'infectada deve ser bem-sucedida em uma JPC ou estes esporos '
                 'se desenvolverão dentro do hospedeiro, levando-o a morte em '
                 '1d6 horas. Uma magia de cura é capaz de interromper o '
                 'processo de desenvolvimento do esporo.\n'
                 '\n'
                 '  * **Regeneração**: uma Vinha Mortal é capaz de regenerar 1 '
                 'ponto de vida a cada rodada.  Apenas dano causado por fogo '
                 'ou ácido não pode ser regenerado.\n'
                 '\n'
                 '  * **Ventriloquismo**: usando suas flores, a Vinha consegue '
                 'reproduzir qualquer som que tenha ouvido anteriormente, como '
                 'gritos, chamados de socorro, conversas, sons de animais ou '
                 'de objetos para atrair vítimas.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Esperam o momento certo para infectar um hospedeiro, '
                 'procriando em busca de garantir sua existência e expansão da '
                 'atuação.\n'
                 '\n'
                 'Civilizações mais antigas acreditavam que as Vinhas Mortais '
                 'cantavam músicas vindas dos deuses malignos.',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1',
  'flavor': 'Trepadeira de cipós resistentes, folhagem densa e simpáticas '
            'flores alaranjadas de perfume doce.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 175},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas', 'subterraneos'],
  'id': 'vinha-mortal',
  'jp': '8',
  'mo': 8,
  'mv': 1,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Vinha Mortal',
  'picture': 'https://public.olddragon.com.br/wbnahg668sbw6894v22uz3f2q01i',
  'pv': '30',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/96mfouk31jgq8wz0jj6jp58tpth3',
  'treasure': None,
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/vinha-mortal.json',
  'variant': False,
  'xp': '305'},
 {'access': 'partial',
  'alignment': 'neutro',
  'attacks': [{'ba': 6,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4 + Afogar',
               'description': 'Tentáculos',
               'text': '2 × Tentáculos +6 (2d4 + Afogar)',
               'times': 2,
               'weapon': False}],
  'ca': '15',
  'concept': 'planta',
  'description': '  * **Esporo**: qualquer alvo que receber dano de uma Vinha '
                 'Mortal tem uma chance de 1 em 1d6, cumulativa por ataque '
                 'recebido (dois ataques, 1-2 chances; três ataques, 1-3 '
                 'chances; etc.) de ser infectado por um esporo. Cada vítima '
                 'infectada deve ser bem-sucedida em uma JPC ou estes esporos '
                 'se desenvolverão dentro do hospedeiro, levando-o a morte em '
                 '1d6 horas. Uma magia de cura é capaz de interromper o '
                 'processo de desenvolvimento do esporo.\n'
                 '\n'
                 '  * **Regeneração**: uma Vinha Mortal é capaz de regenerar 1 '
                 'ponto de vida a cada rodada.  Apenas dano causado por fogo '
                 'ou ácido não pode ser regenerado.\n'
                 '\n'
                 '  * **Ventriloquismo**: usando suas flores, a Vinha consegue '
                 'reproduzir qualquer som que tenha ouvido anteriormente, como '
                 'gritos, chamados de socorro, conversas, sons de animais ou '
                 'de objetos para atrair vítimas.',
  'dv': '6',
  'dv_bonus': '',
  'encounters': '0',
  'encounters_lair': '1',
  'flavor': 'Trepadeira de cipós resistentes, folhagem densa e simpáticas '
            'flores alaranjadas de perfume doce.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday24.json',
              'page': 16}],
  'habitats': ['florestas', 'subterraneos'],
  'id': 'vinha-mortal-afogadora',
  'jp': '8',
  'mo': 8,
  'mv': 1,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Vinha Mortal Afogadora',
  'parent_monster_url': 'https://olddragon.com.br/monstros/vinha-mortal.json',
  'pv': '30',
  'size': 'imenso',
  'treasure': None,
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/vinha-mortal-afogadora.json',
  'variant': True,
  'variant_modifications': ['Afogar: quando acerta um ataque, o alvo deve ser '
                            'bem-sucedido em uma JPC ou será forçado contra a '
                            'água lamacenta, afogando-se (ver página 69 do '
                            'Livro I: Regras Básicas).'],
  'xp': '305'},
 {'access': 'partial',
  'alignment': 'neutro',
  'attacks': [{'ba': 9,
               'damage': '2d6',
               'damage_bonus': None,
               'damage_description': '2d6 + Esporo',
               'description': 'Tentáculos',
               'text': '3 × Tentáculos +9 (2d6 + Esporo)',
               'times': 3,
               'weapon': False}],
  'ca': '16',
  'concept': 'planta',
  'description': '  * **Esporo**: qualquer alvo que receber dano de uma Vinha '
                 'Mortal tem uma chance de 1 em 1d6, cumulativa por ataque '
                 'recebido (dois ataques, 1-2 chances; três ataques, 1-3 '
                 'chances; etc.) de ser infectado por um esporo. Cada vítima '
                 'infectada deve ser bem-sucedida em uma JPC ou estes esporos '
                 'se desenvolverão dentro do hospedeiro, levando-o a morte em '
                 '1d6 horas. Uma magia de cura é capaz de interromper o '
                 'processo de desenvolvimento do esporo.\n'
                 '\n'
                 '  * **Regeneração**: uma Vinha Mortal é capaz de regenerar 1 '
                 'ponto de vida a cada rodada.  Apenas dano causado por fogo '
                 'ou ácido não pode ser regenerado.\n'
                 '\n'
                 '  * **Ventriloquismo**: usando suas flores, a Vinha consegue '
                 'reproduzir qualquer som que tenha ouvido anteriormente, como '
                 'gritos, chamados de socorro, conversas, sons de animais ou '
                 'de objetos para atrair vítimas.',
  'dv': '9',
  'dv_bonus': '+5',
  'encounters': '0',
  'encounters_lair': '1',
  'flavor': 'Trepadeira de cipós resistentes, folhagem densa e simpáticas '
            'flores alaranjadas de perfume doce.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 21}],
  'habitats': ['florestas', 'subterraneos'],
  'id': 'vinha-mortal-mutante',
  'jp': '11',
  'mo': 10,
  'mv': 1,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Vinha Mortal Mutante',
  'parent_monster_url': 'https://olddragon.com.br/monstros/vinha-mortal.json',
  'pv': '50',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': 'b',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/vinha-mortal-mutante.json',
  'variant': True,
  'variant_modifications': ['Plantas retorcidas com a capacidade de imitar '
                            'sons conhecidos por suas presas.',
                            'Ventriloquismo aprimorado: acessando as memórias '
                            'da presa, a Vinha Mortal Mutante imita '
                            'perfeitamente a voz de alguém conhecido de sua '
                            'vítima.'],
  'xp': '925'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'gigante',
  'flavor': 'Os Voldas do Gelo são versões imensas, mais fortes e mais '
            'violentas do que seus parentes distantes e inimigos eternos, os '
            'Voldas das Montanhas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 72}],
  'habitats': ['geleiras'],
  'id': 'volda-do-gelo',
  'name': 'Volda do Gelo',
  'size': 'imenso',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/volda-do-gelo.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 5,
               'damage': '2d4',
               'damage_bonus': None,
               'damage_description': '2d4',
               'description': 'Garra',
               'text': '1 × Garra +5 (2d4)',
               'times': 1,
               'weapon': False},
              {'ba': 5,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6',
               'description': 'Mordida',
               'text': '1 × Mordida +5 (1d6)',
               'times': 1,
               'weapon': False}],
  'ca': '12/17',
  'concept': 'besta',
  'description': 'De aparência feroz e porte assustador, o Worg se porta como '
                 'um lobo, mas em escala muito maior e perigosa.\n'
                 '\n'
                 'São uma ramificação antiga de uma linhagem de lobos '
                 'terríveis que atingiram um grau de inteligência e uma '
                 'tendência para o mal.\n'
                 '\n'
                 'Seu pelo varia do cinza ao marrom, ficando grisalhos '
                 'conforme envelhecem e suas presas são ainda maiores e '
                 'assustadoras do que as dos lobos normais.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Atacam com a matilha correndo e cercando os alvos e tentando '
                 'impedir quaisquer possibilidades de fuga.\n'
                 '\n'
                 'Os Worgs geralmente caçam apenas uma grande presa por semana '
                 'para se alimentarem, conseguindo ficar sem comida por dias '
                 'seguidos.\n'
                 '\n'
                 '  * **Classe de armadura**: Worgs possuem CA 12 ou 17 quando '
                 'usam armadura de placas.\n'
                 '\n'
                 '  * **Montaria**: pode ser usado como montaria apta para '
                 'combater, sendo capaz de realizar ataques de investida se '
                 'ainda não engajado em combate, usar armaduras e atacar na '
                 'mesma rodada que seu condutor.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Apesar de toda crueldade e ferocidade, quando os Worgs vivem '
                 'na natureza, são muito bem organizados e civilizados.\n'
                 '\n'
                 'Muitos são capturados principalmente por goblins para '
                 'servirem de montaria.\n'
                 '\n'
                 'Quando usados como montaria, seguem à risca as ordens do '
                 'cavaleiro adicionando ainda mais selvageria aos ataques '
                 'montados.\n'
                 '\n'
                 'Outras criaturas como Orcs e Gigantes malignos os treinam '
                 'para trabalharem como cães de guerra e atacarem seus '
                 'oponentes.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Presas de Worg são considerados por raças goblinoides como '
                 'objetos de sorte para quem as carrega junto ao pescoço.',
  'dv': '3',
  'dv_bonus': '+5',
  'encounters': '1d4',
  'encounters_lair': '2d4',
  'flavor': 'Lobo gigante cruel, agressivo e muito feroz, usado como montaria '
            'de guerra por criaturas caóticas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 176},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 23},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['florestas'],
  'id': 'worg',
  'jp': '6',
  'mo': 9,
  'mv': 18,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Worg',
  'picture': 'https://public.olddragon.com.br/kl4atbt4z4q3mty5totexp73b1hb',
  'pv': '20',
  'size': 'grande',
  'thumb_picture': 'https://public.olddragon.com.br/8sc7bi3uoi4io248h3dcd6jtf2du',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/worg.json',
  'variant': False,
  'xp': '75'},
 {'access': 'partial',
  'alignment': 'ordeiro',
  'attacks': [{'ba': 8,
               'damage': '2d8',
               'damage_bonus': 4,
               'damage_description': '2d8+4',
               'description': 'Garras',
               'text': '2 × Garras +8 (2d8+4)',
               'times': 2,
               'weapon': False},
              {'ba': 8,
               'damage': '1d10',
               'damage_bonus': 4,
               'damage_description': '1d10+4',
               'description': 'Mordida',
               'text': '1 × Mordida +8 (1d10+4)',
               'times': 1,
               'weapon': False}],
  'ca': '16',
  'concept': 'besta',
  'description': '  * **Atropelar**: um Worg Branco ainda não engajado em '
                 'combate pode usar a manobra de investida para causar o dobro '
                 'de dano com seu ataque.\n'
                 '  * **Dilacerar**: se o Worg Branco acertar os dois ataques '
                 'com suas garras, consegue dilecerar seu alvo, causando 1d8 '
                 'de dano adicional aos ataques e 1d6 de dano extra na próxima '
                 'rodada.\n'
                 '  * **Infravisão**: 18 metros.',
  'dv': '8',
  'dv_bonus': '+24',
  'encounters': '1d6+2',
  'encounters_lair': '2d6+2',
  'flavor': 'O Worg Branco é uma variação maior e mais brutal dos Worgs, os '
            'lobos com traços demoníacos usados como montaria pelos '
            'goblinóides de Kadur.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 74},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday15.json',
              'page': 22}],
  'habitats': ['geleiras', 'florestas'],
  'id': 'worg-branco',
  'jp': '10',
  'mo': 10,
  'mv': 12,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Worg Branco',
  'pv': '64',
  'size': 'grande',
  'treasure': None,
  'treasure_lair': 'c',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/worg-branco.json',
  'variant': False,
  'xp': '740'},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 7,
               'damage': '2d8',
               'damage_bonus': None,
               'damage_description': '2d8',
               'description': 'Mordida',
               'text': '1 × Mordida +7 (2d8)',
               'times': 1,
               'weapon': False},
              {'ba': 7,
               'damage': '1d6',
               'damage_bonus': None,
               'damage_description': '1d6 + Veneno',
               'description': 'Ferrão',
               'text': '1 × Ferrão +7 (1d6 + Veneno)',
               'times': 1,
               'weapon': False}],
  'ca': '17',
  'concept': 'dragao',
  'description': 'Apesar de se parecerem com os dragões, são menores e suas '
                 'escamas de tonalidades mais opacas e sem vida.\n'
                 '\n'
                 'Andam de forma pesada e desajeitada, mesmo que com certa '
                 'agilidade.\n'
                 '\n'
                 'Ao contrário do dragão, eles possuem apenas as patas '
                 'traseiras, usando-as da mesma forma que um pássaro caçador '
                 'faria.\n'
                 '\n'
                 'A ponta da cauda é um nó grosso de cartilagem do qual se '
                 'projeta um ferrão de 60 cm de comprimento, muito parecido '
                 'com o de um escorpião, totalmente recoberto por grossos '
                 'pelos lustrosos.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Tentam atacar voando, usando o ferrão para derrotar o '
                 'inimigo.\n'
                 '\n'
                 'Caso encontrem um cavaleiro, irão atacá-lo primeiro, pois '
                 'adoram a carne de cavalos.\n'
                 '\n'
                 'Se pousados no chão, morderão e usarão seu ferrão, atacando '
                 'os alvos mais próximos.\n'
                 '\n'
                 '  * **Veneno**: seu ferrão inocula veneno mortal, capaz de '
                 'matar em até 1d6+2 rodadas todos os que não passarem em um '
                 'teste de JPC.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Vivem solitários, criando ninhos apenas com seus '
                 'companheiros ocasionais e filhotes, passando quase todo o '
                 'resto do tempo caçando o que comer.\n'
                 '\n'
                 'Se tiverem ovos a proteger, o farão com extrema violência, '
                 'mas expulsarão os filhotes do ninho tão logo estes consigam '
                 'voar.\n'
                 '\n'
                 'Alguns Wyverns são conhecidos por trabalharem com Dragões '
                 'malignos. Normalmente, esses Dragões dominam completamente '
                 'os Wyverns menores e mais fracos.\n'
                 '\n'
                 '## Utilidades\n'
                 '\n'
                 'Sua carne é imprestável para consumo, devido o péssimo sabor '
                 'e textura após cozida.\n'
                 '\n'
                 'Não é conhecida uma forma viável de curtir seu couro para '
                 'uso em armaduras ou como vestimentas, e seu veneno é tão '
                 'volátil que perde seu poder tóxico quando extraído.\n'
                 '\n'
                 'Entretanto, os ossos ocos e quebradiços dos Wyverns são '
                 'usados por Magos como componentes de feitiços, pelos quais '
                 'eles pagarão um preço razoável.',
  'dv': '7',
  'dv_bonus': '',
  'encounters': '1d2',
  'encounters_lair': '1d6',
  'flavor': 'Estes lagartos alados possuem um mortífero ferrão na ponta da '
            'cauda e asas no lugar das patas dianteiras.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 177},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['montanhas', 'florestas'],
  'id': 'wyvern',
  'jp': '12',
  'mo': 9,
  'mv': None,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': 9,
  'name': 'Wyvern',
  'picture': 'https://public.olddragon.com.br/5apmoj0uz1kht9m5ykbn8c5lwxnb',
  'pv': '35',
  'size': 'imenso',
  'thumb_picture': 'https://public.olddragon.com.br/ri4vtenh3t5sou33z858xxl9irxv',
  'treasure': None,
  'treasure_lair': 'e',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/wyvern.json',
  'variant': False,
  'xp': '460'},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'besta',
  'flavor': 'Montarias do deserto. Parecem dromedários, mas com o dobro da '
            'altura, pelagem branca e longas barbas.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 79}],
  'habitats': ['desertos'],
  'id': 'yeldra',
  'name': 'Yeldra',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/yeldra.json',
  'variant': False},
 {'access': 'limited',
  'alignment': 'neutro',
  'concept': 'besta',
  'flavor': 'Os Yeldras da Noite podem atacar inimigos pela estrada com seus '
            'chifres curvados. Apesar da dificuldade extrema em domesticá-los, '
            'os ARKHImancistas o fizeram usando técnicas cruéis e feitiçaria.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 79}],
  'habitats': ['desertos'],
  'id': 'yeldra-da-noite',
  'name': 'Yeldra da Noite',
  'size': 'grande',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/yeldra-da-noite.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1 + Infecção',
               'description': 'Mordida',
               'text': '1 × Mordida +2 (1d4+1 + Infecção)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'Garra',
               'text': '1 × Garra +2 (1d6+2)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'morto_vivo',
  'description': 'Zumbis são criaturas lentas que servem a entidades malignas, '
                 'após serem reanimados de seus túmulos.\n'
                 '\n'
                 'Diferente dos Esqueletos, matam não apenas por ordem, mas '
                 'porque desejam devorar suas vítimas. Quando criados por meio '
                 'de animais, normalmente se encontram presos a coleiras, pois '
                 'a fome pelos vivos é enorme.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Usados como soldados, os Zumbis não costumam trabalhar com '
                 'criaturas vivas, pois são uma ameaça a sua segurança.\n'
                 '\n'
                 'O desejo incontrolável por devorar a carne dos vivos faz com '
                 'que sejam colocados com outros mortos-vivos ou criaturas '
                 'incorpóreas. Quando atacam, usam suas garras para puxar e '
                 'para tentar morder seus alvos, mas só conseguirão caso a '
                 'vítima esteja lutando sem armas ou com armas pequenas como '
                 'adagas.\n'
                 '\n'
                 '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a magias mentais de manipulação, '
                 'controle ou ilusão, ou demais formas mágicas de interferir '
                 'na mente de seres vivos. Sofre 1d6 de dano ácido por frasco '
                 'de água benta.\n'
                 '\n'
                 '  * **Lento**: sempre perde a Iniciativa num combate. Um '
                 'Zumbi sempre ataca por último.\n'
                 '\n'
                 '  * **Infecção**: personagens mordidos devem passar em uma '
                 'JPC ou se tornarão Zumbis em 1d4 dias, a não ser que uma '
                 'magia de Curar Doenças ou Curar Ferimentos seja usada no '
                 'alvo infectado.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral a '
                 'não ser quando sofrem o efeito de um Afastar Mortos-Vivos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Zumbis não se relacionam com nenhuma outra criatura, assim '
                 'como a maioria dos mortos-vivos que não possuem '
                 'inteligência.\n'
                 '\n'
                 'Quando estão em grupos grandes, devoram as vítimas até não '
                 'sobrar mais nada, por isso novos Zumbis surgem destes '
                 'ataques apenas quando o bando é menor e quando resta alguma '
                 'integridade no corpo para que possa se locomover e atacar.\n'
                 '\n'
                 'Além de Magos e Clérigos, existem casos em que energias '
                 'muito malignas acabam criando estes mortos-vivos de forma '
                 'espontânea pela simples emanação energética de planos '
                 'negativos.\n'
                 '\n'
                 '## Variações\n'
                 '\n'
                 'Os acontecimentos que desencadeiam a criação de um Zumbi '
                 'ainda estão longe de serem dominados pelos maiores '
                 'estudiosos da necromancia. Não sendo uma espécie única, os '
                 'Zumbis possuem as mais diferentes origens, comportamentos e '
                 'características, dando origem a diferentes tipos, com '
                 'propósitos e meios de agir únicos.\n'
                 '\n'
                 '### Zumbi do Sal\n'
                 '\n'
                 'Criado pela horrenda experiência de morrer de sede em '
                 'desertos. Desidratados e desesperados, perseguem os vivos '
                 'pela água em seus corpos.  São capazes de se transformarem '
                 'em criaturas realmente determinadas pelo seu objetivo único '
                 'de se hidratar a todo o custo.\n'
                 '\n'
                 'Mantém todas as estatísticas e habilidades de um Zumbi '
                 'comum, mas troca sua habilidade de Infecção pela habilidade '
                 'a seguir:\n'
                 '\n'
                 '  * **Sugar**: se o ataque de mordida for bem-sucedido, ele '
                 'agarra sua vítima e começa a sugar o seu sangue, causando '
                 '1d6 de dano por rodada até ser morta. A única forma de '
                 'soltá-lo da vítima é destruindo sua cabeça, reduzindo seus '
                 'PV a zero ou menos.\n'
                 '\n'
                 '### Zumbi Afogado\n'
                 '\n'
                 'Criado por pessoas afogadas. Seu corpo é inchado, gotejante '
                 'e deformado, como as vítimas de afogamentos.  Sua carne tem '
                 'aspecto de ter sido comida por peixes e outros seres do '
                 'mar.\n'
                 '\n'
                 'Mantém todas as estatísticas e habilidades de um Zumbi '
                 'comum, mas troca sua habilidade de Infecção pela habilidade '
                 'a seguir:\n'
                 '\n'
                 '  * **Explodir**: ao sofrer dano, há uma chance de 1 em 1d6 '
                 'do seu corpo estourar, espalhando em todos dentro de uma '
                 'área de 3m uma onda de dejetos pútridos e purulentos, '
                 'repletos de doenças e infecção. Um alvo atingido deve ser '
                 'bem-sucedido numa JPC ou sofrerá os efeitos do contágio, '
                 'deixando o doente com Constituição 1 durante 1d6 dias.  Há '
                 'uma chance de 1 em 1d6 do doente morrer.\n'
                 '\n'
                 '### Esporo-Zumbi\n'
                 '\n'
                 'Resultado imprevisível de mortos-vivos atacados por fungos '
                 'desconhecidos dos subterrâneos.\n'
                 '\n'
                 'Os esporos se desenvolvem nos corpos contaminados pelo ar ou '
                 'por alimentos e líquidos contaminados. Passam a controlar o '
                 'cérebros de seus hospedeiros, transformando-os em criaturas '
                 'assassinas e agressivas, que perseguem suas vítimas para '
                 'passar a infecção adiante.\n'
                 '\n'
                 'Possui diferentes habilidades à medida que a infecção cresce '
                 'e toma conta de seu corpo:\n'
                 '\n'
                 '  * **Infectado**: durante os primeiros dias da infecção e '
                 'por toda esta fase, o Esporo-Zumbi troca suas habilidades '
                 'Silencioso e Lento pela habilidade de Correr, tendo o '
                 'movimento de quando era vivo.\n'
                 '\n'
                 '  * **Fendido**: após os primeiros dias de infecção, seu '
                 'crânio fica fendido por vários fungos que brotam de seu '
                 'interior. Nesta fase, ele troca sua habilidade de Correr '
                 'pela habilidade de Perseguir, usando uma espécie de '
                 'ecolocalização para saber precisamente onde todo ser vivo '
                 'está num raio de 30m.\n'
                 '\n'
                 '  * **Rei**: aproximadamente um mês após a infecção, têm seu '
                 'corpo completamente tomado pelo fungo, tornando-se uma '
                 'máquina de propagar seus esporos. Durante um combate, todos '
                 'em até 9m de um Esporo-Zumbi Rei que receberem um ataque '
                 'bem-sucedido, possuem uma chance de 1 em 1d6 de serem '
                 'infectados pelos esporos, tornando-se um Infectado, '
                 'reiniciando todo o processo.',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '4d6',
  'flavor': 'Morto-vivo sem inteligência. Avança para cima de suas vítimas com '
            'o único intuito de destroçá-las com garras e dentes.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 71},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/lb1.json',
              'page': 179},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/lb3.json',
              'page': 178},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday12.json',
              'page': 22},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday17.json',
              'page': 22},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday24.json',
              'page': 18},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/srd.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'zumbi',
  'jp': '7',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Zumbi',
  'picture': 'https://public.olddragon.com.br/cz4xa87qz93imyvxgtmjrpst2zrk',
  'pv': '10',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/6yi5o3kte4bwdldij0z092zdsk4x',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/zumbi.json',
  'variant': False,
  'xp': '35'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Morto-vivo sem inteligência. Avança para cima de suas vítimas com '
            'o único intuito de destroçá-las com garras e dentes.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 113}],
  'habitats': ['qualquer'],
  'id': 'zumbi-antigo',
  'name': 'Zumbi Antigo',
  'parent_monster_url': 'https://olddragon.com.br/monstros/zumbi.json',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/zumbi-antigo.json',
  'variant': True},
 {'access': 'complete',
  'alignment': 'caotico',
  'attacks': [{'ba': 3,
               'damage': '1d4',
               'damage_bonus': None,
               'damage_description': '1d4 + Infecção',
               'description': 'Mordida',
               'text': '1 × Mordida +3 (1d4 + Infecção)',
               'times': 1,
               'weapon': False},
              {'ba': 2,
               'damage': None,
               'damage_bonus': None,
               'damage_description': 'Especial',
               'description': 'Garras',
               'text': '1 × Garras +2 (Especial)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'morto_vivo',
  'description': 'Estes Zumbis Canibais são mortosvivos famintos por cérebros. '
                 'Possuem corpos apodrecidos, aparentemente em avançado '
                 'estágio de decomposição, com larvas e fluidos esquisitos que '
                 'pendem de feridas abertas repletas de purulência.\n'
                 '\n'
                 '## Combate\n'
                 '\n'
                 'Nunca planejam nem possuem táticas. Se valem de bandos '
                 'numerosos que atacam em ondas constantes e avassaladoras.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a magias mentais de manipulação, '
                 'controle ou ilusão, ou formas mágicas de interferir na '
                 'mente. Sofre 1d6 de dano ácido por frasco de água benta.\n'
                 '  * **Lento**: sempre perde a Iniciativa num combate e '
                 'sempre ataca por último.\n'
                 '  * **Agarrar**: o Zumbi Canibal agarrará seu alvo se '
                 'acertar seu ataque com as as garras. Um alvo agarrado '
                 'realiza seus testes como difícil.\n'
                 '  * **Infecção**: personagens mordidos se tornarão Zumbis '
                 'Canibais em 1d4 dias ou assim que morrerem, a não ser que '
                 'uma magia de Curar Doenças seja usada no infectado.\n'
                 '  * **Persistente**: ao serem mortos, existe uma chance de '
                 '1-2 em 1d6 de retornarem e continuarem lutando. Apenas '
                 'destruindo sua cabeça ou os queimando isso pode ser '
                 'evitado.\n'
                 '  * **Ataque em ondas**: a cada nova rodada, existe uma '
                 'chance de 1-3 em 1d6 de uma nova onda onda de 2d6+4 '
                 'aparecerem.\n'
                 '  * **Corredor**: a cada nova onda, existe uma chance de 1-3 '
                 'em 1d6 de metade dos zumbis serem do tipo corredor com o '
                 'movimento 12.\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral a '
                 'não ser quando sofrem o efeito de um Afastar Mortos-Vivos.\n'
                 '\n'
                 '## Ecologia\n'
                 '\n'
                 'Dotados de uma inteligência predadora, que anima seus corpos '
                 'pútridos e os fazem vagar em bandos atrás da única coisa que '
                 'os motiva, atacar tudo aquilo que é vivo para alimentar sua '
                 'incessante fome de cérebros.',
  'dv': '½',
  'dv_bonus': '',
  'encounters': '2d6+4',
  'encounters_lair': None,
  'flavor': 'Versão ainda mais perigosa dos zumbis, que atacam suas vítimas '
            'atrás de cérebros espalhando medo e horror.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao.json',
              'page': 317},
             {'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/legiao-od2.json',
              'page': None}],
  'habitats': ['qualquer'],
  'id': 'zumbi-canibal',
  'jp': '4',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Zumbi Canibal',
  'picture': 'https://public.olddragon.com.br/4scc4otktmawkcmw2y6c85g0uuy1',
  'pv': '2',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/s1mssb35l3ot3zd0oykr70agvxkg',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/zumbi-canibal.json',
  'variant': False,
  'xp': '35'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Frutos de uma maldição contagiosa que surge quando um Possuído, '
            'um demônio encarnado, morre e apodrece em um corpo de água '
            'salgada ou doce.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/monstros-legiao.json',
              'page': 76}],
  'habitats': ['oceanos'],
  'id': 'zumbi-das-aguas',
  'name': 'Zumbi das Águas',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/zumbi-das-aguas.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 4,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2 + Puxar',
               'description': 'Corrente',
               'text': '1 × Corrente +4 (1d6+2 + Puxar)',
               'times': 1,
               'weapon': False},
              {'ba': 4,
               'damage': '1d4',
               'damage_bonus': 2,
               'damage_description': '1d4+2 + Dreno',
               'description': 'Mordida',
               'text': '1 × Mordida +4 (1d4+2 + Dreno)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'morto_vivo',
  'description': '\n'
                 '\n'
                 '  * **Cria da Escuridão**: Zumbis das Correntes são '
                 'extremamente sensíveis à luz e direcionam seus ataques '
                 'contra qualquer um que a carregue. Quando imersos em '
                 'escuridão total, causam o dobro de dano.\n'
                 '  * **Puxar**: o alvo deve passar em uma JPD para '
                 'esquivar-se de ser puxado para a escuridão.\n'
                 '  * **Morto-vivo**: imune a magias mentais de manipulação, '
                 'controle ou ilusão, ou demais formas mágicas de interferir '
                 'na mente de seres vivos. Sofre 1d6 de dano ácido por frasco '
                 'de água benta.\n'
                 '  * **Lento**: sempre perde a Iniciativa num combate. Um '
                 'Zumbi sempre ataca por último.\n'
                 '  * **Dreno**: o alvo deve passar em uma JPC para evitar um '
                 'dreno de 1d4 pontos em seu valor de Constituição. Um alvo '
                 'que tenha todos os seus pontos de Constituição drenados, '
                 'ficará permanentemente morto. O personagem recupera 1 ponto '
                 'drenado a cada descanso completo.\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral a '
                 'não ser quando sofrem o efeito de um Afastar Mortos-Vivos.\n'
                 '\n',
  'dv': '4',
  'dv_bonus': '',
  'encounters': None,
  'encounters_lair': None,
  'flavor': 'Criaturas esqueléticas presas por correntes, com estranhas '
            'feições suínas, com o corpo cheio de vergões e ossos '
            'proeminentes.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday16.json',
              'page': 17}],
  'habitats': ['qualquer'],
  'id': 'zumbi-das-correntes',
  'jp': '7',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Zumbi das Correntes',
  'picture': 'https://public.olddragon.com.br/7w94oksahc6jycofydrjtlt0yvlg',
  'pv': '20',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/u6lcoh8jazunshojwhle81a5sim2',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/zumbi-das-correntes.json',
  'variant': False,
  'xp': '150'},
 {'access': 'limited',
  'alignment': 'caotico',
  'concept': 'morto_vivo',
  'flavor': 'Corpos humanoides apáticos, reanimados como guardiões por '
            'Clérigos ou Magos poderosos.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/arkhi.json',
              'page': 80}],
  'habitats': ['desertos'],
  'id': 'zumbi-desidratado',
  'name': 'Zumbi Desidratado',
  'size': 'medio',
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/zumbi-desidratado.json',
  'variant': False},
 {'access': 'complete',
  'alignment': 'neutro',
  'attacks': [{'ba': 3,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1 + Efeito',
               'description': 'Cordames Vivos',
               'text': '1 × Cordames Vivos +3 (1d6+1 + Efeito)',
               'times': 1,
               'weapon': False},
              {'ba': 3,
               'damage': '1d6',
               'damage_bonus': 1,
               'damage_description': '1d6+1 + Infecção',
               'description': 'Mordida',
               'text': '1 × Mordida +3 (1d6+1 + Infecção)',
               'times': 1,
               'weapon': False}],
  'ca': '12',
  'concept': 'morto_vivo',
  'description': '\n'
                 '\n'
                 '  * **Cordames Vivos**: os cordames podem atingir um alvo a '
                 'até 9m de distância. Alvos atingidos devem passar em uma JPD '
                 'ou ficarão presos pelos cordames por 1d4 rodadas. Ao final '
                 'de cada rodada preso, o alvo pode fazer uma JPC para evitar '
                 'receber um dano de 1d4 pontos de vida, ou se soltar, caso '
                 'seja bem sucedido. O Zumbi pode prender no máximo 2 '
                 'criaturas dessa forma.\n'
                 '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantém silencioso até atacar.\n'
                 '  * **Morto-vivo**: imune a magias mentais de manipulação, '
                 'controle ou ilusão, ou demais formas mágicas de interferir '
                 'na mente de seres vivos. Sofre 1d6 de dano ácido por frasco '
                 'de água benta.\n'
                 '  * **Lento**: sempre perde a Iniciativa num combate. Um '
                 'Zumbi sempre ataca por último.\n'
                 '  * **Infecção**: personagens mordidos devem passar em uma '
                 'JPC ou se tornarão Zumbis em 1d4 dias, a não ser que uma '
                 'magia de Curar Doenças ou Curar Ferimentos seja usada no '
                 'alvo infectado.\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral a '
                 'não ser quando sofrem o efeito de um Afastar Mortos-Vivos.\n'
                 '\n',
  'dv': '3',
  'dv_bonus': '',
  'encounters': None,
  'encounters_lair': None,
  'flavor': 'Um zumbi inchado e deformado pelos seus pecados, com partes de '
            'seu corpo bizarramente mesclada aos cordames de navios.',
  'fontes': [{'compact': False,
              'digital_item_url': 'https://olddragon.com.br/livros/odday16.json',
              'page': 15}],
  'habitats': ['qualquer'],
  'id': 'zumbi-dos-cordames',
  'jp': '6',
  'mo': 7,
  'mv': 9,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Zumbi dos Cordames',
  'picture': 'https://public.olddragon.com.br/nucw0d2i9k2yyqrnepew0ifl3meq',
  'pv': '15',
  'size': 'medio',
  'thumb_picture': 'https://public.olddragon.com.br/vljlj99v1z070tg0p055aaxlqn9l',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/zumbi-dos-cordames.json',
  'variant': False,
  'xp': '100'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 2,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2 + Explosão',
               'description': 'Picareta',
               'text': '1 × Picareta +2 (1d6+2 + Explosão)',
               'times': 1,
               'weapon': False}],
  'ca': '14',
  'concept': 'morto_vivo',
  'description': '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a magias mentais de manipulação, '
                 'controle ou ilusão, ou demais formas mágicas de interferir '
                 'na mente de seres vivos. Sofre 1d6 de dano ácido por frasco '
                 'de água benta.\n'
                 '\n'
                 '  * **Lento**: sempre perde a Iniciativa num combate. Um '
                 'Zumbi sempre ataca por último.\n'
                 '\n'
                 '  * **Infecção**: personagens mordidos devem passar em uma '
                 'JPC ou se tornarão Zumbis em 1d4 dias, a não ser que uma '
                 'magia de Curar Doenças ou Curar Ferimentos seja usada no '
                 'alvo infectado.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral a '
                 'não ser quando sofrem o efeito de um Afastar Mortos-Vivos.',
  'dv': '2',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '4d6',
  'flavor': 'Morto-vivo sem inteligência. Avança para cima de suas vítimas com '
            'o único intuito de destroçá-las com garras e dentes.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday12.json',
              'page': 23}],
  'habitats': ['qualquer'],
  'id': 'zumbi-explosivo',
  'jp': '7',
  'mo': 8,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Zumbi Explosivo',
  'parent_monster_url': 'https://olddragon.com.br/monstros/zumbi.json',
  'pv': '10',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/zumbi-explosivo.json',
  'variant': True,
  'variant_modifications': ['Explosão: sempre que faz ou recebe um ataque com '
                            'armas de metal, há 3 chances em 1d6 de engatilhar '
                            'uma explosão. Caso ocorra, todos os personagens '
                            'num raio de 3 metros devem fazer uma JPD para '
                            'reduzir 2d6 de dano pela metade, além de evitar '
                            'ficarem cegos. Criaturas cegas fazem rolagens de '
                            'ataque ou que incluam visão como Muito Difícil. '
                            'Ao explodir, o morto-vivo se desintegra, morrendo '
                            'de vez.'],
  'xp': '35'},
 {'access': 'partial',
  'alignment': 'caotico',
  'attacks': [{'ba': 4,
               'damage': '1d4',
               'damage_bonus': 1,
               'damage_description': '1d4+1 + Infecção',
               'description': 'Mordida',
               'text': '1 × Mordida +4 (1d4+1 + Infecção)',
               'times': 1,
               'weapon': False},
              {'ba': 4,
               'damage': '1d6',
               'damage_bonus': 2,
               'damage_description': '1d6+2',
               'description': 'garra',
               'text': '1 × garra +4 (1d6+2)',
               'times': 1,
               'weapon': False}],
  'ca': '13',
  'concept': 'morto_vivo',
  'description': '  * **Silencioso**: não produz som algum ao movimentar- se e '
                 'se mantém silencioso até atacar.\n'
                 '\n'
                 '  * **Morto-vivo**: imune a magias mentais de manipulação, '
                 'controle ou ilusão, ou demais formas mágicas de interferir '
                 'na mente de seres vivos. Sofre 1d6 de dano ácido por frasco '
                 'de água benta.\n'
                 '\n'
                 '  * **Lento**: sempre perde a Iniciativa num combate. Um '
                 'Zumbi sempre ataca por último.\n'
                 '\n'
                 '  * **Infecção**: personagens mordidos devem passar em uma '
                 'JPC ou se tornarão Zumbis em 1d4 dias, a não ser que uma '
                 'magia de Curar Doenças ou Curar Ferimentos seja usada no '
                 'alvo infectado.\n'
                 '\n'
                 '  * **Inabalável**: mortos-vivos não fazem testes de moral a '
                 'não ser quando sofrem o efeito de um Afastar Mortos-Vivos.',
  'dv': '4',
  'dv_bonus': '',
  'encounters': '2d4',
  'encounters_lair': '4d6',
  'flavor': 'Morto-vivo sem inteligência. Avança para cima de suas vítimas com '
            'o único intuito de destroçá-las com garras e dentes.',
  'fontes': [{'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/cl1.json',
              'page': 99},
             {'compact': True,
              'digital_item_url': 'https://olddragon.com.br/livros/odday12.json',
              'page': 26}],
  'habitats': ['qualquer'],
  'id': 'zumbi-nefasto',
  'jp': '7',
  'mo': 7,
  'mv': 6,
  'mvc': None,
  'mve': None,
  'mvn': None,
  'mvo': None,
  'mvv': None,
  'name': 'Zumbi Nefasto',
  'parent_monster_url': 'https://olddragon.com.br/monstros/zumbi.json',
  'pv': '20',
  'size': 'medio',
  'treasure': None,
  'treasure_lair': None,
  'type': 'Monster',
  'url': 'https://olddragon.com.br/monstros/zumbi-nefasto.json',
  'variant': True,
  'variant_modifications': [],
  'xp': '125'}]
